(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     36984,       1366]
NotebookOptionsPosition[     20912,        777]
NotebookOutlinePosition[     29071,       1051]
CellTagsIndexPosition[     28945,       1044]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ABCD Calibration", "Chapter",
 CellTags->"Overview",
 CellID->171278725],

Cell["\<\
For further information on ABCD calibration see:
Ametrano, Ferdinando and Joshi, Mark S., Smooth Simultaneous Calibration of \
the LMM to Caplets and Coterminal Swaptions (February 12, 2008).Available at \
SSRN : http : // ssrn.com/abstract = 1092665\
\>", "Reference",
 CellID->4502211],

Cell[CellGroupData[{

Cell["", "HowToDelimiter",
 CellID->142569770],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->509811587],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->29445291],

Cell["\<\
Within the ABCD part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->736951734],

Cell[CellGroupData[{

Cell["Select[Category[Abcd],QLConstructor[#]&]", "Input",
 CellChangeTimes->{{3.436186674578125*^9, 3.436186675484375*^9}},
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->242617041],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"AbcdCalibration", ",", "AbcdFunction"}], "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->10235241]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Abcd],QLMember[#]&]", "Input",
 CellChangeTimes->{{3.436186681296875*^9, 3.436186682484375*^9}},
 CellTags->"Overview",
 CellLabel->"In[4]:=",
 CellID->1010528463],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AbcdCalibrationA", ",", "AbcdCalibrationB", ",", "AbcdCalibrationC", ",", 
   "AbcdCalibrationCompute", ",", "AbcdCalibrationD", ",", 
   "AbcdCalibrationEndCriteria", ",", "AbcdCalibrationError", ",", 
   "AbcdCalibrationK", ",", "AbcdCalibrationMaxError", ",", "AbcdDFunction", 
   ",", "AbcdFunctionA", ",", "AbcdFunctionB", ",", "AbcdFunctionC", ",", 
   "AbcdFunctionCovariance", ",", "AbcdFunctionD", ",", 
   "AbcdFunctionInstantaneousCovariance", ",", 
   "AbcdFunctionInstantaneousValue", ",", "AbcdFunctionInstantaneousVariance",
    ",", "AbcdFunctionInstantaneousVolatility", ",", 
   "AbcdFunctionLongTermVolatility", ",", "AbcdFunctionMaximumLocation", ",", 
   "AbcdFunctionMaximumVolatility", ",", "AbcdFunctionShortTermVolatility", 
   ",", "AbcdFunctionVariance", ",", "AbcdFunctionVolatility"}], 
  "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[4]=",
 CellID->628119763]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor",
 CellID->314230137],

Cell[CellGroupData[{

Cell["AbcdFunction", "Subsubsection",
 CellTags->"Constructor",
 CellID->210906133],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"A", 
     RowBox[{"-", "0.06"}], 
     RowBox[{
     "the", " ", "a", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"B", "0.17", 
     RowBox[{
     "the", " ", "b", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"C", "0.54", 
     RowBox[{
     "the", " ", "c", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"D", "0.17", 
     RowBox[{
     "the", " ", "d", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->458018307]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibration", "Subsubsection",
 CellTags->"Constructor",
 CellID->347035975],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Times", 
     RowBox[{"times", "."}]},
    {"BlackVols", 
     RowBox[{"Black", " ", 
      RowBox[{"Volatilities", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->75495364],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"A", 
     RowBox[{"-", "0.06"}], 
     RowBox[{
     "the", " ", "a", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"B", "0.17", 
     RowBox[{
     "the", " ", "b", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"C", "0.54", 
     RowBox[{
     "the", " ", "c", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"D", "0.17", 
     RowBox[{
     "the", " ", "d", " ", "coefficient", " ", "in", " ", "the", " ", "abcd", 
      " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"AIsFixed", "False", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "a", " ", "coefficient", " ", "must",
       " ", "be", " ", "kept", " ", "fixed", " ", "in", " ", "later", " ", 
      RowBox[{"calibrations", "."}]}]},
    {"BIsFixed", "False", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "a", " ", "coefficient", " ", "must",
       " ", "be", " ", "kept", " ", "fixed", " ", "in", " ", "later", " ", 
      RowBox[{"calibrations", "."}]}]},
    {"CIsFixed", "False", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "a", " ", "coefficient", " ", "must",
       " ", "be", " ", "kept", " ", "fixed", " ", "in", " ", "later", " ", 
      RowBox[{"calibrations", "."}]}]},
    {"DIsFixed", "False", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "a", " ", "coefficient", " ", "must",
       " ", "be", " ", "kept", " ", "fixed", " ", "in", " ", "later", " ", 
      RowBox[{"calibrations", "."}]}]},
    {"VegaWeighted", "False", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "interpolation", " ", "is", " ", 
      "weighted", " ", "using", " ", "options", " ", 
      RowBox[{"Vega", "."}]}]},
    {"EndCriteria", "\"\<\>\"", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Method", "\"\<\>\"", 
     RowBox[{"OptimizationMethod", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellChangeTimes->{{3.436186938625*^9, 3.43618695465625*^9}},
 CellID->10997762],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CTimes", "=", 
   RowBox[{"{", 
    RowBox[{"0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04"}], 
    " ", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BlackVols", "=", 
   RowBox[{"{", 
    RowBox[{"0.2", ",", "0.3", ",", "0.2", ",", "0.15"}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.436186789828125*^9, 3.4361868340625*^9}, {
  3.436186899*^9, 3.436186925609375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[1]:=",
 CellID->187159541],

Cell[CellGroupData[{

Cell["obj=AbcdCalibration[CTimes,BlackVols]", "Input",
 CellChangeTimes->{3.436186839203125*^9},
 CellTags->"Constructor",
 CellLabel->"In[3]:=",
 CellID->154357171],

Cell[BoxData[
 RowBox[{"AbcdCalibration", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.01`", ",", "0.02`", ",", "0.03`", ",", "0.04`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2`", ",", "0.3`", ",", "0.2`", ",", "0.15`"}], "}"}]}], 
  "]"}]], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[3]=",
 CellID->21192161]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->17623496],

Cell[CellGroupData[{

Cell["AbcdFunctionInstantaneousValue", "Subsubsection",
 CellTags->"Member",
 CellID->535566083],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"U", 
     RowBox[{"residual", " ", "time", 
      RowBox[{"(", "s", ")"}], " ", "to", " ", 
      RowBox[{"maturity", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->711535274],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"{", 
    RowBox[{"5.0", ",", "4.0", ",", "3.0", ",", "2.0", ",", "1.0"}], "}"}]}], 
  ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[1]:=",
 CellID->415840253],

Cell[CellGroupData[{

Cell["AbcdFunctionInstantaneousValue[obj,U]", "Input",
 CellTags->"Member",
 CellLabel->"In[2]:=",
 CellID->358302587],

Cell[BoxData[
 RowBox[{"AbcdFunctionInstantaneousValue", "[", 
  RowBox[{"obj", ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", "4.`", ",", "3.`", ",", "2.`", ",", "1.`"}], "}"}]}], 
  "]"}]], "Output",
 CellTags->"Member",
 CellLabel->"Out[2]=",
 CellID->854529779]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionInstantaneousCovariance", "Subsubsection",
 CellTags->"Member",
 CellID->270785932],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"U", 
     RowBox[{"calendar", " ", "time", 
      RowBox[{
       RowBox[{"(", "s", ")"}], "."}]}]},
    {"T", 
     RowBox[{"fixing", " ", "time", " ", "of", " ", "first", " ", 
      RowBox[{"rate", "."}]}]},
    {"S", 
     RowBox[{"fixing", " ", "time", " ", "of", " ", "second", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->438154236],

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "0.5", ",", "1.0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"T", "=", "0.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S", "=", "1.0"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->332295356],

Cell["AbcdFunctionInstantaneousCovariance[obj,U,T,S]", "Input",
 CellTags->"Member",
 CellID->112544599]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionInstantaneousVariance", "Subsubsection",
 CellTags->"Member",
 CellID->108920463],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"U", 
     RowBox[{"calendar", " ", "time", 
      RowBox[{
       RowBox[{"(", "s", ")"}], "."}]}]},
    {"T", 
     RowBox[{"fixing", " ", "time", " ", "of", " ", "the", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->200470768],

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "0.5", ",", "1.0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"T", "=", "1.0"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->517480703],

Cell["AbcdFunctionInstantaneousVariance[obj,U,T]", "Input",
 CellTags->"Member",
 CellID->217972467]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionInstantaneousVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->40328307],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"U", 
     RowBox[{"calendar", " ", "time", 
      RowBox[{
       RowBox[{"(", "s", ")"}], "."}]}]},
    {"T", 
     RowBox[{
     "fixing", " ", "calendar", " ", "time", " ", "of", " ", "the", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->155533586],

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "0.5", ",", "1.0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"T", "=", "1.0"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->171919951],

Cell["AbcdFunctionInstantaneousVolatility[obj,U,T]", "Input",
 CellTags->"Member",
 CellID->42280079]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionCovariance", "Subsubsection",
 CellTags->"Member",
 CellID->449622144],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TMin", 
     RowBox[{
     "lower", " ", "bound", " ", "of", " ", "the", " ", "covariance", " ", 
      RowBox[{"integral", "."}]}]},
    {"TMax", 
     RowBox[{"upper", " ", "bound", 
      RowBox[{"(", "s", ")"}], " ", "of", " ", "the", " ", "covariance", " ", 
      "integral", 
      RowBox[{
       RowBox[{"(", "s", ")"}], "."}]}]},
    {"T", 
     RowBox[{
     "fixing", " ", "calendar", " ", "time", " ", "of", " ", "first", " ", 
      RowBox[{"rate", "."}]}]},
    {"S", 
     RowBox[{
     "fixing", " ", "calendar", " ", "time", " ", "of", " ", "second", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->195659988],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TMin", "=", "0.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TMax", "=", 
   RowBox[{"{", 
    RowBox[{"0.25", ",", "0.5"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"T", "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S", "=", "1.0"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->70770213],

Cell["AbcdFunctionCovariance[obj,TMin,TMax,T,S]", "Input",
 CellTags->"Member",
 CellID->152898329]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionVariance", "Subsubsection",
 CellTags->"Member",
 CellID->28513966],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TMin", 
     RowBox[{
     "lower", " ", "bound", " ", "of", " ", "the", " ", "covariance", " ", 
      RowBox[{"integral", "."}]}]},
    {"TMax", 
     RowBox[{
     "upper", " ", "bound", " ", "of", " ", "the", " ", "covariance", " ", 
      RowBox[{"integral", "."}]}]},
    {"T", 
     RowBox[{
     "fixing", " ", "calendar", " ", "time", " ", "of", " ", "the", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->76096523],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TMin", "=", "0.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TMax", "=", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", "1.0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"T", "=", "1.0"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->55729046],

Cell["AbcdFunctionVariance[obj,TMin,TMax,T]", "Input",
 CellTags->"Member",
 CellID->139418163]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->602636873],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TMin", 
     RowBox[{
     "lower", " ", "bound", " ", "of", " ", "the", " ", "covariance", " ", 
      RowBox[{"integral", "."}]}]},
    {"TMax", 
     RowBox[{"upper", " ", "bound", 
      RowBox[{"(", "s", ")"}], " ", "of", " ", "the", " ", "covariance", " ", 
      "integral", 
      RowBox[{
       RowBox[{"(", "s", ")"}], "."}]}]},
    {"T", 
     RowBox[{
     "fixing", " ", "calendar", " ", "time", " ", "of", " ", "the", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->78971787],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TMin", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TMax", "=", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", "1.0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"T", "=", "1.0"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->355410113],

Cell["AbcdFunctionVolatility[obj,TMin,TMax,T]", "Input",
 CellTags->"Member",
 CellID->71011048]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionShortTermVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->668298037],

Cell["AbcdFunctionShortTermVolatility[obj]", "Input",
 CellTags->"Member",
 CellID->281883716]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionLongTermVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->152963806],

Cell["AbcdFunctionLongTermVolatility[obj]", "Input",
 CellTags->"Member",
 CellID->521624050]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionMaximumLocation", "Subsubsection",
 CellTags->"Member",
 CellID->717029400],

Cell["AbcdFunctionMaximumLocation[obj]", "Input",
 CellTags->"Member",
 CellID->514227733]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionMaximumVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->127084512],

Cell["AbcdFunctionMaximumVolatility[obj]", "Input",
 CellTags->"Member",
 CellID->16770616]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionA", "Subsubsection",
 CellTags->"Member",
 CellID->84701398],

Cell["AbcdFunctionA[obj]", "Input",
 CellTags->"Member",
 CellID->70581399]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionB", "Subsubsection",
 CellTags->"Member",
 CellID->201456047],

Cell["AbcdFunctionB[obj]", "Input",
 CellTags->"Member",
 CellID->251041918]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionC", "Subsubsection",
 CellTags->"Member",
 CellID->406821401],

Cell["AbcdFunctionC[obj]", "Input",
 CellTags->"Member",
 CellID->576845138]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdFunctionD", "Subsubsection",
 CellTags->"Member",
 CellID->46612310],

Cell["AbcdFunctionD[obj]", "Input",
 CellTags->"Member",
 CellID->28536823]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdDFunction", "Subsubsection",
 CellTags->"Member",
 CellID->342110096],

Cell["AbcdDFunction[obj]", "Input",
 CellTags->"Member",
 CellID->170316475]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationCompute", "Subsubsection",
 CellTags->"Member",
 CellID->147546141],

Cell["AbcdCalibrationCompute[obj]", "Input",
 CellTags->"Member",
 CellID->180460215]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationK", "Subsubsection",
 CellTags->"Member",
 CellID->427332089],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Times", 
     RowBox[{"times", "."}]},
    {"BlackVols", 
     RowBox[{"Black", " ", 
      RowBox[{"Volatilities", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->15786097],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CTimes", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BlackVols", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.43618703625*^9},
 CellTags->"Member",
 CellID->103807086],

Cell["AbcdCalibrationK[obj,Times,BlackVols]", "Input",
 CellTags->"Member",
 CellID->337472507]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationError", "Subsubsection",
 CellTags->"Member",
 CellID->184071120],

Cell["AbcdCalibrationError[obj]", "Input",
 CellTags->"Member",
 CellID->318985665]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationMaxError", "Subsubsection",
 CellTags->"Member",
 CellID->22915385],

Cell["AbcdCalibrationMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->301892816]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationEndCriteria", "Subsubsection",
 CellTags->"Member",
 CellID->5329931],

Cell["AbcdCalibrationEndCriteria[obj]", "Input",
 CellTags->"Member",
 CellID->513072082]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationA", "Subsubsection",
 CellTags->"Member",
 CellID->61220571],

Cell["AbcdCalibrationA[obj]", "Input",
 CellTags->"Member",
 CellID->203651656]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationB", "Subsubsection",
 CellTags->"Member",
 CellID->199685619],

Cell["AbcdCalibrationB[obj]", "Input",
 CellTags->"Member",
 CellID->244586481]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationC", "Subsubsection",
 CellTags->"Member",
 CellID->540363298],

Cell["AbcdCalibrationC[obj]", "Input",
 CellTags->"Member",
 CellID->445973463]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdCalibrationD", "Subsubsection",
 CellTags->"Member",
 CellID->23219480],

Cell["AbcdCalibrationD[obj]", "Input",
 CellTags->"Member",
 CellID->319535884]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
PrintingStyleEnvironment->"Working",
WindowSize->{616, 750},
WindowMargins->{{226, Automatic}, {Automatic, 48}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
ShowSelection->True,
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Wolfram"}, "Reference.nb", CharacterEncoding -> 
       "WindowsANSI"]]]}, WindowSize -> {616, 750}, 
  WindowMargins -> {{0, Automatic}, {Automatic, 0}}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
   StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 78, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->171278725],
  Cell[1019, 39, 114, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->509811587],
  Cell[1136, 43, 102, 3, 28, "Input",
   CellTags->"Overview",
   CellID->29445291],
  Cell[1241, 48, 152, 5, 50, "Text",
   CellTags->"Overview",
   CellID->736951734],
  Cell[1418, 57, 189, 4, 28, "Input",
   CellTags->"Overview",
   CellID->242617041],
  Cell[1610, 63, 163, 5, 36, "Output",
   CellTags->"Overview",
   CellID->10235241],
  Cell[1810, 73, 185, 4, 28, "Input",
   CellTags->"Overview",
   CellID->1010528463],
  Cell[1998, 79, 944, 18, 207, "Output",
   CellTags->"Overview",
   CellID->628119763]},
 "Constructor"->{
  Cell[2991, 103, 77, 2, 51, "Section",
   CellTags->"Constructor",
   CellID->314230137],
  Cell[3093, 109, 83, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->210906133],
  Cell[4713, 150, 86, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->347035975],
  Cell[8040, 231, 496, 15, 47, "Input",
   CellTags->"Constructor",
   CellID->187159541],
  Cell[8561, 250, 165, 4, 28, "Input",
   CellTags->"Constructor",
   CellID->154357171],
  Cell[8729, 256, 330, 10, 36, "Output",
   CellTags->"Constructor",
   CellID->21192161]},
 "Member"->{
  Cell[9120, 273, 74, 2, 51, "Section",
   CellTags->"Member",
   CellID->17623496],
  Cell[9219, 279, 96, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->535566083],
  Cell[9614, 292, 223, 8, 28, "Input",
   CellTags->"Member",
   CellID->415840253],
  Cell[9862, 304, 118, 3, 28, "Input",
   CellTags->"Member",
   CellID->358302587],
  Cell[9983, 309, 265, 8, 36, "Output",
   CellTags->"Member",
   CellID->854529779],
  Cell[10297, 323, 101, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->270785932],
  Cell[10891, 342, 281, 10, 65, "Input",
   CellTags->"Member",
   CellID->332295356],
  Cell[11175, 354, 104, 2, 28, "Input",
   CellTags->"Member",
   CellID->112544599],
  Cell[11316, 361, 99, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->108920463],
  Cell[11795, 377, 228, 8, 47, "Input",
   CellTags->"Member",
   CellID->517480703],
  Cell[12026, 387, 100, 2, 28, "Input",
   CellTags->"Member",
   CellID->217972467],
  Cell[12163, 394, 100, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->40328307],
  Cell[12666, 411, 228, 8, 47, "Input",
   CellTags->"Member",
   CellID->171919951],
  Cell[12897, 421, 101, 2, 28, "Input",
   CellTags->"Member",
   CellID->42280079],
  Cell[13035, 428, 88, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->449622144],
  Cell[13901, 455, 328, 12, 83, "Input",
   CellTags->"Member",
   CellID->70770213],
  Cell[14232, 469, 99, 2, 28, "Input",
   CellTags->"Member",
   CellID->152898329],
  Cell[14368, 476, 85, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->28513966],
  Cell[15028, 497, 274, 10, 65, "Input",
   CellTags->"Member",
   CellID->55729046],
  Cell[15305, 509, 95, 2, 28, "Input",
   CellTags->"Member",
   CellID->139418163],
  Cell[15437, 516, 88, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->602636873],
  Cell[16166, 539, 275, 10, 65, "Input",
   CellTags->"Member",
   CellID->355410113],
  Cell[16444, 551, 96, 2, 28, "Input",
   CellTags->"Member",
   CellID->71011048],
  Cell[16577, 558, 97, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->668298037],
  Cell[16677, 562, 94, 2, 28, "Input",
   CellTags->"Member",
   CellID->281883716],
  Cell[16808, 569, 96, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->152963806],
  Cell[16907, 573, 93, 2, 28, "Input",
   CellTags->"Member",
   CellID->521624050],
  Cell[17037, 580, 93, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->717029400],
  Cell[17133, 584, 90, 2, 28, "Input",
   CellTags->"Member",
   CellID->514227733],
  Cell[17260, 591, 95, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->127084512],
  Cell[17358, 595, 91, 2, 28, "Input",
   CellTags->"Member",
   CellID->16770616],
  Cell[17486, 602, 78, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->84701398],
  Cell[17567, 606, 75, 2, 70, "Input",
   CellTags->"Member",
   CellID->70581399],
  Cell[17679, 613, 79, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->201456047],
  Cell[17761, 617, 76, 2, 70, "Input",
   CellTags->"Member",
   CellID->251041918],
  Cell[17874, 624, 79, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->406821401],
  Cell[17956, 628, 76, 2, 70, "Input",
   CellTags->"Member",
   CellID->576845138],
  Cell[18069, 635, 78, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->46612310],
  Cell[18150, 639, 75, 2, 28, "Input",
   CellTags->"Member",
   CellID->28536823],
  Cell[18262, 646, 79, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->342110096],
  Cell[18344, 650, 76, 2, 28, "Input",
   CellTags->"Member",
   CellID->170316475],
  Cell[18457, 657, 88, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->147546141],
  Cell[18548, 661, 85, 2, 28, "Input",
   CellTags->"Member",
   CellID->180460215],
  Cell[18670, 668, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->427332089],
  Cell[19048, 682, 282, 9, 47, "Input",
   CellTags->"Member",
   CellID->103807086],
  Cell[19333, 693, 95, 2, 28, "Input",
   CellTags->"Member",
   CellID->337472507],
  Cell[19465, 700, 86, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->184071120],
  Cell[19554, 704, 83, 2, 28, "Input",
   CellTags->"Member",
   CellID->318985665],
  Cell[19674, 711, 88, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->22915385],
  Cell[19765, 715, 86, 2, 28, "Input",
   CellTags->"Member",
   CellID->301892816],
  Cell[19888, 722, 90, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->5329931],
  Cell[19981, 726, 89, 2, 28, "Input",
   CellTags->"Member",
   CellID->513072082],
  Cell[20107, 733, 81, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->61220571],
  Cell[20191, 737, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->203651656],
  Cell[20307, 744, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->199685619],
  Cell[20392, 748, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->244586481],
  Cell[20508, 755, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->540363298],
  Cell[20593, 759, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->445973463],
  Cell[20709, 766, 81, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->23219480],
  Cell[20793, 770, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->319535884]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 22335, 816},
 {"Constructor", 23050, 841},
 {"Member", 23621, 860}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 78, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->171278725],
Cell[648, 26, 297, 6, 102, "Reference",
 CellID->4502211],
Cell[CellGroupData[{
Cell[970, 36, 46, 1, 15, "HowToDelimiter",
 CellID->142569770],
Cell[1019, 39, 114, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->509811587],
Cell[1136, 43, 102, 3, 28, "Input",
 CellTags->"Overview",
 CellID->29445291],
Cell[1241, 48, 152, 5, 50, "Text",
 CellTags->"Overview",
 CellID->736951734],
Cell[CellGroupData[{
Cell[1418, 57, 189, 4, 28, "Input",
 CellTags->"Overview",
 CellID->242617041],
Cell[1610, 63, 163, 5, 36, "Output",
 CellTags->"Overview",
 CellID->10235241]
}, Open  ]],
Cell[CellGroupData[{
Cell[1810, 73, 185, 4, 28, "Input",
 CellTags->"Overview",
 CellID->1010528463],
Cell[1998, 79, 944, 18, 207, "Output",
 CellTags->"Overview",
 CellID->628119763]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2991, 103, 77, 2, 51, "Section",
 CellTags->"Constructor",
 CellID->314230137],
Cell[CellGroupData[{
Cell[3093, 109, 83, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->210906133],
Cell[3179, 113, 1497, 32, 393, "Input",
 CellID->458018307]
}, Open  ]],
Cell[CellGroupData[{
Cell[4713, 150, 86, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->347035975],
Cell[4802, 154, 298, 9, 78, "Input",
 CellID->75495364],
Cell[5103, 165, 2934, 64, 690, "Input",
 CellID->10997762],
Cell[8040, 231, 496, 15, 47, "Input",
 CellTags->"Constructor",
 CellID->187159541],
Cell[CellGroupData[{
Cell[8561, 250, 165, 4, 28, "Input",
 CellTags->"Constructor",
 CellID->154357171],
Cell[8729, 256, 330, 10, 36, "Output",
 CellTags->"Constructor",
 CellID->21192161]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9120, 273, 74, 2, 51, "Section",
 CellTags->"Member",
 CellID->17623496],
Cell[CellGroupData[{
Cell[9219, 279, 96, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->535566083],
Cell[9318, 283, 293, 7, 65, "Input",
 CellID->711535274],
Cell[9614, 292, 223, 8, 28, "Input",
 CellTags->"Member",
 CellID->415840253],
Cell[CellGroupData[{
Cell[9862, 304, 118, 3, 28, "Input",
 CellTags->"Member",
 CellID->358302587],
Cell[9983, 309, 265, 8, 36, "Output",
 CellTags->"Member",
 CellID->854529779]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10297, 323, 101, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->270785932],
Cell[10401, 327, 487, 13, 95, "Input",
 CellID->438154236],
Cell[10891, 342, 281, 10, 65, "Input",
 CellTags->"Member",
 CellID->332295356],
Cell[11175, 354, 104, 2, 28, "Input",
 CellTags->"Member",
 CellID->112544599]
}, Open  ]],
Cell[CellGroupData[{
Cell[11316, 361, 99, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->108920463],
Cell[11418, 365, 374, 10, 78, "Input",
 CellID->200470768],
Cell[11795, 377, 228, 8, 47, "Input",
 CellTags->"Member",
 CellID->517480703],
Cell[12026, 387, 100, 2, 28, "Input",
 CellTags->"Member",
 CellID->217972467]
}, Open  ]],
Cell[CellGroupData[{
Cell[12163, 394, 100, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->40328307],
Cell[12266, 398, 397, 11, 78, "Input",
 CellID->155533586],
Cell[12666, 411, 228, 8, 47, "Input",
 CellTags->"Member",
 CellID->171919951],
Cell[12897, 421, 101, 2, 28, "Input",
 CellTags->"Member",
 CellID->42280079]
}, Open  ]],
Cell[CellGroupData[{
Cell[13035, 428, 88, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->449622144],
Cell[13126, 432, 772, 21, 133, "Input",
 CellID->195659988],
Cell[13901, 455, 328, 12, 83, "Input",
 CellTags->"Member",
 CellID->70770213],
Cell[14232, 469, 99, 2, 28, "Input",
 CellTags->"Member",
 CellID->152898329]
}, Open  ]],
Cell[CellGroupData[{
Cell[14368, 476, 85, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->28513966],
Cell[14456, 480, 569, 15, 95, "Input",
 CellID->76096523],
Cell[15028, 497, 274, 10, 65, "Input",
 CellTags->"Member",
 CellID->55729046],
Cell[15305, 509, 95, 2, 28, "Input",
 CellTags->"Member",
 CellID->139418163]
}, Open  ]],
Cell[CellGroupData[{
Cell[15437, 516, 88, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->602636873],
Cell[15528, 520, 635, 17, 116, "Input",
 CellID->78971787],
Cell[16166, 539, 275, 10, 65, "Input",
 CellTags->"Member",
 CellID->355410113],
Cell[16444, 551, 96, 2, 28, "Input",
 CellTags->"Member",
 CellID->71011048]
}, Open  ]],
Cell[CellGroupData[{
Cell[16577, 558, 97, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->668298037],
Cell[16677, 562, 94, 2, 28, "Input",
 CellTags->"Member",
 CellID->281883716]
}, Open  ]],
Cell[CellGroupData[{
Cell[16808, 569, 96, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->152963806],
Cell[16907, 573, 93, 2, 28, "Input",
 CellTags->"Member",
 CellID->521624050]
}, Open  ]],
Cell[CellGroupData[{
Cell[17037, 580, 93, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->717029400],
Cell[17133, 584, 90, 2, 28, "Input",
 CellTags->"Member",
 CellID->514227733]
}, Open  ]],
Cell[CellGroupData[{
Cell[17260, 591, 95, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->127084512],
Cell[17358, 595, 91, 2, 28, "Input",
 CellTags->"Member",
 CellID->16770616]
}, Open  ]],
Cell[CellGroupData[{
Cell[17486, 602, 78, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->84701398],
Cell[17567, 606, 75, 2, 70, "Input",
 CellTags->"Member",
 CellID->70581399]
}, Open  ]],
Cell[CellGroupData[{
Cell[17679, 613, 79, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->201456047],
Cell[17761, 617, 76, 2, 70, "Input",
 CellTags->"Member",
 CellID->251041918]
}, Open  ]],
Cell[CellGroupData[{
Cell[17874, 624, 79, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->406821401],
Cell[17956, 628, 76, 2, 70, "Input",
 CellTags->"Member",
 CellID->576845138]
}, Open  ]],
Cell[CellGroupData[{
Cell[18069, 635, 78, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->46612310],
Cell[18150, 639, 75, 2, 28, "Input",
 CellTags->"Member",
 CellID->28536823]
}, Open  ]],
Cell[CellGroupData[{
Cell[18262, 646, 79, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->342110096],
Cell[18344, 650, 76, 2, 28, "Input",
 CellTags->"Member",
 CellID->170316475]
}, Open  ]],
Cell[CellGroupData[{
Cell[18457, 657, 88, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->147546141],
Cell[18548, 661, 85, 2, 28, "Input",
 CellTags->"Member",
 CellID->180460215]
}, Open  ]],
Cell[CellGroupData[{
Cell[18670, 668, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->427332089],
Cell[18755, 672, 290, 8, 78, "Input",
 CellID->15786097],
Cell[19048, 682, 282, 9, 47, "Input",
 CellTags->"Member",
 CellID->103807086],
Cell[19333, 693, 95, 2, 28, "Input",
 CellTags->"Member",
 CellID->337472507]
}, Open  ]],
Cell[CellGroupData[{
Cell[19465, 700, 86, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->184071120],
Cell[19554, 704, 83, 2, 28, "Input",
 CellTags->"Member",
 CellID->318985665]
}, Open  ]],
Cell[CellGroupData[{
Cell[19674, 711, 88, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->22915385],
Cell[19765, 715, 86, 2, 28, "Input",
 CellTags->"Member",
 CellID->301892816]
}, Open  ]],
Cell[CellGroupData[{
Cell[19888, 722, 90, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->5329931],
Cell[19981, 726, 89, 2, 28, "Input",
 CellTags->"Member",
 CellID->513072082]
}, Open  ]],
Cell[CellGroupData[{
Cell[20107, 733, 81, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->61220571],
Cell[20191, 737, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->203651656]
}, Open  ]],
Cell[CellGroupData[{
Cell[20307, 744, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->199685619],
Cell[20392, 748, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->244586481]
}, Open  ]],
Cell[CellGroupData[{
Cell[20508, 755, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->540363298],
Cell[20593, 759, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->445973463]
}, Open  ]],
Cell[CellGroupData[{
Cell[20709, 766, 81, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->23219480],
Cell[20793, 770, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->319535884]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
