(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     30101,       1148]
NotebookOptionsPosition[     17087,        680]
NotebookOutlinePosition[     23498,        892]
CellTagsIndexPosition[     23328,        884]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Calendar", "Chapter",
 CellTags->"Overview",
 CellID->129916062],

Cell["Calendar related functions.", "Text",
 CellTags->"Overview",
 CellID->718378184],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->270217803],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->1254907],

Cell["\<\
Within the Calendar part there are several procedures and member functions \
available \
\>", "Text",
 CellChangeTimes->{{3.436596482671875*^9, 3.436596485328125*^9}},
 CellTags->"Overview",
 CellID->195940307],

Cell[CellGroupData[{

Cell["Select[Category[Calendar],QLProcedure[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->6104487],

Cell[BoxData[
 RowBox[{"{", "CalendarHolidayList", "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->112973502]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Calendar],QLEnumerationMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->427947670],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CalendarAddHoliday", ",", "CalendarAdjust", ",", "CalendarAdvance", ",", 
   "CalendarBusinessDaysBetween", ",", "CalendarEndOfMonth", ",", 
   "CalendarIsBusinessDay", ",", "CalendarIsEndOfMonth", ",", 
   "CalendarIsHoliday", ",", "CalendarName", ",", "CalendarRemoveHoliday"}], 
  "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->68403555]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedures", "Section",
 CellTags->"Procedure",
 CellID->101315972],

Cell[CellGroupData[{

Cell["CalendarHolidayList", "Subsubsection",
 CellTags->"Procedure",
 CellID->691578319],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Calendar", 
     RowBox[{
     "Calendar", " ", "to", " ", "use", " ", "for", " ", "holiday", " ", 
      RowBox[{"determination", "."}]}]},
    {"FromDate", 
     RowBox[{"first", " ", "date", " ", "of", " ", "the", " ", 
      RowBox[{"period", "."}]}]},
    {"ToDate", 
     RowBox[{"last", " ", "date", " ", "of", " ", "the", " ", 
      RowBox[{"period", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->99756323],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"IncludeWeekEnds", "false", 
     RowBox[{
      RowBox[{"include", " ", "week"}], "-", 
      RowBox[{"end", " ", "as", " ", 
       RowBox[{"holidays", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->129489133],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fromDate", "=", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "1", ",", "1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toDate", "=", 
   RowBox[{"{", 
    RowBox[{"2006", ",", "1", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellTags->"Procedure",
 CellLabel->"In[1]:=",
 CellID->24455485],

Cell[CellGroupData[{

Cell["\<\
CalendarHolidayList[fromDate,toDate,Calendar->\"TARGET\"]
\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[4]:=",
 CellID->333616146],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2005", ",", "3", ",", "25"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "3", ",", "28"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "12", ",", "26"}], "}"}]}], "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[4]=",
 CellID->395638734]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enumeration Member", "Section",
 CellTags->"EnumerationMember",
 CellID->44851749],

Cell[CellGroupData[{

Cell["CalendarName", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->227996691],

Cell[CellGroupData[{

Cell["\<\
Needs[\"QuantLib`\"]
CalendarName[]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[1]:=",
 CellID->863567140],

Cell[BoxData["\<\"TARGET\"\>"], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[2]=",
 CellID->85354402]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarIsBusinessDay", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->66715191],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", "."}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->466976350],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "1", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->399132291],

Cell[CellGroupData[{

Cell["CalendarIsBusinessDay[{date}]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[3]:=",
 CellID->226487527],

Cell[BoxData[
 RowBox[{"{", "False", "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[3]=",
 CellID->175687855]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarIsHoliday", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->94687178],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", "."}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->80678956],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2005", ",", "1", ",", "1"}], "}"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->53948499],

Cell[CellGroupData[{

Cell["CalendarIsHoliday[date]", "Input",
 CellChangeTimes->{3.43659665290625*^9},
 CellTags->"Procedure",
 CellLabel->"In[3]:=",
 CellID->38974668],

Cell[BoxData[
 RowBox[{"{", "True", "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[3]=",
 CellID->766663970]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarIsEndOfMonth", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->88007002],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", "."}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->239959559],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2005", ",", "1", ",", "1"}], "}"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->142385597],

Cell[CellGroupData[{

Cell["CalendarIsEndOfMonth[date]", "Input",
 CellChangeTimes->{3.43659668403125*^9},
 CellTags->"Procedure",
 CellLabel->"In[3]:=",
 CellID->666775278],

Cell[BoxData[
 RowBox[{"{", "False", "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[3]=",
 CellID->508923767]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarEndOfMonth", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->25978282],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", "."}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->604848759],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "1", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->70904296],

Cell[CellGroupData[{

Cell["CalendarEndOfMonth[date] ", "Input",
 CellTags->"Procedure",
 CellLabel->"In[4]:=",
 CellID->406782677],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"2005", ",", "1", ",", "31"}], "}"}], "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[4]=",
 CellID->401475611]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarAddHoliday", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->118081274],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", "."}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->147042316],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "11", ",", "11"}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->114861492],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CalendarIsHoliday", "[", 
  RowBox[{"{", "date", "}"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CalendarAddHoliday", "[", "date", "]"}], "\[IndentingNewLine]", 
 RowBox[{"CalendarIsHoliday", "[", 
  RowBox[{"{", "date", "}"}], "]"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->314245],

Cell[BoxData[
 RowBox[{"{", "False", "}"}]], "Output",
 CellLabel->"Out[3]=",
 CellID->238652120],

Cell[BoxData["True"], "Output",
 CellLabel->"Out[4]=",
 CellID->36507524],

Cell[BoxData[
 RowBox[{"{", "True", "}"}]], "Output",
 CellLabel->"Out[5]=",
 CellID->239997702]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarRemoveHoliday", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->522757588],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", "."}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->350203716],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "11", ",", "11"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->85108895],

Cell[CellGroupData[{

Cell["\<\
CalendarIsHoliday[{date}]
CalendarRemoveHoliday[date]
CalendarIsHoliday[{date}]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[3]:=",
 CellID->52918540],

Cell[BoxData[
 RowBox[{"{", "True", "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[3]=",
 CellID->694601281],

Cell[BoxData["True"], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[4]=",
 CellID->576472941],

Cell[BoxData[
 RowBox[{"{", "False", "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[5]=",
 CellID->6347343]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarAdjust", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->160369047],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{"date", " ", "to", " ", "be", " ", 
      RowBox[{"adjusted", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->672113496],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"BusinessDayConvention", "\"\<Following\>\"", 
     RowBox[{"rolling", " ", 
      RowBox[{"convention", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"EnumertionMember"], "\n", Cell["Option Setting", 
  "Caption"]}], "Text",
 CellID->14374571],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2005", ",", "11", ",", "11"}], "}"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->266243808],

Cell[CellGroupData[{

Cell["CalendarAdjust[date]", "Input",
 CellChangeTimes->{{3.43661336346875*^9, 3.436613363625*^9}},
 CellTags->"Procedure",
 CellLabel->"In[3]:=",
 CellID->423579442],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"2005", ",", "11", ",", "11"}], "}"}], "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[3]=",
 CellID->51877727]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
CalendarAdjust[{{2005,11,11}}]  \
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[1]:=",
 CellID->532021617],

Cell[BoxData[
 RowBox[{"CalendarAdjust", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "11", ",", "11"}], "}"}], "}"}], "]"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[1]=",
 CellID->17189863]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarAdvance", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->276175045],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"StartDate", 
     RowBox[{"start", " ", "date", " ", "to", " ", "be", " ", 
      RowBox[{"advanced", "."}]}]},
    {"Period", 
     RowBox[{"period", 
      RowBox[{"(", "s", ")"}], " ", "to", " ", "advance", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"e", ".", "g", ".", " ", "2"}], "D", " ", "for", " ", "two",
           " ", "days"}], " ", ",", " ", 
         RowBox[{"3", "W", " ", "for", " ", "three", " ", "weeks"}], ",", " ", 
         RowBox[{"6", "M", " ", "for", " ", "six", " ", "months"}], ",", " ", 
         RowBox[{"1", "Y", " ", "for", " ", "one", " ", "year"}]}], ")"}], 
       "."}]}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->35365726],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"BusinessDayConvention", "\"\<Following\>\"", 
     RowBox[{"rolling", " ", 
      RowBox[{"convention", "."}]}]},
    {"EndOfMonth", "false", 
     RowBox[{
     "flag", " ", "to", " ", "enforce", " ", "end", " ", "of", " ", "month", 
      " ", 
      RowBox[{"convention", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"EnumertionMember"], "\n", Cell["Option Setting", 
  "Caption"]}], "Text",
 CellID->36614051],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StartDate", "=", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "11", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Period", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<2D\>\"", ",", "\"\<3W\>\"", ",", "\"\<6M\>\"", ",", "\"\<1Y\>\""}], 
    "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[2]:=",
 CellID->36870070],

Cell[CellGroupData[{

Cell["CalendarAdvance[StartDate,Period]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[5]:=",
 CellID->90484221],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2005", ",", "11", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "12", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2006", ",", "5", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2006", ",", "11", ",", "13"}], "}"}]}], "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[5]=",
 CellID->242562103]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalendarBusinessDaysBetween", "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->539331047],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FirstDate", 
     RowBox[{"first", " ", 
      RowBox[{"date", 
       RowBox[{"(", "s", ")"}]}], " ", "of", " ", "the", " ", 
      RowBox[{"period", "."}]}]},
    {"LastDate", 
     RowBox[{"last", " ", "date", " ", "of", " ", "the", " ", 
      RowBox[{"period", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"EnumertionMember"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->47915218],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"IncludeFirst", "false", 
     RowBox[{
     "include", " ", "the", " ", "first", " ", "date", " ", "when", " ", 
      "counting", " ", "business", " ", 
      RowBox[{"days", "."}]}]},
    {"IncludeLast", "false", 
     RowBox[{
     "include", " ", "the", " ", "last", " ", "date", " ", "when", " ", 
      "counting", " ", "business", " ", 
      RowBox[{"days", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"EnumertionMember"], "\n", Cell["Option Setting", 
  "Caption"]}], "Text",
 CellID->113193361],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstDate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"LastDate", "=", 
   RowBox[{"{", 
    RowBox[{"2006", ",", "1", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellTags->"EnumertionMember",
 CellLabel->"In[1]:=",
 CellID->658297105],

Cell[CellGroupData[{

Cell["CalendarBusinessDaysBetween[FirstDate,LastDate]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[4]:=",
 CellID->94054909],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257", ",", "152"}], "}"}]], "Output",
 CellTags->"Procedure",
 CellLabel->"Out[4]=",
 CellID->1933086]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, -1195}, {Automatic, 11}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "EnumerationMember"->{
  Cell[4116, 161, 88, 2, 51, "Section",
   CellTags->"EnumerationMember",
   CellID->44851749]},
 "EnumertionMember"->{
  Cell[4229, 167, 88, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->227996691],
  Cell[4628, 190, 96, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->66715191],
  Cell[4944, 202, 283, 8, 47, "Input",
   CellTags->"EnumertionMember",
   CellID->399132291],
  Cell[5538, 229, 92, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->94687178],
  Cell[5849, 241, 308, 9, 47, "Input",
   CellTags->"EnumertionMember",
   CellID->53948499],
  Cell[6501, 270, 95, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->88007002],
  Cell[6816, 282, 309, 9, 47, "Input",
   CellTags->"EnumertionMember",
   CellID->142385597],
  Cell[7474, 311, 93, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->25978282],
  Cell[7787, 323, 282, 8, 47, "Input",
   CellTags->"EnumertionMember",
   CellID->70904296],
  Cell[8433, 352, 94, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->118081274],
  Cell[9660, 402, 97, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->522757588],
  Cell[9977, 414, 284, 8, 47, "Input",
   CellTags->"EnumertionMember",
   CellID->85108895],
  Cell[10851, 456, 90, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->160369047],
  Cell[11510, 478, 311, 9, 47, "Input",
   CellTags->"EnumertionMember",
   CellID->266243808],
  Cell[12627, 528, 91, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->276175045],
  Cell[14024, 568, 460, 14, 65, "Input",
   CellTags->"EnumertionMember",
   CellID->36870070],
  Cell[15091, 610, 103, 2, 30, "Subsubsection",
   CellTags->"EnumertionMember",
   CellID->539331047],
  Cell[16208, 644, 527, 16, 65, "Input",
   CellTags->"EnumertionMember",
   CellID->658297105]},
 "Overview"->{
  Cell[567, 22, 70, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->129916062],
  Cell[640, 26, 86, 2, 30, "Text",
   CellTags->"Overview",
   CellID->718378184],
  Cell[729, 30, 114, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->270217803],
  Cell[846, 34, 101, 3, 28, "Input",
   CellTags->"Overview",
   CellID->1254907],
  Cell[950, 39, 220, 6, 50, "Text",
   CellTags->"Overview",
   CellID->195940307],
  Cell[1195, 49, 123, 3, 28, "Input",
   CellTags->"Overview",
   CellID->6104487],
  Cell[1321, 54, 134, 4, 36, "Output",
   CellTags->"Overview",
   CellID->112973502],
  Cell[1492, 63, 133, 3, 28, "Input",
   CellTags->"Overview",
   CellID->427947670],
  Cell[1628, 68, 409, 10, 88, "Output",
   CellTags->"Overview",
   CellID->68403555]},
 "Procedure"->{
  Cell[2074, 83, 73, 2, 51, "Section",
   CellTags->"Procedure",
   CellID->101315972],
  Cell[2172, 89, 88, 2, 30, "Subsubsection",
   CellTags->"Procedure",
   CellID->691578319],
  Cell[3140, 119, 397, 12, 65, "Input",
   CellTags->"Procedure",
   CellID->24455485],
  Cell[3562, 135, 150, 6, 45, "Input",
   CellTags->"Procedure",
   CellID->333616146],
  Cell[3715, 143, 340, 11, 36, "Output",
   CellTags->"Procedure",
   CellID->395638734],
  Cell[4342, 173, 127, 6, 45, "Input",
   CellTags->"Procedure",
   CellID->863567140],
  Cell[4472, 181, 107, 3, 36, "Output",
   CellTags->"Procedure",
   CellID->85354402],
  Cell[5252, 214, 113, 3, 28, "Input",
   CellTags->"Procedure",
   CellID->226487527],
  Cell[5368, 219, 121, 4, 36, "Output",
   CellTags->"Procedure",
   CellID->175687855],
  Cell[6182, 254, 147, 4, 28, "Input",
   CellTags->"Procedure",
   CellID->38974668],
  Cell[6332, 260, 120, 4, 36, "Output",
   CellTags->"Procedure",
   CellID->766663970],
  Cell[7150, 295, 151, 4, 28, "Input",
   CellTags->"Procedure",
   CellID->666775278],
  Cell[7304, 301, 121, 4, 36, "Output",
   CellTags->"Procedure",
   CellID->508923767],
  Cell[8094, 335, 109, 3, 28, "Input",
   CellTags->"Procedure",
   CellID->406782677],
  Cell[8206, 340, 178, 6, 36, "Output",
   CellTags->"Procedure",
   CellID->401475611],
  Cell[10286, 426, 170, 7, 62, "Input",
   CellTags->"Procedure",
   CellID->52918540],
  Cell[10459, 435, 120, 4, 36, "Output",
   CellTags->"Procedure",
   CellID->694601281],
  Cell[10582, 441, 98, 3, 36, "Output",
   CellTags->"Procedure",
   CellID->576472941],
  Cell[10683, 446, 119, 4, 36, "Output",
   CellTags->"Procedure",
   CellID->6347343],
  Cell[11846, 491, 166, 4, 28, "Input",
   CellTags->"Procedure",
   CellID->423579442],
  Cell[12015, 497, 178, 6, 36, "Output",
   CellTags->"Procedure",
   CellID->51877727],
  Cell[12230, 508, 124, 5, 28, "Input",
   CellTags->"Procedure",
   CellID->532021617],
  Cell[12357, 515, 221, 7, 36, "Output",
   CellTags->"Procedure",
   CellID->17189863],
  Cell[14509, 586, 116, 3, 28, "Input",
   CellTags->"Procedure",
   CellID->90484221],
  Cell[14628, 591, 414, 13, 36, "Output",
   CellTags->"Procedure",
   CellID->242562103],
  Cell[16760, 664, 130, 3, 28, "Input",
   CellTags->"Procedure",
   CellID->94054909],
  Cell[16893, 669, 142, 5, 36, "Output",
   CellTags->"Procedure",
   CellID->1933086]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"EnumerationMember", 18202, 712},
 {"EnumertionMember", 18322, 716},
 {"Overview", 20119, 771},
 {"Procedure", 20907, 799}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 70, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->129916062],
Cell[640, 26, 86, 2, 30, "Text",
 CellTags->"Overview",
 CellID->718378184],
Cell[729, 30, 114, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->270217803],
Cell[846, 34, 101, 3, 28, "Input",
 CellTags->"Overview",
 CellID->1254907],
Cell[950, 39, 220, 6, 50, "Text",
 CellTags->"Overview",
 CellID->195940307],
Cell[CellGroupData[{
Cell[1195, 49, 123, 3, 28, "Input",
 CellTags->"Overview",
 CellID->6104487],
Cell[1321, 54, 134, 4, 36, "Output",
 CellTags->"Overview",
 CellID->112973502]
}, Open  ]],
Cell[CellGroupData[{
Cell[1492, 63, 133, 3, 28, "Input",
 CellTags->"Overview",
 CellID->427947670],
Cell[1628, 68, 409, 10, 88, "Output",
 CellTags->"Overview",
 CellID->68403555]
}, Open  ]],
Cell[CellGroupData[{
Cell[2074, 83, 73, 2, 51, "Section",
 CellTags->"Procedure",
 CellID->101315972],
Cell[CellGroupData[{
Cell[2172, 89, 88, 2, 30, "Subsubsection",
 CellTags->"Procedure",
 CellID->691578319],
Cell[2263, 93, 539, 14, 119, "Text",
 CellID->99756323],
Cell[2805, 109, 332, 8, 84, "Text",
 CellID->129489133],
Cell[3140, 119, 397, 12, 65, "Input",
 CellTags->"Procedure",
 CellID->24455485],
Cell[CellGroupData[{
Cell[3562, 135, 150, 6, 45, "Input",
 CellTags->"Procedure",
 CellID->333616146],
Cell[3715, 143, 340, 11, 36, "Output",
 CellTags->"Procedure",
 CellID->395638734]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4116, 161, 88, 2, 51, "Section",
 CellTags->"EnumerationMember",
 CellID->44851749],
Cell[CellGroupData[{
Cell[4229, 167, 88, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->227996691],
Cell[CellGroupData[{
Cell[4342, 173, 127, 6, 45, "Input",
 CellTags->"Procedure",
 CellID->863567140],
Cell[4472, 181, 107, 3, 36, "Output",
 CellTags->"Procedure",
 CellID->85354402]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4628, 190, 96, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->66715191],
Cell[4727, 194, 214, 6, 67, "Text",
 CellID->466976350],
Cell[4944, 202, 283, 8, 47, "Input",
 CellTags->"EnumertionMember",
 CellID->399132291],
Cell[CellGroupData[{
Cell[5252, 214, 113, 3, 28, "Input",
 CellTags->"Procedure",
 CellID->226487527],
Cell[5368, 219, 121, 4, 36, "Output",
 CellTags->"Procedure",
 CellID->175687855]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5538, 229, 92, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->94687178],
Cell[5633, 233, 213, 6, 67, "Text",
 CellID->80678956],
Cell[5849, 241, 308, 9, 47, "Input",
 CellTags->"EnumertionMember",
 CellID->53948499],
Cell[CellGroupData[{
Cell[6182, 254, 147, 4, 28, "Input",
 CellTags->"Procedure",
 CellID->38974668],
Cell[6332, 260, 120, 4, 36, "Output",
 CellTags->"Procedure",
 CellID->766663970]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6501, 270, 95, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->88007002],
Cell[6599, 274, 214, 6, 67, "Text",
 CellID->239959559],
Cell[6816, 282, 309, 9, 47, "Input",
 CellTags->"EnumertionMember",
 CellID->142385597],
Cell[CellGroupData[{
Cell[7150, 295, 151, 4, 28, "Input",
 CellTags->"Procedure",
 CellID->666775278],
Cell[7304, 301, 121, 4, 36, "Output",
 CellTags->"Procedure",
 CellID->508923767]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7474, 311, 93, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->25978282],
Cell[7570, 315, 214, 6, 67, "Text",
 CellID->604848759],
Cell[7787, 323, 282, 8, 47, "Input",
 CellTags->"EnumertionMember",
 CellID->70904296],
Cell[CellGroupData[{
Cell[8094, 335, 109, 3, 28, "Input",
 CellTags->"Procedure",
 CellID->406782677],
Cell[8206, 340, 178, 6, 36, "Output",
 CellTags->"Procedure",
 CellID->401475611]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8433, 352, 94, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->118081274],
Cell[8530, 356, 214, 6, 67, "Text",
 CellID->147042316],
Cell[8747, 364, 254, 7, 47, "Input",
 CellID->114861492],
Cell[CellGroupData[{
Cell[9026, 375, 310, 7, 65, "Input",
 CellID->314245],
Cell[9339, 384, 97, 3, 36, "Output",
 CellID->238652120],
Cell[9439, 389, 73, 2, 36, "Output",
 CellID->36507524],
Cell[9515, 393, 96, 3, 36, "Output",
 CellID->239997702]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9660, 402, 97, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->522757588],
Cell[9760, 406, 214, 6, 67, "Text",
 CellID->350203716],
Cell[9977, 414, 284, 8, 47, "Input",
 CellTags->"EnumertionMember",
 CellID->85108895],
Cell[CellGroupData[{
Cell[10286, 426, 170, 7, 62, "Input",
 CellTags->"Procedure",
 CellID->52918540],
Cell[10459, 435, 120, 4, 36, "Output",
 CellTags->"Procedure",
 CellID->694601281],
Cell[10582, 441, 98, 3, 36, "Output",
 CellTags->"Procedure",
 CellID->576472941],
Cell[10683, 446, 119, 4, 36, "Output",
 CellTags->"Procedure",
 CellID->6347343]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10851, 456, 90, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->160369047],
Cell[10944, 460, 270, 7, 67, "Text",
 CellID->672113496],
Cell[11217, 469, 290, 7, 84, "Text",
 CellID->14374571],
Cell[11510, 478, 311, 9, 47, "Input",
 CellTags->"EnumertionMember",
 CellID->266243808],
Cell[CellGroupData[{
Cell[11846, 491, 166, 4, 28, "Input",
 CellTags->"Procedure",
 CellID->423579442],
Cell[12015, 497, 178, 6, 36, "Output",
 CellTags->"Procedure",
 CellID->51877727]
}, Open  ]],
Cell[CellGroupData[{
Cell[12230, 508, 124, 5, 28, "Input",
 CellTags->"Procedure",
 CellID->532021617],
Cell[12357, 515, 221, 7, 36, "Output",
 CellTags->"Procedure",
 CellID->17189863]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12627, 528, 91, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->276175045],
Cell[12721, 532, 836, 20, 136, "Text",
 CellID->35365726],
Cell[13560, 554, 461, 12, 120, "Text",
 CellID->36614051],
Cell[14024, 568, 460, 14, 65, "Input",
 CellTags->"EnumertionMember",
 CellID->36870070],
Cell[CellGroupData[{
Cell[14509, 586, 116, 3, 28, "Input",
 CellTags->"Procedure",
 CellID->90484221],
Cell[14628, 591, 414, 13, 36, "Output",
 CellTags->"Procedure",
 CellID->242562103]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15091, 610, 103, 2, 30, "Subsubsection",
 CellTags->"EnumertionMember",
 CellID->539331047],
Cell[15197, 614, 452, 12, 81, "Text",
 CellID->47915218],
Cell[15652, 628, 553, 14, 142, "Text",
 CellID->113193361],
Cell[16208, 644, 527, 16, 65, "Input",
 CellTags->"EnumertionMember",
 CellID->658297105],
Cell[CellGroupData[{
Cell[16760, 664, 130, 3, 28, "Input",
 CellTags->"Procedure",
 CellID->94054909],
Cell[16893, 669, 142, 5, 36, "Output",
 CellTags->"Procedure",
 CellID->1933086]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
