(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      9719,        354]
NotebookOptionsPosition[      5766,        207]
NotebookOutlinePosition[      8229,        293]
CellTagsIndexPosition[      8106,        286]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["CmsMarket"], "Title",
 CellTags->"Overview",
 CellID->248634200],

Cell["functions to construct and use CmsMarket objects.", "Text",
 CellTags->"Overview",
 CellID->105446816],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->297122142],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[101]:=",
 CellID->222049415],

Cell["\<\
Within the CmsMarket part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->126902940],

Cell[CellGroupData[{

Cell["Select[Category[CmsMarket],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[102]:=",
 CellID->356016551],

Cell[BoxData[
 RowBox[{"{", "CmsMarket", "}"}]], "Output",
 CellChangeTimes->{3.436070086078125*^9},
 CellTags->"Overview",
 CellLabel->"Out[102]=",
 CellID->431306873]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[CmsMarket],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[103]:=",
 CellID->130128039],

Cell[BoxData[
 RowBox[{"{", "BrowseCmsMarket", "}"}]], "Output",
 CellChangeTimes->{3.436070088484375*^9},
 CellTags->"Overview",
 CellLabel->"Out[103]=",
 CellID->77961794]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarket", "Subsection",
 CellTags->"Constructor",
 CellID->299356867],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapLengths", 
     RowBox[{
      RowBox[{"2", "Y"}], ",", 
      RowBox[{"5", "Y"}], ",", 
      RowBox[{"10", "Y"}], ",", 
      RowBox[{"20", "Y"}], ",", 
      RowBox[{"30", "Y"}]}], 
     RowBox[{"vector", " ", "of", " ", "swap", " ", 
      RowBox[{"lengths", "."}]}]},
    {"SwapIndexes", 
     RowBox[{
     "EuriborSwapFixA2Y", ",", "EuriborSwapFixA5Y", ",", "EuriborSwapFixA10Y",
       ",", "EuriborSwapFixA20Y", ",", "EuriborSwapFixA30Y"}], 
     RowBox[{"vector", " ", "of", " ", "SwapIndex", " ", "object", " ", 
      RowBox[{"IDs", "."}]}]},
    {"IborIndex", "Euribor3M", 
     RowBox[{"IborIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"BidAskSpreads", "exampleValue", 
     RowBox[{"matrix", " ", "of", " ", 
      RowBox[{"bid", "/", "ask"}], " ", "cms", " ", "quotes", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"spread", " ", "over", " ", "ibor", " ", "leg"}], ")"}], 
       "."}]}]},
    {"CmsCouponPricers", "exampleValue", 
     RowBox[{"vector", " ", "of", " ", "HaganPricer", " ", "object", " ", 
      RowBox[{"IDs", "."}]}]},
    {"YieldCurve", "EURYC", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->101544216],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SwapLengths", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<2Y\>\"", ",", 
     RowBox[{"\"\<5Y,\>\"", "\"\<10Y\>\""}], ",", "\"\<20Y\>\"", ",", 
     "\"\<30Y\>\""}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SwapIndexes", "=", 
   RowBox[{"{", 
    RowBox[{
    "EuriborSwapFixA2Y", ",", "EuriborSwapFixA5Y", ",", "EuriborSwapFixA10Y", 
     ",", "EuriborSwapFixA20Y", ",", "EuriborSwapFixA30Y"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IborIndex", "=", "Euribor3M"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BidAskSpreads", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CmsCouponPricers", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YieldCurve", "=", "EURYC"}], ";"}]}], "Input",
 CellChangeTimes->{{3.436070062828125*^9, 3.436070074671875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[104]:=",
 CellID->229127801],

Cell[CellGroupData[{

Cell["\<\
obj=CmsMarket[SwapLengths,SwapIndexes,IborIndex,BidAskSpreads,\
CmsCouponPricers,YieldCurve]\
\>", "Input",
 CellTags->"Constructor",
 CellLabel->"In[110]:=",
 CellID->141464046],

Cell[BoxData[
 RowBox[{"CmsMarket", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"2Y\"\>", ",", 
     RowBox[{"\<\"10Y\"\>", " ", "\<\"5Y,\"\>"}], ",", "\<\"20Y\"\>", 
     ",", "\<\"30Y\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "EuriborSwapFixA2Y", ",", "EuriborSwapFixA5Y", ",", "EuriborSwapFixA10Y", 
     ",", "EuriborSwapFixA20Y", ",", "EuriborSwapFixA30Y"}], "}"}], ",", 
   "Euribor3M", ",", "exampleValue", ",", 
   RowBox[{"{", "exampleValue", "}"}], ",", "EURYC"}], "]"}]], "Output",
 CellChangeTimes->{3.436070095140625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[110]=",
 CellID->611386251]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "CmsMarket", "]"}]], "Input",
 CellChangeTimes->{{3.43607009778125*^9, 3.4360701178125*^9}},
 CellLabel->"In[111]:=",
 CellID->74445553],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Permanent", "\[Rule]", "True"}], ",", 
   RowBox[{"Overwrite", "\[Rule]", "True"}]}], "}"}]], "Output",
 CellChangeTimes->{3.436070118609375*^9},
 CellLabel->"Out[111]=",
 CellID->488789155]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BrowseCmsMarket", "Subsection",
 CellTags->"Member",
 CellID->87045584],

Cell["No Parameters", "DefinitionBox",
 CellID->957916150]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 310}, {60, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 78, 2, 115, "Title",
   CellTags->"Overview",
   CellID->248634200],
  Cell[671, 27, 108, 2, 37, "Text",
   CellTags->"Overview",
   CellID->105446816],
  Cell[782, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->297122142],
  Cell[899, 35, 105, 3, 41, "Input",
   CellTags->"Overview",
   CellID->222049415],
  Cell[1007, 40, 157, 5, 37, "Text",
   CellTags->"Overview",
   CellID->126902940],
  Cell[1189, 49, 130, 3, 41, "Input",
   CellTags->"Overview",
   CellID->356016551],
  Cell[1322, 54, 168, 5, 39, "Output",
   CellTags->"Overview",
   CellID->431306873],
  Cell[1527, 64, 125, 3, 41, "Input",
   CellTags->"Overview",
   CellID->130128039],
  Cell[1655, 69, 173, 5, 39, "Output",
   CellTags->"Overview",
   CellID->77961794]},
 "Constructor"->{
  Cell[1865, 79, 77, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->299356867],
  Cell[3350, 120, 904, 26, 137, "Input",
   CellTags->"Constructor",
   CellID->229127801],
  Cell[4279, 150, 188, 6, 28, "Input",
   CellTags->"Constructor",
   CellID->141464046],
  Cell[4470, 158, 624, 16, 88, "Output",
   CellTags->"Constructor",
   CellID->611386251]},
 "Member"->{
  Cell[5600, 198, 77, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->87045584]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 6819, 238},
 {"Constructor", 7613, 266},
 {"Member", 7994, 279}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 78, 2, 115, "Title",
 CellTags->"Overview",
 CellID->248634200],
Cell[671, 27, 108, 2, 37, "Text",
 CellTags->"Overview",
 CellID->105446816],
Cell[782, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->297122142],
Cell[899, 35, 105, 3, 41, "Input",
 CellTags->"Overview",
 CellID->222049415],
Cell[1007, 40, 157, 5, 37, "Text",
 CellTags->"Overview",
 CellID->126902940],
Cell[CellGroupData[{
Cell[1189, 49, 130, 3, 41, "Input",
 CellTags->"Overview",
 CellID->356016551],
Cell[1322, 54, 168, 5, 39, "Output",
 CellTags->"Overview",
 CellID->431306873]
}, Open  ]],
Cell[CellGroupData[{
Cell[1527, 64, 125, 3, 41, "Input",
 CellTags->"Overview",
 CellID->130128039],
Cell[1655, 69, 173, 5, 39, "Output",
 CellTags->"Overview",
 CellID->77961794]
}, Open  ]],
Cell[CellGroupData[{
Cell[1865, 79, 77, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->299356867],
Cell[1945, 83, 1402, 35, 385, "Input",
 CellID->101544216],
Cell[3350, 120, 904, 26, 137, "Input",
 CellTags->"Constructor",
 CellID->229127801],
Cell[CellGroupData[{
Cell[4279, 150, 188, 6, 28, "Input",
 CellTags->"Constructor",
 CellID->141464046],
Cell[4470, 158, 624, 16, 88, "Output",
 CellTags->"Constructor",
 CellID->611386251]
}, Open  ]],
Cell[CellGroupData[{
Cell[5131, 179, 175, 4, 28, "Input",
 CellID->74445553],
Cell[5309, 185, 242, 7, 36, "Output",
 CellID->488789155]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5600, 198, 77, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->87045584],
Cell[5680, 202, 58, 1, 55, "DefinitionBox",
 CellID->957916150]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
