(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14892,        569]
NotebookOptionsPosition[      7423,        292]
NotebookOutlinePosition[     11503,        435]
CellTagsIndexPosition[     11380,        428]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["CmsMarketCalibration"], "Title",
 CellTags->"Overview",
 CellID->641179820],

Cell["functions to construct and use CmsMarketCalibration objects.", "Text",
 CellTags->"Overview",
 CellID->340153351],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->961622563],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->54364007],

Cell["\<\
Within the CmsMarketCalibration part there are several constructors and \
member functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->159109261],

Cell[CellGroupData[{

Cell["Select[Category[CmsMarketCalibration],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[170]:=",
 CellID->655464944],

Cell[BoxData[
 RowBox[{"{", "CmsMarketCalibration", "}"}]], "Output",
 CellChangeTimes->{3.436070353921875*^9},
 CellTags->"Overview",
 CellLabel->"Out[170]=",
 CellID->235995834]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[CmsMarketCalibration],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[171]:=",
 CellID->283605949],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CmsMarketCalibrationCompute", ",", 
   "CmsMarketCalibrationDenseSabrParameters", ",", 
   "CmsMarketCalibrationElapsed", ",", "CmsMarketCalibrationEndCriteria", ",",
    "CmsMarketCalibrationError", ",", 
   "CmsMarketCalibrationSparseSabrParameters", ",", 
   "SimultaneousCalibrationBrowseCmsMarket"}], "}"}]], "Output",
 CellChangeTimes->{3.43607035621875*^9},
 CellTags->"Overview",
 CellLabel->"Out[171]=",
 CellID->44422177]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibration", "Subsection",
 CellTags->"Constructor",
 CellID->240349627],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"VolCube", "exampleValue", 
     RowBox[{"Volatility", " ", "Cube", " ", "by", " ", 
      RowBox[{"Sabr", "."}]}]},
    {"CmsMarket", "exampleValue", 
     RowBox[{"CmsMarket", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Weights", "exampleValue", 
     RowBox[{"weights", " ", "for", " ", "cms", " ", "market", " ", 
      RowBox[{"calibration", "."}]}]},
    {"CalibrationType", "exampleValue", 
     RowBox[{"calibration", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "OnSpread"}], ",", " ", "OnPrice", 
         ",", " ", "OnForwardPrice"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->15535919],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VolCube", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CmsMarket", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Weights", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CalibrationType", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->162890473],

Cell["\<\
obj=CmsMarketCalibration[VolCube,CmsMarket,Weights,CalibrationType]\
\>", "Input",
 CellTags->"Constructor",
 CellID->13436031]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibrationCompute", "Subsection",
 CellTags->"Member",
 CellID->90375681],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"EndCriteria", "exampleValue", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"OptimizationMethod", "exampleValue", 
     RowBox[{"OptimizationMethod", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Guess", "exampleValue", 
     RowBox[{"guess", "."}]},
    {"IsMeanRevFixed", "FALSE", 
     RowBox[{
      RowBox[{
      "if", " ", "TRUE", " ", "mean", " ", "reversion", " ", "parameter", " ",
        "is", " ", "not", " ", "calibrated"}], ",", " ", 
      RowBox[{"the", " ", "guess", " ", "is", " ", 
       RowBox[{"used", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->643639392],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EndCriteria", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptimizationMethod", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Guess", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"IsMeanRevFixed", "=", "FALSE"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->353933968],

Cell["\<\
CmsMarketCalibrationCompute[obj,EndCriteria,OptimizationMethod,Guess,\
IsMeanRevFixed]\
\>", "Input",
 CellTags->"Member",
 CellID->335975502]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibrationError", "Subsection",
 CellTags->"Member",
 CellID->230583135],

Cell["No Parameters", "DefinitionBox",
 CellID->315637766],

Cell[BoxData[""], "Input",
 CellTags->"Member",
 CellID->26149171],

Cell["CmsMarketCalibrationError[obj,]", "Input",
 CellTags->"Member",
 CellID->11770324]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibrationEndCriteria", "Subsection",
 CellTags->"Member",
 CellID->85596048],

Cell["No Parameters", "DefinitionBox",
 CellID->20181696],

Cell[BoxData[""], "Input",
 CellTags->"Member",
 CellID->239773905],

Cell["CmsMarketCalibrationEndCriteria[obj]", "Input",
 CellChangeTimes->{3.4360704266875*^9},
 CellTags->"Member",
 CellID->998243]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibrationElapsed", "Subsection",
 CellTags->"Member",
 CellID->33889924],

Cell["No Parameters", "DefinitionBox",
 CellID->22545140],

Cell[BoxData[""], "Input",
 CellTags->"Member",
 CellID->439163065],

Cell["CmsMarketCalibrationElapsed[obj]", "Input",
 CellChangeTimes->{3.436070422734375*^9},
 CellTags->"Member",
 CellID->23138621]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibrationSparseSabrParameters", "Subsection",
 CellTags->"Member",
 CellID->967594780],

Cell["No Parameters", "DefinitionBox",
 CellID->250450083],

Cell[BoxData[""], "Input",
 CellTags->"Member",
 CellID->460715039],

Cell["CmsMarketCalibrationSparseSabrParameters[obj]", "Input",
 CellChangeTimes->{3.436070419046875*^9},
 CellTags->"Member",
 CellID->688166653]
}, Open  ]],

Cell[CellGroupData[{

Cell["CmsMarketCalibrationDenseSabrParameters", "Subsection",
 CellTags->"Member",
 CellID->181554747],

Cell["No Parameters", "DefinitionBox",
 CellID->117692109],

Cell[BoxData[""], "Input",
 CellTags->"Member",
 CellID->59228004],

Cell["CmsMarketCalibrationDenseSabrParameters[obj]", "Input",
 CellChangeTimes->{3.4360704163125*^9},
 CellTags->"Member",
 CellID->719656623]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimultaneousCalibrationBrowseCmsMarket", "Subsection",
 CellTags->"Member",
 CellID->630880839],

Cell["No Parameters", "DefinitionBox",
 CellID->123600627],

Cell[BoxData[""], "Input",
 CellTags->"Member",
 CellID->459717191],

Cell["SimultaneousCalibrationBrowseCmsMarket[obj]", "Input",
 CellChangeTimes->{3.4360704134375*^9},
 CellTags->"Member",
 CellID->113241506]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 568}, {84, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 89, 2, 115, "Title",
   CellTags->"Overview",
   CellID->641179820],
  Cell[682, 27, 119, 2, 37, "Text",
   CellTags->"Overview",
   CellID->340153351],
  Cell[804, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->961622563],
  Cell[921, 35, 79, 2, 41, "Input",
   CellTags->"Overview",
   CellID->54364007],
  Cell[1003, 39, 168, 5, 37, "Text",
   CellTags->"Overview",
   CellID->159109261],
  Cell[1196, 48, 141, 3, 41, "Input",
   CellTags->"Overview",
   CellID->655464944],
  Cell[1340, 53, 179, 5, 39, "Output",
   CellTags->"Overview",
   CellID->235995834],
  Cell[1556, 63, 136, 3, 41, "Input",
   CellTags->"Overview",
   CellID->283605949],
  Cell[1695, 68, 474, 12, 97, "Output",
   CellTags->"Overview",
   CellID->44422177]},
 "Constructor"->{
  Cell[2206, 85, 88, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->240349627],
  Cell[3120, 111, 346, 10, 70, "Input",
   CellTags->"Constructor",
   CellID->162890473],
  Cell[3469, 123, 137, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->13436031]},
 "Member"->{
  Cell[3643, 132, 89, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->90375681],
  Cell[4496, 157, 368, 11, 70, "Input",
   CellTags->"Member",
   CellID->353933968],
  Cell[4867, 170, 152, 5, 70, "Input",
   CellTags->"Member",
   CellID->335975502],
  Cell[5056, 180, 88, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->230583135],
  Cell[5208, 187, 66, 2, 70, "Input",
   CellTags->"Member",
   CellID->26149171],
  Cell[5277, 191, 88, 2, 28, "Input",
   CellTags->"Member",
   CellID->11770324],
  Cell[5402, 198, 93, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->85596048],
  Cell[5558, 205, 67, 2, 28, "Input",
   CellTags->"Member",
   CellID->239773905],
  Cell[5628, 209, 131, 3, 28, "Input",
   CellTags->"Member",
   CellID->998243],
  Cell[5796, 217, 89, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->33889924],
  Cell[5948, 224, 67, 2, 28, "Input",
   CellTags->"Member",
   CellID->439163065],
  Cell[6018, 228, 131, 3, 28, "Input",
   CellTags->"Member",
   CellID->23138621],
  Cell[6186, 236, 103, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->967594780],
  Cell[6353, 243, 67, 2, 28, "Input",
   CellTags->"Member",
   CellID->460715039],
  Cell[6423, 247, 145, 3, 28, "Input",
   CellTags->"Member",
   CellID->688166653],
  Cell[6605, 255, 102, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->181554747],
  Cell[6771, 262, 66, 2, 28, "Input",
   CellTags->"Member",
   CellID->59228004],
  Cell[6840, 266, 142, 3, 28, "Input",
   CellTags->"Member",
   CellID->719656623],
  Cell[7019, 274, 101, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->630880839],
  Cell[7184, 281, 67, 2, 28, "Input",
   CellTags->"Member",
   CellID->459717191],
  Cell[7254, 285, 141, 3, 28, "Input",
   CellTags->"Member",
   CellID->113241506]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 8476, 323},
 {"Constructor", 9269, 351},
 {"Member", 9556, 361}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 89, 2, 115, "Title",
 CellTags->"Overview",
 CellID->641179820],
Cell[682, 27, 119, 2, 37, "Text",
 CellTags->"Overview",
 CellID->340153351],
Cell[804, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->961622563],
Cell[921, 35, 79, 2, 41, "Input",
 CellTags->"Overview",
 CellID->54364007],
Cell[1003, 39, 168, 5, 37, "Text",
 CellTags->"Overview",
 CellID->159109261],
Cell[CellGroupData[{
Cell[1196, 48, 141, 3, 41, "Input",
 CellTags->"Overview",
 CellID->655464944],
Cell[1340, 53, 179, 5, 39, "Output",
 CellTags->"Overview",
 CellID->235995834]
}, Open  ]],
Cell[CellGroupData[{
Cell[1556, 63, 136, 3, 41, "Input",
 CellTags->"Overview",
 CellID->283605949],
Cell[1695, 68, 474, 12, 97, "Output",
 CellTags->"Overview",
 CellID->44422177]
}, Open  ]],
Cell[CellGroupData[{
Cell[2206, 85, 88, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->240349627],
Cell[2297, 89, 820, 20, 190, "Input",
 CellID->15535919],
Cell[3120, 111, 346, 10, 70, "Input",
 CellTags->"Constructor",
 CellID->162890473],
Cell[3469, 123, 137, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->13436031]
}, Open  ]],
Cell[CellGroupData[{
Cell[3643, 132, 89, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->90375681],
Cell[3735, 136, 758, 19, 70, "Input",
 CellID->643639392],
Cell[4496, 157, 368, 11, 70, "Input",
 CellTags->"Member",
 CellID->353933968],
Cell[4867, 170, 152, 5, 70, "Input",
 CellTags->"Member",
 CellID->335975502]
}, Open  ]],
Cell[CellGroupData[{
Cell[5056, 180, 88, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->230583135],
Cell[5147, 184, 58, 1, 70, "DefinitionBox",
 CellID->315637766],
Cell[5208, 187, 66, 2, 70, "Input",
 CellTags->"Member",
 CellID->26149171],
Cell[5277, 191, 88, 2, 28, "Input",
 CellTags->"Member",
 CellID->11770324]
}, Open  ]],
Cell[CellGroupData[{
Cell[5402, 198, 93, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->85596048],
Cell[5498, 202, 57, 1, 55, "DefinitionBox",
 CellID->20181696],
Cell[5558, 205, 67, 2, 28, "Input",
 CellTags->"Member",
 CellID->239773905],
Cell[5628, 209, 131, 3, 28, "Input",
 CellTags->"Member",
 CellID->998243]
}, Open  ]],
Cell[CellGroupData[{
Cell[5796, 217, 89, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->33889924],
Cell[5888, 221, 57, 1, 55, "DefinitionBox",
 CellID->22545140],
Cell[5948, 224, 67, 2, 28, "Input",
 CellTags->"Member",
 CellID->439163065],
Cell[6018, 228, 131, 3, 28, "Input",
 CellTags->"Member",
 CellID->23138621]
}, Open  ]],
Cell[CellGroupData[{
Cell[6186, 236, 103, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->967594780],
Cell[6292, 240, 58, 1, 55, "DefinitionBox",
 CellID->250450083],
Cell[6353, 243, 67, 2, 28, "Input",
 CellTags->"Member",
 CellID->460715039],
Cell[6423, 247, 145, 3, 28, "Input",
 CellTags->"Member",
 CellID->688166653]
}, Open  ]],
Cell[CellGroupData[{
Cell[6605, 255, 102, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->181554747],
Cell[6710, 259, 58, 1, 55, "DefinitionBox",
 CellID->117692109],
Cell[6771, 262, 66, 2, 28, "Input",
 CellTags->"Member",
 CellID->59228004],
Cell[6840, 266, 142, 3, 28, "Input",
 CellTags->"Member",
 CellID->719656623]
}, Open  ]],
Cell[CellGroupData[{
Cell[7019, 274, 101, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->630880839],
Cell[7123, 278, 58, 1, 55, "DefinitionBox",
 CellID->123600627],
Cell[7184, 281, 67, 2, 28, "Input",
 CellTags->"Member",
 CellID->459717191],
Cell[7254, 285, 141, 3, 28, "Input",
 CellTags->"Member",
 CellID->113241506]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
