(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     27312,       1002]
NotebookOptionsPosition[     15869,        581]
NotebookOutlinePosition[     21779,        783]
CellTagsIndexPosition[     21624,        775]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["Correlation"], "Chapter",
 CellTags->"Overview",
 CellID->508292414],

Cell["functions to construct and use Correlation objects.", "Text",
 CellTags->"Overview",
 CellID->466712985],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->117904462],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[658]:=",
 CellID->570188374],

Cell["\<\
Within the Correlation part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->26441731],

Cell[CellGroupData[{

Cell["Select[Category[Correlation],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[659]:=",
 CellID->42178824],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CotSwapFromFwdCorrelation", ",", "ExponentialForwardCorrelation", ",", 
   "MarketModelLmLinearExponentialCorrelationModel", ",", 
   "TimeHomogeneousForwardCorrelation"}], "}"}]], "Output",
 CellChangeTimes->{3.436077518140625*^9},
 CellTags->"Overview",
 CellLabel->"Out[659]=",
 CellID->343609906]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Correlation],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[660]:=",
 CellID->160428465],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "HistoricalForwardRatesAnalysisFailedDates", ",", 
   "HistoricalForwardRatesAnalysisFailedDatesErrorMessage", ",", 
   "HistoricalForwardRatesAnalysisFixingPeriods", ",", 
   "HistoricalForwardRatesAnalysisSkippedDates", ",", 
   "HistoricalForwardRatesAnalysisSkippedDatesErrorMessage", ",", 
   "HistoricalRatesAnalysisSkippedDates", ",", 
   "HistoricalRatesAnalysisSkippedDatesErrorMessage", ",", 
   "PiecewiseConstantCorrelationCorrelation", ",", 
   "PiecewiseConstantCorrelationNumberOfRates", ",", 
   "PiecewiseConstantCorrelationTimes"}], "}"}]], "Output",
 CellChangeTimes->{3.436077519203125*^9},
 CellTags->"Overview",
 CellLabel->"Out[660]=",
 CellID->37266151]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructor", "Section",
 CellTags->"Constructo",
 CellID->89655516],

Cell[CellGroupData[{

Cell["MarketModelLmLinearExponentialCorrelationModel", "Subsection",
 CellTags->"Constructor",
 CellID->228498626],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Size", "4", 
     RowBox[{"size", "."}]},
    {"Rho", "0.5", 
     RowBox[{"rho", "."}]},
    {"Beta", ".6", 
     RowBox[{"beta", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->312989253],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Factors", "1", 
     RowBox[{"factors", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->11286935],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Size", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Rho", "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"beta", "=", ".6"}], ";"}]}], "Input",
 CellChangeTimes->{3.436077528859375*^9},
 CellTags->"Constructor",
 CellLabel->"In[661]:=",
 CellID->485680285],

Cell[BoxData[
 RowBox[{
  RowBox[{"Set", "::", "\<\"wrsym\"\>"}], ":", 
  " ", "\<\"Symbol \\!\\(Beta\\) is Protected. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", ButtonNote -> \
\\\"Set::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.436077525265625*^9},
 CellTags->"Constructor",
 CellLabel->"During evaluation of In[661]:=",
 CellID->440708904]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
obj=MarketModelLmLinearExponentialCorrelationModel[Size,Rho,beta]\
\>", "Input",
 CellChangeTimes->{3.436077533875*^9},
 CellTags->"Constructor",
 CellLabel->"In[665]:=",
 CellID->444283665],

Cell[BoxData["MarketModelLmLinearExponentialCorrelationModel3"], "Output",
 CellChangeTimes->{{3.436077530703125*^9, 3.436077534890625*^9}},
 CellTags->"Constructor",
 CellLabel->"Out[665]=",
 CellID->261061158]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalForwardRatesAnalysis", "Subsection",
 CellTags->"Constructor",
 CellID->100198360],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SequenceStats", "exampleValue", 
     RowBox[{"Sequence", " ", "Statistics", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"StartDate", "37413", 
     RowBox[{"beginning", " ", "of", " ", "the", " ", "time", " ", 
      RowBox[{"series", "."}]}]},
    {"EndDate", "39248", 
     RowBox[{"end", " ", "of", " ", "the", " ", "time", " ", 
      RowBox[{"series", "."}]}]},
    {"Step", 
     RowBox[{"1", "D"}], 
     RowBox[{"time", " ", 
      RowBox[{"series", "'"}], " ", "time", " ", 
      RowBox[{"step", "."}]}]},
    {"IborIndex", "exampleValue", 
     RowBox[{"floating", " ", "rate", " ", 
      RowBox[{"index", "."}]}]},
    {"InitialGap", 
     RowBox[{"3", "M"}], 
     RowBox[{"initialGap", "."}]},
    {"Horizon", 
     RowBox[{"30", "Y"}], 
     RowBox[{"bootstrap", " ", 
      RowBox[{"horizon", "."}]}]},
    {"IborIndexes", "exampleValue", 
     RowBox[{"Ibor", " ", 
      RowBox[{"indexes", "."}]}]},
    {"SwapIndexes", "exampleValue", 
     RowBox[{"Swap", " ", 
      RowBox[{"indexes", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->597532940],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
     RowBox[{"yield", " ", "curve", " ", "DayCounter", " ", 
      RowBox[{"ID", "."}]}]},
    {"TraitsID", "\"\<Discount\>\"", 
     RowBox[{"Discount", ",", " ", "ZeroRate", ",", " ", 
      RowBox[{"or", " ", 
       RowBox[{"ForwardRate", "."}]}]}]},
    {"InterpolatorID", "\"\<CubicSpline\>\"", 
     RowBox[{"Linear", ",", " ", "LogLinear", ",", " ", 
      RowBox[{"or", " ", 
       RowBox[{"CubicSpline", "."}]}]}]},
    {"BootstrapAccuracy", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "12"}], 
     RowBox[{"boostrap", " ", 
      RowBox[{"accuracy", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->201126740],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SequenceStats", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StartDate", "=", "37413"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"EndDate", "=", "39248"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Step", "=", 
   RowBox[{"1", "D"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"IborIndex", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"InitialGap", "=", 
   RowBox[{"3", "M"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Horizon", "=", 
   RowBox[{"30", "Y"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"IborIndexes", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SwapIndexes", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->235897592],

Cell["\<\
obj=HistoricalForwardRatesAnalysis[SequenceStats,StartDate,EndDate,Step,\
IborIndex,InitialGap,Horizon,IborIndexes,SwapIndexes]\
\>", "Input",
 CellTags->"Constructor",
 CellID->9787716]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalRatesAnalysis", "Subsection",
 CellTags->"Constructor",
 CellID->95190],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SequenceStats", "exampleValue", 
     RowBox[{"Sequence", " ", "Statistics", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"StartDate", "37413", 
     RowBox[{"beginning", " ", "of", " ", "the", " ", "time", " ", 
      RowBox[{"series", "."}]}]},
    {"EndDate", "39248", 
     RowBox[{"end", " ", "of", " ", "the", " ", "time", " ", 
      RowBox[{"series", "."}]}]},
    {"Step", 
     RowBox[{"1", "D"}], 
     RowBox[{"time", " ", 
      RowBox[{"series", "'"}], " ", "time", " ", 
      RowBox[{"step", "."}]}]},
    {"InterestRateIndexes", "exampleValue", 
     RowBox[{"interest", " ", "rate", " ", "indexes", " ", "object", " ", 
      RowBox[{"IDs", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->3026131],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SequenceStats", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StartDate", "=", "37413"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"EndDate", "=", "39248"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Step", "=", 
   RowBox[{"1", "D"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"InterestRateIndexes", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->164487640],

Cell["\<\
obj=HistoricalRatesAnalysis[SequenceStats,StartDate,EndDate,Step,\
InterestRateIndexes]\
\>", "Input",
 CellTags->"Constructor",
 CellID->655205279]
}, Open  ]],

Cell[CellGroupData[{

Cell["TimeHomogeneousForwardCorrelation", "Subsection",
 CellTags->"Constructor",
 CellID->313479807],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FwdCorrMatrix", "exampleValue", 
     RowBox[{"forward", " ", "correlation", " ", 
      RowBox[{"matrix", "."}]}]},
    {"RateTimes", "exampleValue", 
     RowBox[{"rate", " ", 
      RowBox[{"times", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->342656348],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FwdCorrMatrix", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RateTimes", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->105735729],

Cell["\<\
obj=TimeHomogeneousForwardCorrelation[FwdCorrMatrix,RateTimes]\
\>", "Input",
 CellTags->"Constructor",
 CellID->53679648]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExponentialForwardCorrelation", "Subsection",
 CellTags->"Constructor",
 CellID->898945835],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"RateTimes", "exampleValue", 
     RowBox[{"rate", " ", 
      RowBox[{"times", "."}]}]},
    {"LongTermCorr", "0.5", 
     RowBox[{"Long", " ", "term", " ", 
      RowBox[{"correlation", " ", "."}]}]},
    {"Beta", "0.2", 
     RowBox[{"exponential", " ", "decay", " ", 
      RowBox[{"factor", "."}]}]},
    {"Gamma", "0.9", 
     RowBox[{"exponent", " ", "for", " ", "time", " ", "to", " ", 
      RowBox[{"go", "."}]}]},
    {"Times", "exampleValue", 
     RowBox[{"times", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->72522874],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RateTimes", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"LongTermCorr", "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Beta", "=", "0.2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Gamma", "=", "0.9"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Times", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->604802933],

Cell["\<\
obj=ExponentialForwardCorrelation[RateTimes,LongTermCorr,Beta,Gamma,Times]\
\>", "Input",
 CellTags->"Constructor",
 CellID->2216376]
}, Open  ]],

Cell[CellGroupData[{

Cell["CotSwapFromFwdCorrelation", "Subsection",
 CellTags->"Constructor",
 CellID->506114733],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FwdCorr", "PiecewiseConstantCorrelationID", 
     RowBox[{"Forward", " ", "rates", " ", "correlation", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "PiecewiseConstantCorrelation"}], 
         " ", "object", " ", "ID"}], ")"}], "."}]}]},
    {"CurveState", "CurveStateID", 
     RowBox[{"curveState", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->209231257],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Displacement", "0.0", 
     RowBox[{"displacement", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->118692462],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FwdCorr", "=", "PiecewiseConstantCorrelationID"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CurveState", "=", "CurveStateID"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->639250026],

Cell["obj=CotSwapFromFwdCorrelation[FwdCorr,CurveState]", "Input",
 CellTags->"Constructor",
 CellID->142054488]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->57788339],

Cell[CellGroupData[{

Cell["HistoricalForwardRatesAnalysisSkippedDates", "Subsection",
 CellTags->"Member",
 CellID->648859934],

Cell["HistoricalForwardRatesAnalysisSkippedDates[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[666]:=",
 CellID->68566316]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalForwardRatesAnalysisSkippedDatesErrorMessage", "Subsection",
 CellTags->"Member",
 CellID->178263042],

Cell["HistoricalForwardRatesAnalysisSkippedDatesErrorMessage[obj]", "Input",
 CellTags->"Member",
 CellID->178598239]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalForwardRatesAnalysisFailedDates", "Subsection",
 CellTags->"Member",
 CellID->171818084],

Cell["HistoricalForwardRatesAnalysisFailedDates[obj]", "Input",
 CellTags->"Member",
 CellID->54009948]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalForwardRatesAnalysisFailedDatesErrorMessage", "Subsection",
 CellTags->"Member",
 CellID->3620702],

Cell["HistoricalForwardRatesAnalysisFailedDatesErrorMessage[obj]", "Input",
 CellTags->"Member",
 CellID->361310720]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalForwardRatesAnalysisFixingPeriods", "Subsection",
 CellTags->"Member",
 CellID->158779185],

Cell["HistoricalForwardRatesAnalysisFixingPeriods[obj]", "Input",
 CellTags->"Member",
 CellID->463797324]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalRatesAnalysisSkippedDates", "Subsection",
 CellTags->"Member",
 CellID->344036699],

Cell["HistoricalRatesAnalysisSkippedDates[obj]", "Input",
 CellTags->"Member",
 CellID->5030021]
}, Open  ]],

Cell[CellGroupData[{

Cell["HistoricalRatesAnalysisSkippedDatesErrorMessage", "Subsection",
 CellTags->"Member",
 CellID->476872788],

Cell["HistoricalRatesAnalysisSkippedDatesErrorMessage[obj]", "Input",
 CellTags->"Member",
 CellID->399539800]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantCorrelationCorrelation", "Subsection",
 CellTags->"Member",
 CellID->135105177],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeIndex", "0", 
     RowBox[{"time", " ", 
      RowBox[{"index", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->24751650],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeIndex", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->26042551],

Cell["PiecewiseConstantCorrelationCorrelation[objTimeIndex]", "Input",
 CellTags->"Member",
 CellID->526265224]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantCorrelationTimes", "Subsection",
 CellTags->"Member",
 CellID->155004797],

Cell["PiecewiseConstantCorrelationTimes[obj]", "Input",
 CellTags->"Member",
 CellID->365970122]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantCorrelationNumberOfRates", "Subsection",
 CellTags->"Member",
 CellID->177957558],

Cell["PiecewiseConstantCorrelationNumberOfRates[obj]", "Input",
 CellTags->"Member",
 CellID->132237189]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 545}, {Automatic, 58}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 82, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->508292414],
  Cell[675, 27, 110, 2, 37, "Text",
   CellTags->"Overview",
   CellID->466712985],
  Cell[788, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->117904462],
  Cell[905, 35, 105, 3, 41, "Input",
   CellTags->"Overview",
   CellID->570188374],
  Cell[1013, 40, 158, 5, 37, "Text",
   CellTags->"Overview",
   CellID->26441731],
  Cell[1196, 49, 131, 3, 41, "Input",
   CellTags->"Overview",
   CellID->42178824],
  Cell[1330, 54, 343, 9, 78, "Output",
   CellTags->"Overview",
   CellID->343609906],
  Cell[1710, 68, 127, 3, 41, "Input",
   CellTags->"Overview",
   CellID->160428465],
  Cell[1840, 73, 719, 16, 211, "Output",
   CellTags->"Overview",
   CellID->37266151]},
 "Constructo"->{
  Cell[2596, 94, 74, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->89655516]},
 "Constructor"->{
  Cell[2695, 100, 114, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->228498626],
  Cell[3375, 126, 295, 10, 70, "Input",
   CellTags->"Constructor",
   CellID->485680285],
  Cell[3673, 138, 467, 10, 70, "Message",
   CellTags->"Constructor",
   CellID->440708904],
  Cell[4177, 153, 200, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->444283665],
  Cell[4380, 161, 211, 4, 70, "Output",
   CellTags->"Constructor",
   CellID->261061158],
  Cell[4640, 171, 98, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->100198360],
  Cell[6748, 233, 753, 25, 70, "Input",
   CellTags->"Constructor",
   CellID->235897592],
  Cell[7504, 260, 196, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->9787716],
  Cell[7737, 270, 87, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->95190],
  Cell[8685, 297, 439, 14, 70, "Input",
   CellTags->"Constructor",
   CellID->164487640],
  Cell[9127, 313, 158, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->655205279],
  Cell[9322, 323, 101, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->313479807],
  Cell[9818, 339, 232, 7, 70, "Input",
   CellTags->"Constructor",
   CellID->105735729],
  Cell[10053, 348, 132, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->53679648],
  Cell[10222, 357, 97, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->898945835],
  Cell[10986, 381, 425, 14, 70, "Input",
   CellTags->"Constructor",
   CellID->604802933],
  Cell[11414, 397, 143, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->2216376],
  Cell[11594, 406, 93, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->506114733],
  Cell[12469, 433, 221, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->639250026],
  Cell[12693, 441, 112, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->142054488]},
 "Member"->{
  Cell[12854, 449, 74, 2, 70, "Section",
   CellTags->"Member",
   CellID->57788339],
  Cell[12953, 455, 105, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->648859934],
  Cell[13061, 459, 129, 3, 70, "Input",
   CellTags->"Member",
   CellID->68566316],
  Cell[13227, 467, 117, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->178263042],
  Cell[13347, 471, 117, 2, 28, "Input",
   CellTags->"Member",
   CellID->178598239],
  Cell[13501, 478, 104, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->171818084],
  Cell[13608, 482, 103, 2, 28, "Input",
   CellTags->"Member",
   CellID->54009948],
  Cell[13748, 489, 114, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->3620702],
  Cell[13865, 493, 116, 2, 28, "Input",
   CellTags->"Member",
   CellID->361310720],
  Cell[14018, 500, 106, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->158779185],
  Cell[14127, 504, 106, 2, 28, "Input",
   CellTags->"Member",
   CellID->463797324],
  Cell[14270, 511, 98, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->344036699],
  Cell[14371, 515, 96, 2, 28, "Input",
   CellTags->"Member",
   CellID->5030021],
  Cell[14504, 522, 110, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->476872788],
  Cell[14617, 526, 110, 2, 28, "Input",
   CellTags->"Member",
   CellID->399539800],
  Cell[14764, 533, 102, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->135105177],
  Cell[15120, 546, 115, 4, 28, "Input",
   CellTags->"Member",
   CellID->26042551],
  Cell[15238, 552, 111, 2, 28, "Input",
   CellTags->"Member",
   CellID->526265224],
  Cell[15386, 559, 96, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->155004797],
  Cell[15485, 563, 96, 2, 28, "Input",
   CellTags->"Member",
   CellID->365970122],
  Cell[15618, 570, 104, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->177957558],
  Cell[15725, 574, 104, 2, 28, "Input",
   CellTags->"Member",
   CellID->132237189]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 16922, 612},
 {"Constructo", 17716, 640},
 {"Constructor", 17823, 644},
 {"Member", 19669, 705}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 82, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->508292414],
Cell[675, 27, 110, 2, 37, "Text",
 CellTags->"Overview",
 CellID->466712985],
Cell[788, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->117904462],
Cell[905, 35, 105, 3, 41, "Input",
 CellTags->"Overview",
 CellID->570188374],
Cell[1013, 40, 158, 5, 37, "Text",
 CellTags->"Overview",
 CellID->26441731],
Cell[CellGroupData[{
Cell[1196, 49, 131, 3, 41, "Input",
 CellTags->"Overview",
 CellID->42178824],
Cell[1330, 54, 343, 9, 78, "Output",
 CellTags->"Overview",
 CellID->343609906]
}, Open  ]],
Cell[CellGroupData[{
Cell[1710, 68, 127, 3, 41, "Input",
 CellTags->"Overview",
 CellID->160428465],
Cell[1840, 73, 719, 16, 211, "Output",
 CellTags->"Overview",
 CellID->37266151]
}, Open  ]],
Cell[CellGroupData[{
Cell[2596, 94, 74, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->89655516],
Cell[CellGroupData[{
Cell[2695, 100, 114, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->228498626],
Cell[2812, 104, 316, 10, 70, "Input",
 CellID->312989253],
Cell[3131, 116, 219, 6, 70, "Input",
 CellID->11286935],
Cell[CellGroupData[{
Cell[3375, 126, 295, 10, 70, "Input",
 CellTags->"Constructor",
 CellID->485680285],
Cell[3673, 138, 467, 10, 70, "Message",
 CellTags->"Constructor",
 CellID->440708904]
}, Open  ]],
Cell[CellGroupData[{
Cell[4177, 153, 200, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->444283665],
Cell[4380, 161, 211, 4, 70, "Output",
 CellTags->"Constructor",
 CellID->261061158]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4640, 171, 98, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->100198360],
Cell[4741, 175, 1208, 34, 70, "Input",
 CellID->597532940],
Cell[5952, 211, 793, 20, 70, "Input",
 CellID->201126740],
Cell[6748, 233, 753, 25, 70, "Input",
 CellTags->"Constructor",
 CellID->235897592],
Cell[7504, 260, 196, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->9787716]
}, Open  ]],
Cell[CellGroupData[{
Cell[7737, 270, 87, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->95190],
Cell[7827, 274, 855, 21, 70, "Input",
 CellID->3026131],
Cell[8685, 297, 439, 14, 70, "Input",
 CellTags->"Constructor",
 CellID->164487640],
Cell[9127, 313, 158, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->655205279]
}, Open  ]],
Cell[CellGroupData[{
Cell[9322, 323, 101, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->313479807],
Cell[9426, 327, 389, 10, 70, "Input",
 CellID->342656348],
Cell[9818, 339, 232, 7, 70, "Input",
 CellTags->"Constructor",
 CellID->105735729],
Cell[10053, 348, 132, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->53679648]
}, Open  ]],
Cell[CellGroupData[{
Cell[10222, 357, 97, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->898945835],
Cell[10322, 361, 661, 18, 70, "Input",
 CellID->72522874],
Cell[10986, 381, 425, 14, 70, "Input",
 CellTags->"Constructor",
 CellID->604802933],
Cell[11414, 397, 143, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->2216376]
}, Open  ]],
Cell[CellGroupData[{
Cell[11594, 406, 93, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->506114733],
Cell[11690, 410, 541, 13, 70, "Input",
 CellID->209231257],
Cell[12234, 425, 232, 6, 70, "Input",
 CellID->118692462],
Cell[12469, 433, 221, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->639250026],
Cell[12693, 441, 112, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->142054488]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12854, 449, 74, 2, 70, "Section",
 CellTags->"Member",
 CellID->57788339],
Cell[CellGroupData[{
Cell[12953, 455, 105, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->648859934],
Cell[13061, 459, 129, 3, 70, "Input",
 CellTags->"Member",
 CellID->68566316]
}, Open  ]],
Cell[CellGroupData[{
Cell[13227, 467, 117, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->178263042],
Cell[13347, 471, 117, 2, 28, "Input",
 CellTags->"Member",
 CellID->178598239]
}, Open  ]],
Cell[CellGroupData[{
Cell[13501, 478, 104, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->171818084],
Cell[13608, 482, 103, 2, 28, "Input",
 CellTags->"Member",
 CellID->54009948]
}, Open  ]],
Cell[CellGroupData[{
Cell[13748, 489, 114, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->3620702],
Cell[13865, 493, 116, 2, 28, "Input",
 CellTags->"Member",
 CellID->361310720]
}, Open  ]],
Cell[CellGroupData[{
Cell[14018, 500, 106, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->158779185],
Cell[14127, 504, 106, 2, 28, "Input",
 CellTags->"Member",
 CellID->463797324]
}, Open  ]],
Cell[CellGroupData[{
Cell[14270, 511, 98, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->344036699],
Cell[14371, 515, 96, 2, 28, "Input",
 CellTags->"Member",
 CellID->5030021]
}, Open  ]],
Cell[CellGroupData[{
Cell[14504, 522, 110, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->476872788],
Cell[14617, 526, 110, 2, 28, "Input",
 CellTags->"Member",
 CellID->399539800]
}, Open  ]],
Cell[CellGroupData[{
Cell[14764, 533, 102, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->135105177],
Cell[14869, 537, 248, 7, 65, "Input",
 CellID->24751650],
Cell[15120, 546, 115, 4, 28, "Input",
 CellTags->"Member",
 CellID->26042551],
Cell[15238, 552, 111, 2, 28, "Input",
 CellTags->"Member",
 CellID->526265224]
}, Open  ]],
Cell[CellGroupData[{
Cell[15386, 559, 96, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->155004797],
Cell[15485, 563, 96, 2, 28, "Input",
 CellTags->"Member",
 CellID->365970122]
}, Open  ]],
Cell[CellGroupData[{
Cell[15618, 570, 104, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->177957558],
Cell[15725, 574, 104, 2, 28, "Input",
 CellTags->"Member",
 CellID->132237189]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
