(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     29471,        979]
NotebookOptionsPosition[     21513,        689]
NotebookOutlinePosition[     25485,        823]
CellTagsIndexPosition[     25384,        817]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Credit", "Chapter",
 CellTags->"Overview",
 CellID->117875620],

Cell["QuantLib Credit", "Text",
 CellTags->"Overview",
 CellID->6493930],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->809458595],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[4]:=",
 CellID->54295873],

Cell["\<\
Within the Credit part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->355894081],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "Credit", "]"}], ",", 
   RowBox[{
    RowBox[{"QLConstructor", "[", "#", "]"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{3.524995575182*^9},
 CellLabel->"In[5]:=",
 CellID->556390066],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CreditDefaultSwap", ",", "HazardRateCurve", ",", "MidPointCdsEngine", ",", 
   "PiecewiseFlatHazardRateCurve", ",", "SpreadCdsHelper", ",", 
   "UpfrontCdsHelper"}], "}"}]], "Output",
 CellChangeTimes->{3.52499557715075*^9, 3.5249958129945*^9},
 CellLabel->"Out[5]=",
 CellID->551540789]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Select[Category[Credit],QLMember[#]&]\
\>", "Input",
 CellChangeTimes->{{3.524559167015625*^9, 3.524559171125*^9}, {
   3.524995351541375*^9, 3.524995352557*^9}, {3.524995396416375*^9, 
   3.524995420557*^9}, {3.5249954564945*^9, 3.5249954583695*^9}, 
   3.524995568072625*^9},
 CellTags->"Overview",
 CellLabel->"In[6]:=",
 CellID->4241845],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CreditDefaultSwapFairSpread", ",", "CreditDefaultSwapFairUpfront", ",", 
   "CreditDefaultSwapCouponLegNPV", ",", "CreditDefaultSwapDefaultLegNPV", 
   ",", "CreditDefaultSwapImpliedHazardRate", ",", 
   "CreditDefaultSwapConventionalSpread"}], "}"}]], "Output",
 CellChangeTimes->{
  3.524559158703125*^9, {3.524995334057*^9, 3.52499535327575*^9}, {
   3.524995403510125*^9, 3.524995421103875*^9}, 3.524995459353875*^9, 
   3.52499558883825*^9, 3.52499581452575*^9},
 CellTags->"Overview",
 CellLabel->"Out[6]=",
 CellID->261933588]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor",
 CellID->141872723],

Cell[CellGroupData[{

Cell["CreditDefaultSwap", "Subsubsection",
 CellTags->"Constructor",
 CellID->223591226],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Notional", 
     RowBox[{"Nominal", " ", "amount"}]},
    {"Spread", 
     RowBox[{
     "running", " ", "spread", " ", "in", " ", "fractional", " ", "units"}]},
    {"PremiumSchedule", 
     RowBox[{"premium", " ", "leg", " ", "Schedule", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellChangeTimes->{{3.524917466885737*^9, 3.524917466885737*^9}, {
  3.524917581182612*^9, 3.524917581182612*^9}},
 CellID->444861851],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"BuyerSeller", "\<\"Buyer\"\>", 
     RowBox[{
      RowBox[{"BUYER", " ", "for", " ", "bought"}], ",", " ", 
      RowBox[{"SELLER", " ", "for", " ", "sold", " ", 
       RowBox[{"protection", "."}]}]}]},
    {"PaymentConvention", "\<\"Following\"\>", 
     RowBox[{"Payment", " ", 
      RowBox[{"dates", "'"}], " ", "business", " ", "day", " ", 
      RowBox[{"convention", "."}]}]},
    {"SettlesAccrual", "true", 
     RowBox[{"TRUE", " ", "ensures", " ", "settlement", " ", "of", " ", 
      RowBox[{"accural", "."}]}]},
    {"PayAtDefault", "true", 
     RowBox[{
     "TRUE", " ", "ensures", " ", "payment", " ", "at", " ", "default", " ", 
      "time"}]},
    {"ProtectionStart", 
     RowBox[{"EvaluationDate", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"protection", " ", "start", " ", 
      RowBox[{"date", "."}]}]},
    {"Upfront", "0.0", 
     RowBox[{"upfront", " ", "in", " ", "fractional", " ", "units"}]},
    {"UpfrontDate", 
     RowBox[{"EvaluationDate", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"upfront", " ", 
      RowBox[{"date", "."}]}]},
    {"DayCounter", 
     RowBox[{
      RowBox[{"Actual", "/", "365"}], " ", 
      RowBox[{"(", "Fixed", ")"}]}], 
     RowBox[{"premium", " ", "leg", " ", "day", " ", "count", " ", "rule"}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->349879365],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Notional", "=", "1000000"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Spread", "=", "0.01"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PremiumSchedule", "=", 
   RowBox[{"Schedule", "[", 
    RowBox[{
     RowBox[{"CalendarAdvance", "[", "\"\<1Y\>\"", "]"}], ",", "\"\<3M\>\""}],
     "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.524917607260737*^9, 3.524917681651362*^9}},
 CellTags->"Constructor",
 CellLabel->"In[7]:=",
 CellID->456832970],

Cell[CellGroupData[{

Cell["obj=CreditDefaultSwap[Notional,Spread,PremiumSchedule]", "Input",
 CellChangeTimes->{{3.524917689682612*^9, 3.524917694370112*^9}},
 CellTags->"Constructor",
 CellLabel->"In[37]:=",
 CellID->57438002],

Cell[BoxData["CreditDefaultSwap19"], "Output",
 CellChangeTimes->{3.524917696729487*^9, 3.5249953341195*^9},
 CellTags->"Constructor",
 CellLabel->"Out[37]=",
 CellID->491659384]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MidPointCdsEngine", "Subsubsection",
 CellTags->"Constructor",
 CellID->661287446],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DefaultCurve", 
     RowBox[{"default", " ", "term", " ", "structure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"RecoveryRate", 
     RowBox[{"constant", " ", "recovery", " ", "rate"}]},
    {"YieldCurve", 
     RowBox[{
     "discounting", " ", "yield", " ", "term", " ", "structure", " ", 
      "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->232579951],

Cell[BoxData[{
 RowBox[{
  RowBox[{"curveDates", "=", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<2M\>\"", ",", "\"\<3M\>\"", ",", "\"\<4M\>\"", ",", "\"\<5M\>\"", 
      ",", "\"\<6M\>\""}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"curveRates", "=", 
   RowBox[{"{", 
    RowBox[{"0.02", ",", "0.02", ",", "0.02", ",", "0.02", ",", "0.02"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defaultCurve", "=", 
   RowBox[{"HazardRateCurve", "[", 
    RowBox[{"curveDates", ",", "curveRates"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yieldCurve", "=", 
   RowBox[{"FlatForward", "[", "0.04", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.524995606510125*^9, {3.524995646666375*^9, 3.524995669682*^9}, {
   3.524996203510125*^9, 3.524996234916375*^9}, {3.524996286416375*^9, 
   3.52499632308825*^9}},
 CellTags->"Constructor",
 CellLabel->"In[42]:=",
 CellID->815450064],

Cell[CellGroupData[{

Cell["\<\
obj=MidPointCdsEngine[defaultCurve,yieldCurve,RecoveryRate->0.4]\
\>", "Input",
 CellChangeTimes->{{3.524995610197625*^9, 3.524995630603875*^9}, {
  3.524996343916375*^9, 3.524996346103875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[47]:=",
 CellID->2016262],

Cell[BoxData["MidPointCdsEngine17"], "Output",
 CellChangeTimes->{
  3.524995334166375*^9, {3.52499633283825*^9, 3.524996346697625*^9}},
 CellTags->"Constructor",
 CellLabel->"Out[47]=",
 CellID->1213099]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HazardRateCurve", "Subsubsection",
 CellTags->"Constructor",
 CellID->100080654],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveDates", 
     RowBox[{"dates", " ", "of", " ", "the", " ", 
      RowBox[{"curve", "."}]}]},
    {"CurveRates", 
     RowBox[{
     "hazard", " ", "rates", " ", "for", " ", "the", " ", "above", " ", 
      RowBox[{"dates", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->36719777],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->815054969],

Cell[BoxData[{
 RowBox[{
  RowBox[{"curveDates", "=", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<2M\>\"", ",", "\"\<3M\>\"", ",", "\"\<4M\>\"", ",", "\"\<5M\>\"", 
      ",", "\"\<6M\>\""}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"curveRates", "=", 
   RowBox[{"{", 
    RowBox[{"0.02", ",", "0.02", ",", "0.02", ",", "0.02", ",", "0.02"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.52499570296325*^9, 3.5249957208695*^9}, {
  3.52499583996325*^9, 3.524995860416375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[13]:=",
 CellID->52885243],

Cell[CellGroupData[{

Cell["\<\
obj=HazardRateCurve[curveDates,curveRates]\
\>", "Input",
 CellChangeTimes->{{3.5249958433695*^9, 3.524995845822625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[15]:=",
 CellID->377796905],

Cell[BoxData["HazardRateCurve5"], "Output",
 CellChangeTimes->{
  3.524995334572625*^9, {3.52499584640075*^9, 3.524995862416375*^9}},
 CellTags->"Constructor",
 CellLabel->"Out[15]=",
 CellID->138277867]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpreadCdsHelper", "Subsubsection",
 CellTags->"Constructor",
 CellID->154775505],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"RunningSpread", 
     RowBox[{"quote", "."}]},
    {"Tenor", 
     RowBox[{"CDS", " ", "length", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "5"}], "Y", " ", "for", " ", "five",
          " ", "years"}], ")"}], "."}]}]},
    {"Calendar", 
     RowBox[{"holiday", " ", "calendar", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], "."}]}]},
    {"Frequency", 
     RowBox[{"payment", " ", "frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]},
    {"PaymentConvention", 
     RowBox[{"payment", " ", "leg", " ", "convention", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "Unadjusted"}], ")"}], "."}]}]},
    {"GenRule", 
     RowBox[{"Date", " ", "generation", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "Backward", ",", " ", "Forward", ",", " ", "ThirdWednesday", ",", " ",
          "Twentieth", ",", " ", "TwentiethIMM", ",", " ", "Zero"}], ")"}], 
       "."}]}]},
    {"DayCounter", 
     RowBox[{"day", " ", "counter", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Actual"}], "/", "360"}], ")"}], 
       "."}]}]},
    {"RecoveryRate", 
     RowBox[{"recovery", " ", "rate"}]},
    {"DiscountingCurve", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->727056345],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDays", "0", 
     RowBox[{"settlement", " ", "days"}]},
    {"SettleAccrual", "true", 
     RowBox[{"TRUE", " ", "ensures", " ", "settlement", " ", "of", " ", 
      RowBox[{"accural", "."}]}]},
    {"PayAtDefault", "true", 
     RowBox[{
     "TRUE", " ", "ensures", " ", "payment", " ", "at", " ", "default", " ", 
      "time"}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->285728904],

Cell[BoxData[{
 RowBox[{
  RowBox[{"runningSpread", "=", "0.042322"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tenor", "=", "\"\<10Y\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"calendar", "=", "\"\<TARGET\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"frequency", "=", "\"\<Annual\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"paymentConvention", "=", "\"\<Following\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"genRule", "=", "\"\<Backward\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dayCounter", "=", "\"\<30/360 (Bond Basis)\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"recoveryRate", "=", "0.4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"discountingCurve", "=", 
   RowBox[{"FlatForward", "[", "0.04", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5249958892445*^9, 3.524995926057*^9}, {
   3.524996067572625*^9, 3.524996138057*^9}, 3.52499618565075*^9},
 CellTags->"Constructor",
 CellLabel->"In[27]:=",
 CellID->525422655],

Cell[CellGroupData[{

Cell["\<\
obj=SpreadCdsHelper[runningSpread,tenor,frequency,paymentConvention,genRule,\
dayCounter,recoveryRate,discountingCurve]\
\>", "Input",
 CellChangeTimes->{{3.524995997807*^9, 3.524996032572625*^9}, {
  3.52499614577575*^9, 3.524996161853875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[36]:=",
 CellID->681187604],

Cell[BoxData["SpreadCdsHelper9"], "Output",
 CellChangeTimes->{
  3.524995334635125*^9, {3.52499616265075*^9, 3.524996187260125*^9}},
 CellTags->"Constructor",
 CellLabel->"Out[36]=",
 CellID->277678551]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UpfrontCdsHelper", "Subsubsection",
 CellTags->"Constructor",
 CellID->37314022],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"UpfrontSpread", 
     RowBox[{"upfront", " ", "spread", " ", 
      RowBox[{"quote", "."}]}]},
    {"RunningSpread", 
     RowBox[{"running", " ", 
      RowBox[{"spread", "."}]}]},
    {"Tenor", 
     RowBox[{"CDS", " ", "length", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "5"}], "Y", " ", "for", " ", "five",
          " ", "years"}], ")"}], "."}]}]},
    {"Calendar", 
     RowBox[{"holiday", " ", "calendar", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], "."}]}]},
    {"Frequency", 
     RowBox[{"payment", " ", "frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]},
    {"PaymentConvention", 
     RowBox[{"payment", " ", "leg", " ", "convention", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "Unadjusted"}], ")"}], "."}]}]},
    {"GenRule", 
     RowBox[{"Date", " ", "generation", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "Backward", ",", " ", "Forward", ",", " ", "ThirdWednesday", ",", " ",
          "Twentieth", ",", " ", "TwentiethIMM", ",", " ", "Zero"}], ")"}], 
       "."}]}]},
    {"DayCounter", 
     RowBox[{"day", " ", "counter", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Actual"}], "/", "360"}], ")"}], 
       "."}]}]},
    {"RecoveryRate", 
     RowBox[{"recovery", " ", "rate"}]},
    {"DiscountingCurve", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"UpfrontSettlementDays", 
     RowBox[{"upfront", " ", "settlement", " ", "days"}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->257929087],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDays", "0", 
     RowBox[{"settlement", " ", "days"}]},
    {"SettleAccrual", "true", 
     RowBox[{"TRUE", " ", "ensures", " ", "settlement", " ", "of", " ", 
      RowBox[{"accural", "."}]}]},
    {"PayAtDefault", "true", 
     RowBox[{
     "TRUE", " ", "ensures", " ", "payment", " ", "at", " ", "default", " ", 
      "time"}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->72374145],

Cell[BoxData[{
 RowBox[{
  RowBox[{"upfrontSpread", "=", "0.042322"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"runningSpread", "=", "0.042322"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tenor", "=", "\"\<10Y\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"frequency", "=", "\"\<Annual\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"paymentConvention", "=", "\"\<Following\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"genRule", "=", "\"\<Backward\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dayCounter", "=", "\"\<30/360 (Bond Basis)\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"recoveryRate", "=", "0.4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"discountingCurve", "=", 
   RowBox[{"FlatForward", "[", "0.04", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"upfrontSettlementDays", "=", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.524996398728875*^9, 3.52499643752575*^9}, 
   3.524996639635125*^9},
 CellTags->"Constructor",
 CellLabel->"In[48]:=",
 CellID->178351157],

Cell[CellGroupData[{

Cell["\<\
obj=UpfrontCdsHelper[upfrontSpread,runningSpread,tenor,frequency,\
paymentConvention,genRule,dayCounter,recoveryRate,discountingCurve,\
upfrontSettlementDays]\
\>", "Input",
 CellChangeTimes->{{3.52499644233825*^9, 3.52499647596325*^9}, {
  3.52499660296325*^9, 3.5249966352445*^9}},
 CellTags->"Constructor",
 CellLabel->"In[62]:=",
 CellID->675699712],

Cell[BoxData["UpfrontCdsHelper19"], "Output",
 CellChangeTimes->{3.524996635807*^9},
 CellTags->"Constructor",
 CellLabel->"Out[62]=",
 CellID->51606967]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseFlatHazardRateCurve", "Subsubsection",
 CellTags->"Constructor",
 CellID->5947487],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Helpers", 
     RowBox[{"vector", " ", "of", " ", "default", " ", "probability", " ", 
      RowBox[{"helpers", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->828090767],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"ReferenceDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"term", " ", "structure", " ", "reference", " ", 
      RowBox[{"date", "."}]}]},
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]},
    {"Accuracy", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "12"}], 
     RowBox[{"Bootstrapping", " ", 
      RowBox[{"accuracy", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->231329476],

Cell[BoxData[{
 RowBox[{
  RowBox[{"recoveryRate", "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QuotedSpreads", "=", 
   RowBox[{"{", 
    RowBox[{"0.0150", ",", "0.0150", ",", "0.0150", ",", "0.0150"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tenors", " ", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<3M\>\"", ",", "\"\<6M\>\"", ",", "\"\<1Y\>\"", ",", "\"\<2Y\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"discountingCurve", "=", 
   RowBox[{"FlatForward", "[", "0.04", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.524544490703125*^9, 3.524544498*^9}, 
   3.524912352995112*^9, 3.52499048271325*^9, 3.524993392322625*^9, 
   3.524995071103875*^9, {3.5249967002445*^9, 3.524996700541375*^9}},
 CellLabel->"In[63]:=",
 CellID->633555988],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rateHelpers", " ", "=", 
  RowBox[{"MapThread", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SpreadCdsHelper", "[", 
      RowBox[{
      "#1", ",", "#2", ",", "\"\<Quarterly\>\"", ",", "\"\<Following\>\"", 
       ",", "\"\<TwentiethIMM\>\"", ",", "\"\<Actual/365 (Fixed)\>\"", ",", 
       "recoveryRate", ",", "discountingCurve", ",", 
       RowBox[{"Calendar", "\[Rule]", "\"\<Target\>\""}]}], "]"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"QuotedSpreads", ",", "Tenors"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.524544719875*^9, 3.52454475603125*^9}, {
   3.524544840796875*^9, 3.524544960765625*^9}, {3.5245451899375*^9, 
   3.524545199796875*^9}, {3.52454556278125*^9, 3.524545568*^9}, 
   3.52499048271325*^9, 3.524993394072625*^9, 3.524995071103875*^9, 
   3.5249967064945*^9},
 CellLabel->"In[67]:=",
 CellID->36434531],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "SpreadCdsHelper24", ",", "SpreadCdsHelper25", ",", "SpreadCdsHelper26", 
   ",", "SpreadCdsHelper27"}], "}"}]], "Output",
 CellChangeTimes->{{3.524996684260125*^9, 3.52499670815075*^9}},
 CellLabel->"Out[67]=",
 CellID->38074428]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
obj=PiecewiseFlatHazardRateCurve[rateHelpers]\
\>", "Input",
 CellChangeTimes->{3.524996722932*^9},
 CellTags->"Constructor",
 CellLabel->"In[68]:=",
 CellID->394301395],

Cell[BoxData["PiecewiseFlatHazardRateCurve28"], "Output",
 CellChangeTimes->{3.524995334916375*^9, 3.524996724260125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[68]=",
 CellID->3385951]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{716, 867},
WindowMargins->{{Automatic, -923}, {34, Automatic}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"LinkTrails" -> "", "SearchTextTranslated" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[579, 22, 68, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->117875620],
  Cell[650, 26, 72, 2, 23, "Text",
   CellTags->"Overview",
   CellID->6493930],
  Cell[725, 30, 114, 2, 39, "MathCaption",
   CellTags->"Overview",
   CellID->809458595],
  Cell[842, 34, 102, 3, 27, "Input",
   CellTags->"Overview",
   CellID->54295873],
  Cell[947, 39, 154, 5, 23, "Text",
   CellTags->"Overview",
   CellID->355894081],
  Cell[1762, 71, 351, 9, 27, "Input",
   CellTags->"Overview",
   CellID->4241845],
  Cell[2116, 82, 576, 13, 64, "Output",
   CellTags->"Overview",
   CellID->261933588]},
 "Constructor"->{
  Cell[2729, 100, 77, 2, 63, "Section",
   CellTags->"Constructor",
   CellID->141872723],
  Cell[2831, 106, 88, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->223591226],
  Cell[4938, 164, 470, 14, 68, "Input",
   CellTags->"Constructor",
   CellID->456832970],
  Cell[5433, 182, 206, 4, 27, "Input",
   CellTags->"Constructor",
   CellID->57438002],
  Cell[5642, 188, 178, 4, 25, "Output",
   CellTags->"Constructor",
   CellID->491659384],
  Cell[5869, 198, 88, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->661287446],
  Cell[6494, 218, 943, 26, 88, "Input",
   CellTags->"Constructor",
   CellID->815450064],
  Cell[7462, 248, 272, 7, 27, "Input",
   CellTags->"Constructor",
   CellID->2016262],
  Cell[7737, 257, 204, 5, 25, "Output",
   CellTags->"Constructor",
   CellID->1213099],
  Cell[7990, 268, 86, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->100080654],
  Cell[8770, 293, 599, 17, 48, "Input",
   CellTags->"Constructor",
   CellID->52885243],
  Cell[9394, 314, 201, 6, 27, "Input",
   CellTags->"Constructor",
   CellID->377796905],
  Cell[9598, 322, 203, 5, 25, "Output",
   CellTags->"Constructor",
   CellID->138277867],
  Cell[9850, 333, 86, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->154775505],
  Cell[12311, 404, 908, 24, 188, "Input",
   CellTags->"Constructor",
   CellID->525422655],
  Cell[13244, 432, 325, 8, 47, "Input",
   CellTags->"Constructor",
   CellID->681187604],
  Cell[13572, 442, 203, 5, 25, "Output",
   CellTags->"Constructor",
   CellID->277678551],
  Cell[13824, 453, 86, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->37314022],
  Cell[16509, 530, 957, 26, 208, "Input",
   CellTags->"Constructor",
   CellID->178351157],
  Cell[17491, 560, 363, 9, 47, "Input",
   CellTags->"Constructor",
   CellID->675699712],
  Cell[17857, 571, 153, 4, 25, "Output",
   CellTags->"Constructor",
   CellID->51606967],
  Cell[18059, 581, 97, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->5947487],
  Cell[21090, 671, 179, 6, 27, "Input",
   CellTags->"Constructor",
   CellID->394301395],
  Cell[21272, 679, 189, 4, 25, "Output",
   CellTags->"Constructor",
   CellID->3385951]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 22529, 719},
 {"Constructor", 23146, 741}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 68, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->117875620],
Cell[650, 26, 72, 2, 23, "Text",
 CellTags->"Overview",
 CellID->6493930],
Cell[725, 30, 114, 2, 39, "MathCaption",
 CellTags->"Overview",
 CellID->809458595],
Cell[842, 34, 102, 3, 27, "Input",
 CellTags->"Overview",
 CellID->54295873],
Cell[947, 39, 154, 5, 23, "Text",
 CellTags->"Overview",
 CellID->355894081],
Cell[CellGroupData[{
Cell[1126, 48, 266, 8, 27, "Input",
 CellID->556390066],
Cell[1395, 58, 330, 8, 45, "Output",
 CellID->551540789]
}, Open  ]],
Cell[CellGroupData[{
Cell[1762, 71, 351, 9, 27, "Input",
 CellTags->"Overview",
 CellID->4241845],
Cell[2116, 82, 576, 13, 64, "Output",
 CellTags->"Overview",
 CellID->261933588]
}, Open  ]],
Cell[CellGroupData[{
Cell[2729, 100, 77, 2, 63, "Section",
 CellTags->"Constructor",
 CellID->141872723],
Cell[CellGroupData[{
Cell[2831, 106, 88, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->223591226],
Cell[2922, 110, 578, 14, 99, "Text",
 CellID->444861851],
Cell[3503, 126, 1432, 36, 257, "Text",
 CellID->349879365],
Cell[4938, 164, 470, 14, 68, "Input",
 CellTags->"Constructor",
 CellID->456832970],
Cell[CellGroupData[{
Cell[5433, 182, 206, 4, 27, "Input",
 CellTags->"Constructor",
 CellID->57438002],
Cell[5642, 188, 178, 4, 25, "Output",
 CellTags->"Constructor",
 CellID->491659384]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5869, 198, 88, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->661287446],
Cell[5960, 202, 531, 14, 99, "Text",
 CellID->232579951],
Cell[6494, 218, 943, 26, 88, "Input",
 CellTags->"Constructor",
 CellID->815450064],
Cell[CellGroupData[{
Cell[7462, 248, 272, 7, 27, "Input",
 CellTags->"Constructor",
 CellID->2016262],
Cell[7737, 257, 204, 5, 25, "Output",
 CellTags->"Constructor",
 CellID->1213099]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7990, 268, 86, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->100080654],
Cell[8079, 272, 409, 11, 80, "Text",
 CellID->36719777],
Cell[8491, 285, 276, 6, 87, "Text",
 CellID->815054969],
Cell[8770, 293, 599, 17, 48, "Input",
 CellTags->"Constructor",
 CellID->52885243],
Cell[CellGroupData[{
Cell[9394, 314, 201, 6, 27, "Input",
 CellTags->"Constructor",
 CellID->377796905],
Cell[9598, 322, 203, 5, 25, "Output",
 CellTags->"Constructor",
 CellID->138277867]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9850, 333, 86, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->154775505],
Cell[9939, 337, 1853, 51, 288, "Text",
 CellID->727056345],
Cell[11795, 390, 513, 12, 99, "Text",
 CellID->285728904],
Cell[12311, 404, 908, 24, 188, "Input",
 CellTags->"Constructor",
 CellID->525422655],
Cell[CellGroupData[{
Cell[13244, 432, 325, 8, 47, "Input",
 CellTags->"Constructor",
 CellID->681187604],
Cell[13572, 442, 203, 5, 25, "Output",
 CellTags->"Constructor",
 CellID->277678551]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13824, 453, 86, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->37314022],
Cell[13913, 457, 2078, 57, 322, "Text",
 CellID->257929087],
Cell[15994, 516, 512, 12, 99, "Text",
 CellID->72374145],
Cell[16509, 530, 957, 26, 208, "Input",
 CellTags->"Constructor",
 CellID->178351157],
Cell[CellGroupData[{
Cell[17491, 560, 363, 9, 47, "Input",
 CellTags->"Constructor",
 CellID->675699712],
Cell[17857, 571, 153, 4, 25, "Output",
 CellTags->"Constructor",
 CellID->51606967]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18059, 581, 97, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->5947487],
Cell[18159, 585, 294, 7, 64, "Text",
 CellID->828090767],
Cell[18456, 594, 626, 17, 124, "Text",
 CellID->231329476],
Cell[19085, 613, 798, 21, 88, "Input",
 CellID->633555988],
Cell[CellGroupData[{
Cell[19908, 638, 870, 19, 88, "Input",
 CellID->36434531],
Cell[20781, 659, 272, 7, 25, "Output",
 CellID->38074428]
}, Open  ]],
Cell[CellGroupData[{
Cell[21090, 671, 179, 6, 27, "Input",
 CellTags->"Constructor",
 CellID->394301395],
Cell[21272, 679, 189, 4, 25, "Output",
 CellTags->"Constructor",
 CellID->3385951]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
