(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     28466,       1048]
NotebookOptionsPosition[     16425,        607]
NotebookOutlinePosition[     22612,        818]
CellTagsIndexPosition[     22458,        810]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Ctsmmcapletcalibration", "Chapter",
 CellTags->"Overview",
 CellID->2878252],

Cell["\<\
functions to construct and use ctsmmcapletcalibration objects.\
\>", "Text",
 CellTags->"Overview",
 CellID->454967570],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->326053822],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->760079725],

Cell["\<\
Within the Ctsmmcapletcalibration part there are several constructors and \
member functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->183348807],

Cell[CellGroupData[{

Cell["Select[Category[Ctsmmcapletcalibration],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->200739695],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CTSMMCapletAlphaFormCalibration", ",", 
   "CTSMMCapletMaxHomogeneityCalibration", ",", 
   "CTSMMCapletOriginalCalibration"}], "}"}]], "Output",
 CellChangeTimes->{3.436162896546875*^9},
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->684346350]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Ctsmmcapletcalibration],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->127307520],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CTSMMCapletAlphaFormCalibrationAlpha", ",", 
   "CTSMMCapletCalibrationCalibrate", ",", 
   "CTSMMCapletCalibrationCapletMaxError", ",", 
   "CTSMMCapletCalibrationCapletRmsError", ",", 
   "CTSMMCapletCalibrationDeformationSize", ",", 
   "CTSMMCapletCalibrationFailures", ",", 
   "CTSMMCapletCalibrationMarketCapletVols", ",", 
   "CTSMMCapletCalibrationMarketSwaptionVols", ",", 
   "CTSMMCapletCalibrationModelCapletVols", ",", 
   "CTSMMCapletCalibrationModelSwaptionVols", ",", 
   "CTSMMCapletCalibrationSwapPseudoRoot", ",", 
   "CTSMMCapletCalibrationSwaptionMaxError", ",", 
   "CTSMMCapletCalibrationSwaptionRmsError", ",", 
   "CTSMMCapletCalibrationTimeDependentCalibratedSwaptionVols", ",", 
   "CTSMMCapletCalibrationTimeDependentUnCalibratedSwaptionVols"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4361628974375*^9},
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->58275666]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor",
 CellID->493175575],

Cell[CellGroupData[{

Cell["CTSMMCapletOriginalCalibration", "Subsubsection",
 CellTags->"Constructor",
 CellID->180723736],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Evolution", 
     RowBox[{"Evolution", " ", 
      RowBox[{"Description", "."}]}]},
    {"Correlations", 
     RowBox[{"PiecewiseConstantCorrelation", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"SwapPiecewiseConstantVariances", 
     RowBox[{"PiecewiseConstantVariance", " ", 
      RowBox[{"IDs", "."}]}]},
    {"CapletVols", 
     RowBox[{"caplet", " ", 
      RowBox[{"volatilities", "."}]}]},
    {"CurveState", 
     RowBox[{"CurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Alphas", 
     RowBox[{"alphas", "."}]},
    {"UseFullApprox", 
     RowBox[{"TRUE", " ", "for", " ", "using", " ", "Full", " ", 
      RowBox[{"Approximation", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->666948570],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Displacement", "0.0", 
     RowBox[{"displacement", "."}]},
    {"LowestRoot", "true", 
     RowBox[{
      RowBox[{"TRUE", " ", "for", " ", "lowest", " ", "root"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "for", " ", "the", " ", "root", " ", "nearest", " ", "to",
        " ", 
       RowBox[{"1.0", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->257523824],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Evolution", "=", "EvolutionDescriptionID"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Correlations", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SwapPiecewiseConstantVariances", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CapletVols", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", 
     "0.1", ",", "0.1", ",", "0.1", ",", "0.1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CurveState", "=", "CurveStateID"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Alphas", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.01", ",", "0.01", ",", "0.01", ",", "0.01", ",", "0.01", ",", "0.01", 
     ",", "0.01", ",", "0.01", ",", "0.01", ",", "0.01"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"UseFullApprox", "=", "TRUE"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->59445951],

Cell["\<\
obj=CTSMMCapletOriginalCalibration[Evolution,Correlations,\
SwapPiecewiseConstantVariances,CapletVols,CurveState,Alphas,UseFullApprox]\
\>", "Input",
 CellTags->"Constructor",
 CellID->21431805]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletAlphaFormCalibration", "Subsubsection",
 CellTags->"Constructor",
 CellID->19785173],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Evolution", 
     RowBox[{"Evolution", " ", 
      RowBox[{"Description", "."}]}]},
    {"Correlations", 
     RowBox[{"PiecewiseConstantCorrelation", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"SwapPiecewiseConstantVariances", 
     RowBox[{"PiecewiseConstantVariance", " ", 
      RowBox[{"IDs", "."}]}]},
    {"CapletVols", 
     RowBox[{"caplet", " ", 
      RowBox[{"volatilities", "."}]}]},
    {"CurveState", 
     RowBox[{"CurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AlphaInitial", 
     RowBox[{"alphaInitial", "."}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->193659434],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Displacement", "0.0", 
     RowBox[{"displacement", "."}]},
    {"AlphaMax", 
     RowBox[{
     "1.0", ",", "1.0", ",", "1.0", ",", "1.0", ",", "1.0", ",", "1.0", ",", 
      "1.0", ",", "1.0", ",", "1.0", ",", "1.0"}], 
     RowBox[{"alphaMax", "."}]},
    {"AlphaMin", 
     RowBox[{
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}], ",", 
      RowBox[{"-", "1.0"}]}], 
     RowBox[{"alphaMin", "."}]},
    {"MaximizeHomogeneity", "true", 
     RowBox[{"TRUE", " ", "for", " ", "maximizing", " ", 
      RowBox[{"homogeneity", "."}]}]},
    {"AlphaForm", "\"\<\>\"", 
     RowBox[{"alpha", " ", "form", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->447940245],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Evolution", "=", "EvolutionDescriptionID"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Correlations", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SwapPiecewiseConstantVariances", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CapletVols", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", 
     "0.1", ",", "0.1", ",", "0.1", ",", "0.1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CurveState", "=", "CurveStateID"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AlphaInitial", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.01", ",", "0.01", ",", "0.01", ",", "0.01", ",", "0.01", ",", "0.01", 
     ",", "0.01", ",", "0.01", ",", "0.01", ",", "0.01"}], "}"}]}], 
  ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->358860572],

Cell["\<\
obj=CTSMMCapletAlphaFormCalibration[Evolution,Correlations,\
SwapPiecewiseConstantVariances,CapletVols,CurveState,AlphaInitial]\
\>", "Input",
 CellTags->"Constructor",
 CellID->296875812]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletMaxHomogeneityCalibration", "Subsubsection",
 CellTags->"Constructor",
 CellID->162619346],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Evolution", 
     RowBox[{"Evolution", " ", 
      RowBox[{"Description", "."}]}]},
    {"Correlations", 
     RowBox[{"PiecewiseConstantCorrelation", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"SwapPiecewiseConstantVariances", 
     RowBox[{"PiecewiseConstantVariance", " ", 
      RowBox[{"IDs", "."}]}]},
    {"CapletVols", 
     RowBox[{"caplet", " ", 
      RowBox[{"volatilities", "."}]}]},
    {"CurveState", 
     RowBox[{"CurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->628241479],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Displacement", "0.0", 
     RowBox[{"displacement", "."}]},
    {"Caplet0Swaption1Priority", "1.0", 
     RowBox[{"caplet0Swaption1Priority", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->115082708],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Evolution", "=", "EvolutionDescriptionID"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Correlations", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SwapPiecewiseConstantVariances", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CapletVols", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", 
     "0.1", ",", "0.1", ",", "0.1", ",", "0.1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CurveState", "=", "CurveStateID"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->732981566],

Cell["\<\
obj=CTSMMCapletMaxHomogeneityCalibration[Evolution,Correlations,\
SwapPiecewiseConstantVariances,CapletVols,CurveState]\
\>", "Input",
 CellTags->"Constructor",
 CellID->474589339]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->237742736],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationCalibrate", "Subsubsection",
 CellTags->"Member",
 CellID->12719433],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"NumberOfFactors", 
     RowBox[{"number", " ", "of", " ", 
      RowBox[{"factors", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->240375490],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"MaxIter", "2", 
     RowBox[{"maximum", " ", "number", " ", "of", " ", 
      RowBox[{"iterations", "."}]}]},
    {"Tol", "0.0001", 
     RowBox[{"caplet", " ", "vol", " ", 
      RowBox[{"tolerance", "."}]}]},
    {"InnerMaxIter", "100", 
     RowBox[{"innerMaxIter", "."}]},
    {"InnerTol", 
     RowBox[{
      RowBox[{"1", "e"}], "-", "8"}], 
     RowBox[{"caplet", " ", "vol", " ", 
      RowBox[{"tolerance", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->49186221],

Cell[BoxData[
 RowBox[{
  RowBox[{"NumberOfFactors", "=", "3"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->201835914],

Cell["CTSMMCapletCalibrationCalibrate[obj,NumberOfFactors]", "Input",
 CellTags->"Member",
 CellID->502536334]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationFailures", "Subsubsection",
 CellTags->"Member",
 CellID->1202835],

Cell["CTSMMCapletCalibrationFailures[obj]", "Input",
 CellTags->"Member",
 CellID->366827718]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationDeformationSize", "Subsubsection",
 CellTags->"Member",
 CellID->327736330],

Cell["CTSMMCapletCalibrationDeformationSize[obj]", "Input",
 CellTags->"Member",
 CellID->51348107]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationMarketCapletVols", "Subsubsection",
 CellTags->"Member",
 CellID->49893903],

Cell["CTSMMCapletCalibrationMarketCapletVols[obj]", "Input",
 CellTags->"Member",
 CellID->110519050]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationModelCapletVols", "Subsubsection",
 CellTags->"Member",
 CellID->335128386],

Cell["CTSMMCapletCalibrationModelCapletVols[obj]", "Input",
 CellTags->"Member",
 CellID->19960370]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationCapletRmsError", "Subsubsection",
 CellTags->"Member",
 CellID->993941010],

Cell["CTSMMCapletCalibrationCapletRmsError[obj]", "Input",
 CellTags->"Member",
 CellID->630007097]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationCapletMaxError", "Subsubsection",
 CellTags->"Member",
 CellID->650092674],

Cell["CTSMMCapletCalibrationCapletMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->208279599]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationMarketSwaptionVols", "Subsubsection",
 CellTags->"Member",
 CellID->471758203],

Cell["CTSMMCapletCalibrationMarketSwaptionVols[obj]", "Input",
 CellTags->"Member",
 CellID->279016816]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationModelSwaptionVols", "Subsubsection",
 CellTags->"Member",
 CellID->313397350],

Cell["CTSMMCapletCalibrationModelSwaptionVols[obj]", "Input",
 CellTags->"Member",
 CellID->171427347]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationSwaptionRmsError", "Subsubsection",
 CellTags->"Member",
 CellID->186683777],

Cell["CTSMMCapletCalibrationSwaptionRmsError[obj]", "Input",
 CellTags->"Member",
 CellID->267630234]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationSwaptionMaxError", "Subsubsection",
 CellTags->"Member",
 CellID->70485143],

Cell["CTSMMCapletCalibrationSwaptionMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->441420245]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationSwapPseudoRoot", "Subsubsection",
 CellTags->"Member",
 CellID->413397785],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Index", 
     RowBox[{"index", "."}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->262616098],

Cell[BoxData[
 RowBox[{
  RowBox[{"Index", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->216298691],

Cell["CTSMMCapletCalibrationSwapPseudoRoot[obj,Index]", "Input",
 CellTags->"Member",
 CellID->890798670]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationTimeDependentCalibratedSwaptionVols", \
"Subsubsection",
 CellTags->"Member",
 CellID->8310805],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Index", 
     RowBox[{"index", "."}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->77487699],

Cell[BoxData[
 RowBox[{
  RowBox[{"Index", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->114195704],

Cell["\<\
CTSMMCapletCalibrationTimeDependentCalibratedSwaptionVols[obj,Index]\
\>", "Input",
 CellTags->"Member",
 CellID->185626642]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletCalibrationTimeDependentUnCalibratedSwaptionVols", \
"Subsubsection",
 CellTags->"Member",
 CellID->172006823],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Index", 
     RowBox[{"index", "."}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->146809347],

Cell[BoxData[
 RowBox[{
  RowBox[{"Index", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->287234947],

Cell["\<\
CTSMMCapletCalibrationTimeDependentUnCalibratedSwaptionVols[obj,Index]\
\>", "Input",
 CellTags->"Member",
 CellID->10627216]
}, Open  ]],

Cell[CellGroupData[{

Cell["CTSMMCapletAlphaFormCalibrationAlpha", "Subsubsection",
 CellTags->"Member",
 CellID->244456539],

Cell["CTSMMCapletAlphaFormCalibrationAlpha[obj]", "Input",
 CellTags->"Member",
 CellID->378021480]
}, Open  ]]
}, Open  ]],

Cell["Procedures", "Section",
 CellTags->"Procedure",
 CellID->128502860]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{200, Automatic}, {Automatic, 101}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 82, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->2878252],
  Cell[675, 27, 129, 4, 37, "Text",
   CellTags->"Overview",
   CellID->454967570],
  Cell[807, 33, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->326053822],
  Cell[924, 37, 103, 3, 41, "Input",
   CellTags->"Overview",
   CellID->760079725],
  Cell[1030, 42, 170, 5, 37, "Text",
   CellTags->"Overview",
   CellID->183348807],
  Cell[1225, 51, 141, 3, 41, "Input",
   CellTags->"Overview",
   CellID->200739695],
  Cell[1369, 56, 296, 9, 59, "Output",
   CellTags->"Overview",
   CellID->684346350],
  Cell[1702, 70, 136, 3, 41, "Input",
   CellTags->"Overview",
   CellID->127307520],
  Cell[1841, 75, 943, 22, 268, "Output",
   CellTags->"Overview",
   CellID->58275666]},
 "Constructor"->{
  Cell[2821, 102, 77, 2, 77, "Section",
   CellTags->"Constructor",
   CellID->493175575],
  Cell[2923, 108, 101, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->180723736],
  Cell[4382, 153, 917, 26, 70, "Input",
   CellTags->"Constructor",
   CellID->59445951],
  Cell[5302, 181, 204, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->21431805],
  Cell[5543, 191, 101, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->19785173],
  Cell[7458, 250, 858, 24, 70, "Input",
   CellTags->"Constructor",
   CellID->358860572],
  Cell[8319, 276, 198, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->296875812],
  Cell[8554, 286, 107, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->162619346],
  Cell[9673, 321, 623, 17, 70, "Input",
   CellTags->"Constructor",
   CellID->732981566],
  Cell[10299, 340, 190, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->474589339]},
 "Member"->{
  Cell[10538, 351, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->237742736],
  Cell[10638, 357, 96, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->12719433],
  Cell[11594, 388, 122, 4, 70, "Input",
   CellTags->"Member",
   CellID->201835914],
  Cell[11719, 394, 110, 2, 70, "Input",
   CellTags->"Member",
   CellID->502536334],
  Cell[11866, 401, 94, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->1202835],
  Cell[11963, 405, 93, 2, 70, "Input",
   CellTags->"Member",
   CellID->366827718],
  Cell[12093, 412, 103, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->327736330],
  Cell[12199, 416, 99, 2, 70, "Input",
   CellTags->"Member",
   CellID->51348107],
  Cell[12335, 423, 103, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->49893903],
  Cell[12441, 427, 101, 2, 70, "Input",
   CellTags->"Member",
   CellID->110519050],
  Cell[12579, 434, 103, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->335128386],
  Cell[12685, 438, 99, 2, 70, "Input",
   CellTags->"Member",
   CellID->19960370],
  Cell[12821, 445, 102, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->993941010],
  Cell[12926, 449, 99, 2, 70, "Input",
   CellTags->"Member",
   CellID->630007097],
  Cell[13062, 456, 102, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->650092674],
  Cell[13167, 460, 99, 2, 70, "Input",
   CellTags->"Member",
   CellID->208279599],
  Cell[13303, 467, 106, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->471758203],
  Cell[13412, 471, 103, 2, 70, "Input",
   CellTags->"Member",
   CellID->279016816],
  Cell[13552, 478, 105, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->313397350],
  Cell[13660, 482, 102, 2, 28, "Input",
   CellTags->"Member",
   CellID->171427347],
  Cell[13799, 489, 104, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->186683777],
  Cell[13906, 493, 101, 2, 28, "Input",
   CellTags->"Member",
   CellID->267630234],
  Cell[14044, 500, 103, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->70485143],
  Cell[14150, 504, 101, 2, 28, "Input",
   CellTags->"Member",
   CellID->441420245],
  Cell[14288, 511, 102, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->413397785],
  Cell[14602, 523, 112, 4, 28, "Input",
   CellTags->"Member",
   CellID->216298691],
  Cell[14717, 529, 105, 2, 28, "Input",
   CellTags->"Member",
   CellID->890798670],
  Cell[14859, 536, 123, 3, 30, "Subsubsection",
   CellTags->"Member",
   CellID->8310805],
  Cell[15193, 549, 112, 4, 28, "Input",
   CellTags->"Member",
   CellID->114195704],
  Cell[15308, 555, 134, 4, 28, "Input",
   CellTags->"Member",
   CellID->185626642],
  Cell[15479, 564, 127, 3, 30, "Subsubsection",
   CellTags->"Member",
   CellID->172006823],
  Cell[15818, 577, 112, 4, 28, "Input",
   CellTags->"Member",
   CellID->287234947],
  Cell[15933, 583, 135, 4, 28, "Input",
   CellTags->"Member",
   CellID->10627216],
  Cell[16105, 592, 102, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->244456539],
  Cell[16210, 596, 99, 2, 28, "Input",
   CellTags->"Member",
   CellID->378021480]},
 "Procedure"->{
  Cell[16336, 602, 73, 2, 51, "Section",
   CellTags->"Procedure",
   CellID->128502860]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 17479, 638},
 {"Constructor", 18274, 666},
 {"Member", 19214, 697},
 {"Procedure", 22344, 803}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 82, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->2878252],
Cell[675, 27, 129, 4, 37, "Text",
 CellTags->"Overview",
 CellID->454967570],
Cell[807, 33, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->326053822],
Cell[924, 37, 103, 3, 41, "Input",
 CellTags->"Overview",
 CellID->760079725],
Cell[1030, 42, 170, 5, 37, "Text",
 CellTags->"Overview",
 CellID->183348807],
Cell[CellGroupData[{
Cell[1225, 51, 141, 3, 41, "Input",
 CellTags->"Overview",
 CellID->200739695],
Cell[1369, 56, 296, 9, 59, "Output",
 CellTags->"Overview",
 CellID->684346350]
}, Open  ]],
Cell[CellGroupData[{
Cell[1702, 70, 136, 3, 41, "Input",
 CellTags->"Overview",
 CellID->127307520],
Cell[1841, 75, 943, 22, 268, "Output",
 CellTags->"Overview",
 CellID->58275666]
}, Open  ]],
Cell[CellGroupData[{
Cell[2821, 102, 77, 2, 77, "Section",
 CellTags->"Constructor",
 CellID->493175575],
Cell[CellGroupData[{
Cell[2923, 108, 101, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->180723736],
Cell[3027, 112, 858, 24, 70, "Input",
 CellID->666948570],
Cell[3888, 138, 491, 13, 70, "Input",
 CellID->257523824],
Cell[4382, 153, 917, 26, 70, "Input",
 CellTags->"Constructor",
 CellID->59445951],
Cell[5302, 181, 204, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->21431805]
}, Open  ]],
Cell[CellGroupData[{
Cell[5543, 191, 101, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->19785173],
Cell[5647, 195, 740, 21, 70, "Input",
 CellID->193659434],
Cell[6390, 218, 1065, 30, 70, "Input",
 CellID->447940245],
Cell[7458, 250, 858, 24, 70, "Input",
 CellTags->"Constructor",
 CellID->358860572],
Cell[8319, 276, 198, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->296875812]
}, Open  ]],
Cell[CellGroupData[{
Cell[8554, 286, 107, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->162619346],
Cell[8664, 290, 681, 19, 70, "Input",
 CellID->628241479],
Cell[9348, 311, 322, 8, 70, "Input",
 CellID->115082708],
Cell[9673, 321, 623, 17, 70, "Input",
 CellTags->"Constructor",
 CellID->732981566],
Cell[10299, 340, 190, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->474589339]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10538, 351, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->237742736],
Cell[CellGroupData[{
Cell[10638, 357, 96, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->12719433],
Cell[10737, 361, 261, 7, 70, "Input",
 CellID->240375490],
Cell[11001, 370, 590, 16, 70, "Input",
 CellID->49186221],
Cell[11594, 388, 122, 4, 70, "Input",
 CellTags->"Member",
 CellID->201835914],
Cell[11719, 394, 110, 2, 70, "Input",
 CellTags->"Member",
 CellID->502536334]
}, Open  ]],
Cell[CellGroupData[{
Cell[11866, 401, 94, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->1202835],
Cell[11963, 405, 93, 2, 70, "Input",
 CellTags->"Member",
 CellID->366827718]
}, Open  ]],
Cell[CellGroupData[{
Cell[12093, 412, 103, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->327736330],
Cell[12199, 416, 99, 2, 70, "Input",
 CellTags->"Member",
 CellID->51348107]
}, Open  ]],
Cell[CellGroupData[{
Cell[12335, 423, 103, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->49893903],
Cell[12441, 427, 101, 2, 70, "Input",
 CellTags->"Member",
 CellID->110519050]
}, Open  ]],
Cell[CellGroupData[{
Cell[12579, 434, 103, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->335128386],
Cell[12685, 438, 99, 2, 70, "Input",
 CellTags->"Member",
 CellID->19960370]
}, Open  ]],
Cell[CellGroupData[{
Cell[12821, 445, 102, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->993941010],
Cell[12926, 449, 99, 2, 70, "Input",
 CellTags->"Member",
 CellID->630007097]
}, Open  ]],
Cell[CellGroupData[{
Cell[13062, 456, 102, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->650092674],
Cell[13167, 460, 99, 2, 70, "Input",
 CellTags->"Member",
 CellID->208279599]
}, Open  ]],
Cell[CellGroupData[{
Cell[13303, 467, 106, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->471758203],
Cell[13412, 471, 103, 2, 70, "Input",
 CellTags->"Member",
 CellID->279016816]
}, Open  ]],
Cell[CellGroupData[{
Cell[13552, 478, 105, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->313397350],
Cell[13660, 482, 102, 2, 28, "Input",
 CellTags->"Member",
 CellID->171427347]
}, Open  ]],
Cell[CellGroupData[{
Cell[13799, 489, 104, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->186683777],
Cell[13906, 493, 101, 2, 28, "Input",
 CellTags->"Member",
 CellID->267630234]
}, Open  ]],
Cell[CellGroupData[{
Cell[14044, 500, 103, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->70485143],
Cell[14150, 504, 101, 2, 28, "Input",
 CellTags->"Member",
 CellID->441420245]
}, Open  ]],
Cell[CellGroupData[{
Cell[14288, 511, 102, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->413397785],
Cell[14393, 515, 206, 6, 65, "Input",
 CellID->262616098],
Cell[14602, 523, 112, 4, 28, "Input",
 CellTags->"Member",
 CellID->216298691],
Cell[14717, 529, 105, 2, 28, "Input",
 CellTags->"Member",
 CellID->890798670]
}, Open  ]],
Cell[CellGroupData[{
Cell[14859, 536, 123, 3, 30, "Subsubsection",
 CellTags->"Member",
 CellID->8310805],
Cell[14985, 541, 205, 6, 65, "Input",
 CellID->77487699],
Cell[15193, 549, 112, 4, 28, "Input",
 CellTags->"Member",
 CellID->114195704],
Cell[15308, 555, 134, 4, 28, "Input",
 CellTags->"Member",
 CellID->185626642]
}, Open  ]],
Cell[CellGroupData[{
Cell[15479, 564, 127, 3, 30, "Subsubsection",
 CellTags->"Member",
 CellID->172006823],
Cell[15609, 569, 206, 6, 65, "Input",
 CellID->146809347],
Cell[15818, 577, 112, 4, 28, "Input",
 CellTags->"Member",
 CellID->287234947],
Cell[15933, 583, 135, 4, 28, "Input",
 CellTags->"Member",
 CellID->10627216]
}, Open  ]],
Cell[CellGroupData[{
Cell[16105, 592, 102, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->244456539],
Cell[16210, 596, 99, 2, 28, "Input",
 CellTags->"Member",
 CellID->378021480]
}, Open  ]]
}, Open  ]],
Cell[16336, 602, 73, 2, 51, "Section",
 CellTags->"Procedure",
 CellID->128502860]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
