(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     18749,        663]
NotebookOptionsPosition[     11638,        400]
NotebookOutlinePosition[     15496,        532]
CellTagsIndexPosition[     15296,        523]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["DefaultTermStructures", "Chapter",
 CellTags->"Overview",
 CellID->237035917],

Cell["\<\
functions to construct and use DefaultProbabilityTermStructure objects.\
\>", "Text",
 CellTags->"Overview",
 CellID->612809703],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->221034052],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->543634195],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Category", "[", "DefaultProbabilityTermStructures", "]"}]], "Input",
 CellChangeTimes->{3.435903019052853*^9, 3.52454735334375*^9},
 CellTags->"Bonds Overview",
 CellLabel->"In[2]:=",
 CellID->510695],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "DefaultTSDefaultProbability", ",", "DefaultTSSurvivalProbability", ",", 
   "DefaultTSDefaultDensity", ",", "FlatHazardRate", ",", 
   "RelinkableHandleDefaultProbabilityTermStructure"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5245473546875*^9, 3.524547996921875*^9, 3.52454828984375*^9, {
   3.524548569375*^9, 3.524548593921875*^9}, 3.52454866240625*^9, 
   3.52454880103125*^9, 3.52481713575*^9},
 CellTags->"Bonds Overview",
 CellLabel->"Out[2]=",
 CellID->836850940]
}, Open  ]],

Cell["There are several functions available to construct bonds", "Text",
 CellChangeTimes->{{3.435652644703125*^9, 3.435652663703125*^9}},
 CellTags->"Bonds Overview",
 CellID->38547467],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "DefaultProbabilityTermStructures", "]"}], ",", 
   RowBox[{
    RowBox[{"QLConstructor", "[", "#", "]"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.435652296953125*^9, 3.43565233153125*^9}, {
   3.435652380375*^9, 3.4356523806875*^9}, {3.43565263409375*^9, 
   3.435652636078125*^9}, 3.5245473620625*^9},
 CellTags->"Bonds Overview",
 CellLabel->"In[3]:=",
 CellID->67846344],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "FlatHazardRate", ",", "RelinkableHandleDefaultProbabilityTermStructure"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.524547363796875*^9, 3.52454799875*^9, 3.524548289953125*^9, {
   3.52454856940625*^9, 3.52454859396875*^9}, 3.524548662453125*^9, 
   3.524548801140625*^9, 3.524817143140625*^9},
 CellTags->"Bonds Overview",
 CellLabel->"Out[3]=",
 CellID->671783662]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "DefaultProbabilityTermStructures", "]"}], ",", 
   RowBox[{
    RowBox[{"QLMember", "[", "#", "]"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{3.52454736684375*^9},
 CellLabel->"In[4]:=",
 CellID->314610079],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "DefaultTSDefaultProbability", ",", "DefaultTSSurvivalProbability", ",", 
   "DefaultTSDefaultDensity"}], "}"}]], "Output",
 CellChangeTimes->{
  3.524547368046875*^9, 3.524547999546875*^9, 3.52454829*^9, {
   3.5245485694375*^9, 3.524548594015625*^9}, 3.524548662484375*^9, 
   3.5245488011875*^9, 3.524817144703125*^9},
 CellLabel->"Out[4]=",
 CellID->134747294]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor",
 CellID->342467181],

Cell[CellGroupData[{

Cell["RelinkableHandleDefaultProbabilityTermStructure", "Subsubsection",
 CellTags->"Constructor",
 CellID->603872752],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurrentLink", "\<\"\"\>", 
     RowBox[{
      RowBox[{"DefaultProbabilityTermStructure", " ", "object", " ", 
       RowBox[{"ID", ".", " ", "If"}], " ", "omitted"}], ",", " ", 
      RowBox[{"nothing", " ", "is", " ", "linked", " ", "by", " ", "the", " ", 
       RowBox[{"RelinkableHandle", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->557908359],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.524548029109375*^9, 3.524548029125*^9}},
 CellLabel->"In[5]:=",
 CellID->271450837],

Cell[CellGroupData[{

Cell["obj=RelinkableHandleDefaultProbabilityTermStructure[]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[6]:=",
 CellID->365083110],

Cell[BoxData["RelinkableHandleDefaultProbabilityTermStructure3"], "Output",
 CellChangeTimes->{{3.52454800825*^9, 3.524548030703125*^9}, 
   3.524548290046875*^9, {3.524548569484375*^9, 3.52454859409375*^9}, 
   3.524548662765625*^9, 3.524548801453125*^9, 3.52481715209375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[6]=",
 CellID->625797304]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FlatHazardRate", "Subsubsection",
 CellTags->"Constructor",
 CellID->335343139],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Rate", 
     RowBox[{"the", " ", "curve", " ", 
      RowBox[{"level", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text",
 CellID->34334516],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"NDays", "0", 
     RowBox[{
      RowBox[{
       RowBox[{
       "number", " ", "of", " ", "days", " ", "to", " ", "advance", " ", 
        "from", " ", "EvaluationDate", " ", 
        RowBox[{"(", 
         RowBox[{"usually", " ", "zero", " ", "or", " ", "two"}], ")"}]}], 
       ":", " ", 
       RowBox[{
       "it", " ", "fixes", " ", "the", " ", "date", " ", "at", " ", "which", 
        " ", "the", " ", "discount", " ", "factor"}]}], " ", "=", " ", 
      RowBox[{"1.0", "."}]}]},
    {"Calendar", "\<\"NullCalendar\"\>", 
     RowBox[{"holiday", " ", "calendar", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], " ", "to", " ", 
      "advance", " ", "from", " ", "global", " ", 
      RowBox[{"EvaluationDate", "."}]}]},
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->334955400],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rate", "=", "0.01"}], ";"}]], "Input",
 CellChangeTimes->{{3.524547404828125*^9, 3.5245474055*^9}},
 CellTags->"Constructor",
 CellLabel->"In[7]:=",
 CellID->294924434],

Cell[CellGroupData[{

Cell["obj=FlatHazardRate[Rate]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[8]:=",
 CellID->550157968],

Cell[BoxData["FlatHazardRate4"], "Output",
 CellChangeTimes->{
  3.52454740725*^9, {3.524548054140625*^9, 3.524548059734375*^9}, 
   3.524548290265625*^9, {3.52454856953125*^9, 3.524548594140625*^9}, 
   3.5245486628125*^9, 3.5245488015*^9, 3.524817158*^9},
 CellTags->"Constructor",
 CellLabel->"Out[8]=",
 CellID->203085872]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->224242434],

Cell[CellGroupData[{

Cell["DefaultTSDefaultProbability", "Subsubsection",
 CellTags->"Member",
 CellID->21571979],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Dates", 
     RowBox[{"vector", " ", "of", " ", 
      RowBox[{"dates", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text",
 CellID->37145109],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "false", 
     RowBox[{"TRUE", " ", "allows", " ", 
      RowBox[{"extrapolation", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellID->411977635],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dates", "=", 
  RowBox[{"CalendarAdvance", "[", 
   RowBox[{
    RowBox[{"EvaluationDate", "[", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<1Y\>\"", ",", "\"\<2Y\>\"", ",", "\"\<3Y\>\"", ",", "\"\<4Y\>\"", 
      ",", "\"\<5Y\>\""}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52454742809375*^9, 3.524547438953125*^9}, {
   3.524548329265625*^9, 3.5245483488125*^9}, 3.524548612203125*^9, {
   3.524548823890625*^9, 3.52454883003125*^9}, {3.524817163125*^9, 
   3.524817163421875*^9}},
 CellTags->"Member",
 CellLabel->"In[9]:=",
 CellID->170507264],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2012", ",", "9", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "9", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2014", ",", "9", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "9", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2016", ",", "9", ",", "12"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5245483384375*^9, 3.5245483499375*^9}, {
   3.524548569578125*^9, 3.524548613484375*^9}, 3.52454866284375*^9, 
   3.52454880153125*^9, 3.524817164109375*^9},
 CellTags->"Member",
 CellLabel->"Out[9]=",
 CellID->462835981]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DefaultTSDefaultProbability[obj,dates]\
\>", "Input",
 CellChangeTimes->{{3.524817167765625*^9, 3.524817168015625*^9}},
 CellTags->"Member",
 CellLabel->"In[10]:=",
 CellID->354222954],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.009977290532244165`", ",", "0.019828181083547447`", ",", 
   "0.029581053636146493`", ",", "0.03928952659746332`", ",", 
   "0.04882269623155433`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5245474510625*^9, 3.524548290359375*^9, 3.52454835221875*^9, {
   3.524548569625*^9, 3.524548594453125*^9}, 3.5245486629375*^9, 
   3.5245488015625*^9, 3.52481716875*^9},
 CellTags->"Member",
 CellLabel->"Out[10]=",
 CellID->804031799]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DefaultTSSurvivalProbability[obj,dates]\
\>", "Input",
 CellChangeTimes->{{3.524817167765625*^9, 3.524817177625*^9}},
 CellTags->"Member",
 CellLabel->"In[11]:=",
 CellID->711696626],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9900227094677558`", ",", "0.9801718189164526`", ",", 
   "0.9704189463638535`", ",", "0.9607104734025367`", ",", 
   "0.9511773037684457`"}], "}"}]], "Output",
 CellChangeTimes->{3.5248171785625*^9},
 CellTags->"Member",
 CellLabel->"Out[11]=",
 CellID->38375496]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DefaultTSDefaultDensity[obj,dates]\
\>", "Input",
 CellChangeTimes->{{3.524817167765625*^9, 3.524817201875*^9}},
 CellTags->"Member",
 CellLabel->"In[12]:=",
 CellID->197001915],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.009900227094677558`", ",", "0.009801718189164525`", ",", 
   "0.009704189463638536`", ",", "0.009607104734025367`", ",", 
   "0.009511773037684457`"}], "}"}]], "Output",
 CellChangeTimes->{3.524817202515625*^9},
 CellTags->"Member",
 CellLabel->"Out[12]=",
 CellID->212524872]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Credit"}]], "Input",
 CellChangeTimes->{{3.524917371073237*^9, 3.524917372760737*^9}},
 CellLabel->"In[35]:=",
 CellID->772546257],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"QuantLib Credit\"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:QuantLib/ref/Credit"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.524917373510737*^9},
 CellTags->"Info3524924573-4144957",
 CellID->81089894]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{716, 867},
WindowMargins->{{Automatic, 173}, {-505, Automatic}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
ShowSelection->True,
TaggingRules->{"LinkTrails" -> "", "SearchTextTranslated" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[579, 22, 83, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->237035917],
  Cell[665, 26, 138, 4, 23, "Text",
   CellTags->"Overview",
   CellID->612809703],
  Cell[806, 32, 114, 2, 39, "MathCaption",
   CellTags->"Overview",
   CellID->221034052],
  Cell[923, 36, 103, 3, 27, "Input",
   CellTags->"Overview",
   CellID->543634195]},
 "Bonds Overview"->{
  Cell[1051, 43, 224, 5, 27, "Input",
   CellTags->"Bonds Overview",
   CellID->510695],
  Cell[1278, 50, 517, 12, 45, "Output",
   CellTags->"Bonds Overview",
   CellID->836850940],
  Cell[1810, 65, 186, 3, 23, "Text",
   CellTags->"Bonds Overview",
   CellID->38547467],
  Cell[2021, 72, 460, 11, 27, "Input",
   CellTags->"Bonds Overview",
   CellID->67846344],
  Cell[2484, 85, 413, 11, 25, "Output",
   CellTags->"Bonds Overview",
   CellID->671783662]},
 "Constructor"->{
  Cell[3669, 126, 77, 2, 63, "Section",
   CellTags->"Constructor",
   CellID->342467181],
  Cell[3771, 132, 118, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->603872752],
  Cell[4575, 155, 139, 3, 27, "Input",
   CellTags->"Constructor",
   CellID->365083110],
  Cell[4717, 160, 346, 6, 25, "Output",
   CellTags->"Constructor",
   CellID->625797304],
  Cell[5112, 172, 85, 2, 33, "Subsubsection",
   CellTags->"Constructor",
   CellID->335343139],
  Cell[6509, 212, 203, 6, 27, "Input",
   CellTags->"Constructor",
   CellID->294924434],
  Cell[6737, 222, 110, 3, 27, "Input",
   CellTags->"Constructor",
   CellID->550157968],
  Cell[6850, 227, 326, 7, 25, "Output",
   CellTags->"Constructor",
   CellID->203085872]},
 "Member"->{
  Cell[7237, 241, 75, 2, 63, "Section",
   CellTags->"Member",
   CellID->224242434],
  Cell[7337, 247, 92, 2, 33, "Subsubsection",
   CellTags->"Member",
   CellID->21571979],
  Cell[7983, 269, 591, 15, 27, "Input",
   CellTags->"Member",
   CellID->170507264],
  Cell[8577, 286, 662, 18, 25, "Output",
   CellTags->"Member",
   CellID->462835981],
  Cell[9276, 309, 194, 6, 27, "Input",
   CellTags->"Member",
   CellID->354222954],
  Cell[9473, 317, 472, 12, 25, "Output",
   CellTags->"Member",
   CellID->804031799],
  Cell[9982, 334, 192, 6, 27, "Input",
   CellTags->"Member",
   CellID->711696626],
  Cell[10177, 342, 308, 9, 25, "Output",
   CellTags->"Member",
   CellID->38375496],
  Cell[10522, 356, 187, 6, 27, "Input",
   CellTags->"Member",
   CellID->197001915],
  Cell[10712, 364, 321, 9, 25, "Output",
   CellTags->"Member",
   CellID->212524872]},
 "Info3524924573-4144957"->{
  Cell[11232, 384, 354, 10, 40, "Print",
   CellTags->"Info3524924573-4144957",
   CellID->81089894]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 12676, 431},
 {"Bonds Overview", 13044, 444},
 {"Constructor", 13522, 460},
 {"Member", 14274, 485},
 {"Info3524924573-4144957", 15170, 516}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 83, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->237035917],
Cell[665, 26, 138, 4, 23, "Text",
 CellTags->"Overview",
 CellID->612809703],
Cell[806, 32, 114, 2, 39, "MathCaption",
 CellTags->"Overview",
 CellID->221034052],
Cell[923, 36, 103, 3, 27, "Input",
 CellTags->"Overview",
 CellID->543634195],
Cell[CellGroupData[{
Cell[1051, 43, 224, 5, 27, "Input",
 CellTags->"Bonds Overview",
 CellID->510695],
Cell[1278, 50, 517, 12, 45, "Output",
 CellTags->"Bonds Overview",
 CellID->836850940]
}, Open  ]],
Cell[1810, 65, 186, 3, 23, "Text",
 CellTags->"Bonds Overview",
 CellID->38547467],
Cell[CellGroupData[{
Cell[2021, 72, 460, 11, 27, "Input",
 CellTags->"Bonds Overview",
 CellID->67846344],
Cell[2484, 85, 413, 11, 25, "Output",
 CellTags->"Bonds Overview",
 CellID->671783662]
}, Open  ]],
Cell[CellGroupData[{
Cell[2934, 101, 289, 8, 27, "Input",
 CellID->314610079],
Cell[3226, 111, 406, 10, 25, "Output",
 CellID->134747294]
}, Open  ]],
Cell[CellGroupData[{
Cell[3669, 126, 77, 2, 63, "Section",
 CellTags->"Constructor",
 CellID->342467181],
Cell[CellGroupData[{
Cell[3771, 132, 118, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->603872752],
Cell[3892, 136, 475, 9, 109, "Text",
 CellID->557908359],
Cell[4370, 147, 180, 4, 27, "Input",
 CellID->271450837],
Cell[CellGroupData[{
Cell[4575, 155, 139, 3, 27, "Input",
 CellTags->"Constructor",
 CellID->365083110],
Cell[4717, 160, 346, 6, 25, "Output",
 CellTags->"Constructor",
 CellID->625797304]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5112, 172, 85, 2, 33, "Subsubsection",
 CellTags->"Constructor",
 CellID->335343139],
Cell[5200, 176, 252, 7, 64, "Text",
 CellID->34334516],
Cell[5455, 185, 1051, 25, 210, "Text",
 CellID->334955400],
Cell[6509, 212, 203, 6, 27, "Input",
 CellTags->"Constructor",
 CellID->294924434],
Cell[CellGroupData[{
Cell[6737, 222, 110, 3, 27, "Input",
 CellTags->"Constructor",
 CellID->550157968],
Cell[6850, 227, 326, 7, 25, "Output",
 CellTags->"Constructor",
 CellID->203085872]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7237, 241, 75, 2, 63, "Section",
 CellTags->"Member",
 CellID->224242434],
Cell[CellGroupData[{
Cell[7337, 247, 92, 2, 33, "Subsubsection",
 CellTags->"Member",
 CellID->21571979],
Cell[7432, 251, 245, 6, 64, "Text",
 CellID->37145109],
Cell[7680, 259, 278, 6, 64, "Text",
 CellID->411977635],
Cell[CellGroupData[{
Cell[7983, 269, 591, 15, 27, "Input",
 CellTags->"Member",
 CellID->170507264],
Cell[8577, 286, 662, 18, 25, "Output",
 CellTags->"Member",
 CellID->462835981]
}, Open  ]],
Cell[CellGroupData[{
Cell[9276, 309, 194, 6, 27, "Input",
 CellTags->"Member",
 CellID->354222954],
Cell[9473, 317, 472, 12, 25, "Output",
 CellTags->"Member",
 CellID->804031799]
}, Open  ]],
Cell[CellGroupData[{
Cell[9982, 334, 192, 6, 27, "Input",
 CellTags->"Member",
 CellID->711696626],
Cell[10177, 342, 308, 9, 25, "Output",
 CellTags->"Member",
 CellID->38375496]
}, Open  ]],
Cell[CellGroupData[{
Cell[10522, 356, 187, 6, 27, "Input",
 CellTags->"Member",
 CellID->197001915],
Cell[10712, 364, 321, 9, 25, "Output",
 CellTags->"Member",
 CellID->212524872]
}, Open  ]],
Cell[CellGroupData[{
Cell[11070, 378, 159, 4, 27, "Input",
 CellID->772546257],
Cell[11232, 384, 354, 10, 40, "Print",
 CellTags->"Info3524924573-4144957",
 CellID->81089894]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
