(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     23818,        881]
NotebookOptionsPosition[     13846,        514]
NotebookOutlinePosition[     19074,        695]
CellTagsIndexPosition[     18919,        687]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["Driftcalculators"], "Chapter",
 CellTags->"Overview",
 CellID->427638705],

Cell["functions to construct and use Driftcalculators objects.", "Text",
 CellTags->"Overview",
 CellID->307278040],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->126956375],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->53042332],

Cell["\<\
Within the Driftcalculators part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->137596567],

Cell["Select[Category[Driftcalculators],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellID->930134735],

Cell["Select[Category[Driftcalculators],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellID->9695731],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->96923363],

Cell[CellGroupData[{

Cell["LMMDriftCalculator", "Subsection",
 CellTags->"Constructor",
 CellID->331781085],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PseudoSquareRoot", "exampleValue", 
     RowBox[{
     "Pseudo", " ", "square", " ", "root", " ", "of", " ", "the", " ", 
      "covariance", " ", 
      RowBox[{"matrix", "."}]}]},
    {"Displacements", 
     RowBox[{"0.0", ",", "0.0", ",", "0.0", ",", "0.0", ",", "0.0"}], 
     RowBox[{"displacements", "."}]},
    {"Taus", 
     RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], 
     RowBox[{"taus", "."}]},
    {"Numeraire", "5", 
     RowBox[{"numeraire", "."}]},
    {"Alive", "1", 
     RowBox[{
     "index", " ", "of", " ", "the", " ", "first", " ", "rates", " ", "still",
       " ", 
      RowBox[{"alive", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.43607765525*^9, 3.4360776586875*^9}},
 CellID->788322739],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PseudoSquareRoot", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Displacements", "=", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "0.0", ",", "0.0", ",", "0.0", ",", "0.0"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Taus", "=", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraire", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Alive", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.436077669078125*^9, 3.436077672328125*^9}},
 CellTags->"Constructor",
 CellID->269166043],

Cell["\<\
obj=LMMDriftCalculator[PseudoSquareRoot,Displacements,Taus,Numeraire,Alive]\
\>", "Input",
 CellChangeTimes->{3.436077684984375*^9},
 CellTags->"Constructor",
 CellID->4047523]
}, Open  ]],

Cell[CellGroupData[{

Cell["LMMNormalDriftCalculator", "Subsection",
 CellTags->"Constructor",
 CellID->333914043],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PseudoSquareRoot", "exampleValue", 
     RowBox[{
     "Pseudo", " ", "square", " ", "root", " ", "of", " ", "the", " ", 
      "covariance", " ", 
      RowBox[{"matrix", "."}]}]},
    {"Taus", 
     RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], 
     RowBox[{"taus", "."}]},
    {"Numeraire", "5", 
     RowBox[{"numeraire", "."}]},
    {"Alive", "1", 
     RowBox[{
     "index", " ", "of", " ", "the", " ", "first", " ", "rates", " ", "still",
       " ", 
      RowBox[{"alive", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.4360776995*^9, 3.4360776995*^9}},
 CellID->29196422],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PseudoSquareRoot", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Taus", "=", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraire", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Alive", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{3.43607770375*^9},
 CellTags->"Constructor",
 CellID->53804469],

Cell["\<\
obj=LMMNormalDriftCalculator[Pseudo_square_root,Taus,Numeraire,Alive]\
\>", "Input",
 CellTags->"Constructor",
 CellID->23861210]
}, Open  ]],

Cell[CellGroupData[{

Cell["CMSMMDriftCalculator", "Subsection",
 CellTags->"Constructor",
 CellID->784245354],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {
     RowBox[{"Pseudo_square", "_root"}], "exampleValue", 
     RowBox[{
     "Pseudo", " ", "square", " ", "root", " ", "of", " ", "the", " ", 
      "covariance", " ", 
      RowBox[{"matrix", "."}]}]},
    {"Displacements", 
     RowBox[{"0.0", ",", "0.0", ",", "0.0", ",", "0.0", ",", "0.0"}], 
     RowBox[{"displacements", "."}]},
    {"Taus", 
     RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], 
     RowBox[{"taus", "."}]},
    {"Numeraire", "5", 
     RowBox[{"numeraire", "."}]},
    {"Alive", "1", 
     RowBox[{
     "index", " ", "of", " ", "the", " ", "first", " ", "rates", " ", "still",
       " ", 
      RowBox[{"alive", "."}]}]},
    {"SpanningFwds", "5", 
     RowBox[{
     "number", " ", "of", " ", "forwards", " ", "to", " ", "be", " ", 
      RowBox[{"spanned", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->296351887],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PseudoSquareRoot", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Displacements", "=", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "0.0", ",", "0.0", ",", "0.0", ",", "0.0"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Taus", "=", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraire", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Alive", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SpanningFwds", "=", "5"}], ";"}]}], "Input",
 CellChangeTimes->{3.4360777115625*^9},
 CellTags->"Constructor",
 CellID->50097946],

Cell["\<\
obj=CMSMMDriftCalculator[Pseudo_square_root,Displacements,Taus,Numeraire,\
Alive,SpanningFwds]\
\>", "Input",
 CellTags->"Constructor",
 CellID->315145166]
}, Open  ]],

Cell[CellGroupData[{

Cell["SMMDriftCalculator", "Subsection",
 CellTags->"Constructor",
 CellID->848811665],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PseudoSquareRoot", "exampleValue", 
     RowBox[{
     "Pseudo", " ", "square", " ", "root", " ", "of", " ", "the", " ", 
      "covariance", " ", 
      RowBox[{"matrix", "."}]}]},
    {"Displacements", 
     RowBox[{"0.0", ",", "0.0", ",", "0.0", ",", "0.0", ",", "0.0"}], 
     RowBox[{"displacements", "."}]},
    {"Taus", 
     RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], 
     RowBox[{"taus", "."}]},
    {"Numeraire", "5", 
     RowBox[{"numeraire", "."}]},
    {"Alive", "1", 
     RowBox[{
     "index", " ", "of", " ", "the", " ", "first", " ", "rates", " ", "still",
       " ", 
      RowBox[{"alive", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.436077718140625*^9, 3.436077718140625*^9}},
 CellID->67452330],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PseudoSquareRoot", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Displacements", "=", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "0.0", ",", "0.0", ",", "0.0", ",", "0.0"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Taus", "=", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", "0.5", ",", "0.5", ",", "0.5", ",", "0.5"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraire", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Alive", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{3.43607772159375*^9},
 CellTags->"Constructor",
 CellID->756442059],

Cell["\<\
obj=SMMDriftCalculator[Pseudo_square_root,Displacements,Taus,Numeraire,Alive]\
\
\>", "Input",
 CellTags->"Constructor",
 CellID->469124634]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->407972970],

Cell[CellGroupData[{

Cell["LMMDriftCalculatorComputePlain", "Subsection",
 CellTags->"Member",
 CellID->87270922],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"LMMCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->75039538],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->571764146],

Cell["LMMDriftCalculatorComputePlain[objCurveState]", "Input",
 CellTags->"Member",
 CellID->403888999]
}, Open  ]],

Cell[CellGroupData[{

Cell["LMMDriftCalculatorComputeReduced", "Subsection",
 CellTags->"Member",
 CellID->105533654],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"LMMCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->116975205],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->57515901],

Cell["LMMDriftCalculatorComputeReduced[objCurveState]", "Input",
 CellTags->"Member",
 CellID->488595433]
}, Open  ]],

Cell[CellGroupData[{

Cell["LMMDriftCalculatorCompute", "Subsection",
 CellTags->"Member",
 CellID->33490170],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"LMMCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->450110402],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->296946223],

Cell["LMMDriftCalculatorCompute[objCurveState]", "Input",
 CellTags->"Member",
 CellID->169675332]
}, Open  ]],

Cell[CellGroupData[{

Cell["LMMNormalDriftCalculatorComputePlain", "Subsection",
 CellTags->"Member",
 CellID->280192131],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"LMMCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->210361544],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->48521459],

Cell["LMMNormalDriftCalculatorComputePlain[objCurveState]", "Input",
 CellTags->"Member",
 CellID->182967615]
}, Open  ]],

Cell[CellGroupData[{

Cell["LMMNormalDriftCalculatorComputeReduced", "Subsection",
 CellTags->"Member",
 CellID->43937595],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"LMMCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->174606995],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->575237200],

Cell["LMMNormalDriftCalculatorComputeReduced[objCurveState]", "Input",
 CellTags->"Member",
 CellID->165852362]
}, Open  ]],

Cell[CellGroupData[{

Cell["LMMNormalDriftCalculatorCompute", "Subsection",
 CellTags->"Member",
 CellID->174856102],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"LMMCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->92907491],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->387792166],

Cell["LMMNormalDriftCalculatorCompute[objCurveState]", "Input",
 CellTags->"Member",
 CellID->489398675]
}, Open  ]],

Cell[CellGroupData[{

Cell["CMSMMDriftCalculatorCompute", "Subsection",
 CellTags->"Member",
 CellID->98911734],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"CMSwapCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->261152084],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->493259],

Cell["CMSMMDriftCalculatorCompute[objCurveState]", "Input",
 CellTags->"Member",
 CellID->265917334]
}, Open  ]],

Cell[CellGroupData[{

Cell["SMMDriftCalculatorCompute", "Subsection",
 CellTags->"Member",
 CellID->302102660],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveState", "exampleValue", 
     RowBox[{"CoterminalSwapCurveState", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->240626055],

Cell[BoxData[
 RowBox[{
  RowBox[{"CurveState", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->160258624],

Cell["SMMDriftCalculatorCompute[objCurveState]", "Input",
 CellTags->"Member",
 CellID->541615047]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 582}, {Automatic, 92}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 87, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->427638705],
  Cell[680, 27, 115, 2, 37, "Text",
   CellTags->"Overview",
   CellID->307278040],
  Cell[798, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->126956375],
  Cell[915, 35, 79, 2, 41, "Input",
   CellTags->"Overview",
   CellID->53042332],
  Cell[997, 39, 164, 5, 37, "Text",
   CellTags->"Overview",
   CellID->137596567],
  Cell[1164, 46, 112, 2, 41, "Input",
   CellTags->"Overview",
   CellID->930134735],
  Cell[1279, 50, 105, 2, 41, "Input",
   CellTags->"Overview",
   CellID->9695731]},
 "Constructo"->{
  Cell[1409, 56, 75, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->96923363]},
 "Constructor"->{
  Cell[1509, 62, 86, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->331781085],
  Cell[2483, 91, 622, 19, 122, "Input",
   CellTags->"Constructor",
   CellID->269166043],
  Cell[3108, 112, 186, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->4047523],
  Cell[3331, 122, 92, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->333914043],
  Cell[4174, 148, 438, 14, 70, "Input",
   CellTags->"Constructor",
   CellID->53804469],
  Cell[4615, 164, 139, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->23861210],
  Cell[4791, 173, 88, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->784245354],
  Cell[5876, 206, 657, 21, 70, "Input",
   CellTags->"Constructor",
   CellID->50097946],
  Cell[6536, 229, 165, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->315145166],
  Cell[6738, 239, 86, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->848811665],
  Cell[7717, 268, 597, 19, 70, "Input",
   CellTags->"Constructor",
   CellID->756442059],
  Cell[8317, 289, 150, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->469124634]},
 "Member"->{
  Cell[8516, 300, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->407972970],
  Cell[8616, 306, 92, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->87270922],
  Cell[8995, 319, 128, 4, 70, "Input",
   CellTags->"Member",
   CellID->571764146],
  Cell[9126, 325, 103, 2, 70, "Input",
   CellTags->"Member",
   CellID->403888999],
  Cell[9266, 332, 95, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->105533654],
  Cell[9649, 345, 127, 4, 70, "Input",
   CellTags->"Member",
   CellID->57515901],
  Cell[9779, 351, 105, 2, 70, "Input",
   CellTags->"Member",
   CellID->488595433],
  Cell[9921, 358, 87, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->33490170],
  Cell[10296, 371, 128, 4, 70, "Input",
   CellTags->"Member",
   CellID->296946223],
  Cell[10427, 377, 98, 2, 70, "Input",
   CellTags->"Member",
   CellID->169675332],
  Cell[10562, 384, 99, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->280192131],
  Cell[10949, 397, 127, 4, 28, "Input",
   CellTags->"Member",
   CellID->48521459],
  Cell[11079, 403, 109, 2, 28, "Input",
   CellTags->"Member",
   CellID->182967615],
  Cell[11225, 410, 100, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->43937595],
  Cell[11613, 423, 128, 4, 28, "Input",
   CellTags->"Member",
   CellID->575237200],
  Cell[11744, 429, 111, 2, 28, "Input",
   CellTags->"Member",
   CellID->165852362],
  Cell[11892, 436, 94, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->174856102],
  Cell[12273, 449, 128, 4, 28, "Input",
   CellTags->"Member",
   CellID->387792166],
  Cell[12404, 455, 104, 2, 28, "Input",
   CellTags->"Member",
   CellID->489398675],
  Cell[12545, 462, 89, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->98911734],
  Cell[12925, 475, 125, 4, 28, "Input",
   CellTags->"Member",
   CellID->493259],
  Cell[13053, 481, 100, 2, 28, "Input",
   CellTags->"Member",
   CellID->265917334],
  Cell[13190, 488, 88, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->302102660],
  Cell[13577, 501, 128, 4, 28, "Input",
   CellTags->"Member",
   CellID->160258624],
  Cell[13708, 507, 98, 2, 28, "Input",
   CellTags->"Member",
   CellID->541615047]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 14899, 545},
 {"Constructo", 15515, 567},
 {"Constructor", 15622, 571},
 {"Member", 16730, 608}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 87, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->427638705],
Cell[680, 27, 115, 2, 37, "Text",
 CellTags->"Overview",
 CellID->307278040],
Cell[798, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->126956375],
Cell[915, 35, 79, 2, 41, "Input",
 CellTags->"Overview",
 CellID->53042332],
Cell[997, 39, 164, 5, 37, "Text",
 CellTags->"Overview",
 CellID->137596567],
Cell[1164, 46, 112, 2, 41, "Input",
 CellTags->"Overview",
 CellID->930134735],
Cell[1279, 50, 105, 2, 41, "Input",
 CellTags->"Overview",
 CellID->9695731],
Cell[CellGroupData[{
Cell[1409, 56, 75, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->96923363],
Cell[CellGroupData[{
Cell[1509, 62, 86, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->331781085],
Cell[1598, 66, 882, 23, 236, "Input",
 CellID->788322739],
Cell[2483, 91, 622, 19, 122, "Input",
 CellTags->"Constructor",
 CellID->269166043],
Cell[3108, 112, 186, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->4047523]
}, Open  ]],
Cell[CellGroupData[{
Cell[3331, 122, 92, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->333914043],
Cell[3426, 126, 745, 20, 70, "Input",
 CellID->29196422],
Cell[4174, 148, 438, 14, 70, "Input",
 CellTags->"Constructor",
 CellID->53804469],
Cell[4615, 164, 139, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->23861210]
}, Open  ]],
Cell[CellGroupData[{
Cell[4791, 173, 88, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->784245354],
Cell[4882, 177, 991, 27, 70, "Input",
 CellID->296351887],
Cell[5876, 206, 657, 21, 70, "Input",
 CellTags->"Constructor",
 CellID->50097946],
Cell[6536, 229, 165, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->315145166]
}, Open  ]],
Cell[CellGroupData[{
Cell[6738, 239, 86, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->848811665],
Cell[6827, 243, 887, 23, 70, "Input",
 CellID->67452330],
Cell[7717, 268, 597, 19, 70, "Input",
 CellTags->"Constructor",
 CellID->756442059],
Cell[8317, 289, 150, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->469124634]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8516, 300, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->407972970],
Cell[CellGroupData[{
Cell[8616, 306, 92, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->87270922],
Cell[8711, 310, 281, 7, 70, "Input",
 CellID->75039538],
Cell[8995, 319, 128, 4, 70, "Input",
 CellTags->"Member",
 CellID->571764146],
Cell[9126, 325, 103, 2, 70, "Input",
 CellTags->"Member",
 CellID->403888999]
}, Open  ]],
Cell[CellGroupData[{
Cell[9266, 332, 95, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->105533654],
Cell[9364, 336, 282, 7, 70, "Input",
 CellID->116975205],
Cell[9649, 345, 127, 4, 70, "Input",
 CellTags->"Member",
 CellID->57515901],
Cell[9779, 351, 105, 2, 70, "Input",
 CellTags->"Member",
 CellID->488595433]
}, Open  ]],
Cell[CellGroupData[{
Cell[9921, 358, 87, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->33490170],
Cell[10011, 362, 282, 7, 70, "Input",
 CellID->450110402],
Cell[10296, 371, 128, 4, 70, "Input",
 CellTags->"Member",
 CellID->296946223],
Cell[10427, 377, 98, 2, 70, "Input",
 CellTags->"Member",
 CellID->169675332]
}, Open  ]],
Cell[CellGroupData[{
Cell[10562, 384, 99, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->280192131],
Cell[10664, 388, 282, 7, 70, "Input",
 CellID->210361544],
Cell[10949, 397, 127, 4, 28, "Input",
 CellTags->"Member",
 CellID->48521459],
Cell[11079, 403, 109, 2, 28, "Input",
 CellTags->"Member",
 CellID->182967615]
}, Open  ]],
Cell[CellGroupData[{
Cell[11225, 410, 100, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->43937595],
Cell[11328, 414, 282, 7, 65, "Input",
 CellID->174606995],
Cell[11613, 423, 128, 4, 28, "Input",
 CellTags->"Member",
 CellID->575237200],
Cell[11744, 429, 111, 2, 28, "Input",
 CellTags->"Member",
 CellID->165852362]
}, Open  ]],
Cell[CellGroupData[{
Cell[11892, 436, 94, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->174856102],
Cell[11989, 440, 281, 7, 65, "Input",
 CellID->92907491],
Cell[12273, 449, 128, 4, 28, "Input",
 CellTags->"Member",
 CellID->387792166],
Cell[12404, 455, 104, 2, 28, "Input",
 CellTags->"Member",
 CellID->489398675]
}, Open  ]],
Cell[CellGroupData[{
Cell[12545, 462, 89, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->98911734],
Cell[12637, 466, 285, 7, 65, "Input",
 CellID->261152084],
Cell[12925, 475, 125, 4, 28, "Input",
 CellTags->"Member",
 CellID->493259],
Cell[13053, 481, 100, 2, 28, "Input",
 CellTags->"Member",
 CellID->265917334]
}, Open  ]],
Cell[CellGroupData[{
Cell[13190, 488, 88, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->302102660],
Cell[13281, 492, 293, 7, 82, "Input",
 CellID->240626055],
Cell[13577, 501, 128, 4, 28, "Input",
 CellTags->"Member",
 CellID->160258624],
Cell[13708, 507, 98, 2, 28, "Input",
 CellTags->"Member",
 CellID->541615047]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
