(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12116,        442]
NotebookOptionsPosition[      6874,        246]
NotebookOutlinePosition[     10084,        358]
CellTagsIndexPosition[      9893,        349]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["ForwardRateAgreement"], "Chapter",
 CellTags->"Overview",
 CellID->235357553],

Cell["Functions to construct and use ForwardRateAgreement objects.", "Text",
 CellTags->"Overview",
 CellID->64680313],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->303829145],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->266724141],

Cell["\<\
Within the ForwardRateAgreement part there are several constructors and \
member functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->626726214],

Cell[CellGroupData[{

Cell["Select[Category[ForwardRateAgreement],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[794]:=",
 CellID->16308136],

Cell[BoxData[
 RowBox[{"{", "FRA", "}"}]], "Output",
 CellChangeTimes->{3.436078640796875*^9},
 CellTags->"Overview",
 CellLabel->"Out[794]=",
 CellID->16540250]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[ForwardRateAgreement],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[795]:=",
 CellID->212926045],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"FRAforwardRate", ",", "FRAforwardValue", ",", "FRAspotValue"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.43607864246875*^9},
 CellTags->"Overview",
 CellLabel->"Out[795]=",
 CellID->469385523]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->85125301],

Cell[CellGroupData[{

Cell["FRA", "Subsection",
 CellTags->"Constructor",
 CellID->181707865],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"ValueDate", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "11"}], "}"}], 
     RowBox[{"Value", " ", 
      RowBox[{"date", "."}]}]},
    {"MaturityDate", 
     RowBox[{"{", 
      RowBox[{"2018", ",", "11", ",", "11"}], "}"}], 
     RowBox[{"Maturity", " ", 
      RowBox[{"date", "."}]}]},
    {"Position", "Long", 
     RowBox[{"Instrument", " ", "position", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Long", " ", "=", " ", "purchase"}], ",", " ", 
         RowBox[{"Short", " ", "=", " ", "sale"}]}], ")"}], "."}]}]},
    {"Strike", "0.02", 
     RowBox[{"Strike", " ", 
      RowBox[{"rate", "."}]}]},
    {"Notional", "1000000", 
     RowBox[{"Notional", " ", 
      RowBox[{"amount", "."}]}]},
    {"IborIndex", "exampleValue", 
     RowBox[{"Underlying", " ", "index", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"YieldCurve", "EURYC", 
     RowBox[{
     "Discounting", " ", "yield", " ", "term", " ", "structure", " ", 
      "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.436078646734375*^9, 3.436078657984375*^9}},
 CellID->1292505],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ValueDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "3", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MaturityDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "9", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"position", "=", "\"\<Long\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", "0.02"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Notional", "=", "1000000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IborIndex", "=", 
   RowBox[{"IborIndex", "[", 
    RowBox[{
    "\"\<Test\>\"", ",", "\"\<2D\>\"", ",", "2", ",", "\"\<USD\>\"", ",", 
     "\"\<Following\>\"", ",", "True", ",", "\"\<30/360\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", 
      RowBox[{"FlatForward", "[", 
       RowBox[{"0.04", ",", "\"\<Simple\>\""}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"YieldCurve", "=", "EURYC"}], ";"}]}], "Input",
 CellChangeTimes->{{3.43607872765625*^9, 3.436078867046875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[804]:=",
 CellID->126182423],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Position"}]], "Input",
 CellChangeTimes->{{3.43607885653125*^9, 3.43607885928125*^9}},
 CellLabel->"In[803]:=",
 CellID->227054130],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Position\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"pattern\\\
\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives a list of the positions at which \
objects matching \\!\\(\\*StyleBox[\\\"pattern\\\", \\\"TI\\\"]\\) appear in \
\\!\\(\\*StyleBox[\\\"expr\\\", \\\"TI\\\"]\\). \
\\n\\!\\(\\*RowBox[{\\\"Position\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"pattern\\\
\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"levelspec\\\", \\\"TI\\\"]}], \
\\\"]\\\"}]\\) finds only objects that appear on levels specified by \
\\!\\(\\*StyleBox[\\\"levelspec\\\", \\\"TI\\\"]\\). \
\\n\\!\\(\\*RowBox[{\\\"Position\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"pattern\\\
\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"levelspec\\\", \\\"TI\\\"], \
\\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives the \
positions of the first \\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\\\"]\\) objects \
found. \"\>", "MSG"], " ", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Position"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.4360788599375*^9},
 CellTags->"Info3436082459-7899706",
 CellID->8952706]
}, Open  ]],

Cell["\<\
obj=FRA[ValueDate,MaturityDate,Position,Strike,Notional,IborIndex,YieldCurve]\
\
\>", "Input",
 CellTags->"Constructor",
 CellID->157620967]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->44399864],

Cell[CellGroupData[{

Cell["FRAforwardRate", "Subsection",
 CellTags->"Member",
 CellID->2745098],

Cell["FRAforwardRate[obj]", "Input",
 CellTags->"Member",
 CellID->163627880]
}, Open  ]],

Cell[CellGroupData[{

Cell["FRAforwardValue", "Subsection",
 CellTags->"Member",
 CellID->335400642],

Cell["FRAforwardValue[obj]", "Input",
 CellTags->"Member",
 CellID->930650472]
}, Open  ]],

Cell[CellGroupData[{

Cell["FRAspotValue", "Subsection",
 CellTags->"Member",
 CellID->86395698],

Cell["FRAspotValue[obj]", "Input",
 CellTags->"Member",
 CellID->154268740]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 464}, {Automatic, 38}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
ShowSelection->True,
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 91, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->235357553],
  Cell[684, 27, 118, 2, 37, "Text",
   CellTags->"Overview",
   CellID->64680313],
  Cell[805, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->303829145],
  Cell[922, 35, 80, 2, 41, "Input",
   CellTags->"Overview",
   CellID->266724141],
  Cell[1005, 39, 168, 5, 37, "Text",
   CellTags->"Overview",
   CellID->626726214],
  Cell[1198, 48, 140, 3, 41, "Input",
   CellTags->"Overview",
   CellID->16308136],
  Cell[1341, 53, 161, 5, 39, "Output",
   CellTags->"Overview",
   CellID->16540250],
  Cell[1539, 63, 136, 3, 41, "Input",
   CellTags->"Overview",
   CellID->212926045],
  Cell[1678, 68, 233, 7, 39, "Output",
   CellTags->"Overview",
   CellID->469385523]},
 "Constructo"->{
  Cell[1948, 80, 75, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->85125301]},
 "Constructor"->{
  Cell[2048, 86, 71, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->181707865],
  Cell[3406, 128, 1058, 30, 155, "Input",
   CellTags->"Constructor",
   CellID->126182423],
  Cell[5996, 196, 150, 5, 28, "Input",
   CellTags->"Constructor",
   CellID->157620967]},
 "Info3436082459-7899706"->{
  Cell[4652, 168, 1329, 25, 111, "Print",
   CellTags->"Info3436082459-7899706",
   CellID->8952706]},
 "Member"->{
  Cell[6195, 207, 74, 2, 51, "Section",
   CellTags->"Member",
   CellID->44399864],
  Cell[6294, 213, 75, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->2745098],
  Cell[6372, 217, 77, 2, 28, "Input",
   CellTags->"Member",
   CellID->163627880],
  Cell[6486, 224, 78, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->335400642],
  Cell[6567, 228, 78, 2, 28, "Input",
   CellTags->"Member",
   CellID->930650472],
  Cell[6682, 235, 74, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->86395698],
  Cell[6759, 239, 75, 2, 28, "Input",
   CellTags->"Member",
   CellID->154268740]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 7948, 278},
 {"Constructo", 8739, 306},
 {"Constructor", 8846, 310},
 {"Info3436082459-7899706", 9152, 320},
 {"Member", 9268, 324}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 91, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->235357553],
Cell[684, 27, 118, 2, 37, "Text",
 CellTags->"Overview",
 CellID->64680313],
Cell[805, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->303829145],
Cell[922, 35, 80, 2, 41, "Input",
 CellTags->"Overview",
 CellID->266724141],
Cell[1005, 39, 168, 5, 37, "Text",
 CellTags->"Overview",
 CellID->626726214],
Cell[CellGroupData[{
Cell[1198, 48, 140, 3, 41, "Input",
 CellTags->"Overview",
 CellID->16308136],
Cell[1341, 53, 161, 5, 39, "Output",
 CellTags->"Overview",
 CellID->16540250]
}, Open  ]],
Cell[CellGroupData[{
Cell[1539, 63, 136, 3, 41, "Input",
 CellTags->"Overview",
 CellID->212926045],
Cell[1678, 68, 233, 7, 39, "Output",
 CellTags->"Overview",
 CellID->469385523]
}, Open  ]],
Cell[CellGroupData[{
Cell[1948, 80, 75, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->85125301],
Cell[CellGroupData[{
Cell[2048, 86, 71, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->181707865],
Cell[2122, 90, 1281, 36, 219, "Input",
 CellID->1292505],
Cell[3406, 128, 1058, 30, 155, "Input",
 CellTags->"Constructor",
 CellID->126182423],
Cell[CellGroupData[{
Cell[4489, 162, 160, 4, 28, "Input",
 CellID->227054130],
Cell[4652, 168, 1329, 25, 111, "Print",
 CellTags->"Info3436082459-7899706",
 CellID->8952706]
}, Open  ]],
Cell[5996, 196, 150, 5, 28, "Input",
 CellTags->"Constructor",
 CellID->157620967]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6195, 207, 74, 2, 51, "Section",
 CellTags->"Member",
 CellID->44399864],
Cell[CellGroupData[{
Cell[6294, 213, 75, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->2745098],
Cell[6372, 217, 77, 2, 28, "Input",
 CellTags->"Member",
 CellID->163627880]
}, Open  ]],
Cell[CellGroupData[{
Cell[6486, 224, 78, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->335400642],
Cell[6567, 228, 78, 2, 28, "Input",
 CellTags->"Member",
 CellID->930650472]
}, Open  ]],
Cell[CellGroupData[{
Cell[6682, 235, 74, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->86395698],
Cell[6759, 239, 75, 2, 28, "Input",
 CellTags->"Member",
 CellID->154268740]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
