(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     64856,       2421]
NotebookOptionsPosition[     38743,       1450]
NotebookOutlinePosition[     51164,       1874]
CellTagsIndexPosition[     51005,       1866]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["Interpolation"], "Chapter",
 CellTags->"Overview",
 CellID->147529134],

Cell["\<\
functions to construct and use Interpolation and Interpolation2D objects.\
\>", "Text",
 CellTags->"Overview",
 CellID->400023536],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->53024819],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->129362553],

Cell["\<\
Within the Interpolation part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->519880885],

Cell[CellGroupData[{

Cell["Select[Category[Interpolation],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[873]:=",
 CellID->120708382],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AbcdInterpolation", ",", "CubicInterpolation", ",", "Interpolation", ",", 
   "Interpolation2D", ",", "SABRInterpolation"}], "}"}]], "Output",
 CellChangeTimes->{3.43607918246875*^9},
 CellTags->"Overview",
 CellLabel->"Out[873]=",
 CellID->360829308]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Interpolation],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[874]:=",
 CellID->120015940],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AbcdInterpolationA", ",", "AbcdInterpolationB", ",", "AbcdInterpolationC", 
   ",", "AbcdInterpolationD", ",", "AbcdInterpolationEndCriteria", ",", 
   "AbcdInterpolationMaxError", ",", "AbcdInterpolationRmsError", ",", 
   "CubicInterpolationACoefficients", ",", "CubicInterpolationBCoefficients", 
   ",", "CubicInterpolationCCoefficients", ",", 
   "CubicInterpolationMonotonicityAdjustments", ",", 
   "CubicInterpolationPrimitiveConstants", ",", 
   "ExtrapolatorEnableExtrapolation", ",", "Interpolation2DInterpolate", ",", 
   "Interpolation2DIsInRange", ",", "Interpolation2DXmax", ",", 
   "Interpolation2DXmin", ",", "Interpolation2DXvalues", ",", 
   "Interpolation2DYmax", ",", "Interpolation2DYmin", ",", 
   "Interpolation2DYvalues", ",", "Interpolation2DzData", ",", 
   "InterpolationDerivative", ",", "InterpolationInterpolate", ",", 
   "InterpolationIsInRange", ",", "InterpolationPrimitive", ",", 
   "InterpolationSecondDerivative", ",", "InterpolationXmax", ",", 
   "InterpolationXmin", ",", "SABRInterpolationAlpha", ",", 
   "SABRInterpolationBeta", ",", "SABRInterpolationEndCriteria", ",", 
   "SABRInterpolationExpiry", ",", "SABRInterpolationForward", ",", 
   "SABRInterpolationMaxError", ",", "SABRInterpolationNu", ",", 
   "SABRInterpolationRho", ",", "SABRInterpolationRmsError", ",", 
   "SABRInterpolationWeights"}], "}"}]], "Output",
 CellChangeTimes->{3.4360791835*^9},
 CellTags->"Overview",
 CellLabel->"Out[874]=",
 CellID->182552731]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->128445744],

Cell[CellGroupData[{

Cell["Interpolation", "Subsection",
 CellTags->"Constructor",
 CellID->234347461],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XArray", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"array", "."}]}]},
    {"YArray", 
     RowBox[{
     "2.0", ",", "4.0", ",", "6.0", ",", "8.0", ",", "10.0", ",", "12.0"}], 
     RowBox[{"y", " ", 
      RowBox[{"array", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->156970020],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterpolationType", "\"\<Monotonic\>\"", 
     RowBox[{"interpolation", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"e", ".", "g"}], " ", "BackwardFlat"}], ",", " ", 
         "ForwardFlat", ",", " ", "Linear", ",", " ", "LogLinear", ",", " ", 
         "NaturalCubicSpline", ",", " ", "NaturalLogCubic", ",", " ", 
         "MonotonicNaturalCubicSpline", ",", " ", "MonotonicNaturalLogCubic", 
         ",", " ", "KrugerCubic", ",", " ", "KrugerLogCubic"}], ")"}], 
       "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellChangeTimes->{{3.436079225890625*^9, 3.436079225890625*^9}},
 CellID->390104680],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XArray", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YArray", "=", 
   RowBox[{"{", 
    RowBox[{
    "2.0", ",", "4.0", ",", "6.0", ",", "8.0", ",", "10.0", ",", "12.0"}], 
    "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[875]:=",
 CellID->307590788],

Cell[CellGroupData[{

Cell["\<\
obj=Interpolation[XArray,YArray,InterpolationType->\"ForwardFlat\"]\
\>", "Input",
 CellChangeTimes->{{3.436079235875*^9, 3.436079264390625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[899]:=",
 CellID->8205107],

Cell[BoxData["Interpolation4"], "Output",
 CellChangeTimes->{
  3.436079190109375*^9, {3.43607924509375*^9, 3.4360792658125*^9}, 
   3.436079385640625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[899]=",
 CellID->6576384]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicInterpolation", "Subsection",
 CellTags->"Constructor",
 CellID->132038921],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XArray", 
     RowBox[{"1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"array", "."}]}]},
    {"YArray", 
     RowBox[{"1.0", ",", "8.0", ",", "27.0", ",", "64.0", ",", "125.0"}], 
     RowBox[{"y", " ", 
      RowBox[{"array", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 EmphasizeSyntaxErrors->True,
 CellLabel->"In[880]:=",
 CellID->296791721],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DerApprox", "\"\<Kruger\>\"", 
     RowBox[{"Derivative", " ", "Approximation", " ", 
      RowBox[{
       RowBox[{"(", ")"}], "."}]}]},
    {"Monotonic", "TRUE", 
     RowBox[{"monotonicity", " ", "constraint", " ", 
      RowBox[{"flag", "."}]}]},
    {"LeftConditionType", "\"\<SecondDerivative\>\"", 
     RowBox[{"left", " ", "boundary", " ", "condition", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "NotAKnot", ",", " ", "FirstDerivative", ",", " ", "SecondDerivative",
          ",", " ", "Periodic", ",", " ", "Lagrange"}], ")"}], "."}]}]},
    {"LeftConditionValue", "0.0", 
     RowBox[{"left", " ", "condition", " ", 
      RowBox[{"value", "."}]}]},
    {"RightConditionType", "\"\<SecondDerivative\>\"", 
     RowBox[{"right", " ", "boundary", " ", "condition", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "NotAKnot", ",", " ", "FirstDerivative", ",", " ", "SecondDerivative",
          ",", " ", "Periodic", ",", " ", "Lagrange"}], ")"}], "."}]}]},
    {"RightConditionValue", "0.0", 
     RowBox[{"right", " ", "condition", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->592009787],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XArray", "=", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"YArray", "=", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "8.0", ",", "27.0", ",", "64.0", ",", "125.0"}], 
    "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[880]:=",
 CellID->91620548],

Cell[CellGroupData[{

Cell["obj=CubicInterpolation[XArray,YArray]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[882]:=",
 CellID->900179266],

Cell[BoxData["CubicInterpolation1"], "Output",
 CellChangeTimes->{3.4360792879375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[882]=",
 CellID->342003258]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolation", "Subsection",
 CellTags->"Constructor",
 CellID->53413663],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XArray", 
     RowBox[{"0.0300", ",", "0.0400", ",", "0.0500", ",", "0.0700"}], 
     RowBox[{"x", " ", 
      RowBox[{"array", "."}]}]},
    {"YArray", 
     RowBox[{"0.0850", ",", "0.0733", ",", "0.0844", ",", "0.1082"}], 
     RowBox[{"y", " ", 
      RowBox[{"array", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->381788490],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"A", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"alpha", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"B", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"beta", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"C", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"nu", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"D", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"rho", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"AIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "A", " ", "value", " ", "provided", 
       " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", " ",
       
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"BIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "B", " ", "value", " ", "provided", 
       " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", " ",
       
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"CIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "C", " ", "value", " ", "provided", 
       " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", " ",
       
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"DIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "D", " ", "value", " ", "provided", 
       " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", " ",
       
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"VegaWeighted", "true", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "interpolation", " ", "is", " ", 
      "weighted", " ", "using", " ", "options", " ", 
      RowBox[{"Vega", "."}]}]},
    {"EndCriteria", "\"\<\>\"", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"OptimizationMethod", "\"\<\>\"", 
     RowBox[{"OptimizationMethod", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->772821948],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XArray", "=", 
   RowBox[{"{", 
    RowBox[{"0.0300", ",", "0.0400", ",", "0.0500", ",", "0.0700"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"YArray", "=", 
   RowBox[{"{", 
    RowBox[{"0.0850", ",", "0.0733", ",", "0.0844", ",", "0.1082"}], "}"}]}], 
  ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[883]:=",
 CellID->261483164],

Cell[CellGroupData[{

Cell["obj=AbcdInterpolation[XArray,YArray]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[885]:=",
 CellID->86092494],

Cell[BoxData[
 RowBox[{"QuantLib`Private`qlAbcdInterpolation", "[", 
  RowBox[{"AbcdInterpolation1", ",", 
   RowBox[{"{", 
    RowBox[{"0.03`", ",", "0.04`", ",", "0.05`", ",", "0.07`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.085`", ",", "0.0733`", ",", "0.0844`", ",", "0.1082`"}], "}"}],
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "\<\"\"\>", ",", "\<\"\"\>", ",", 
   "True", ",", "True"}], "]"}]], "Output",
 CellChangeTimes->{3.43607930109375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[885]=",
 CellID->157888383]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolation", "Subsection",
 CellTags->"Constructor",
 CellID->232613869],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XArray", 
     RowBox[{"0.0300", ",", "0.0400", ",", "0.0500", ",", "0.0700"}], 
     RowBox[{"x", " ", 
      RowBox[{"array", "."}]}]},
    {"YArray", 
     RowBox[{"0.0850", ",", "0.0733", ",", "0.0844", ",", "0.1082"}], 
     RowBox[{"y", " ", 
      RowBox[{"array", "."}]}]},
    {"Expiry", "1.0", 
     RowBox[{"expiry", " ", "time", " ", "in", " ", 
      RowBox[{"years", "."}]}]},
    {"Forward", "0.039", 
     RowBox[{"forward", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->144245425],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Alpha", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"alpha", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Beta", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"beta", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Nu", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"nu", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Rho", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"rho", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"AlphaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "alpha", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"BetaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "beta", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"NuIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "nu", " ", "value", " ", "provided",
        " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", 
      " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"RhoIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "rho", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"VegaWeighted", "true", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "interpolation", " ", "is", " ", 
      "weighted", " ", "using", " ", "options", " ", 
      RowBox[{"Vega", "."}]}]},
    {"EndCriteria", "\"\<\>\"", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"OptimizationMethod", "\"\<\>\"", 
     RowBox[{"OptimizationMethod", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->49775439],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XArray", "=", 
   RowBox[{"{", 
    RowBox[{"0.0300", ",", "0.0400", ",", "0.0500", ",", "0.0700"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"YArray", "=", 
   RowBox[{"{", 
    RowBox[{"0.0850", ",", "0.0733", ",", "0.0844", ",", "0.1082"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Expiry", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"forward", "=", "0.039"}], ";"}]}], "Input",
 CellChangeTimes->{{3.43607933203125*^9, 3.4360793321875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[890]:=",
 CellID->111606186],

Cell[CellGroupData[{

Cell["obj=SABRInterpolation[XArray,YArray,Expiry,forward]", "Input",
 CellChangeTimes->{3.436079336296875*^9},
 CellTags->"Constructor",
 CellLabel->"In[894]:=",
 CellID->312834165],

Cell[BoxData[
 RowBox[{"QuantLib`Private`qlSABRInterpolation", "[", 
  RowBox[{"SABRInterpolation1", ",", 
   RowBox[{"{", 
    RowBox[{"0.03`", ",", "0.04`", ",", "0.05`", ",", "0.07`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.085`", ",", "0.0733`", ",", "0.0844`", ",", "0.1082`"}], "}"}],
    ",", "1.`", ",", "0.039`", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "\<\"\"\>", ",", "\<\"\"\>", ",", "True", ",", "True"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.436079336765625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[894]=",
 CellID->114210782]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2D", "Subsection",
 CellTags->"Constructor",
 CellID->43867995],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XArray", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"array", "."}]}]},
    {"YArray", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"y", " ", 
      RowBox[{"array", "."}]}]},
    {"ZMatrix", "exampleValue", 
     RowBox[{"z", "-", 
      RowBox[{"matrix", " ", 
       RowBox[{"values", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->5507110],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterpolationType", "\"\<BiLinear\>\"", 
     RowBox[{
      RowBox[{"2", "D"}], "-", 
      RowBox[{"interpolation", " ", "type", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"e", ".", "g"}], " ", "BiLinear"}], ",", " ", "BiCubic"}], 
         ")"}], "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->1254635],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XArray", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YArray", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ZMatrix", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[895]:=",
 CellID->157722367],

Cell[CellGroupData[{

Cell["obj=Interpolation2D[XArray,YArray,ZMatrix]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[898]:=",
 CellID->620247676],

Cell[BoxData[
 RowBox[{"Interpolation2D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1.`", ",", "2.`", ",", "3.`", ",", "4.`", ",", "5.`", ",", "6.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.`", ",", "2.`", ",", "3.`", ",", "4.`", ",", "5.`", ",", "6.`"}], 
    "}"}], ",", "\<\"0\"\>"}], "]"}]], "Output",
 CellChangeTimes->{3.436079353765625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[898]=",
 CellID->159739971]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->275817596],

Cell[CellGroupData[{

Cell["ExtrapolatorEnableExtrapolation", "Subsection",
 CellTags->"Member",
 CellID->487609906],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"ExtrapolationFlag", "true", 
     RowBox[{"global", " ", "extrapolation", " ", 
      RowBox[{"flag", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->14339098],

Cell[CellGroupData[{

Cell["ExtrapolatorEnableExtrapolation[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[900]:=",
 CellID->28420308],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.436079393875*^9},
 CellTags->"Member",
 CellLabel->"Out[900]=",
 CellID->64004324]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationInterpolate", "Subsection",
 CellTags->"Member",
 CellID->884117755],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValues", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"values", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->371009069],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "0", 
     RowBox[{"allow", " ", "extrapolation", " ", 
      RowBox[{"flag", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->72837732],

Cell[BoxData[
 RowBox[{
  RowBox[{"XValues", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[901]:=",
 CellID->80958084],

Cell[CellGroupData[{

Cell["InterpolationInterpolate[obj,XValues]", "Input",
 CellTags->"Member",
 CellLabel->"In[902]:=",
 CellID->159838357],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.`", ",", "2.`", ",", "3.`", ",", "4.`", ",", "5.`", ",", "6.`"}],
   "}"}]], "Output",
 CellChangeTimes->{3.436079398859375*^9},
 CellTags->"Member",
 CellLabel->"Out[902]=",
 CellID->120279073]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationDerivative", "Subsection",
 CellTags->"Member",
 CellID->465047398],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValues", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"values", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->160066529],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "0", 
     RowBox[{"allow", " ", "extrapolation", " ", 
      RowBox[{"flag", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->335266551],

Cell[BoxData[
 RowBox[{
  RowBox[{"XValues", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[903]:=",
 CellID->361073077],

Cell[CellGroupData[{

Cell["InterpolationDerivative[obj,XValues]", "Input",
 CellTags->"Member",
 CellLabel->"In[904]:=",
 CellID->115870380],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}],
   "}"}]], "Output",
 CellChangeTimes->{3.43607940784375*^9},
 CellTags->"Member",
 CellLabel->"Out[904]=",
 CellID->71316328]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationSecondDerivative", "Subsection",
 CellTags->"Member",
 CellID->416750468],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValues", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"values", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->757377309],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "0", 
     RowBox[{"allow", " ", "extrapolation", " ", 
      RowBox[{"flag", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->650114071],

Cell[BoxData[
 RowBox[{
  RowBox[{"XValues", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[905]:=",
 CellID->205492950],

Cell[CellGroupData[{

Cell["InterpolationSecondDerivative[obj,XValues]", "Input",
 CellTags->"Member",
 CellLabel->"In[906]:=",
 CellID->205959934],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}],
   "}"}]], "Output",
 CellChangeTimes->{3.436079417078125*^9},
 CellTags->"Member",
 CellLabel->"Out[906]=",
 CellID->236630483]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationPrimitive", "Subsection",
 CellTags->"Member",
 CellID->34366807],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValues", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"values", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->201415519],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "0", 
     RowBox[{"allow", " ", "extrapolation", " ", 
      RowBox[{"flag", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->643215689],

Cell[BoxData[
 RowBox[{
  RowBox[{"XValues", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[907]:=",
 CellID->39445489],

Cell[CellGroupData[{

Cell["InterpolationPrimitive[obj,XValues]", "Input",
 CellTags->"Member",
 CellLabel->"In[908]:=",
 CellID->359880906],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "1.`", ",", "3.`", ",", "6.`", ",", "10.`", ",", "15.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436079423015625*^9},
 CellTags->"Member",
 CellLabel->"Out[908]=",
 CellID->129270353]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationIsInRange", "Subsection",
 CellTags->"Member",
 CellID->38738764],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValues", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"values", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->170984309],

Cell[BoxData[
 RowBox[{
  RowBox[{"XValues", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[909]:=",
 CellID->55155204],

Cell[CellGroupData[{

Cell["InterpolationIsInRange[obj,XValues]", "Input",
 CellTags->"Member",
 CellLabel->"In[910]:=",
 CellID->63041376],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.43607943171875*^9},
 CellTags->"Member",
 CellLabel->"Out[910]=",
 CellID->109733683]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationXmin", "Subsection",
 CellTags->"Member",
 CellID->259892943],

Cell[CellGroupData[{

Cell["InterpolationXmin[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[911]:=",
 CellID->28491173],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{3.43607943346875*^9},
 CellTags->"Member",
 CellLabel->"Out[911]=",
 CellID->49323480]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolationXmax", "Subsection",
 CellTags->"Member",
 CellID->89978008],

Cell[CellGroupData[{

Cell["InterpolationXmax[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[912]:=",
 CellID->7372894],

Cell[BoxData["6.`"], "Output",
 CellChangeTimes->{3.43607943578125*^9},
 CellTags->"Member",
 CellLabel->"Out[912]=",
 CellID->148020332]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicInterpolationPrimitiveConstants", "Subsection",
 CellTags->"Member",
 CellID->438909136],

Cell[CellGroupData[{

Cell["CubicInterpolationPrimitiveConstants[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[913]:=",
 CellID->297882399],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantLibError", "::", "\<\"msg\"\>"}], ":", 
  " ", "\<\"\\!\\(\\\"Error retrieving object with id 'Interpolation4' - \
unable to convert reference to type 'class QuantLibAddin::CubicInterpolation' \
found instead 'class QuantLibAddin::GenericInterp'\\\"\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.436079437296875*^9},
 CellTags->"Member",
 CellLabel->"During evaluation of In[913]:=",
 CellID->29142630],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{3.4360794373125*^9},
 CellTags->"Member",
 CellLabel->"Out[913]=",
 CellID->351918545]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicInterpolationACoefficients", "Subsection",
 CellTags->"Member",
 CellID->355663089],

Cell["CubicInterpolationACoefficients[obj]", "Input",
 CellTags->"Member",
 CellID->291824426]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicInterpolationBCoefficients", "Subsection",
 CellTags->"Member",
 CellID->202636195],

Cell["CubicInterpolationBCoefficients[obj]", "Input",
 CellTags->"Member",
 CellID->141390136]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicInterpolationCCoefficients", "Subsection",
 CellTags->"Member",
 CellID->373473921],

Cell["CubicInterpolationCCoefficients[obj]", "Input",
 CellTags->"Member",
 CellID->30651981]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicInterpolationMonotonicityAdjustments", "Subsection",
 CellTags->"Member",
 CellID->666015529],

Cell["CubicInterpolationMonotonicityAdjustments[obj]", "Input",
 CellTags->"Member",
 CellID->299234558]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationA", "Subsection",
 CellTags->"Member",
 CellID->115631053],

Cell["AbcdInterpolationA[obj]", "Input",
 CellTags->"Member",
 CellID->220909795]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationB", "Subsection",
 CellTags->"Member",
 CellID->103680860],

Cell["AbcdInterpolationB[obj]", "Input",
 CellTags->"Member",
 CellID->161867647]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationC", "Subsection",
 CellTags->"Member",
 CellID->260229652],

Cell["AbcdInterpolationC[obj]", "Input",
 CellTags->"Member",
 CellID->566836269]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationD", "Subsection",
 CellTags->"Member",
 CellID->256352235],

Cell["AbcdInterpolationD[obj]", "Input",
 CellTags->"Member",
 CellID->28225329]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationRmsError", "Subsection",
 CellTags->"Member",
 CellID->496517752],

Cell["AbcdInterpolationRmsError[obj]", "Input",
 CellTags->"Member",
 CellID->7379934]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationMaxError", "Subsection",
 CellTags->"Member",
 CellID->773383237],

Cell["AbcdInterpolationMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->152627268]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdInterpolationEndCriteria", "Subsection",
 CellTags->"Member",
 CellID->245463121],

Cell["AbcdInterpolationEndCriteria[obj]", "Input",
 CellTags->"Member",
 CellID->19095549]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationExpiry", "Subsection",
 CellTags->"Member",
 CellID->31336303],

Cell["SABRInterpolationExpiry[obj]", "Input",
 CellTags->"Member",
 CellID->426584260]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationForward", "Subsection",
 CellTags->"Member",
 CellID->84718387],

Cell["SABRInterpolationForward[obj]", "Input",
 CellTags->"Member",
 CellID->759034250]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationAlpha", "Subsection",
 CellTags->"Member",
 CellID->220725109],

Cell["SABRInterpolationAlpha[obj]", "Input",
 CellTags->"Member",
 CellID->81014588]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationBeta", "Subsection",
 CellTags->"Member",
 CellID->139985562],

Cell["SABRInterpolationBeta[obj]", "Input",
 CellTags->"Member",
 CellID->93011036]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationNu", "Subsection",
 CellTags->"Member",
 CellID->92169930],

Cell["SABRInterpolationNu[obj]", "Input",
 CellTags->"Member",
 CellID->263114120]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationRho", "Subsection",
 CellTags->"Member",
 CellID->72621121],

Cell["SABRInterpolationRho[obj]", "Input",
 CellTags->"Member",
 CellID->355748207]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationRmsError", "Subsection",
 CellTags->"Member",
 CellID->576790866],

Cell["SABRInterpolationRmsError[obj]", "Input",
 CellTags->"Member",
 CellID->70744239]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationMaxError", "Subsection",
 CellTags->"Member",
 CellID->106614377],

Cell["SABRInterpolationMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->601252092]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationEndCriteria", "Subsection",
 CellTags->"Member",
 CellID->123560657],

Cell["SABRInterpolationEndCriteria[obj]", "Input",
 CellTags->"Member",
 CellID->527315663]
}, Open  ]],

Cell[CellGroupData[{

Cell["SABRInterpolationWeights", "Subsection",
 CellTags->"Member",
 CellID->115219872],

Cell["SABRInterpolationWeights[obj]", "Input",
 CellTags->"Member",
 CellID->660087686]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DXmin", "Subsection",
 CellTags->"Member",
 CellID->109327145],

Cell["Interpolation2DXmin[obj]", "Input",
 CellTags->"Member",
 CellID->323293494]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DXmax", "Subsection",
 CellTags->"Member",
 CellID->74432868],

Cell["Interpolation2DXmax[obj]", "Input",
 CellTags->"Member",
 CellID->113490632]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DXvalues", "Subsection",
 CellTags->"Member",
 CellID->30186865],

Cell["Interpolation2DXvalues[obj]", "Input",
 CellTags->"Member",
 CellID->388995928]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DYmin", "Subsection",
 CellTags->"Member",
 CellID->300190666],

Cell["Interpolation2DYmin[obj]", "Input",
 CellTags->"Member",
 CellID->94724625]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DYmax", "Subsection",
 CellTags->"Member",
 CellID->788509],

Cell["Interpolation2DYmax[obj]", "Input",
 CellTags->"Member",
 CellID->558981709]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DYvalues", "Subsection",
 CellTags->"Member",
 CellID->433740737],

Cell["Interpolation2DYvalues[obj]", "Input",
 CellTags->"Member",
 CellID->41985933]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DzData", "Subsection",
 CellTags->"Member",
 CellID->44984628],

Cell["Interpolation2DzData[obj]", "Input",
 CellTags->"Member",
 CellID->11447685]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DIsInRange", "Subsection",
 CellTags->"Member",
 CellID->258314603],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValues", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", 
      RowBox[{"values", "."}]}]},
    {"YValue", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"y", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->813445636],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XValues", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YValue", "=", "1.0"}], ",", "2.0", ",", "3.0", ",", "4.0", ",", 
  "5.0", ",", 
  RowBox[{"6.0", ";"}]}]}], "Input",
 CellTags->"Member",
 CellID->567666906],

Cell["Interpolation2DIsInRange[obj,XValues,YValue]", "Input",
 CellTags->"Member",
 CellID->85263842]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation2DInterpolate", "Subsection",
 CellTags->"Member",
 CellID->202769687],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"XValue", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"x", " ", "value", 
      RowBox[{
       RowBox[{"(", "s", ")"}], "."}]}]},
    {"YValue", 
     RowBox[{
     "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
     RowBox[{"y", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->17120061],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "0", 
     RowBox[{"allow", " ", "extrapolation", " ", 
      RowBox[{"flag", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->190954813],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XValue", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0", ",", "6.0"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YValue", "=", "1.0"}], ",", "2.0", ",", "3.0", ",", "4.0", ",", 
  "5.0", ",", 
  RowBox[{"6.0", ";"}]}]}], "Input",
 CellTags->"Member",
 CellID->15855050],

Cell["Interpolation2DInterpolate[obj,XValue,YValue]", "Input",
 CellTags->"Member",
 CellID->52936936]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 603}, {70, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 84, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->147529134],
  Cell[677, 27, 140, 4, 37, "Text",
   CellTags->"Overview",
   CellID->400023536],
  Cell[820, 33, 113, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->53024819],
  Cell[936, 37, 80, 2, 41, "Input",
   CellTags->"Overview",
   CellID->129362553],
  Cell[1019, 41, 161, 5, 37, "Text",
   CellTags->"Overview",
   CellID->519880885],
  Cell[1205, 50, 134, 3, 41, "Input",
   CellTags->"Overview",
   CellID->120708382],
  Cell[1342, 55, 294, 8, 59, "Output",
   CellTags->"Overview",
   CellID->360829308],
  Cell[1673, 68, 129, 3, 41, "Input",
   CellTags->"Overview",
   CellID->120015940],
  Cell[1805, 73, 1518, 27, 363, "Output",
   CellTags->"Overview",
   CellID->182552731]},
 "Constructo"->{
  Cell[3360, 105, 76, 2, 70, "Section",
   CellTags->"Constructo",
   CellID->128445744]},
 "Constructor"->{
  Cell[3461, 111, 81, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->234347461],
  Cell[4834, 150, 425, 15, 70, "Input",
   CellTags->"Constructor",
   CellID->307590788],
  Cell[5284, 169, 224, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->8205107],
  Cell[5511, 177, 224, 6, 70, "Output",
   CellTags->"Constructor",
   CellID->6576384],
  Cell[5784, 189, 86, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->132038921],
  Cell[7694, 242, 390, 13, 70, "Input",
   CellTags->"Constructor",
   CellID->91620548],
  Cell[8109, 259, 125, 3, 70, "Input",
   CellTags->"Constructor",
   CellID->900179266],
  Cell[8237, 264, 157, 4, 70, "Output",
   CellTags->"Constructor",
   CellID->342003258],
  Cell[8443, 274, 84, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->53413663],
  Cell[12218, 385, 385, 13, 70, "Input",
   CellTags->"Constructor",
   CellID->261483164],
  Cell[12628, 402, 123, 3, 70, "Input",
   CellTags->"Constructor",
   CellID->86092494],
  Cell[12754, 407, 606, 13, 70, "Output",
   CellTags->"Constructor",
   CellID->157888383],
  Cell[13409, 426, 85, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->232613869],
  Cell[17384, 542, 567, 18, 70, "Input",
   CellTags->"Constructor",
   CellID->111606186],
  Cell[17976, 564, 181, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->312834165],
  Cell[18160, 570, 637, 14, 70, "Output",
   CellTags->"Constructor",
   CellID->114210782],
  Cell[18846, 590, 82, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->43867995],
  Cell[20043, 630, 491, 17, 70, "Input",
   CellTags->"Constructor",
   CellID->157722367],
  Cell[20559, 651, 130, 3, 70, "Input",
   CellTags->"Constructor",
   CellID->620247676],
  Cell[20692, 656, 445, 14, 70, "Output",
   CellTags->"Constructor",
   CellID->159739971]},
 "Member"->{
  Cell[21198, 677, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->275817596],
  Cell[21298, 683, 94, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->487609906],
  Cell[21696, 697, 118, 3, 70, "Input",
   CellTags->"Member",
   CellID->28420308],
  Cell[21817, 702, 135, 4, 70, "Output",
   CellTags->"Member",
   CellID->64004324],
  Cell[22001, 712, 87, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->884117755],
  Cell[22699, 735, 249, 9, 70, "Input",
   CellTags->"Member",
   CellID->80958084],
  Cell[22973, 748, 120, 3, 70, "Input",
   CellTags->"Member",
   CellID->159838357],
  Cell[23096, 753, 236, 7, 70, "Output",
   CellTags->"Member",
   CellID->120279073],
  Cell[23381, 766, 86, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->465047398],
  Cell[24079, 789, 250, 9, 70, "Input",
   CellTags->"Member",
   CellID->361073077],
  Cell[24354, 802, 119, 3, 70, "Input",
   CellTags->"Member",
   CellID->115870380],
  Cell[24476, 807, 234, 7, 70, "Output",
   CellTags->"Member",
   CellID->71316328],
  Cell[24759, 820, 92, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->416750468],
  Cell[25463, 843, 250, 9, 70, "Input",
   CellTags->"Member",
   CellID->205492950],
  Cell[25738, 856, 125, 3, 70, "Input",
   CellTags->"Member",
   CellID->205959934],
  Cell[25866, 861, 236, 7, 70, "Output",
   CellTags->"Member",
   CellID->236630483],
  Cell[26151, 874, 84, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->34366807],
  Cell[26847, 897, 249, 9, 70, "Input",
   CellTags->"Member",
   CellID->39445489],
  Cell[27121, 910, 118, 3, 70, "Input",
   CellTags->"Member",
   CellID->359880906],
  Cell[27242, 915, 241, 8, 70, "Output",
   CellTags->"Member",
   CellID->129270353],
  Cell[27532, 929, 84, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->38738764],
  Cell[27951, 944, 249, 9, 70, "Input",
   CellTags->"Member",
   CellID->55155204],
  Cell[28225, 957, 117, 3, 70, "Input",
   CellTags->"Member",
   CellID->63041376],
  Cell[28345, 962, 244, 8, 70, "Output",
   CellTags->"Member",
   CellID->109733683],
  Cell[28638, 976, 80, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->259892943],
  Cell[28743, 982, 104, 3, 70, "Input",
   CellTags->"Member",
   CellID->28491173],
  Cell[28850, 987, 136, 4, 70, "Output",
   CellTags->"Member",
   CellID->49323480],
  Cell[29035, 997, 79, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->89978008],
  Cell[29139, 1003, 103, 3, 70, "Input",
   CellTags->"Member",
   CellID->7372894],
  Cell[29245, 1008, 137, 4, 70, "Output",
   CellTags->"Member",
   CellID->148020332],
  Cell[29431, 1018, 99, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->438909136],
  Cell[29555, 1024, 124, 3, 70, "Input",
   CellTags->"Member",
   CellID->297882399],
  Cell[29682, 1029, 449, 10, 70, "Message",
   CellTags->"Member",
   CellID->29142630],
  Cell[30134, 1041, 140, 4, 70, "Output",
   CellTags->"Member",
   CellID->351918545],
  Cell[30323, 1051, 94, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->355663089],
  Cell[30420, 1055, 94, 2, 70, "Input",
   CellTags->"Member",
   CellID->291824426],
  Cell[30551, 1062, 94, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->202636195],
  Cell[30648, 1066, 94, 2, 70, "Input",
   CellTags->"Member",
   CellID->141390136],
  Cell[30779, 1073, 94, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->373473921],
  Cell[30876, 1077, 93, 2, 70, "Input",
   CellTags->"Member",
   CellID->30651981],
  Cell[31006, 1084, 104, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->666015529],
  Cell[31113, 1088, 104, 2, 70, "Input",
   CellTags->"Member",
   CellID->299234558],
  Cell[31254, 1095, 81, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->115631053],
  Cell[31338, 1099, 81, 2, 70, "Input",
   CellTags->"Member",
   CellID->220909795],
  Cell[31456, 1106, 81, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->103680860],
  Cell[31540, 1110, 81, 2, 70, "Input",
   CellTags->"Member",
   CellID->161867647],
  Cell[31658, 1117, 81, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->260229652],
  Cell[31742, 1121, 81, 2, 70, "Input",
   CellTags->"Member",
   CellID->566836269],
  Cell[31860, 1128, 81, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->256352235],
  Cell[31944, 1132, 80, 2, 70, "Input",
   CellTags->"Member",
   CellID->28225329],
  Cell[32061, 1139, 88, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->496517752],
  Cell[32152, 1143, 86, 2, 70, "Input",
   CellTags->"Member",
   CellID->7379934],
  Cell[32275, 1150, 88, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->773383237],
  Cell[32366, 1154, 88, 2, 70, "Input",
   CellTags->"Member",
   CellID->152627268],
  Cell[32491, 1161, 91, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->245463121],
  Cell[32585, 1165, 90, 2, 70, "Input",
   CellTags->"Member",
   CellID->19095549],
  Cell[32712, 1172, 85, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->31336303],
  Cell[32800, 1176, 86, 2, 70, "Input",
   CellTags->"Member",
   CellID->426584260],
  Cell[32923, 1183, 86, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->84718387],
  Cell[33012, 1187, 87, 2, 70, "Input",
   CellTags->"Member",
   CellID->759034250],
  Cell[33136, 1194, 85, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->220725109],
  Cell[33224, 1198, 84, 2, 70, "Input",
   CellTags->"Member",
   CellID->81014588],
  Cell[33345, 1205, 84, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->139985562],
  Cell[33432, 1209, 83, 2, 70, "Input",
   CellTags->"Member",
   CellID->93011036],
  Cell[33552, 1216, 81, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->92169930],
  Cell[33636, 1220, 82, 2, 70, "Input",
   CellTags->"Member",
   CellID->263114120],
  Cell[33755, 1227, 82, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->72621121],
  Cell[33840, 1231, 83, 2, 70, "Input",
   CellTags->"Member",
   CellID->355748207],
  Cell[33960, 1238, 88, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->576790866],
  Cell[34051, 1242, 87, 2, 70, "Input",
   CellTags->"Member",
   CellID->70744239],
  Cell[34175, 1249, 88, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->106614377],
  Cell[34266, 1253, 88, 2, 70, "Input",
   CellTags->"Member",
   CellID->601252092],
  Cell[34391, 1260, 91, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->123560657],
  Cell[34485, 1264, 91, 2, 70, "Input",
   CellTags->"Member",
   CellID->527315663],
  Cell[34613, 1271, 87, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->115219872],
  Cell[34703, 1275, 87, 2, 70, "Input",
   CellTags->"Member",
   CellID->660087686],
  Cell[34827, 1282, 82, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->109327145],
  Cell[34912, 1286, 82, 2, 70, "Input",
   CellTags->"Member",
   CellID->323293494],
  Cell[35031, 1293, 81, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->74432868],
  Cell[35115, 1297, 82, 2, 70, "Input",
   CellTags->"Member",
   CellID->113490632],
  Cell[35234, 1304, 84, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->30186865],
  Cell[35321, 1308, 85, 2, 70, "Input",
   CellTags->"Member",
   CellID->388995928],
  Cell[35443, 1315, 82, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->300190666],
  Cell[35528, 1319, 81, 2, 70, "Input",
   CellTags->"Member",
   CellID->94724625],
  Cell[35646, 1326, 79, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->788509],
  Cell[35728, 1330, 82, 2, 28, "Input",
   CellTags->"Member",
   CellID->558981709],
  Cell[35847, 1337, 85, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->433740737],
  Cell[35935, 1341, 84, 2, 28, "Input",
   CellTags->"Member",
   CellID->41985933],
  Cell[36056, 1348, 82, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->44984628],
  Cell[36141, 1352, 82, 2, 28, "Input",
   CellTags->"Member",
   CellID->11447685],
  Cell[36260, 1359, 87, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->258314603],
  Cell[36844, 1379, 361, 12, 47, "Input",
   CellTags->"Member",
   CellID->567666906],
  Cell[37208, 1393, 101, 2, 28, "Input",
   CellTags->"Member",
   CellID->85263842],
  Cell[37346, 1400, 89, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->202769687],
  Cell[38239, 1429, 359, 12, 47, "Input",
   CellTags->"Member",
   CellID->15855050],
  Cell[38601, 1443, 102, 2, 28, "Input",
   CellTags->"Member",
   CellID->52936936]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 39796, 1481},
 {"Constructo", 40592, 1509},
 {"Constructor", 40701, 1513},
 {"Member", 42551, 1574}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 84, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->147529134],
Cell[677, 27, 140, 4, 37, "Text",
 CellTags->"Overview",
 CellID->400023536],
Cell[820, 33, 113, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->53024819],
Cell[936, 37, 80, 2, 41, "Input",
 CellTags->"Overview",
 CellID->129362553],
Cell[1019, 41, 161, 5, 37, "Text",
 CellTags->"Overview",
 CellID->519880885],
Cell[CellGroupData[{
Cell[1205, 50, 134, 3, 41, "Input",
 CellTags->"Overview",
 CellID->120708382],
Cell[1342, 55, 294, 8, 59, "Output",
 CellTags->"Overview",
 CellID->360829308]
}, Open  ]],
Cell[CellGroupData[{
Cell[1673, 68, 129, 3, 41, "Input",
 CellTags->"Overview",
 CellID->120015940],
Cell[1805, 73, 1518, 27, 363, "Output",
 CellTags->"Overview",
 CellID->182552731]
}, Open  ]],
Cell[CellGroupData[{
Cell[3360, 105, 76, 2, 70, "Section",
 CellTags->"Constructo",
 CellID->128445744],
Cell[CellGroupData[{
Cell[3461, 111, 81, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->234347461],
Cell[3545, 115, 497, 14, 70, "Input",
 CellID->156970020],
Cell[4045, 131, 786, 17, 70, "Input",
 CellID->390104680],
Cell[4834, 150, 425, 15, 70, "Input",
 CellTags->"Constructor",
 CellID->307590788],
Cell[CellGroupData[{
Cell[5284, 169, 224, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->8205107],
Cell[5511, 177, 224, 6, 70, "Output",
 CellTags->"Constructor",
 CellID->6576384]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5784, 189, 86, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->132038921],
Cell[5873, 193, 518, 14, 70, "Input",
 CellID->296791721],
Cell[6394, 209, 1297, 31, 70, "Input",
 CellID->592009787],
Cell[7694, 242, 390, 13, 70, "Input",
 CellTags->"Constructor",
 CellID->91620548],
Cell[CellGroupData[{
Cell[8109, 259, 125, 3, 70, "Input",
 CellTags->"Constructor",
 CellID->900179266],
Cell[8237, 264, 157, 4, 70, "Output",
 CellTags->"Constructor",
 CellID->342003258]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8443, 274, 84, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->53413663],
Cell[8530, 278, 459, 12, 70, "Input",
 CellID->381788490],
Cell[8992, 292, 3223, 91, 70, "Input",
 CellID->772821948],
Cell[12218, 385, 385, 13, 70, "Input",
 CellTags->"Constructor",
 CellID->261483164],
Cell[CellGroupData[{
Cell[12628, 402, 123, 3, 70, "Input",
 CellTags->"Constructor",
 CellID->86092494],
Cell[12754, 407, 606, 13, 70, "Output",
 CellTags->"Constructor",
 CellID->157888383]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13409, 426, 85, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->232613869],
Cell[13497, 430, 626, 17, 70, "Input",
 CellID->144245425],
Cell[14126, 449, 3255, 91, 70, "Input",
 CellID->49775439],
Cell[17384, 542, 567, 18, 70, "Input",
 CellTags->"Constructor",
 CellID->111606186],
Cell[CellGroupData[{
Cell[17976, 564, 181, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->312834165],
Cell[18160, 570, 637, 14, 70, "Output",
 CellTags->"Constructor",
 CellID->114210782]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18846, 590, 82, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->43867995],
Cell[18931, 594, 617, 18, 70, "Input",
 CellID->5507110],
Cell[19551, 614, 489, 14, 70, "Input",
 CellID->1254635],
Cell[20043, 630, 491, 17, 70, "Input",
 CellTags->"Constructor",
 CellID->157722367],
Cell[CellGroupData[{
Cell[20559, 651, 130, 3, 70, "Input",
 CellTags->"Constructor",
 CellID->620247676],
Cell[20692, 656, 445, 14, 70, "Output",
 CellTags->"Constructor",
 CellID->159739971]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21198, 677, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->275817596],
Cell[CellGroupData[{
Cell[21298, 683, 94, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->487609906],
Cell[21395, 687, 276, 6, 70, "Input",
 CellID->14339098],
Cell[CellGroupData[{
Cell[21696, 697, 118, 3, 70, "Input",
 CellTags->"Member",
 CellID->28420308],
Cell[21817, 702, 135, 4, 70, "Output",
 CellTags->"Member",
 CellID->64004324]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22001, 712, 87, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->884117755],
Cell[22091, 716, 329, 9, 70, "Input",
 CellID->371009069],
Cell[22423, 727, 273, 6, 70, "Input",
 CellID->72837732],
Cell[22699, 735, 249, 9, 70, "Input",
 CellTags->"Member",
 CellID->80958084],
Cell[CellGroupData[{
Cell[22973, 748, 120, 3, 70, "Input",
 CellTags->"Member",
 CellID->159838357],
Cell[23096, 753, 236, 7, 70, "Output",
 CellTags->"Member",
 CellID->120279073]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23381, 766, 86, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->465047398],
Cell[23470, 770, 329, 9, 70, "Input",
 CellID->160066529],
Cell[23802, 781, 274, 6, 70, "Input",
 CellID->335266551],
Cell[24079, 789, 250, 9, 70, "Input",
 CellTags->"Member",
 CellID->361073077],
Cell[CellGroupData[{
Cell[24354, 802, 119, 3, 70, "Input",
 CellTags->"Member",
 CellID->115870380],
Cell[24476, 807, 234, 7, 70, "Output",
 CellTags->"Member",
 CellID->71316328]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24759, 820, 92, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->416750468],
Cell[24854, 824, 329, 9, 70, "Input",
 CellID->757377309],
Cell[25186, 835, 274, 6, 70, "Input",
 CellID->650114071],
Cell[25463, 843, 250, 9, 70, "Input",
 CellTags->"Member",
 CellID->205492950],
Cell[CellGroupData[{
Cell[25738, 856, 125, 3, 70, "Input",
 CellTags->"Member",
 CellID->205959934],
Cell[25866, 861, 236, 7, 70, "Output",
 CellTags->"Member",
 CellID->236630483]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26151, 874, 84, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->34366807],
Cell[26238, 878, 329, 9, 70, "Input",
 CellID->201415519],
Cell[26570, 889, 274, 6, 70, "Input",
 CellID->643215689],
Cell[26847, 897, 249, 9, 70, "Input",
 CellTags->"Member",
 CellID->39445489],
Cell[CellGroupData[{
Cell[27121, 910, 118, 3, 70, "Input",
 CellTags->"Member",
 CellID->359880906],
Cell[27242, 915, 241, 8, 70, "Output",
 CellTags->"Member",
 CellID->129270353]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27532, 929, 84, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->38738764],
Cell[27619, 933, 329, 9, 70, "Input",
 CellID->170984309],
Cell[27951, 944, 249, 9, 70, "Input",
 CellTags->"Member",
 CellID->55155204],
Cell[CellGroupData[{
Cell[28225, 957, 117, 3, 70, "Input",
 CellTags->"Member",
 CellID->63041376],
Cell[28345, 962, 244, 8, 70, "Output",
 CellTags->"Member",
 CellID->109733683]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28638, 976, 80, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->259892943],
Cell[CellGroupData[{
Cell[28743, 982, 104, 3, 70, "Input",
 CellTags->"Member",
 CellID->28491173],
Cell[28850, 987, 136, 4, 70, "Output",
 CellTags->"Member",
 CellID->49323480]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29035, 997, 79, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->89978008],
Cell[CellGroupData[{
Cell[29139, 1003, 103, 3, 70, "Input",
 CellTags->"Member",
 CellID->7372894],
Cell[29245, 1008, 137, 4, 70, "Output",
 CellTags->"Member",
 CellID->148020332]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29431, 1018, 99, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->438909136],
Cell[CellGroupData[{
Cell[29555, 1024, 124, 3, 70, "Input",
 CellTags->"Member",
 CellID->297882399],
Cell[29682, 1029, 449, 10, 70, "Message",
 CellTags->"Member",
 CellID->29142630],
Cell[30134, 1041, 140, 4, 70, "Output",
 CellTags->"Member",
 CellID->351918545]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30323, 1051, 94, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->355663089],
Cell[30420, 1055, 94, 2, 70, "Input",
 CellTags->"Member",
 CellID->291824426]
}, Open  ]],
Cell[CellGroupData[{
Cell[30551, 1062, 94, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->202636195],
Cell[30648, 1066, 94, 2, 70, "Input",
 CellTags->"Member",
 CellID->141390136]
}, Open  ]],
Cell[CellGroupData[{
Cell[30779, 1073, 94, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->373473921],
Cell[30876, 1077, 93, 2, 70, "Input",
 CellTags->"Member",
 CellID->30651981]
}, Open  ]],
Cell[CellGroupData[{
Cell[31006, 1084, 104, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->666015529],
Cell[31113, 1088, 104, 2, 70, "Input",
 CellTags->"Member",
 CellID->299234558]
}, Open  ]],
Cell[CellGroupData[{
Cell[31254, 1095, 81, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->115631053],
Cell[31338, 1099, 81, 2, 70, "Input",
 CellTags->"Member",
 CellID->220909795]
}, Open  ]],
Cell[CellGroupData[{
Cell[31456, 1106, 81, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->103680860],
Cell[31540, 1110, 81, 2, 70, "Input",
 CellTags->"Member",
 CellID->161867647]
}, Open  ]],
Cell[CellGroupData[{
Cell[31658, 1117, 81, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->260229652],
Cell[31742, 1121, 81, 2, 70, "Input",
 CellTags->"Member",
 CellID->566836269]
}, Open  ]],
Cell[CellGroupData[{
Cell[31860, 1128, 81, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->256352235],
Cell[31944, 1132, 80, 2, 70, "Input",
 CellTags->"Member",
 CellID->28225329]
}, Open  ]],
Cell[CellGroupData[{
Cell[32061, 1139, 88, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->496517752],
Cell[32152, 1143, 86, 2, 70, "Input",
 CellTags->"Member",
 CellID->7379934]
}, Open  ]],
Cell[CellGroupData[{
Cell[32275, 1150, 88, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->773383237],
Cell[32366, 1154, 88, 2, 70, "Input",
 CellTags->"Member",
 CellID->152627268]
}, Open  ]],
Cell[CellGroupData[{
Cell[32491, 1161, 91, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->245463121],
Cell[32585, 1165, 90, 2, 70, "Input",
 CellTags->"Member",
 CellID->19095549]
}, Open  ]],
Cell[CellGroupData[{
Cell[32712, 1172, 85, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->31336303],
Cell[32800, 1176, 86, 2, 70, "Input",
 CellTags->"Member",
 CellID->426584260]
}, Open  ]],
Cell[CellGroupData[{
Cell[32923, 1183, 86, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->84718387],
Cell[33012, 1187, 87, 2, 70, "Input",
 CellTags->"Member",
 CellID->759034250]
}, Open  ]],
Cell[CellGroupData[{
Cell[33136, 1194, 85, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->220725109],
Cell[33224, 1198, 84, 2, 70, "Input",
 CellTags->"Member",
 CellID->81014588]
}, Open  ]],
Cell[CellGroupData[{
Cell[33345, 1205, 84, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->139985562],
Cell[33432, 1209, 83, 2, 70, "Input",
 CellTags->"Member",
 CellID->93011036]
}, Open  ]],
Cell[CellGroupData[{
Cell[33552, 1216, 81, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->92169930],
Cell[33636, 1220, 82, 2, 70, "Input",
 CellTags->"Member",
 CellID->263114120]
}, Open  ]],
Cell[CellGroupData[{
Cell[33755, 1227, 82, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->72621121],
Cell[33840, 1231, 83, 2, 70, "Input",
 CellTags->"Member",
 CellID->355748207]
}, Open  ]],
Cell[CellGroupData[{
Cell[33960, 1238, 88, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->576790866],
Cell[34051, 1242, 87, 2, 70, "Input",
 CellTags->"Member",
 CellID->70744239]
}, Open  ]],
Cell[CellGroupData[{
Cell[34175, 1249, 88, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->106614377],
Cell[34266, 1253, 88, 2, 70, "Input",
 CellTags->"Member",
 CellID->601252092]
}, Open  ]],
Cell[CellGroupData[{
Cell[34391, 1260, 91, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->123560657],
Cell[34485, 1264, 91, 2, 70, "Input",
 CellTags->"Member",
 CellID->527315663]
}, Open  ]],
Cell[CellGroupData[{
Cell[34613, 1271, 87, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->115219872],
Cell[34703, 1275, 87, 2, 70, "Input",
 CellTags->"Member",
 CellID->660087686]
}, Open  ]],
Cell[CellGroupData[{
Cell[34827, 1282, 82, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->109327145],
Cell[34912, 1286, 82, 2, 70, "Input",
 CellTags->"Member",
 CellID->323293494]
}, Open  ]],
Cell[CellGroupData[{
Cell[35031, 1293, 81, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->74432868],
Cell[35115, 1297, 82, 2, 70, "Input",
 CellTags->"Member",
 CellID->113490632]
}, Open  ]],
Cell[CellGroupData[{
Cell[35234, 1304, 84, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->30186865],
Cell[35321, 1308, 85, 2, 70, "Input",
 CellTags->"Member",
 CellID->388995928]
}, Open  ]],
Cell[CellGroupData[{
Cell[35443, 1315, 82, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->300190666],
Cell[35528, 1319, 81, 2, 70, "Input",
 CellTags->"Member",
 CellID->94724625]
}, Open  ]],
Cell[CellGroupData[{
Cell[35646, 1326, 79, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->788509],
Cell[35728, 1330, 82, 2, 28, "Input",
 CellTags->"Member",
 CellID->558981709]
}, Open  ]],
Cell[CellGroupData[{
Cell[35847, 1337, 85, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->433740737],
Cell[35935, 1341, 84, 2, 28, "Input",
 CellTags->"Member",
 CellID->41985933]
}, Open  ]],
Cell[CellGroupData[{
Cell[36056, 1348, 82, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->44984628],
Cell[36141, 1352, 82, 2, 28, "Input",
 CellTags->"Member",
 CellID->11447685]
}, Open  ]],
Cell[CellGroupData[{
Cell[36260, 1359, 87, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->258314603],
Cell[36350, 1363, 491, 14, 119, "Input",
 CellID->813445636],
Cell[36844, 1379, 361, 12, 47, "Input",
 CellTags->"Member",
 CellID->567666906],
Cell[37208, 1393, 101, 2, 28, "Input",
 CellTags->"Member",
 CellID->85263842]
}, Open  ]],
Cell[CellGroupData[{
Cell[37346, 1400, 89, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->202769687],
Cell[37438, 1404, 521, 15, 119, "Input",
 CellID->17120061],
Cell[37962, 1421, 274, 6, 65, "Input",
 CellID->190954813],
Cell[38239, 1429, 359, 12, 47, "Input",
 CellTags->"Member",
 CellID->15855050],
Cell[38601, 1443, 102, 2, 28, "Input",
 CellTags->"Member",
 CellID->52936936]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
