(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     34012,       1289]
NotebookOptionsPosition[     19719,        756]
NotebookOutlinePosition[     26647,        997]
CellTagsIndexPosition[     26492,        989]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["Leg"], "Chapter",
 CellTags->"Overview",
 CellID->438105594],

Cell["functions to construct and use Leg objects.", "Text",
 CellTags->"Overview",
 CellID->871458186],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->387525675],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->21269361],

Cell["\<\
Within the Leg part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->422800860],

Cell[CellGroupData[{

Cell["Select[Category[Leg],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[943]:=",
 CellID->489339667],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"InterestRate", ",", "MultiPhaseLeg"}], "}"}]], "Output",
 CellChangeTimes->{3.4360794965*^9},
 CellTags->"Overview",
 CellLabel->"Out[943]=",
 CellID->19459365]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Leg],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[944]:=",
 CellID->516112855],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "InterestRateCompounding", ",", "InterestRateDayCounter", ",", 
   "InterestRateFrequency", ",", "InterestRateRate", ",", "LegAnalysis", ",", 
   "LegAtmRate", ",", "LegBPS", ",", "LegBPS2", ",", "LegConvexity", ",", 
   "LegDuration", ",", "LegIrr", ",", "LegMaturityDate", ",", "LegNPV", ",", 
   "LegNPV2", ",", "LegNextCouponRate", ",", "LegPreviousCouponRate", ",", 
   "LegSetCouponPricers", ",", "LegStartDate"}], "}"}]], "Output",
 CellChangeTimes->{3.43607949734375*^9},
 CellTags->"Overview",
 CellLabel->"Out[944]=",
 CellID->120461403]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->169957675],

Cell[CellGroupData[{

Cell["MultiPhaseLeg", "Subsection",
 CellTags->"Constructor",
 CellID->446300727],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LegIDs", "exampleValue", 
     RowBox[{
      RowBox[{"leg", " ", "object", " ", "IDs"}], ",", " ", 
      RowBox[{"one", " ", "for", " ", "each", " ", 
       RowBox[{"phase", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->67793889],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"ToBeSorted", "true", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "CashFlows", " ", "in", " ", "the", 
      " ", "merged", " ", "Leg", " ", "must", " ", "be", " ", "sorted", " ", 
      "according", " ", "to", " ", 
      RowBox[{"date", "/", 
       RowBox[{"amount", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->307164518],

Cell[BoxData[
 RowBox[{
  RowBox[{"LegIDs", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]], "Input",
 CellTags->"Constructor",
 CellID->187164799],

Cell["obj=MultiPhaseLeg[LegIDs]", "Input",
 CellTags->"Constructor",
 CellID->266059714]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterestRate", "Subsection",
 CellTags->"Constructor",
 CellID->460561115],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Rate", "0.04", 
     RowBox[{"rate", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->483723954],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
     RowBox[{"Irr", " ", "DayCounter", " ", 
      RowBox[{"ID", "."}]}]},
    {"Compounding", "\"\<Continuous\>\"", 
     RowBox[{"Interest", " ", "rate", " ", "coumpounding", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Simple", ":", 
          RowBox[{"1", "+", "rt"}]}], ",", " ", 
         RowBox[{"Compounded", ":", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "^", "t"}]}], ",", " ", 
         RowBox[{"Continuous", ":", 
          RowBox[{"e", "^", 
           RowBox[{"{", "rt", "}"}]}]}]}], ")"}], "."}]}]},
    {"Frequency", "\"\<Annual\>\"", 
     RowBox[{"frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->294901263],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rate", "=", "0.04"}], ";"}]], "Input",
 CellTags->"Constructor",
 CellLabel->"In[941]:=",
 CellID->176258563],

Cell[CellGroupData[{

Cell["obj=InterestRate[Rate]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[942]:=",
 CellID->40487384],

Cell[BoxData["InterestRate1"], "Output",
 CellChangeTimes->{3.4360794919375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[942]=",
 CellID->180849005]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->281647150],

Cell[CellGroupData[{

Cell["LegPreviousCouponRate", "Subsection",
 CellTags->"Member",
 CellID->2665082],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->395588543],

Cell[CellGroupData[{

Cell["LegPreviousCouponRate[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[945]:=",
 CellID->115688449],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantLibError", "::", "\<\"msg\"\>"}], ":", 
  " ", "\<\"\\!\\(\\\"Error retrieving object with id 'InterestRate1' - \
unable to convert reference to type 'class QuantLibAddin::Leg' found instead \
'class QuantLibAddin::InterestRate'\\\"\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.436079502625*^9},
 CellTags->"Member",
 CellLabel->"During evaluation of In[945]:=",
 CellID->54458810],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{3.436079502625*^9},
 CellTags->"Member",
 CellLabel->"Out[945]=",
 CellID->98848353]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegNextCouponRate", "Subsection",
 CellTags->"Member",
 CellID->170550518],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->493152365],

Cell["LegNextCouponRate[obj]", "Input",
 CellTags->"Member",
 CellID->4116332]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegStartDate", "Subsection",
 CellTags->"Member",
 CellID->128615301],

Cell["LegStartDate[obj]", "Input",
 CellTags->"Member",
 CellID->121500215]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegMaturityDate", "Subsection",
 CellTags->"Member",
 CellID->523833029],

Cell["LegMaturityDate[obj]", "Input",
 CellTags->"Member",
 CellID->606545059]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegNPV", "Subsection",
 CellTags->"Member",
 CellID->856937496],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", "EURYC", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->157885765],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]},
    {"NpvDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"npv", " ", 
      RowBox[{"date", "."}]}]},
    {"ExDividendDays", "0", 
     RowBox[{"ex", "-", 
      RowBox[{"dividend", " ", 
       RowBox[{"days", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->157783548],

Cell[BoxData[
 RowBox[{
  RowBox[{"YieldCurve", "=", "EURYC"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->312606946],

Cell["LegNPV[obj,YieldCurve]", "Input",
 CellTags->"Member",
 CellID->694085938]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegNPV2", "Subsection",
 CellTags->"Member",
 CellID->250065491],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterestRate", "exampleValue", 
     RowBox[{"interest", " ", "rate", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->48706409],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->545533062],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterestRate", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->205250757],

Cell["LegNPV2[obj,InterestRate]", "Input",
 CellTags->"Member",
 CellID->246453759]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegBPS", "Subsection",
 CellTags->"Member",
 CellID->98920351],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", "EURYC", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->287023002],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]},
    {"NpvDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"npv", " ", 
      RowBox[{"date", "."}]}]},
    {"ExDividendDays", "0", 
     RowBox[{"ex", "-", 
      RowBox[{"dividend", " ", 
       RowBox[{"days", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->153236216],

Cell[BoxData[
 RowBox[{
  RowBox[{"YieldCurve", "=", "EURYC"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->9586265],

Cell["LegBPS[obj,YieldCurve]", "Input",
 CellTags->"Member",
 CellID->9829634]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegBPS2", "Subsection",
 CellTags->"Member",
 CellID->514205396],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterestRate", "exampleValue", 
     RowBox[{"interest", " ", "rate", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->29439241],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->249056131],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterestRate", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->68890458],

Cell["LegBPS2[obj,InterestRate]", "Input",
 CellTags->"Member",
 CellID->152722081]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegAtmRate", "Subsection",
 CellTags->"Member",
 CellID->9147348],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", "EURYC", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->280343960],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]},
    {"NpvDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"npv", " ", 
      RowBox[{"date", "."}]}]},
    {"ExDividendDays", "0", 
     RowBox[{"ex", "-", 
      RowBox[{"dividend", " ", 
       RowBox[{"days", "."}]}]}]},
    {"NPV", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Real"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"market", " ", 
      RowBox[{"Price", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->1204570],

Cell[BoxData[
 RowBox[{
  RowBox[{"YieldCurve", "=", "EURYC"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->76535909],

Cell["LegAtmRate[obj,YieldCurve]", "Input",
 CellTags->"Member",
 CellID->107258109]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegIrr", "Subsection",
 CellTags->"Member",
 CellID->685981342],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"MarketPrice", "100.0", 
     RowBox[{"market", " ", 
      RowBox[{"Price", "."}]}]},
    {"DayCounter", 
     RowBox[{
      RowBox[{"Actual", "/", "Actual"}], " ", 
      RowBox[{"(", "ISMA", ")"}]}], 
     RowBox[{"Irr", " ", "DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->51246083],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Compounding", "\"\<Continuous\>\"", 
     RowBox[{"Interest", " ", "rate", " ", "coumpounding", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Simple", ":", 
          RowBox[{"1", "+", "rt"}]}], ",", " ", 
         RowBox[{"Compounded", ":", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "^", "t"}]}], ",", " ", 
         RowBox[{"Continuous", ":", 
          RowBox[{"e", "^", 
           RowBox[{"{", "rt", "}"}]}]}]}], ")"}], "."}]}]},
    {"Frequency", "\"\<Annual\>\"", 
     RowBox[{"frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]},
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]},
    {"Accuracy", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "10"}], 
     RowBox[{"tolerance", "."}]},
    {"MaxIterations", "100", 
     RowBox[{"max", " ", "number", " ", "of", " ", 
      RowBox[{"iterations", "."}]}]},
    {"Guess", "0.05", 
     RowBox[{"guess", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->276771592],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MarketPrice", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"DayCounter", "=", 
   RowBox[{
    RowBox[{"Actual", "/", "Actual"}], " ", 
    RowBox[{"(", "ISMA", ")"}]}]}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->585538125],

Cell["LegIrr[obj,MarketPrice,DayCounter]", "Input",
 CellTags->"Member",
 CellID->475627948]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegDuration", "Subsection",
 CellTags->"Member",
 CellID->47635424],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterestRate", "exampleValue", 
     RowBox[{"InterestRate", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->210419695],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DurationType", "\"\<Modified\>\"", 
     RowBox[{"Duration", " ", 
      RowBox[{"type", "."}]}]},
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->418006382],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterestRate", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->59243658],

Cell["LegDuration[obj,InterestRate]", "Input",
 CellTags->"Member",
 CellID->10628452]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegConvexity", "Subsection",
 CellTags->"Member",
 CellID->1055336179],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterestRate", "exampleValue", 
     RowBox[{"interest", " ", "rate", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->23427619],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->11970386],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterestRate", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->475078751],

Cell["LegConvexity[obj,InterestRate]", "Input",
 CellTags->"Member",
 CellID->10254929]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegAnalysis", "Subsection",
 CellTags->"Member",
 CellID->55299686],

Cell["LegAnalysis[obj]", "Input",
 CellTags->"Member",
 CellID->499048731]
}, Open  ]],

Cell[CellGroupData[{

Cell["LegSetCouponPricers", "Subsection",
 CellTags->"Member",
 CellID->415070798],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FloatingRateCouponPricer", "exampleValue", 
     RowBox[{
     "FloatingRate", " ", "coupon", " ", "pricer", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->34637506],

Cell[BoxData[
 RowBox[{
  RowBox[{"FloatingRateCouponPricer", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellID->211038013],

Cell["LegSetCouponPricers[obj,FloatingRateCouponPricer]", "Input",
 CellTags->"Member",
 CellID->8432150]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterestRateRate", "Subsection",
 CellTags->"Member",
 CellID->412118987],

Cell["InterestRateRate[obj]", "Input",
 CellTags->"Member",
 CellID->439037325]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterestRateDayCounter", "Subsection",
 CellTags->"Member",
 CellID->598778145],

Cell["InterestRateDayCounter[obj]", "Input",
 CellTags->"Member",
 CellID->2685260]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterestRateCompounding", "Subsection",
 CellTags->"Member",
 CellID->19020383],

Cell["InterestRateCompounding[obj]", "Input",
 CellTags->"Member",
 CellID->275917672]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterestRateFrequency", "Subsection",
 CellTags->"Member",
 CellID->75312703],

Cell["InterestRateFrequency[obj]", "Input",
 CellTags->"Member",
 CellID->308544809]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 631}, {Automatic, 67}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 74, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->438105594],
  Cell[667, 27, 102, 2, 37, "Text",
   CellTags->"Overview",
   CellID->871458186],
  Cell[772, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->387525675],
  Cell[889, 35, 79, 2, 41, "Input",
   CellTags->"Overview",
   CellID->21269361],
  Cell[971, 39, 151, 5, 37, "Text",
   CellTags->"Overview",
   CellID->422800860],
  Cell[1147, 48, 124, 3, 41, "Input",
   CellTags->"Overview",
   CellID->489339667],
  Cell[1274, 53, 200, 6, 39, "Output",
   CellTags->"Overview",
   CellID->19459365],
  Cell[1511, 64, 119, 3, 41, "Input",
   CellTags->"Overview",
   CellID->516112855],
  Cell[1633, 69, 589, 12, 116, "Output",
   CellTags->"Overview",
   CellID->120461403]},
 "Constructo"->{
  Cell[2259, 86, 76, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->169957675]},
 "Constructor"->{
  Cell[2360, 92, 81, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->446300727],
  Cell[3280, 120, 153, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->187164799],
  Cell[3436, 127, 88, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->266059714],
  Cell[3561, 134, 80, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->460561115],
  Cell[5026, 177, 144, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->176258563],
  Cell[5195, 186, 109, 3, 70, "Input",
   CellTags->"Constructor",
   CellID->40487384],
  Cell[5307, 191, 151, 4, 70, "Output",
   CellTags->"Constructor",
   CellID->180849005]},
 "Member"->{
  Cell[5519, 202, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->281647150],
  Cell[5619, 208, 82, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->2665082],
  Cell[6063, 225, 109, 3, 70, "Input",
   CellTags->"Member",
   CellID->115688449],
  Cell[6175, 230, 427, 9, 70, "Message",
   CellTags->"Member",
   CellID->54458810],
  Cell[6605, 241, 138, 4, 70, "Output",
   CellTags->"Member",
   CellID->98848353],
  Cell[6792, 251, 80, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->170550518],
  Cell[7212, 266, 78, 2, 70, "Input",
   CellTags->"Member",
   CellID->4116332],
  Cell[7327, 273, 75, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->128615301],
  Cell[7405, 277, 75, 2, 70, "Input",
   CellTags->"Member",
   CellID->121500215],
  Cell[7517, 284, 78, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->523833029],
  Cell[7598, 288, 78, 2, 70, "Input",
   CellTags->"Member",
   CellID->606545059],
  Cell[7713, 295, 69, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->856937496],
  Cell[8707, 329, 121, 4, 70, "Input",
   CellTags->"Member",
   CellID->312606946],
  Cell[8831, 335, 80, 2, 70, "Input",
   CellTags->"Member",
   CellID->694085938],
  Cell[8948, 342, 70, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->250065491],
  Cell[9652, 366, 130, 4, 70, "Input",
   CellTags->"Member",
   CellID->205250757],
  Cell[9785, 372, 83, 2, 70, "Input",
   CellTags->"Member",
   CellID->246453759],
  Cell[9905, 379, 68, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->98920351],
  Cell[10898, 413, 119, 4, 70, "Input",
   CellTags->"Member",
   CellID->9586265],
  Cell[11020, 419, 78, 2, 70, "Input",
   CellTags->"Member",
   CellID->9829634],
  Cell[11135, 426, 70, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->514205396],
  Cell[11839, 450, 129, 4, 70, "Input",
   CellTags->"Member",
   CellID->68890458],
  Cell[11971, 456, 83, 2, 70, "Input",
   CellTags->"Member",
   CellID->152722081],
  Cell[12091, 463, 71, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->9147348],
  Cell[13299, 504, 120, 4, 70, "Input",
   CellTags->"Member",
   CellID->76535909],
  Cell[13422, 510, 84, 2, 70, "Input",
   CellTags->"Member",
   CellID->107258109],
  Cell[13543, 517, 69, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->685981342],
  Cell[15548, 578, 271, 9, 70, "Input",
   CellTags->"Member",
   CellID->585538125],
  Cell[15822, 589, 92, 2, 70, "Input",
   CellTags->"Member",
   CellID->475627948],
  Cell[15951, 596, 73, 2, 70, "Subsection",
   CellTags->"Member",
   CellID->47635424],
  Cell[16755, 623, 129, 4, 70, "Input",
   CellTags->"Member",
   CellID->59243658],
  Cell[16887, 629, 86, 2, 70, "Input",
   CellTags->"Member",
   CellID->10628452],
  Cell[17010, 636, 76, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->1055336179],
  Cell[17719, 660, 130, 4, 28, "Input",
   CellTags->"Member",
   CellID->475078751],
  Cell[17852, 666, 87, 2, 28, "Input",
   CellTags->"Member",
   CellID->10254929],
  Cell[17976, 673, 73, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->55299686],
  Cell[18052, 677, 74, 2, 28, "Input",
   CellTags->"Member",
   CellID->499048731],
  Cell[18163, 684, 82, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->415070798],
  Cell[18581, 698, 166, 5, 28, "Input",
   CellTags->"Member",
   CellID->211038013],
  Cell[18750, 705, 105, 2, 28, "Input",
   CellTags->"Member",
   CellID->8432150],
  Cell[18892, 712, 79, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->412118987],
  Cell[18974, 716, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->439037325],
  Cell[19090, 723, 85, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->598778145],
  Cell[19178, 727, 83, 2, 28, "Input",
   CellTags->"Member",
   CellID->2685260],
  Cell[19298, 734, 85, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->19020383],
  Cell[19386, 738, 86, 2, 28, "Input",
   CellTags->"Member",
   CellID->275917672],
  Cell[19509, 745, 83, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->75312703],
  Cell[19595, 749, 84, 2, 28, "Input",
   CellTags->"Member",
   CellID->308544809]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 20772, 787},
 {"Constructo", 21565, 815},
 {"Constructor", 21673, 819},
 {"Member", 22323, 841}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 74, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->438105594],
Cell[667, 27, 102, 2, 37, "Text",
 CellTags->"Overview",
 CellID->871458186],
Cell[772, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->387525675],
Cell[889, 35, 79, 2, 41, "Input",
 CellTags->"Overview",
 CellID->21269361],
Cell[971, 39, 151, 5, 37, "Text",
 CellTags->"Overview",
 CellID->422800860],
Cell[CellGroupData[{
Cell[1147, 48, 124, 3, 41, "Input",
 CellTags->"Overview",
 CellID->489339667],
Cell[1274, 53, 200, 6, 39, "Output",
 CellTags->"Overview",
 CellID->19459365]
}, Open  ]],
Cell[CellGroupData[{
Cell[1511, 64, 119, 3, 41, "Input",
 CellTags->"Overview",
 CellID->516112855],
Cell[1633, 69, 589, 12, 116, "Output",
 CellTags->"Overview",
 CellID->120461403]
}, Open  ]],
Cell[CellGroupData[{
Cell[2259, 86, 76, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->169957675],
Cell[CellGroupData[{
Cell[2360, 92, 81, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->446300727],
Cell[2444, 96, 365, 9, 93, "Input",
 CellID->67793889],
Cell[2812, 107, 465, 11, 113, "Input",
 CellID->307164518],
Cell[3280, 120, 153, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->187164799],
Cell[3436, 127, 88, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->266059714]
}, Open  ]],
Cell[CellGroupData[{
Cell[3561, 134, 80, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->460561115],
Cell[3644, 138, 222, 6, 70, "Input",
 CellID->483723954],
Cell[3869, 146, 1154, 29, 70, "Input",
 CellID->294901263],
Cell[5026, 177, 144, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->176258563],
Cell[CellGroupData[{
Cell[5195, 186, 109, 3, 70, "Input",
 CellTags->"Constructor",
 CellID->40487384],
Cell[5307, 191, 151, 4, 70, "Output",
 CellTags->"Constructor",
 CellID->180849005]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5519, 202, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->281647150],
Cell[CellGroupData[{
Cell[5619, 208, 82, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->2665082],
Cell[5704, 212, 334, 9, 70, "Input",
 CellID->395588543],
Cell[CellGroupData[{
Cell[6063, 225, 109, 3, 70, "Input",
 CellTags->"Member",
 CellID->115688449],
Cell[6175, 230, 427, 9, 70, "Message",
 CellTags->"Member",
 CellID->54458810],
Cell[6605, 241, 138, 4, 70, "Output",
 CellTags->"Member",
 CellID->98848353]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6792, 251, 80, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->170550518],
Cell[6875, 255, 334, 9, 70, "Input",
 CellID->493152365],
Cell[7212, 266, 78, 2, 70, "Input",
 CellTags->"Member",
 CellID->4116332]
}, Open  ]],
Cell[CellGroupData[{
Cell[7327, 273, 75, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->128615301],
Cell[7405, 277, 75, 2, 70, "Input",
 CellTags->"Member",
 CellID->121500215]
}, Open  ]],
Cell[CellGroupData[{
Cell[7517, 284, 78, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->523833029],
Cell[7598, 288, 78, 2, 70, "Input",
 CellTags->"Member",
 CellID->606545059]
}, Open  ]],
Cell[CellGroupData[{
Cell[7713, 295, 69, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->856937496],
Cell[7785, 299, 300, 7, 70, "Input",
 CellID->157885765],
Cell[8088, 308, 616, 19, 70, "Input",
 CellID->157783548],
Cell[8707, 329, 121, 4, 70, "Input",
 CellTags->"Member",
 CellID->312606946],
Cell[8831, 335, 80, 2, 70, "Input",
 CellTags->"Member",
 CellID->694085938]
}, Open  ]],
Cell[CellGroupData[{
Cell[8948, 342, 70, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->250065491],
Cell[9021, 346, 291, 7, 70, "Input",
 CellID->48706409],
Cell[9315, 355, 334, 9, 70, "Input",
 CellID->545533062],
Cell[9652, 366, 130, 4, 70, "Input",
 CellTags->"Member",
 CellID->205250757],
Cell[9785, 372, 83, 2, 70, "Input",
 CellTags->"Member",
 CellID->246453759]
}, Open  ]],
Cell[CellGroupData[{
Cell[9905, 379, 68, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->98920351],
Cell[9976, 383, 300, 7, 70, "Input",
 CellID->287023002],
Cell[10279, 392, 616, 19, 70, "Input",
 CellID->153236216],
Cell[10898, 413, 119, 4, 70, "Input",
 CellTags->"Member",
 CellID->9586265],
Cell[11020, 419, 78, 2, 70, "Input",
 CellTags->"Member",
 CellID->9829634]
}, Open  ]],
Cell[CellGroupData[{
Cell[11135, 426, 70, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->514205396],
Cell[11208, 430, 291, 7, 70, "Input",
 CellID->29439241],
Cell[11502, 439, 334, 9, 70, "Input",
 CellID->249056131],
Cell[11839, 450, 129, 4, 70, "Input",
 CellTags->"Member",
 CellID->68890458],
Cell[11971, 456, 83, 2, 70, "Input",
 CellTags->"Member",
 CellID->152722081]
}, Open  ]],
Cell[CellGroupData[{
Cell[12091, 463, 71, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->9147348],
Cell[12165, 467, 300, 7, 70, "Input",
 CellID->280343960],
Cell[12468, 476, 828, 26, 70, "Input",
 CellID->1204570],
Cell[13299, 504, 120, 4, 70, "Input",
 CellTags->"Member",
 CellID->76535909],
Cell[13422, 510, 84, 2, 70, "Input",
 CellTags->"Member",
 CellID->107258109]
}, Open  ]],
Cell[CellGroupData[{
Cell[13543, 517, 69, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->685981342],
Cell[13615, 521, 449, 13, 70, "Input",
 CellID->51246083],
Cell[14067, 536, 1478, 40, 70, "Input",
 CellID->276771592],
Cell[15548, 578, 271, 9, 70, "Input",
 CellTags->"Member",
 CellID->585538125],
Cell[15822, 589, 92, 2, 70, "Input",
 CellTags->"Member",
 CellID->475627948]
}, Open  ]],
Cell[CellGroupData[{
Cell[15951, 596, 73, 2, 70, "Subsection",
 CellTags->"Member",
 CellID->47635424],
Cell[16027, 600, 283, 7, 70, "Input",
 CellID->210419695],
Cell[16313, 609, 439, 12, 70, "Input",
 CellID->418006382],
Cell[16755, 623, 129, 4, 70, "Input",
 CellTags->"Member",
 CellID->59243658],
Cell[16887, 629, 86, 2, 70, "Input",
 CellTags->"Member",
 CellID->10628452]
}, Open  ]],
Cell[CellGroupData[{
Cell[17010, 636, 76, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->1055336179],
Cell[17089, 640, 291, 7, 65, "Input",
 CellID->23427619],
Cell[17383, 649, 333, 9, 99, "Input",
 CellID->11970386],
Cell[17719, 660, 130, 4, 28, "Input",
 CellTags->"Member",
 CellID->475078751],
Cell[17852, 666, 87, 2, 28, "Input",
 CellTags->"Member",
 CellID->10254929]
}, Open  ]],
Cell[CellGroupData[{
Cell[17976, 673, 73, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->55299686],
Cell[18052, 677, 74, 2, 28, "Input",
 CellTags->"Member",
 CellID->499048731]
}, Open  ]],
Cell[CellGroupData[{
Cell[18163, 684, 82, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->415070798],
Cell[18248, 688, 330, 8, 82, "Input",
 CellID->34637506],
Cell[18581, 698, 166, 5, 28, "Input",
 CellTags->"Member",
 CellID->211038013],
Cell[18750, 705, 105, 2, 28, "Input",
 CellTags->"Member",
 CellID->8432150]
}, Open  ]],
Cell[CellGroupData[{
Cell[18892, 712, 79, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->412118987],
Cell[18974, 716, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->439037325]
}, Open  ]],
Cell[CellGroupData[{
Cell[19090, 723, 85, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->598778145],
Cell[19178, 727, 83, 2, 28, "Input",
 CellTags->"Member",
 CellID->2685260]
}, Open  ]],
Cell[CellGroupData[{
Cell[19298, 734, 85, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->19020383],
Cell[19386, 738, 86, 2, 28, "Input",
 CellTags->"Member",
 CellID->275917672]
}, Open  ]],
Cell[CellGroupData[{
Cell[19509, 745, 83, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->75312703],
Cell[19595, 749, 84, 2, 28, "Input",
 CellTags->"Member",
 CellID->308544809]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
