(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14050,        540]
NotebookOptionsPosition[      7170,        285]
NotebookOutlinePosition[     11100,        421]
CellTagsIndexPosition[     10948,        413]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["MarketModelEvolvers", "Chapter",
 CellTags->"Overview",
 CellID->156953492],

Cell["\<\
functions to construct and use Market Model Evolvers objects.\
\>", "Text",
 CellTags->"Overview",
 CellID->855636285],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->8193919],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->620470792],

Cell["\<\
Within the MarketModelEvolvers part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->189456900],

Cell[CellGroupData[{

Cell["Select[Category[MarketModelEvolvers],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[111]:=",
 CellID->637970272],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "ForwardRateIpc", ",", "ForwardRateNormalPc", ",", "ForwardRatePc"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436084743078125*^9},
 CellTags->"Overview",
 CellLabel->"Out[111]=",
 CellID->71601165]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[MarketModelEvolvers],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[112]:=",
 CellID->1046632],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "MarketModelEvolverAdvanceStep", ",", "MarketModelEvolverCurrentStep", ",", 
   "MarketModelEvolverNumeraires", ",", "MarketModelEvolverStartNewPath"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436084744203125*^9},
 CellTags->"Overview",
 CellLabel->"Out[112]=",
 CellID->23348934]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[MarketModelEvolvers],QLProcedure[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[113]:=",
 CellID->753092905],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.436084746640625*^9},
 CellTags->"Overview",
 CellLabel->"Out[113]=",
 CellID->357170005]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->43777883],

Cell[CellGroupData[{

Cell["ForwardRatePc", "Subsubsection",
 CellTags->"Constructor",
 CellID->379896334],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"MarketModel", "exampleValue", 
     RowBox[{"MarketModel", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"BrownianGeneratorFactory", "exampleValue", 
     RowBox[{"Brownian", " ", "generator", " ", 
      RowBox[{"factory", "."}]}]},
    {"Numeraires", 
     RowBox[{"5", ",", "5", ",", "5", ",", "5", ",", "5"}], 
     RowBox[{"numeraire", " ", 
      RowBox[{"vector", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->167942792],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MarketModel", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BrownianGeneratorFactory", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraires", "=", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5", ",", "5", ",", "5", ",", "5"}], "}"}]}], 
  ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->25329645],

Cell["\<\
obj=ForwardRatePc[MarketModel,BrownianGeneratorFactory,Numeraires]\
\>", "Input",
 CellTags->"Constructor",
 CellID->8087410]
}, Open  ]],

Cell[CellGroupData[{

Cell["ForwardRateIpc", "Subsubsection",
 CellTags->"Constructor",
 CellID->479857727],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"MarketModel", "exampleValue", 
     RowBox[{"MarketModel", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"BrownianGeneratorFactory", "exampleValue", 
     RowBox[{"Brownian", " ", "generator", " ", 
      RowBox[{"factory", "."}]}]},
    {"Numeraires", 
     RowBox[{"5", ",", "5", ",", "5", ",", "5", ",", "5"}], 
     RowBox[{"numeraire", " ", 
      RowBox[{"vector", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->426784263],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MarketModel", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BrownianGeneratorFactory", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraires", "=", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5", ",", "5", ",", "5", ",", "5"}], "}"}]}], 
  ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->55846848],

Cell["\<\
obj=ForwardRateIpc[MarketModel,BrownianGeneratorFactory,Numeraires]\
\>", "Input",
 CellTags->"Constructor",
 CellID->210891157]
}, Open  ]],

Cell[CellGroupData[{

Cell["ForwardRateNormalPc", "Subsubsection",
 CellTags->"Constructor",
 CellID->124623966],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"MarketModel", "exampleValue", 
     RowBox[{"MarketModel", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"BrownianGeneratorFactory", "exampleValue", 
     RowBox[{"Brownian", " ", "generator", " ", 
      RowBox[{"factory", "."}]}]},
    {"Numeraires", 
     RowBox[{"5", ",", "5", ",", "5", ",", "5", ",", "5"}], 
     RowBox[{"numeraire", " ", 
      RowBox[{"vector", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->163237302],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MarketModel", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BrownianGeneratorFactory", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Numeraires", "=", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5", ",", "5", ",", "5", ",", "5"}], "}"}]}], 
  ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->280530060],

Cell["\<\
obj=ForwardRateNormalPc[MarketModel,BrownianGeneratorFactory,Numeraires]\
\>", "Input",
 CellTags->"Constructor",
 CellID->658486375]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->66574782],

Cell[CellGroupData[{

Cell["MarketModelEvolverStartNewPath", "Subsubsection",
 CellTags->"Member",
 CellID->699727686],

Cell["MarketModelEvolverStartNewPath[obj]", "Input",
 CellTags->"Member",
 CellID->552426546]
}, Open  ]],

Cell[CellGroupData[{

Cell["MarketModelEvolverAdvanceStep", "Subsubsection",
 CellTags->"Member",
 CellID->20876274],

Cell["MarketModelEvolverAdvanceStep[obj]", "Input",
 CellTags->"Member",
 CellID->118982761]
}, Open  ]],

Cell[CellGroupData[{

Cell["MarketModelEvolverCurrentStep", "Subsubsection",
 CellTags->"Member",
 CellID->364231878],

Cell["MarketModelEvolverCurrentStep[obj]", "Input",
 CellTags->"Member",
 CellID->21258154]
}, Open  ]],

Cell[CellGroupData[{

Cell["MarketModelEvolverNumeraires", "Subsubsection",
 CellTags->"Member",
 CellID->115552414],

Cell["MarketModelEvolverNumeraires[obj]", "Input",
 CellTags->"Member",
 CellID->747551024]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 497}, {Automatic, 101}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 81, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->156953492],
  Cell[674, 27, 128, 4, 37, "Text",
   CellTags->"Overview",
   CellID->855636285],
  Cell[805, 33, 112, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->8193919],
  Cell[920, 37, 80, 2, 41, "Input",
   CellTags->"Overview",
   CellID->620470792],
  Cell[1003, 41, 167, 5, 37, "Text",
   CellTags->"Overview",
   CellID->189456900],
  Cell[1195, 50, 140, 3, 41, "Input",
   CellTags->"Overview",
   CellID->637970272],
  Cell[1338, 55, 241, 8, 39, "Output",
   CellTags->"Overview",
   CellID->71601165],
  Cell[1616, 68, 133, 3, 41, "Input",
   CellTags->"Overview",
   CellID->1046632],
  Cell[1752, 73, 324, 9, 59, "Output",
   CellTags->"Overview",
   CellID->23348934],
  Cell[2113, 87, 138, 3, 41, "Input",
   CellTags->"Overview",
   CellID->753092905],
  Cell[2254, 92, 155, 5, 39, "Output",
   CellTags->"Overview",
   CellID->357170005]},
 "Constructo"->{
  Cell[2446, 102, 75, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->43777883]},
 "Constructor"->{
  Cell[2546, 108, 84, 2, 47, "Subsubsection",
   CellTags->"Constructor",
   CellID->379896334],
  Cell[3204, 128, 362, 11, 70, "Input",
   CellTags->"Constructor",
   CellID->25329645],
  Cell[3569, 141, 135, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->8087410],
  Cell[3741, 150, 85, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->479857727],
  Cell[4400, 170, 362, 11, 65, "Input",
   CellTags->"Constructor",
   CellID->55846848],
  Cell[4765, 183, 138, 4, 28, "Input",
   CellTags->"Constructor",
   CellID->210891157],
  Cell[4940, 192, 90, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->124623966],
  Cell[5604, 212, 363, 11, 65, "Input",
   CellTags->"Constructor",
   CellID->280530060],
  Cell[5970, 225, 143, 4, 28, "Input",
   CellTags->"Constructor",
   CellID->658486375]},
 "Member"->{
  Cell[6162, 235, 74, 2, 51, "Section",
   CellTags->"Member",
   CellID->66574782],
  Cell[6261, 241, 96, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->699727686],
  Cell[6360, 245, 93, 2, 28, "Input",
   CellTags->"Member",
   CellID->552426546],
  Cell[6490, 252, 94, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->20876274],
  Cell[6587, 256, 92, 2, 28, "Input",
   CellTags->"Member",
   CellID->118982761],
  Cell[6716, 263, 95, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->364231878],
  Cell[6814, 267, 91, 2, 28, "Input",
   CellTags->"Member",
   CellID->21258154],
  Cell[6942, 274, 94, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->115552414],
  Cell[7039, 278, 91, 2, 28, "Input",
   CellTags->"Member",
   CellID->747551024]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 8224, 316},
 {"Constructo", 9185, 350},
 {"Constructor", 9293, 354},
 {"Member", 10137, 382}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 81, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->156953492],
Cell[674, 27, 128, 4, 37, "Text",
 CellTags->"Overview",
 CellID->855636285],
Cell[805, 33, 112, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->8193919],
Cell[920, 37, 80, 2, 41, "Input",
 CellTags->"Overview",
 CellID->620470792],
Cell[1003, 41, 167, 5, 37, "Text",
 CellTags->"Overview",
 CellID->189456900],
Cell[CellGroupData[{
Cell[1195, 50, 140, 3, 41, "Input",
 CellTags->"Overview",
 CellID->637970272],
Cell[1338, 55, 241, 8, 39, "Output",
 CellTags->"Overview",
 CellID->71601165]
}, Open  ]],
Cell[CellGroupData[{
Cell[1616, 68, 133, 3, 41, "Input",
 CellTags->"Overview",
 CellID->1046632],
Cell[1752, 73, 324, 9, 59, "Output",
 CellTags->"Overview",
 CellID->23348934]
}, Open  ]],
Cell[CellGroupData[{
Cell[2113, 87, 138, 3, 41, "Input",
 CellTags->"Overview",
 CellID->753092905],
Cell[2254, 92, 155, 5, 39, "Output",
 CellTags->"Overview",
 CellID->357170005]
}, Open  ]],
Cell[CellGroupData[{
Cell[2446, 102, 75, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->43777883],
Cell[CellGroupData[{
Cell[2546, 108, 84, 2, 47, "Subsubsection",
 CellTags->"Constructor",
 CellID->379896334],
Cell[2633, 112, 568, 14, 130, "Input",
 CellID->167942792],
Cell[3204, 128, 362, 11, 70, "Input",
 CellTags->"Constructor",
 CellID->25329645],
Cell[3569, 141, 135, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->8087410]
}, Open  ]],
Cell[CellGroupData[{
Cell[3741, 150, 85, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->479857727],
Cell[3829, 154, 568, 14, 115, "Input",
 CellID->426784263],
Cell[4400, 170, 362, 11, 65, "Input",
 CellTags->"Constructor",
 CellID->55846848],
Cell[4765, 183, 138, 4, 28, "Input",
 CellTags->"Constructor",
 CellID->210891157]
}, Open  ]],
Cell[CellGroupData[{
Cell[4940, 192, 90, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->124623966],
Cell[5033, 196, 568, 14, 115, "Input",
 CellID->163237302],
Cell[5604, 212, 363, 11, 65, "Input",
 CellTags->"Constructor",
 CellID->280530060],
Cell[5970, 225, 143, 4, 28, "Input",
 CellTags->"Constructor",
 CellID->658486375]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6162, 235, 74, 2, 51, "Section",
 CellTags->"Member",
 CellID->66574782],
Cell[CellGroupData[{
Cell[6261, 241, 96, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->699727686],
Cell[6360, 245, 93, 2, 28, "Input",
 CellTags->"Member",
 CellID->552426546]
}, Open  ]],
Cell[CellGroupData[{
Cell[6490, 252, 94, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->20876274],
Cell[6587, 256, 92, 2, 28, "Input",
 CellTags->"Member",
 CellID->118982761]
}, Open  ]],
Cell[CellGroupData[{
Cell[6716, 263, 95, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->364231878],
Cell[6814, 267, 91, 2, 28, "Input",
 CellTags->"Member",
 CellID->21258154]
}, Open  ]],
Cell[CellGroupData[{
Cell[6942, 274, 94, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->115552414],
Cell[7039, 278, 91, 2, 28, "Input",
 CellTags->"Member",
 CellID->747551024]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
