(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18969,        709]
NotebookOptionsPosition[     10573,        398]
NotebookOutlinePosition[     15119,        555]
CellTagsIndexPosition[     14964,        547]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Volatility", "Chapter",
 CellTags->"Overview",
 CellID->11776582],

Cell["\<\
functions to construct and use Market Model Volatility objects.\
\>", "Text",
 CellTags->"Overview",
 CellID->46271050],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->335683711],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->10328767],

Cell["\<\
Within the MarketModelVolatility part there are several constructors and \
member functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->231377346],

Cell[CellGroupData[{

Cell["Select[Category[MarketModelVolatility],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->510966168],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "MarketModelLmExtLinearExponentialVolModel", ",", 
   "PiecewiseConstantAbcdVariance"}], "}"}]], "Output",
 CellChangeTimes->{3.4360924315625*^9, 3.43609257634375*^9},
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->4526852]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[MarketModelVolatility],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->57960065],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "PiecewiseConstantVarianceRateTimes", ",", 
   "PiecewiseConstantVarianceTotalVariance", ",", 
   "PiecewiseConstantVarianceTotalVolatility", ",", 
   "PiecewiseConstantVarianceVariance", ",", 
   "PiecewiseConstantVarianceVariances", ",", 
   "PiecewiseConstantVarianceVolatilities", ",", 
   "PiecewiseConstantVarianceVolatility"}], "}"}]], "Output",
 CellChangeTimes->{3.436092433484375*^9, 3.436092577125*^9},
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->182583641]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->407235858],

Cell[CellGroupData[{

Cell["PiecewiseConstantAbcdVariance", "Subsubsection",
 CellTags->"Constructor",
 CellID->141458550],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"ResetIndex", 
     RowBox[{
     "Index", " ", "that", " ", "defines", " ", "the", " ", "reset", " ", 
      "time", " ", "of", " ", 
      RowBox[{"rate", "."}]}]},
    {"RateTimes", 
     RowBox[{"rate", " ", "fixing", " ", 
      RowBox[{"times", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->760228114],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"A", 
     RowBox[{"-", "0.06"}], 
     RowBox[{"coefficient", " ", "in", " ", "abcd", " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"B", "0.17", 
     RowBox[{
     "coefficient", " ", "in", " ", "the", " ", "abcd", " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"C", "0.54", 
     RowBox[{
     "coefficient", " ", "in", " ", "the", " ", "abcd", " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]},
    {"D", "0.17", 
     RowBox[{
     "coefficient", " ", "in", " ", "the", " ", "abcd", " ", "vol", " ", 
      RowBox[{"parametrization", ".", " ", "Used"}], " ", "as", " ", "guess", 
      " ", "if", " ", "the", " ", "object", " ", "is", " ", "later", " ", 
      RowBox[{"calibrated", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->290045009],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ResetIndex", "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RateTimes", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.5", ",", "1.0", ",", "1.5", ",", "2.0", ",", "2.5", ",", "3.0", ",", 
     "3.5", ",", "4.0", ",", "4.5", ",", "5.0", ",", "5.5"}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.436092666625*^9, 3.436092666984375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[13]:=",
 CellID->145173669],

Cell[CellGroupData[{

Cell["obj=PiecewiseConstantAbcdVariance[ResetIndex,RateTimes]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[15]:=",
 CellID->25058940],

Cell[BoxData[
 RowBox[{"PiecewiseConstantAbcdVariance", "[", 
  RowBox[{"0.5`", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5`", ",", "1.`", ",", "1.5`", ",", "2.`", ",", "2.5`", ",", "3.`", ",",
      "3.5`", ",", "4.`", ",", "4.5`", ",", "5.`", ",", "5.5`"}], "}"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.436092583765625*^9, 3.436092668390625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[15]=",
 CellID->73065917]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MarketModelLmExtLinearExponentialVolModel", "Subsubsection",
 CellTags->"Constructor",
 CellID->76793735],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FixingTimes", 
     RowBox[{"rate", " ", "fixing", " ", 
      RowBox[{"times", "."}]}]},
    {"a", 
     RowBox[{"a", " ", 
      RowBox[{"parameter", "."}]}]},
    {"b", 
     RowBox[{"b", " ", 
      RowBox[{"parameter", "."}]}]},
    {"c", 
     RowBox[{"c", " ", 
      RowBox[{"parameter", "."}]}]},
    {"d", 
     RowBox[{"d", " ", 
      RowBox[{"parameter", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.4360924678125*^9, 3.4360924724375*^9}},
 CellID->35576829],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FixingTimes", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.0", ",", "1.0", ",", "2.0", ",", "3.0", ",", "4.0", ",", "5.0"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"b", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"d", "=", "1.0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.436092457984375*^9, 3.436092464875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[7]:=",
 CellID->520037331],

Cell[CellGroupData[{

Cell["\<\
obj=MarketModelLmExtLinearExponentialVolModel[FixingTimes,a,b,c,d]\
\>", "Input",
 CellChangeTimes->{{3.43609247615625*^9, 3.436092481265625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[12]:=",
 CellID->625670750],

Cell[BoxData["MarketModelLmExtLinearExponentialVolModel2"], "Output",
 CellChangeTimes->{3.436092482390625*^9, 3.43609254109375*^9, 
  3.436092654375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[12]=",
 CellID->767441680]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->177289488],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceVariances", "Subsubsection",
 CellTags->"Member",
 CellID->359736680],

Cell["PiecewiseConstantVarianceVariances[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[23]:=",
 CellID->47794205]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceVolatilities", "Subsubsection",
 CellTags->"Member",
 CellID->16521449],

Cell["PiecewiseConstantVarianceVolatilities[obj]", "Input",
 CellTags->"Member",
 CellID->24407156]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceRateTimes", "Subsubsection",
 CellTags->"Member",
 CellID->703556187],

Cell["PiecewiseConstantVarianceRateTimes[obj]", "Input",
 CellTags->"Member",
 CellID->228446184]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceVariance", "Subsubsection",
 CellTags->"Member",
 CellID->12798977],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeIndex", 
     RowBox[{"time", " ", 
      RowBox[{"index", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->178269423],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeIndex", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[24]:=",
 CellID->598187976],

Cell["PiecewiseConstantVarianceVariance[obj,TimeIndex]", "Input",
 CellTags->"Member",
 CellID->1195586]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->541884560],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeIndex", 
     RowBox[{"time", " ", 
      RowBox[{"index", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->47256351],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeIndex", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->263932625],

Cell["PiecewiseConstantVarianceVolatility[obj,TimeIndex]", "Input",
 CellTags->"Member",
 CellID->579954305]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceTotalVariance", "Subsubsection",
 CellTags->"Member",
 CellID->461161635],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeIndex", 
     RowBox[{"time", " ", 
      RowBox[{"index", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->208896389],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeIndex", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->14317262],

Cell["PiecewiseConstantVarianceTotalVariance[obj,TimeIndex]", "Input",
 CellTags->"Member",
 CellID->768193594]
}, Open  ]],

Cell[CellGroupData[{

Cell["PiecewiseConstantVarianceTotalVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->394726801],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeIndex", 
     RowBox[{"time", " ", 
      RowBox[{"index", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",\

 CellID->52594977],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeIndex", "=", "0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->790383928],

Cell["PiecewiseConstantVarianceTotalVolatility[obj,TimeIndex]", "Input",
 CellTags->"Member",
 CellID->906820655]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 545}, {27, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 71, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->11776582],
  Cell[664, 27, 129, 4, 37, "Text",
   CellTags->"Overview",
   CellID->46271050],
  Cell[796, 33, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->335683711],
  Cell[913, 37, 102, 3, 41, "Input",
   CellTags->"Overview",
   CellID->10328767],
  Cell[1018, 42, 169, 5, 37, "Text",
   CellTags->"Overview",
   CellID->231377346],
  Cell[1212, 51, 140, 3, 41, "Input",
   CellTags->"Overview",
   CellID->510966168],
  Cell[1355, 56, 273, 8, 59, "Output",
   CellTags->"Overview",
   CellID->4526852],
  Cell[1665, 69, 134, 3, 41, "Input",
   CellTags->"Overview",
   CellID->57960065],
  Cell[1802, 74, 521, 13, 135, "Output",
   CellTags->"Overview",
   CellID->182583641]},
 "Constructo"->{
  Cell[2360, 92, 76, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->407235858]},
 "Constructor"->{
  Cell[2461, 98, 100, 2, 47, "Subsubsection",
   CellTags->"Constructor",
   CellID->141458550],
  Cell[4368, 146, 447, 13, 70, "Input",
   CellTags->"Constructor",
   CellID->145173669],
  Cell[4840, 163, 141, 3, 70, "Input",
   CellTags->"Constructor",
   CellID->25058940],
  Cell[4984, 168, 423, 11, 70, "Output",
   CellTags->"Constructor",
   CellID->73065917],
  Cell[5456, 185, 111, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->76793735],
  Cell[6185, 211, 534, 18, 70, "Input",
   CellTags->"Constructor",
   CellID->520037331],
  Cell[6744, 233, 226, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->625670750],
  Cell[6973, 241, 224, 5, 70, "Output",
   CellTags->"Constructor",
   CellID->767441680]},
 "Member"->{
  Cell[7258, 253, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->177289488],
  Cell[7358, 259, 100, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->359736680],
  Cell[7461, 263, 120, 3, 28, "Input",
   CellTags->"Member",
   CellID->47794205],
  Cell[7618, 271, 102, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->16521449],
  Cell[7723, 275, 99, 2, 28, "Input",
   CellTags->"Member",
   CellID->24407156],
  Cell[7859, 282, 100, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->703556187],
  Cell[7962, 286, 97, 2, 28, "Input",
   CellTags->"Member",
   CellID->228446184],
  Cell[8096, 293, 98, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->12798977],
  Cell[8440, 306, 140, 5, 28, "Input",
   CellTags->"Member",
   CellID->598187976],
  Cell[8583, 313, 104, 2, 28, "Input",
   CellTags->"Member",
   CellID->1195586],
  Cell[8724, 320, 101, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->541884560],
  Cell[9070, 333, 116, 4, 28, "Input",
   CellTags->"Member",
   CellID->263932625],
  Cell[9189, 339, 108, 2, 28, "Input",
   CellTags->"Member",
   CellID->579954305],
  Cell[9334, 346, 104, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->461161635],
  Cell[9684, 359, 115, 4, 28, "Input",
   CellTags->"Member",
   CellID->14317262],
  Cell[9802, 365, 111, 2, 28, "Input",
   CellTags->"Member",
   CellID->768193594],
  Cell[9950, 372, 106, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->394726801],
  Cell[10301, 385, 116, 4, 28, "Input",
   CellTags->"Member",
   CellID->790383928],
  Cell[10420, 391, 113, 2, 28, "Input",
   CellTags->"Member",
   CellID->906820655]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 11626, 429},
 {"Constructo", 12417, 457},
 {"Constructor", 12525, 461},
 {"Member", 13276, 486}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 71, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->11776582],
Cell[664, 27, 129, 4, 37, "Text",
 CellTags->"Overview",
 CellID->46271050],
Cell[796, 33, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->335683711],
Cell[913, 37, 102, 3, 41, "Input",
 CellTags->"Overview",
 CellID->10328767],
Cell[1018, 42, 169, 5, 37, "Text",
 CellTags->"Overview",
 CellID->231377346],
Cell[CellGroupData[{
Cell[1212, 51, 140, 3, 41, "Input",
 CellTags->"Overview",
 CellID->510966168],
Cell[1355, 56, 273, 8, 59, "Output",
 CellTags->"Overview",
 CellID->4526852]
}, Open  ]],
Cell[CellGroupData[{
Cell[1665, 69, 134, 3, 41, "Input",
 CellTags->"Overview",
 CellID->57960065],
Cell[1802, 74, 521, 13, 135, "Output",
 CellTags->"Overview",
 CellID->182583641]
}, Open  ]],
Cell[CellGroupData[{
Cell[2360, 92, 76, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->407235858],
Cell[CellGroupData[{
Cell[2461, 98, 100, 2, 47, "Subsubsection",
 CellTags->"Constructor",
 CellID->141458550],
Cell[2564, 102, 433, 12, 111, "Input",
 CellID->760228114],
Cell[3000, 116, 1365, 28, 70, "Input",
 CellID->290045009],
Cell[4368, 146, 447, 13, 70, "Input",
 CellTags->"Constructor",
 CellID->145173669],
Cell[CellGroupData[{
Cell[4840, 163, 141, 3, 70, "Input",
 CellTags->"Constructor",
 CellID->25058940],
Cell[4984, 168, 423, 11, 70, "Output",
 CellTags->"Constructor",
 CellID->73065917]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5456, 185, 111, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->76793735],
Cell[5570, 189, 612, 20, 70, "Input",
 CellID->35576829],
Cell[6185, 211, 534, 18, 70, "Input",
 CellTags->"Constructor",
 CellID->520037331],
Cell[CellGroupData[{
Cell[6744, 233, 226, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->625670750],
Cell[6973, 241, 224, 5, 70, "Output",
 CellTags->"Constructor",
 CellID->767441680]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7258, 253, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->177289488],
Cell[CellGroupData[{
Cell[7358, 259, 100, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->359736680],
Cell[7461, 263, 120, 3, 28, "Input",
 CellTags->"Member",
 CellID->47794205]
}, Open  ]],
Cell[CellGroupData[{
Cell[7618, 271, 102, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->16521449],
Cell[7723, 275, 99, 2, 28, "Input",
 CellTags->"Member",
 CellID->24407156]
}, Open  ]],
Cell[CellGroupData[{
Cell[7859, 282, 100, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->703556187],
Cell[7962, 286, 97, 2, 28, "Input",
 CellTags->"Member",
 CellID->228446184]
}, Open  ]],
Cell[CellGroupData[{
Cell[8096, 293, 98, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->12798977],
Cell[8197, 297, 240, 7, 65, "Input",
 CellID->178269423],
Cell[8440, 306, 140, 5, 28, "Input",
 CellTags->"Member",
 CellID->598187976],
Cell[8583, 313, 104, 2, 28, "Input",
 CellTags->"Member",
 CellID->1195586]
}, Open  ]],
Cell[CellGroupData[{
Cell[8724, 320, 101, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->541884560],
Cell[8828, 324, 239, 7, 65, "Input",
 CellID->47256351],
Cell[9070, 333, 116, 4, 28, "Input",
 CellTags->"Member",
 CellID->263932625],
Cell[9189, 339, 108, 2, 28, "Input",
 CellTags->"Member",
 CellID->579954305]
}, Open  ]],
Cell[CellGroupData[{
Cell[9334, 346, 104, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->461161635],
Cell[9441, 350, 240, 7, 65, "Input",
 CellID->208896389],
Cell[9684, 359, 115, 4, 28, "Input",
 CellTags->"Member",
 CellID->14317262],
Cell[9802, 365, 111, 2, 28, "Input",
 CellTags->"Member",
 CellID->768193594]
}, Open  ]],
Cell[CellGroupData[{
Cell[9950, 372, 106, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->394726801],
Cell[10059, 376, 239, 7, 65, "Input",
 CellID->52594977],
Cell[10301, 385, 116, 4, 28, "Input",
 CellTags->"Member",
 CellID->790383928],
Cell[10420, 391, 113, 2, 28, "Input",
 CellTags->"Member",
 CellID->906820655]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
