(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     47542,       1591]
NotebookOptionsPosition[     31197,        994]
NotebookOutlinePosition[     39733,       1283]
CellTagsIndexPosition[     39575,       1275]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Mathf", "Chapter",
 CellTags->"Overview",
 CellID->67654189],

Cell["Math utility functions.", "Text",
 CellTags->"Overview",
 CellID->46011424],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->334089964],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->159087362],

Cell["\<\
Within the Math part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->17085649],

Cell[CellGroupData[{

Cell["Select[Category[Math],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->770208946],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"CovarianceDecomposition", ",", "SymmetricSchurDecomposition"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.43608504434375*^9},
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->335158826]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Math],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->274986142],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CovarianceDecompositionCorrelationMatrix", ",", 
   "CovarianceDecompositionStandardDeviations", ",", 
   "CovarianceDecompositionVariances", ",", 
   "SymmetricSchurDecompositionEigenvalues", ",", 
   "SymmetricSchurDecompositionEigenvectors"}], "}"}]], "Output",
 CellChangeTimes->{3.43608504634375*^9},
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->306635806]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Math],QLProcedure[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[4]:=",
 CellID->207616541],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "CholeskyDecomposition", ",", "GetCovariance", ",", "NormDist", ",", 
   "NormInv", ",", "NormSDist", ",", "NormSInv", ",", "PrimeNumber", ",", 
   "PseudoSqrt", ",", "RankReducedSqrt"}], "}"}]], "Output",
 CellChangeTimes->{3.4360850473125*^9},
 CellTags->"Overview",
 CellLabel->"Out[4]=",
 CellID->982914065]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor",
 CellID->599036448],

Cell[CellGroupData[{

Cell["SymmetricSchurDecomposition", "Subsubsection",
 CellTags->"Constructor",
 CellID->173542739],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SymmetricMatrix", "exampleValue", 
     RowBox[{"Symmetrix", " ", "matrix", " ", "to", " ", "be", " ", 
      RowBox[{"decomposed", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->414657126],

Cell[BoxData[
 RowBox[{
  RowBox[{"SymmetricMatrix", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Constructor",
 CellID->491728507],

Cell["obj=SymmetricSchurDecomposition[SymmetricMatrix]", "Input",
 CellTags->"Constructor",
 CellID->168495957]
}, Open  ]],

Cell[CellGroupData[{

Cell["CovarianceDecomposition", "Subsubsection",
 CellTags->"Constructor",
 CellID->168053589],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SymmetricMatrix", "exampleValue", 
     RowBox[{
     "Symmetrix", " ", "covariance", " ", "matrix", " ", "to", " ", "be", " ",
       
      RowBox[{"decomposed", "."}]}]},
    {"SalvagingAlgorithm", "exampleValue", 
     RowBox[{
      RowBox[{
      "Salvaging", " ", "algorithm", " ", "for", " ", "symmetric", " ", 
       "matrix", " ", "not", " ", "positive", " ", "semi"}], "-", 
      RowBox[{"definite", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"None", ",", " ", "Spectral"}], ")"}], "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellTags->"Constructor",
 CellID->3564916],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Tolerance", 
     RowBox[{"1.0", "e12"}], 
     RowBox[{
     "numerical", " ", "tolerance", " ", "for", " ", "non", " ", "symmetric", 
      " ", 
      RowBox[{"matrix", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->38024807],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SymmetricMatrix", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SalvagingAlgorithm", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->90389629],

Cell["\<\
obj=CovarianceDecomposition[SymmetricMatrix,SalvagingAlgorithm]\
\>", "Input",
 CellTags->"Constructor",
 CellID->137580829]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->310227300],

Cell[CellGroupData[{

Cell["SymmetricSchurDecompositionEigenvalues", "Subsubsection",
 CellTags->"Member",
 CellID->37547957],

Cell["SymmetricSchurDecompositionEigenvalues[obj]", "Input",
 CellTags->"Member",
 CellID->502943714]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymmetricSchurDecompositionEigenvectors", "Subsubsection",
 CellTags->"Member",
 CellID->74508406],

Cell["SymmetricSchurDecompositionEigenvectors[obj]", "Input",
 CellTags->"Member",
 CellID->494855]
}, Open  ]],

Cell[CellGroupData[{

Cell["CovarianceDecompositionVariances", "Subsubsection",
 CellTags->"Member",
 CellID->35064720],

Cell["CovarianceDecompositionVariances[obj]", "Input",
 CellTags->"Member",
 CellID->718350878]
}, Open  ]],

Cell[CellGroupData[{

Cell["CovarianceDecompositionStandardDeviations", "Subsubsection",
 CellTags->"Member",
 CellID->226921165],

Cell["CovarianceDecompositionStandardDeviations[obj]", "Input",
 CellTags->"Member",
 CellID->59593500]
}, Open  ]],

Cell[CellGroupData[{

Cell["CovarianceDecompositionCorrelationMatrix", "Subsubsection",
 CellTags->"Member",
 CellID->607120701],

Cell["CovarianceDecompositionCorrelationMatrix[obj]", "Input",
 CellTags->"Member",
 CellID->1897968]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedures", "Section",
 CellTags->"Procedure",
 CellID->347063912],

Cell[CellGroupData[{

Cell["PrimeNumber", "Subsubsection",
 CellTags->"Procedure",
 CellID->1458147],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"n", "2", 
     RowBox[{
     "index", " ", "of", " ", "the", " ", "prime", " ", "number", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"e", ".", "g"}], " ", "N"}], "=", 
         RowBox[{"2", " ", "returns", " ", "3"}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.436085073546875*^9, 3.436085073546875*^9}},
 CellTags->"Procedure",
 CellID->136614548],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{3.436085075203125*^9},
 CellTags->"Procedure",
 CellLabel->"In[5]:=",
 CellID->45793414],

Cell[CellGroupData[{

Cell["PrimeNumber[n]", "Input",
 CellChangeTimes->{{3.43608506809375*^9, 3.436085076796875*^9}},
 CellTags->"Procedure",
 CellLabel->"In[6]:=",
 CellID->202147383],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.436085079671875*^9},
 CellTags->"Procedure",
 CellLabel->"Out[6]=",
 CellID->561398983]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NormDist", "Subsubsection",
 CellTags->"Procedure",
 CellID->619781081],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"X", "0.0", 
     RowBox[{
     "is", " ", "the", " ", "value", " ", "for", " ", "which", " ", "you", 
      " ", "want", " ", "the", " ", 
      RowBox[{"distribution", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->197409627],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Mean", "0.0", 
     RowBox[{
     "is", " ", "the", " ", "arithmetic", " ", "mean", " ", "of", " ", "the", 
      " ", 
      RowBox[{"distribution", "."}]}]},
    {"Standard_dev", "1.0", 
     RowBox[{
      RowBox[{
      "is", " ", "the", " ", "standard", " ", "deviation", " ", "of", " ", 
       "the", " ", "distribution"}], ",", " ", 
      RowBox[{"a", " ", "positive", " ", 
       RowBox[{"number", "."}]}]}]},
    {"Cumulative", "True", 
     RowBox[{
      RowBox[{"is", " ", "a", " ", "logical", " ", 
       RowBox[{"value", ":", " ", 
        RowBox[{
        "for", " ", "the", " ", "cumulative", " ", "distribution", " ", 
         "function"}]}]}], ",", " ", 
      RowBox[{
       RowBox[{"use", " ", "TRUE"}], ";", " ", 
       RowBox[{
       "for", " ", "the", " ", "probability", " ", "mass", " ", 
        "function"}]}], ",", " ", 
      RowBox[{"use", " ", 
       RowBox[{"FALSE", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellChangeTimes->{{3.436085124171875*^9, 3.436085124953125*^9}},
 CellTags->"Procedure",
 CellID->51398832],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "=", "0.0"}], ";"}]], "Input",
 CellTags->"Procedure",
 CellLabel->"In[7]:=",
 CellID->671760331],

Cell[CellGroupData[{

Cell["NormDist[X]", "Input",
 CellChangeTimes->{3.436085063484375*^9},
 CellTags->"Procedure",
 CellLabel->"In[8]:=",
 CellID->695978190],

Cell[BoxData["0.3989422804014327`"], "Output",
 CellChangeTimes->{3.436085115*^9},
 CellTags->"Procedure",
 CellLabel->"Out[8]=",
 CellID->60367720]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"NormDist", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Cumulative", "\[Rule]", "True"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]], "Input",
 CellTags->"Procedure",
 CellLabel->"In[9]:=",
 CellID->622573089],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw12Xc0V2/8APCPzxShlMK3EMlIFDJC71saVouGSsiolNUnm+y9QrJnZGUr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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-3, 3}, {0., 0.39894223786442035`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.436085136421875*^9},
 CellTags->"Procedure",
 CellLabel->"Out[9]=",
 CellID->153712446]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NormSDist", "Subsubsection",
 CellTags->"Procedure",
 CellID->267731323],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Z", "0.0", 
     RowBox[{
     "is", " ", "the", " ", "value", " ", "for", " ", "which", " ", "you", 
      " ", "want", " ", "the", " ", 
      RowBox[{"distribution", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->110775544],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "=", "0.0"}], ";"}]], "Input",
 CellTags->"Procedure",
 CellLabel->"In[10]:=",
 CellID->115662299],

Cell[CellGroupData[{

Cell["NormSDist[Z]", "Input",
 CellChangeTimes->{3.43608514396875*^9},
 CellTags->"Procedure",
 CellLabel->"In[11]:=",
 CellID->23794867],

Cell[BoxData["0.5`"], "Output",
 CellChangeTimes->{3.4360851445*^9},
 CellTags->"Procedure",
 CellLabel->"Out[11]=",
 CellID->21547026]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NormInv", "Subsubsection",
 CellTags->"Procedure",
 CellID->41146177],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Probability", "0.5", 
     RowBox[{
      RowBox[{
      "is", " ", "a", " ", "probability", " ", "corresponding", " ", "to", 
       " ", "the", " ", "normal", " ", "distribution"}], ",", " ", 
      RowBox[{
      "a", " ", "number", " ", "between", " ", "0", " ", "and", " ", "1", " ",
        
       RowBox[{"inclusive", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->290036447],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Mean", "0.0", 
     RowBox[{
     "is", " ", "the", " ", "arithmetic", " ", "mean", " ", "of", " ", "the", 
      " ", 
      RowBox[{"distribution", "."}]}]},
    {"Standard_dev", "1.0", 
     RowBox[{
      RowBox[{
      "is", " ", "the", " ", "standard", " ", "deviation", " ", "of", " ", 
       "the", " ", "distribution"}], ",", " ", 
      RowBox[{"a", " ", "positive", " ", 
       RowBox[{"number", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->304564110],

Cell[BoxData[
 RowBox[{
  RowBox[{"Probability", "=", "0.5"}], ";"}]], "Input",
 CellTags->"Procedure",
 CellLabel->"In[12]:=",
 CellID->629846986],

Cell[CellGroupData[{

Cell["NormInv[Probability]", "Input",
 CellChangeTimes->{3.436085151390625*^9},
 CellTags->"Procedure",
 CellLabel->"In[13]:=",
 CellID->130969512],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.4360851539375*^9},
 CellTags->"Procedure",
 CellLabel->"Out[13]=",
 CellID->391937407]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NormSInv", "Subsubsection",
 CellTags->"Procedure",
 CellID->288059423],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Probability", "0.5", 
     RowBox[{
      RowBox[{
      "is", " ", "a", " ", "probability", " ", "corresponding", " ", "to", 
       " ", "the", " ", "normal", " ", "distribution"}], ",", " ", 
      RowBox[{
      "a", " ", "number", " ", "between", " ", "0", " ", "and", " ", "1", " ",
        
       RowBox[{"inclusive", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->31067251],

Cell[BoxData[
 RowBox[{
  RowBox[{"Probability", "=", "0.5"}], ";"}]], "Input",
 CellTags->"Procedure",
 CellLabel->"In[14]:=",
 CellID->332409826],

Cell[CellGroupData[{

Cell["NormSInv[Probability]", "Input",
 CellChangeTimes->{{3.436085158859375*^9, 3.43608515978125*^9}},
 CellTags->"Procedure",
 CellLabel->"In[15]:=",
 CellID->120609806],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.436085162328125*^9},
 CellTags->"Procedure",
 CellLabel->"Out[15]=",
 CellID->4833190]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CholeskyDecomposition", "Subsubsection",
 CellTags->"Procedure",
 CellID->258337340],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Matrix", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], 
     RowBox[{"symmetric", " ", "matrix", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hopefully", " ", "positive", " ", "semi"}], "-", 
         RowBox[{"definite", " ", "at", " ", "least"}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.43608518759375*^9, 3.43608518759375*^9}},
 CellTags->"Procedure",
 CellID->825252424],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Flexible", "False", 
     RowBox[{
      RowBox[{
      "If", " ", "TRUE", " ", "it", " ", "returns", " ", "a", " ", "result", 
       " ", "also", " ", "for", " ", "positive", " ", "semi"}], "-", 
      RowBox[{"definite", " ", 
       RowBox[{"matrix", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellChangeTimes->{{3.436085253015625*^9, 3.4360852535*^9}},
 CellTags->"Procedure",
 CellID->316713374],

Cell[BoxData[
 RowBox[{
  RowBox[{"Matrix", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.43608519034375*^9},
 CellTags->"Procedure",
 CellLabel->"In[16]:=",
 CellID->19794365],

Cell[CellGroupData[{

Cell["CholeskyDecomposition[Matrix]", "Input",
 CellChangeTimes->{3.436085195015625*^9},
 CellTags->"Procedure",
 CellLabel->"In[17]:=",
 CellID->62127907],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.4142135623730951`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7071067811865475`", ",", "1.224744871391589`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436085195484375*^9},
 CellTags->"Procedure",
 CellLabel->"Out[17]=",
 CellID->212143131]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PseudoSqrt", "Subsubsection",
 CellTags->"Procedure",
 CellID->170302028],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Matrix", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], 
     RowBox[{"symmetric", " ", "matrix", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hopefully", " ", "positive", " ", "semi"}], "-", 
         RowBox[{"definite", " ", "at", " ", "least"}]}], ")"}], "."}]}]},
    {"SalvagingAlgorithm", "\"\<Spectral\>\"", 
     RowBox[{
      RowBox[{
      "Salvaging", " ", "algorithm", " ", "for", " ", "symmetric", " ", 
       "matrix", " ", "not", " ", "positive", " ", "semi"}], "-", 
      RowBox[{"definite", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"None", ",", " ", "Spectral"}], ")"}], "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.436085241703125*^9, 3.436085247921875*^9}},
 CellTags->"Procedure",
 CellID->8672603],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Matrix", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SalvagingAlgorithm", "=", "\"\<Spectral\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.43608520528125*^9, 3.436085256984375*^9}},
 CellTags->"Procedure",
 CellLabel->"In[18]:=",
 CellID->83404339],

Cell[CellGroupData[{

Cell["PseudoSqrt[Matrix,SalvagingAlgorithm]", "Input",
 CellChangeTimes->{3.436085260953125*^9},
 CellTags->"Procedure",
 CellLabel->"In[20]:=",
 CellID->12949972],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.224744871391589`", ",", "0.7071067811865476`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2247448713915892`", ",", 
     RowBox[{"-", "0.7071067811865475`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.436085261515625*^9},
 CellTags->"Procedure",
 CellLabel->"Out[20]=",
 CellID->705128303]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RankReducedSqrt", "Subsubsection",
 CellTags->"Procedure",
 CellID->122890921],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Matrix", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], 
     RowBox[{"symmetric", " ", "matrix", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hopefully", " ", "positive", " ", "semi"}], "-", 
         RowBox[{"definite", " ", "at", " ", "least"}]}], ")"}], "."}]}]},
    {"MaxRank", "10", 
     RowBox[{
      RowBox[{
      "number", " ", "of", " ", "principal", " ", "components", " ", 
       "retained"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "max"}], " ", "rank", " ", "for", " ",
        "the", " ", "result", " ", 
       RowBox[{"matrix", "."}]}]}]},
    {"ComponentPercentage", "0.1", 
     RowBox[{
     "principal", " ", "components", " ", "retained", " ", "as", " ", 
      "percentage", " ", "of", " ", 
      RowBox[{"eigenvalues", "'"}], " ", 
      RowBox[{"sum", "."}]}]},
    {"SalvagingAlgorithm", "\"\<Spectral\>\"", 
     RowBox[{
      RowBox[{
      "Salvaging", " ", "algorithm", " ", "for", " ", "symmetric", " ", 
       "matrix", " ", "not", " ", "positive", " ", "semi"}], "-", 
      RowBox[{"definite", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"None", ",", " ", "Spectral"}], ")"}], "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.4360853241875*^9, 3.43608534234375*^9}},
 CellTags->"Procedure",
 CellID->345332906],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Matrix", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MaxRank", "=", "10"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ComponentPercentage", "=", "0.01"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SalvagingAlgorithm", "=", "\"\<Spectral\>\""}], ";"}]}], "Input",
 CellChangeTimes->{
  3.436085270875*^9, {3.43608530259375*^9, 3.436085308359375*^9}},
 CellTags->"Procedure",
 CellLabel->"In[21]:=",
 CellID->197861599],

Cell[CellGroupData[{

Cell["\<\
RankReducedSqrt[Matrix,MaxRank,ComponentPercentage,SalvagingAlgorithm]\
\>", "Input",
 CellChangeTimes->{3.4360853133125*^9},
 CellTags->"Procedure",
 CellLabel->"In[25]:=",
 CellID->434523170],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1.4142135623730951`", "}"}], ",", 
   RowBox[{"{", "1.4142135623730951`", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.43608531384375*^9},
 CellTags->"Procedure",
 CellLabel->"Out[25]=",
 CellID->212193188]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GetCovariance", "Subsubsection",
 CellTags->"Procedure",
 CellID->313866246],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Vols", "exampleValue", 
     RowBox[{"volatility", " ", 
      RowBox[{"vector", "."}]}]},
    {"Matrix", "exampleValue", 
     RowBox[{"symmetric", " ", "matrix", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hopefully", " ", "positive", " ", "semi"}], "-", 
         RowBox[{"definite", " ", "at", " ", "least"}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->93253897],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Tolerance", 
     RowBox[{"1.0", "e12"}], 
     RowBox[{
     "numerical", " ", "tolerance", " ", "for", " ", "non", " ", "symmetric", 
      " ", 
      RowBox[{"matrix", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellTags->"Procedure",
 CellID->237101834],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Vols", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Matrix", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Procedure",
 CellID->161436599],

Cell["GetCovariance[Vols,Matrix]", "Input",
 CellChangeTimes->{3.436085364265625*^9},
 CellTags->"Procedure",
 CellID->14908880]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 572}, {Automatic, 81}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 66, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->67654189],
  Cell[659, 27, 81, 2, 37, "Text",
   CellTags->"Overview",
   CellID->46011424],
  Cell[743, 31, 114, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->334089964],
  Cell[860, 35, 103, 3, 41, "Input",
   CellTags->"Overview",
   CellID->159087362],
  Cell[966, 40, 151, 5, 37, "Text",
   CellTags->"Overview",
   CellID->17085649],
  Cell[1142, 49, 123, 3, 41, "Input",
   CellTags->"Overview",
   CellID->770208946],
  Cell[1268, 54, 231, 7, 39, "Output",
   CellTags->"Overview",
   CellID->335158826],
  Cell[1536, 66, 118, 3, 41, "Input",
   CellTags->"Overview",
   CellID->274986142],
  Cell[1657, 71, 414, 11, 116, "Output",
   CellTags->"Overview",
   CellID->306635806],
  Cell[2108, 87, 121, 3, 41, "Input",
   CellTags->"Overview",
   CellID->207616541],
  Cell[2232, 92, 353, 9, 59, "Output",
   CellTags->"Overview",
   CellID->982914065]},
 "Constructor"->{
  Cell[2622, 106, 77, 2, 77, "Section",
   CellTags->"Constructor",
   CellID->599036448],
  Cell[2724, 112, 98, 2, 47, "Subsubsection",
   CellTags->"Constructor",
   CellID->173542739],
  Cell[3147, 125, 138, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->491728507],
  Cell[3288, 131, 111, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->168495957],
  Cell[3436, 138, 94, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->168053589],
  Cell[3533, 142, 726, 19, 70, "Input",
   CellTags->"Constructor",
   CellID->3564916],
  Cell[4618, 175, 218, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->90389629],
  Cell[4839, 183, 134, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->137580829]},
 "Member"->{
  Cell[5022, 193, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->310227300],
  Cell[5122, 199, 103, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->37547957],
  Cell[5228, 203, 101, 2, 70, "Input",
   CellTags->"Member",
   CellID->502943714],
  Cell[5366, 210, 104, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->74508406],
  Cell[5473, 214, 99, 2, 70, "Input",
   CellTags->"Member",
   CellID->494855],
  Cell[5609, 221, 97, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->35064720],
  Cell[5709, 225, 95, 2, 70, "Input",
   CellTags->"Member",
   CellID->718350878],
  Cell[5841, 232, 107, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->226921165],
  Cell[5951, 236, 103, 2, 70, "Input",
   CellTags->"Member",
   CellID->59593500],
  Cell[6091, 243, 106, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->607120701],
  Cell[6200, 247, 101, 2, 70, "Input",
   CellTags->"Member",
   CellID->1897968]},
 "Procedure"->{
  Cell[6350, 255, 73, 2, 70, "Section",
   CellTags->"Procedure",
   CellID->347063912],
  Cell[6448, 261, 78, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->1458147],
  Cell[6529, 265, 554, 15, 70, "Input",
   CellTags->"Procedure",
   CellID->136614548],
  Cell[7086, 282, 175, 6, 70, "Input",
   CellTags->"Procedure",
   CellID->45793414],
  Cell[7286, 292, 163, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->202147383],
  Cell[7452, 298, 137, 4, 70, "Output",
   CellTags->"Procedure",
   CellID->561398983],
  Cell[7638, 308, 77, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->619781081],
  Cell[7718, 312, 378, 10, 70, "Input",
   CellTags->"Procedure",
   CellID->197409627],
  Cell[8099, 324, 1177, 31, 70, "Input",
   CellTags->"Procedure",
   CellID->51398832],
  Cell[9279, 357, 136, 5, 70, "Input",
   CellTags->"Procedure",
   CellID->671760331],
  Cell[9440, 366, 137, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->695978190],
  Cell[9580, 372, 148, 4, 70, "Output",
   CellTags->"Procedure",
   CellID->60367720],
  Cell[9765, 381, 332, 11, 70, "Input",
   CellTags->"Procedure",
   CellID->622573089],
  Cell[10100, 394, 8562, 148, 70, "Output",
   CellTags->"Procedure",
   CellID->153712446],
  Cell[18711, 548, 78, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->267731323],
  Cell[18792, 552, 378, 10, 70, "Input",
   CellTags->"Procedure",
   CellID->110775544],
  Cell[19173, 564, 137, 5, 70, "Input",
   CellTags->"Procedure",
   CellID->115662299],
  Cell[19335, 573, 137, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->23794867],
  Cell[19475, 579, 135, 4, 70, "Output",
   CellTags->"Procedure",
   CellID->21547026],
  Cell[19659, 589, 75, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->41146177],
  Cell[19737, 593, 537, 14, 70, "Input",
   CellTags->"Procedure",
   CellID->290036447],
  Cell[20277, 609, 613, 16, 70, "Input",
   CellTags->"Procedure",
   CellID->304564110],
  Cell[20893, 627, 147, 5, 70, "Input",
   CellTags->"Procedure",
   CellID->629846986],
  Cell[21065, 636, 147, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->130969512],
  Cell[21215, 642, 138, 4, 70, "Output",
   CellTags->"Procedure",
   CellID->391937407],
  Cell[21402, 652, 77, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->288059423],
  Cell[21482, 656, 536, 14, 70, "Input",
   CellTags->"Procedure",
   CellID->31067251],
  Cell[22021, 672, 147, 5, 70, "Input",
   CellTags->"Procedure",
   CellID->332409826],
  Cell[22193, 681, 171, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->120609806],
  Cell[22367, 687, 138, 4, 70, "Output",
   CellTags->"Procedure",
   CellID->4833190],
  Cell[22554, 697, 90, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->258337340],
  Cell[22647, 701, 688, 19, 70, "Input",
   CellTags->"Procedure",
   CellID->825252424],
  Cell[23338, 722, 520, 12, 70, "Input",
   CellTags->"Procedure",
   CellID->316713374],
  Cell[23861, 736, 335, 12, 70, "Input",
   CellTags->"Procedure",
   CellID->19794365],
  Cell[24221, 752, 155, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->62127907],
  Cell[24379, 758, 339, 11, 70, "Output",
   CellTags->"Procedure",
   CellID->212143131],
  Cell[24767, 775, 79, 2, 70, "Subsubsection",
   CellTags->"Procedure",
   CellID->170302028],
  Cell[24849, 779, 1043, 28, 70, "Input",
   CellTags->"Procedure",
   CellID->8672603],
  Cell[25895, 809, 444, 14, 70, "Input",
   CellTags->"Procedure",
   CellID->83404339],
  Cell[26364, 827, 163, 4, 70, "Input",
   CellTags->"Procedure",
   CellID->12949972],
  Cell[26530, 833, 373, 11, 39, "Output",
   CellTags->"Procedure",
   CellID->705128303],
  Cell[26952, 850, 84, 2, 30, "Subsubsection",
   CellTags->"Procedure",
   CellID->122890921],
  Cell[27039, 854, 1594, 43, 287, "Input",
   CellTags->"Procedure",
   CellID->345332906],
  Cell[28636, 899, 597, 19, 83, "Input",
   CellTags->"Procedure",
   CellID->197861599],
  Cell[29258, 922, 203, 6, 28, "Input",
   CellTags->"Procedure",
   CellID->434523170],
  Cell[29464, 930, 266, 8, 36, "Output",
   CellTags->"Procedure",
   CellID->212193188],
  Cell[29779, 944, 82, 2, 30, "Subsubsection",
   CellTags->"Procedure",
   CellID->313866246],
  Cell[29864, 948, 564, 15, 115, "Input",
   CellTags->"Procedure",
   CellID->93253897],
  Cell[30431, 965, 374, 10, 82, "Input",
   CellTags->"Procedure",
   CellID->237101834],
  Cell[30808, 977, 218, 7, 47, "Input",
   CellTags->"Procedure",
   CellID->161436599],
  Cell[31029, 986, 128, 3, 28, "Input",
   CellTags->"Procedure",
   CellID->14908880]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 32250, 1025},
 {"Constructor", 33216, 1059},
 {"Member", 33963, 1084},
 {"Procedure", 34944, 1118}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 66, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->67654189],
Cell[659, 27, 81, 2, 37, "Text",
 CellTags->"Overview",
 CellID->46011424],
Cell[743, 31, 114, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->334089964],
Cell[860, 35, 103, 3, 41, "Input",
 CellTags->"Overview",
 CellID->159087362],
Cell[966, 40, 151, 5, 37, "Text",
 CellTags->"Overview",
 CellID->17085649],
Cell[CellGroupData[{
Cell[1142, 49, 123, 3, 41, "Input",
 CellTags->"Overview",
 CellID->770208946],
Cell[1268, 54, 231, 7, 39, "Output",
 CellTags->"Overview",
 CellID->335158826]
}, Open  ]],
Cell[CellGroupData[{
Cell[1536, 66, 118, 3, 41, "Input",
 CellTags->"Overview",
 CellID->274986142],
Cell[1657, 71, 414, 11, 116, "Output",
 CellTags->"Overview",
 CellID->306635806]
}, Open  ]],
Cell[CellGroupData[{
Cell[2108, 87, 121, 3, 41, "Input",
 CellTags->"Overview",
 CellID->207616541],
Cell[2232, 92, 353, 9, 59, "Output",
 CellTags->"Overview",
 CellID->982914065]
}, Open  ]],
Cell[CellGroupData[{
Cell[2622, 106, 77, 2, 77, "Section",
 CellTags->"Constructor",
 CellID->599036448],
Cell[CellGroupData[{
Cell[2724, 112, 98, 2, 47, "Subsubsection",
 CellTags->"Constructor",
 CellID->173542739],
Cell[2825, 116, 319, 7, 93, "Input",
 CellID->414657126],
Cell[3147, 125, 138, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->491728507],
Cell[3288, 131, 111, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->168495957]
}, Open  ]],
Cell[CellGroupData[{
Cell[3436, 138, 94, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->168053589],
Cell[3533, 142, 726, 19, 70, "Input",
 CellTags->"Constructor",
 CellID->3564916],
Cell[4262, 163, 353, 10, 70, "Input",
 CellID->38024807],
Cell[4618, 175, 218, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->90389629],
Cell[4839, 183, 134, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->137580829]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5022, 193, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->310227300],
Cell[CellGroupData[{
Cell[5122, 199, 103, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->37547957],
Cell[5228, 203, 101, 2, 70, "Input",
 CellTags->"Member",
 CellID->502943714]
}, Open  ]],
Cell[CellGroupData[{
Cell[5366, 210, 104, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->74508406],
Cell[5473, 214, 99, 2, 70, "Input",
 CellTags->"Member",
 CellID->494855]
}, Open  ]],
Cell[CellGroupData[{
Cell[5609, 221, 97, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->35064720],
Cell[5709, 225, 95, 2, 70, "Input",
 CellTags->"Member",
 CellID->718350878]
}, Open  ]],
Cell[CellGroupData[{
Cell[5841, 232, 107, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->226921165],
Cell[5951, 236, 103, 2, 70, "Input",
 CellTags->"Member",
 CellID->59593500]
}, Open  ]],
Cell[CellGroupData[{
Cell[6091, 243, 106, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->607120701],
Cell[6200, 247, 101, 2, 70, "Input",
 CellTags->"Member",
 CellID->1897968]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6350, 255, 73, 2, 70, "Section",
 CellTags->"Procedure",
 CellID->347063912],
Cell[CellGroupData[{
Cell[6448, 261, 78, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->1458147],
Cell[6529, 265, 554, 15, 70, "Input",
 CellTags->"Procedure",
 CellID->136614548],
Cell[7086, 282, 175, 6, 70, "Input",
 CellTags->"Procedure",
 CellID->45793414],
Cell[CellGroupData[{
Cell[7286, 292, 163, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->202147383],
Cell[7452, 298, 137, 4, 70, "Output",
 CellTags->"Procedure",
 CellID->561398983]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7638, 308, 77, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->619781081],
Cell[7718, 312, 378, 10, 70, "Input",
 CellTags->"Procedure",
 CellID->197409627],
Cell[8099, 324, 1177, 31, 70, "Input",
 CellTags->"Procedure",
 CellID->51398832],
Cell[9279, 357, 136, 5, 70, "Input",
 CellTags->"Procedure",
 CellID->671760331],
Cell[CellGroupData[{
Cell[9440, 366, 137, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->695978190],
Cell[9580, 372, 148, 4, 70, "Output",
 CellTags->"Procedure",
 CellID->60367720]
}, Open  ]],
Cell[CellGroupData[{
Cell[9765, 381, 332, 11, 70, "Input",
 CellTags->"Procedure",
 CellID->622573089],
Cell[10100, 394, 8562, 148, 70, "Output",
 CellTags->"Procedure",
 CellID->153712446]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18711, 548, 78, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->267731323],
Cell[18792, 552, 378, 10, 70, "Input",
 CellTags->"Procedure",
 CellID->110775544],
Cell[19173, 564, 137, 5, 70, "Input",
 CellTags->"Procedure",
 CellID->115662299],
Cell[CellGroupData[{
Cell[19335, 573, 137, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->23794867],
Cell[19475, 579, 135, 4, 70, "Output",
 CellTags->"Procedure",
 CellID->21547026]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19659, 589, 75, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->41146177],
Cell[19737, 593, 537, 14, 70, "Input",
 CellTags->"Procedure",
 CellID->290036447],
Cell[20277, 609, 613, 16, 70, "Input",
 CellTags->"Procedure",
 CellID->304564110],
Cell[20893, 627, 147, 5, 70, "Input",
 CellTags->"Procedure",
 CellID->629846986],
Cell[CellGroupData[{
Cell[21065, 636, 147, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->130969512],
Cell[21215, 642, 138, 4, 70, "Output",
 CellTags->"Procedure",
 CellID->391937407]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21402, 652, 77, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->288059423],
Cell[21482, 656, 536, 14, 70, "Input",
 CellTags->"Procedure",
 CellID->31067251],
Cell[22021, 672, 147, 5, 70, "Input",
 CellTags->"Procedure",
 CellID->332409826],
Cell[CellGroupData[{
Cell[22193, 681, 171, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->120609806],
Cell[22367, 687, 138, 4, 70, "Output",
 CellTags->"Procedure",
 CellID->4833190]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22554, 697, 90, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->258337340],
Cell[22647, 701, 688, 19, 70, "Input",
 CellTags->"Procedure",
 CellID->825252424],
Cell[23338, 722, 520, 12, 70, "Input",
 CellTags->"Procedure",
 CellID->316713374],
Cell[23861, 736, 335, 12, 70, "Input",
 CellTags->"Procedure",
 CellID->19794365],
Cell[CellGroupData[{
Cell[24221, 752, 155, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->62127907],
Cell[24379, 758, 339, 11, 70, "Output",
 CellTags->"Procedure",
 CellID->212143131]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24767, 775, 79, 2, 70, "Subsubsection",
 CellTags->"Procedure",
 CellID->170302028],
Cell[24849, 779, 1043, 28, 70, "Input",
 CellTags->"Procedure",
 CellID->8672603],
Cell[25895, 809, 444, 14, 70, "Input",
 CellTags->"Procedure",
 CellID->83404339],
Cell[CellGroupData[{
Cell[26364, 827, 163, 4, 70, "Input",
 CellTags->"Procedure",
 CellID->12949972],
Cell[26530, 833, 373, 11, 39, "Output",
 CellTags->"Procedure",
 CellID->705128303]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26952, 850, 84, 2, 30, "Subsubsection",
 CellTags->"Procedure",
 CellID->122890921],
Cell[27039, 854, 1594, 43, 287, "Input",
 CellTags->"Procedure",
 CellID->345332906],
Cell[28636, 899, 597, 19, 83, "Input",
 CellTags->"Procedure",
 CellID->197861599],
Cell[CellGroupData[{
Cell[29258, 922, 203, 6, 28, "Input",
 CellTags->"Procedure",
 CellID->434523170],
Cell[29464, 930, 266, 8, 36, "Output",
 CellTags->"Procedure",
 CellID->212193188]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29779, 944, 82, 2, 30, "Subsubsection",
 CellTags->"Procedure",
 CellID->313866246],
Cell[29864, 948, 564, 15, 115, "Input",
 CellTags->"Procedure",
 CellID->93253897],
Cell[30431, 965, 374, 10, 82, "Input",
 CellTags->"Procedure",
 CellID->237101834],
Cell[30808, 977, 218, 7, 47, "Input",
 CellTags->"Procedure",
 CellID->161436599],
Cell[31029, 986, 128, 3, 28, "Input",
 CellTags->"Procedure",
 CellID->14908880]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
