(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     15018,        563]
NotebookOptionsPosition[      8485,        339]
NotebookOutlinePosition[     11780,        446]
CellTagsIndexPosition[     11592,        437]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Optimization", "Chapter",
 CellTags->"Overview"],

Cell["functions to construct and use Optimization objects.", "Text",
 CellTags->"Overview"],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview"],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview"],

Cell["\<\
Within the Optimization part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview"],

Cell["Select[Category[Optimization],QLConstructor[#]&]", "Input",
 CellTags->"Overview"],

Cell["Select[Category[Optimization],QLMember[#]&]", "Input",
 CellTags->"Overview"],

Cell["Select[Category[Optimization],QLProcedure[#]&]", "Input",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor"],

Cell[CellGroupData[{

Cell["EndCriteria", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"MaxIterations", 
     RowBox[{"max", " ", "number", " ", "of", " ", 
      RowBox[{"iterations", "."}]}]},
    {"MaxStationaryStateIterations", 
     RowBox[{
     "max", " ", "number", " ", "of", " ", "iterations", " ", "in", " ", "a", 
      " ", "stationary", " ", 
      RowBox[{"state", "."}]}]},
    {"RootEpsilon", 
     RowBox[{"tolerance", " ", "on", " ", "the", " ", "root", " ", 
      RowBox[{"value", "."}]}]},
    {"FunctionEpsilon", 
     RowBox[{"tolerance", " ", "on", " ", "the", " ", "function", " ", 
      RowBox[{"value", "."}]}]},
    {"GradientNormEpsilon", 
     RowBox[{
     "tolerance", " ", "on", " ", "the", " ", "function", " ", "gradient", 
      " ", "norm", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MaxIterations", "=", "1000"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MaxStationaryStateIterations", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RootEpsilon", "=", 
   RowBox[{
    RowBox[{"1", "e"}], "-", "8"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FunctionEpsilon", "=", 
   RowBox[{
    RowBox[{"1", "e"}], "-", "8"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"GradientNormEpsilon", "=", 
   RowBox[{
    RowBox[{"1", "e"}], "-", "8"}]}], ";"}]}], "Input",
 CellTags->"Constructor"],

Cell["\<\
obj=EndCriteria[MaxIterations,MaxStationaryStateIterations,RootEpsilon,\
FunctionEpsilon,GradientNormEpsilon]\
\>", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplex", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Lambda", 
     RowBox[{"lambda", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "typical", " ", "scale", " ", "length", " ", "of", " ", "the", " ", 
         "problem"}], ")"}], "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Lambda", "=", "0.01"}], ";"}]], "Input",
 CellTags->"Constructor"],

Cell["obj=Simplex[Lambda]", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LevenbergMarquardt", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Epsfcn", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "8"}], 
     RowBox[{"epsfcn", "."}]},
    {"Xtol", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "8"}], 
     RowBox[{"xtol", "."}]},
    {"Gtol", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "8"}], 
     RowBox[{"gtol", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell["obj=LevenbergMarquardt[]", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConjugateGradient", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LineSearch", "\<\"\"\>", 
     RowBox[{"LineSearch", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell["obj=ConjugateGradient[]", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SteepestDescent", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LineSearch", "\<\"\"\>", 
     RowBox[{"LineSearch", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell["obj=SteepestDescent[]", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ArmijoLineSearch", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Epsilon", 
     RowBox[{
      RowBox[{"1", "e"}], "-", "8"}], 
     RowBox[{"epsilon", "."}]},
    {"Alpha", "0.05", 
     RowBox[{"alpha", "."}]},
    {"Beta", "0.65", 
     RowBox[{"beta", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell["obj=ArmijoLineSearch[]", "Input",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["EndCriteriaMaxIterations", "Subsubsection",
 CellTags->"Member"],

Cell["EndCriteriaMaxIterations[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EndCriteriaMaxStationaryStateIterations", "Subsubsection",
 CellTags->"Member"],

Cell["EndCriteriaMaxStationaryStateIterations[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EndCriteriaFunctionEpsilon", "Subsubsection",
 CellTags->"Member"],

Cell["EndCriteriaFunctionEpsilon[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EndCriteriaGradientNormEpsilon", "Subsubsection",
 CellTags->"Member"],

Cell["EndCriteriaGradientNormEpsilon[obj]", "Input",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedures", "Section",
 CellTags->"Procedure"],

Cell[CellGroupData[{

Cell["SphereCylinderOptimizerClosest", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"R", 
     RowBox[{"r", "."}]},
    {"S", 
     RowBox[{"s", "."}]},
    {"Alpha", 
     RowBox[{"alpha", "."}]},
    {"Z1", 
     RowBox[{"z1", "."}]},
    {"Z2", 
     RowBox[{"z2", "."}]},
    {"Z3", 
     RowBox[{"z3", "."}]},
    {"MaxIter", 
     RowBox[{"maxIter", "."}]},
    {"Tol", 
     RowBox[{"tolerance", "."}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Alpha", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Z1", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Z2", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Z3", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MaxIter", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Tol", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Procedure"],

Cell["\<\
SphereCylinderOptimizerClosest[R,S,Alpha,Z1,Z2,Z3,MaxIter,Tol]\
\>", "Input",
 CellTags->"Procedure"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SecondsToString", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Seconds", 
     RowBox[{"number", " ", "of", " ", 
      RowBox[{"seconds", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Seconds", "=", "3661"}], ";"}]], "Input",
 CellTags->"Procedure"],

Cell["SecondsToString[Seconds]", "Input",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],

Cell["Enumeration Member", "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
},
WindowSize->{716, 867},
WindowMargins->{{278, Automatic}, {Automatic, 42}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[579, 22, 54, 1, 99, "Chapter",
   CellTags->"Overview"],
  Cell[636, 25, 91, 1, 37, "Text",
   CellTags->"Overview"],
  Cell[730, 28, 94, 1, 53, "MathCaption",
   CellTags->"Overview"],
  Cell[827, 31, 60, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[890, 34, 140, 4, 37, "Text",
   CellTags->"Overview"],
  Cell[1033, 40, 88, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[1124, 43, 83, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[1210, 46, 86, 1, 41, "Input",
   CellTags->"Overview"]},
 "Constructor"->{
  Cell[1321, 51, 57, 1, 77, "Section",
   CellTags->"Constructor"],
  Cell[1403, 56, 62, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[2354, 83, 517, 17, 122, "Input",
   CellTags->"Constructor"],
  Cell[2874, 102, 160, 4, 61, "Input",
   CellTags->"Constructor"],
  Cell[3071, 111, 58, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[3495, 126, 101, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[3599, 131, 62, 1, 41, "Input",
   CellTags->"Constructor"],
  Cell[3698, 137, 69, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[4214, 156, 67, 1, 41, "Input",
   CellTags->"Constructor"],
  Cell[4318, 162, 68, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[4645, 172, 66, 1, 41, "Input",
   CellTags->"Constructor"],
  Cell[4748, 178, 66, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[5073, 188, 64, 1, 41, "Input",
   CellTags->"Constructor"],
  Cell[5174, 194, 67, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[5596, 209, 65, 1, 41, "Input",
   CellTags->"Constructor"]},
 "Member"->{
  Cell[5710, 216, 55, 1, 77, "Section",
   CellTags->"Member"],
  Cell[5790, 221, 70, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[5863, 224, 67, 1, 41, "Input",
   CellTags->"Member"],
  Cell[5967, 230, 85, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[6055, 233, 82, 1, 41, "Input",
   CellTags->"Member"],
  Cell[6174, 239, 72, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[6249, 242, 69, 1, 41, "Input",
   CellTags->"Member"],
  Cell[6355, 248, 76, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[6434, 251, 73, 1, 41, "Input",
   CellTags->"Member"]},
 "Procedure"->{
  Cell[6556, 258, 53, 1, 77, "Section",
   CellTags->"Procedure"],
  Cell[6634, 263, 79, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[7195, 287, 553, 17, 182, "Input",
   CellTags->"Procedure"],
  Cell[7751, 306, 111, 3, 41, "Input",
   CellTags->"Procedure"],
  Cell[7899, 314, 64, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[8205, 325, 100, 3, 41, "Input",
   CellTags->"Procedure"],
  Cell[8308, 330, 65, 1, 41, "Input",
   CellTags->"Procedure"]},
 "EnumerationMember"->{
  Cell[8400, 335, 69, 1, 77, "Section",
   CellTags->"EnumerationMember"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 8785, 349},
 {"Constructor", 9310, 366},
 {"Member", 10381, 397},
 {"Procedure", 10990, 416},
 {"EnumerationMember", 11493, 431}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 54, 1, 99, "Chapter",
 CellTags->"Overview"],
Cell[636, 25, 91, 1, 37, "Text",
 CellTags->"Overview"],
Cell[730, 28, 94, 1, 53, "MathCaption",
 CellTags->"Overview"],
Cell[827, 31, 60, 1, 41, "Input",
 CellTags->"Overview"],
Cell[890, 34, 140, 4, 37, "Text",
 CellTags->"Overview"],
Cell[1033, 40, 88, 1, 41, "Input",
 CellTags->"Overview"],
Cell[1124, 43, 83, 1, 41, "Input",
 CellTags->"Overview"],
Cell[1210, 46, 86, 1, 41, "Input",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[1321, 51, 57, 1, 77, "Section",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[1403, 56, 62, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[1468, 59, 883, 22, 134, "Text"],
Cell[2354, 83, 517, 17, 122, "Input",
 CellTags->"Constructor"],
Cell[2874, 102, 160, 4, 61, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3071, 111, 58, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[3132, 114, 360, 10, 64, "Text"],
Cell[3495, 126, 101, 3, 41, "Input",
 CellTags->"Constructor"],
Cell[3599, 131, 62, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3698, 137, 69, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[3770, 140, 441, 14, 99, "Text"],
Cell[4214, 156, 67, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4318, 162, 68, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[4389, 165, 253, 5, 64, "Text"],
Cell[4645, 172, 66, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4748, 178, 66, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[4817, 181, 253, 5, 64, "Text"],
Cell[5073, 188, 64, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5174, 194, 67, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[5244, 197, 349, 10, 99, "Text"],
Cell[5596, 209, 65, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5710, 216, 55, 1, 77, "Section",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[5790, 221, 70, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[5863, 224, 67, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5967, 230, 85, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[6055, 233, 82, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6174, 239, 72, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[6249, 242, 69, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6355, 248, 76, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[6434, 251, 73, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6556, 258, 53, 1, 77, "Section",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[6634, 263, 79, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[6716, 266, 476, 19, 185, "Text"],
Cell[7195, 287, 553, 17, 182, "Input",
 CellTags->"Procedure"],
Cell[7751, 306, 111, 3, 41, "Input",
 CellTags->"Procedure"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7899, 314, 64, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[7966, 317, 236, 6, 64, "Text"],
Cell[8205, 325, 100, 3, 41, "Input",
 CellTags->"Procedure"],
Cell[8308, 330, 65, 1, 41, "Input",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[8400, 335, 69, 1, 77, "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

