(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26911,       1044]
NotebookOptionsPosition[     14484,        587]
NotebookOutlinePosition[     20917,        807]
CellTagsIndexPosition[     20762,        799]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["Options"], "Chapter",
 CellTags->"Overview",
 CellID->220498182],

Cell["functions to construct and use Option objects.", "Text",
 CellTags->"Overview",
 CellID->81262326],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->14100573],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->571118763],

Cell["\<\
Within the Options part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->82711567],

Cell[CellGroupData[{

Cell["Select[Category[Options],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[972]:=",
 CellID->925099932],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "BarrierOption", ",", "CaAsianOption", ",", "DaAsianOption", ",", 
   "DividendVanillaOption", ",", "EuropeanOption", ",", 
   "ForwardVanillaOption", ",", "QuantoForwardVanillaOption", ",", 
   "QuantoVanillaOption", ",", "VanillaOption"}], "}"}]], "Output",
 CellChangeTimes->{3.43607954278125*^9},
 CellTags->"Overview",
 CellLabel->"Out[972]=",
 CellID->433742224]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Options],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[973]:=",
 CellID->616698913],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Delta", ",", "DeltaForward", ",", "DividendRho", ",", "Elasticity", ",", 
   "Gamma", ",", "ItmCashProbability", ",", "Theta", ",", "ThetaPerDay", ",", 
   "Vega"}], "}"}]], "Output",
 CellChangeTimes->{3.43607954434375*^9},
 CellTags->"Overview",
 CellLabel->"Out[973]=",
 CellID->153776582]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->155142613],

Cell[CellGroupData[{

Cell["BarrierOption", "Subsection",
 CellTags->"Constructor",
 CellID->43618401],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"BarrierType", "exampleValue", 
     RowBox[{"barrier", " ", 
      RowBox[{"type", "."}]}]},
    {"Barrier", "1.0", 
     RowBox[{"barrier", "."}]},
    {"Rebate", "1.0", 
     RowBox[{"rebate", "."}]},
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->34992666],

Cell[BoxData[{
 RowBox[{
  RowBox[{"BarrierType", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Barrier", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Rebate", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->3033501],

Cell["\<\
obj=BarrierOption[BarrierType,Barrier,Rebate,Payoff,Exercise]\
\>", "Input",
 CellTags->"Constructor",
 CellID->872718434]
}, Open  ]],

Cell[CellGroupData[{

Cell["CaAsianOption", "Subsection",
 CellTags->"Constructor",
 CellID->527945185],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AverageType", "exampleValue", 
     RowBox[{"average", " ", 
      RowBox[{"type", "."}]}]},
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->26262175],

Cell[BoxData[{
 RowBox[{
  RowBox[{"AverageType", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->31933029],

Cell["obj=CaAsianOption[AverageType,Payoff,Exercise]", "Input",
 CellTags->"Constructor",
 CellID->193811385]
}, Open  ]],

Cell[CellGroupData[{

Cell["DaAsianOption", "Subsection",
 CellTags->"Constructor",
 CellID->38351804],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AverageType", "exampleValue", 
     RowBox[{"average", " ", 
      RowBox[{"type", "."}]}]},
    {"RunningAccumulator", "1.0", 
     RowBox[{"running", " ", 
      RowBox[{"accumulator", "."}]}]},
    {"PastFixings", "3", 
     RowBox[{"past", " ", 
      RowBox[{"fixings", "."}]}]},
    {"FixingDates", 
     RowBox[{
      RowBox[{"1", "Y"}], ",", 
      RowBox[{"2", "Y"}]}], 
     RowBox[{"fixing", " ", 
      RowBox[{"dates", "."}]}]},
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->85599462],

Cell[BoxData[{
 RowBox[{
  RowBox[{"AverageType", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RunningAccumulator", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PastFixings", "=", "3"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FixingDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "Y"}], ",", 
     RowBox[{"2", "Y"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->347646424],

Cell["\<\
obj=DaAsianOption[AverageType,RunningAccumulator,PastFixings,FixingDates,\
Payoff,Exercise]\
\>", "Input",
 CellTags->"Constructor",
 CellID->88342700]
}, Open  ]],

Cell[CellGroupData[{

Cell["DividendVanillaOption", "Subsection",
 CellTags->"Constructor",
 CellID->572471494],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"DividendDates", 
     RowBox[{
      RowBox[{"1", "Y"}], ",", 
      RowBox[{"2", "Y"}]}], 
     RowBox[{"vector", " ", "of", " ", "dividend", " ", 
      RowBox[{"dates", "."}]}]},
    {"Dividends", 
     RowBox[{"0.01", ",", "0.01"}], 
     RowBox[{"vector", " ", "of", " ", 
      RowBox[{"dividends", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->700869359],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"DividendDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "Y"}], ",", 
     RowBox[{"2", "Y"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Dividends", "=", 
   RowBox[{"{", 
    RowBox[{"0.01", ",", "0.01"}], "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->644763797],

Cell["\<\
obj=DividendVanillaOption[Payoff,Exercise,DividendDates,Dividends]\
\>", "Input",
 CellTags->"Constructor",
 CellID->219077782]
}, Open  ]],

Cell[CellGroupData[{

Cell["ForwardVanillaOption", "Subsection",
 CellTags->"Constructor",
 CellID->245085922],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Moneyness", "1.0", 
     RowBox[{"moneyness", "."}]},
    {"ResetDate", 
     RowBox[{"1", "Y"}], 
     RowBox[{"reset", " ", 
      RowBox[{"date", "."}]}]},
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->194730169],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Moneyness", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ResetDate", "=", 
   RowBox[{"1", "Y"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->18054104],

Cell["\<\
obj=ForwardVanillaOption[Moneyness,ResetDate,Payoff,Exercise]\
\>", "Input",
 CellTags->"Constructor",
 CellID->508161048]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaOption", "Subsection",
 CellTags->"Constructor",
 CellID->426145980],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->26194111],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->61831429],

Cell["obj=VanillaOption[Payoff,Exercise]", "Input",
 CellTags->"Constructor",
 CellID->367362080]
}, Open  ]],

Cell[CellGroupData[{

Cell["EuropeanOption", "Subsection",
 CellTags->"Constructor",
 CellID->886260],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->426308459],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->173252841],

Cell["obj=EuropeanOption[Payoff,Exercise]", "Input",
 CellTags->"Constructor",
 CellID->1044434605]
}, Open  ]],

Cell[CellGroupData[{

Cell["QuantoVanillaOption", "Subsection",
 CellTags->"Constructor",
 CellID->226000208],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->181958205],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->2640061],

Cell["obj=QuantoVanillaOption[Payoff,Exercise]", "Input",
 CellTags->"Constructor",
 CellID->4522750]
}, Open  ]],

Cell[CellGroupData[{

Cell["QuantoForwardVanillaOption", "Subsection",
 CellTags->"Constructor",
 CellID->708934115],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Moneyness", "1.0", 
     RowBox[{"moneyness", "."}]},
    {"ResetDate", 
     RowBox[{"1", "Y"}], 
     RowBox[{"reset", " ", 
      RowBox[{"date", "."}]}]},
    {"Payoff", "exampleValue", 
     RowBox[{"StrikedTypePayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", "exampleValue", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->29831889],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Moneyness", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ResetDate", "=", 
   RowBox[{"1", "Y"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Payoff", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->30104521],

Cell["\<\
obj=QuantoForwardVanillaOption[Moneyness,ResetDate,Payoff,Exercise]\
\>", "Input",
 CellTags->"Constructor",
 CellID->39206836]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->666365189],

Cell[CellGroupData[{

Cell["Delta", "Subsection",
 CellTags->"Member",
 CellID->78897666],

Cell["Delta[obj]", "Input",
 CellTags->"Member",
 CellID->214901278]
}, Open  ]],

Cell[CellGroupData[{

Cell["DeltaForward", "Subsection",
 CellTags->"Member",
 CellID->184356306],

Cell["DeltaForward[obj]", "Input",
 CellTags->"Member",
 CellID->273343755]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elasticity", "Subsection",
 CellTags->"Member",
 CellID->690055465],

Cell["Elasticity[obj]", "Input",
 CellTags->"Member",
 CellID->22295319]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gamma", "Subsection",
 CellTags->"Member",
 CellID->107253525],

Cell["Gamma[obj]", "Input",
 CellTags->"Member",
 CellID->366352570]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theta", "Subsection",
 CellTags->"Member",
 CellID->268182746],

Cell["Theta[obj]", "Input",
 CellTags->"Member",
 CellID->548189912]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThetaPerDay", "Subsection",
 CellTags->"Member",
 CellID->58869886],

Cell["ThetaPerDay[obj]", "Input",
 CellTags->"Member",
 CellID->109534840]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vega", "Subsection",
 CellTags->"Member",
 CellID->203683817],

Cell["Vega[obj]", "Input",
 CellTags->"Member",
 CellID->66953212]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rho", "Subsection",
 CellTags->"Member",
 CellID->112178573],

Cell["Rho[obj]", "Input",
 CellTags->"Member",
 CellID->35580565]
}, Open  ]],

Cell[CellGroupData[{

Cell["DividendRho", "Subsection",
 CellTags->"Member",
 CellID->48773229],

Cell["DividendRho[obj]", "Input",
 CellTags->"Member",
 CellID->40700217]
}, Open  ]],

Cell[CellGroupData[{

Cell["ItmCashProbability", "Subsection",
 CellTags->"Member",
 CellID->86731455],

Cell["ItmCashProbability[obj]", "Input",
 CellTags->"Member",
 CellID->86188463]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 405}, {44, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 78, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->220498182],
  Cell[671, 27, 104, 2, 37, "Text",
   CellTags->"Overview",
   CellID->81262326],
  Cell[778, 31, 113, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->14100573],
  Cell[894, 35, 80, 2, 41, "Input",
   CellTags->"Overview",
   CellID->571118763],
  Cell[977, 39, 154, 5, 37, "Text",
   CellTags->"Overview",
   CellID->82711567],
  Cell[1156, 48, 128, 3, 41, "Input",
   CellTags->"Overview",
   CellID->925099932],
  Cell[1287, 53, 410, 10, 78, "Output",
   CellTags->"Overview",
   CellID->433742224],
  Cell[1734, 68, 123, 3, 41, "Input",
   CellTags->"Overview",
   CellID->616698913],
  Cell[1860, 73, 335, 9, 59, "Output",
   CellTags->"Overview",
   CellID->153776582]},
 "Constructo"->{
  Cell[2232, 87, 76, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->155142613]},
 "Constructor"->{
  Cell[2333, 93, 80, 2, 51, "Subsection",
   CellTags->"Constructor",
   CellID->43618401],
  Cell[3025, 116, 387, 12, 70, "Input",
   CellTags->"Constructor",
   CellID->3033501],
  Cell[3415, 130, 132, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->872718434],
  Cell[3584, 139, 81, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->527945185],
  Cell[4167, 158, 271, 8, 70, "Input",
   CellTags->"Constructor",
   CellID->31933029],
  Cell[4441, 168, 109, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->193811385],
  Cell[4587, 175, 80, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->38351804],
  Cell[5519, 206, 555, 18, 70, "Input",
   CellTags->"Constructor",
   CellID->347646424],
  Cell[6077, 226, 161, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->88342700],
  Cell[6275, 236, 89, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->572471494],
  Cell[7089, 262, 468, 16, 70, "Input",
   CellTags->"Constructor",
   CellID->644763797],
  Cell[7560, 280, 137, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->219077782],
  Cell[7734, 289, 88, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->245085922],
  Cell[8391, 311, 338, 11, 70, "Input",
   CellTags->"Constructor",
   CellID->18054104],
  Cell[8732, 324, 132, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->508161048],
  Cell[8901, 333, 81, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->426145980],
  Cell[9385, 349, 199, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->61831429],
  Cell[9587, 357, 97, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->367362080],
  Cell[9721, 364, 79, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->886260],
  Cell[10204, 380, 200, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->173252841],
  Cell[10407, 388, 99, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->1044434605],
  Cell[10543, 395, 87, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->226000208],
  Cell[11034, 411, 198, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->2640061],
  Cell[11235, 419, 101, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->4522750],
  Cell[11373, 426, 94, 2, 70, "Subsection",
   CellTags->"Constructor",
   CellID->708934115],
  Cell[12035, 448, 338, 11, 70, "Input",
   CellTags->"Constructor",
   CellID->30104521],
  Cell[12376, 461, 137, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->39206836]},
 "Member"->{
  Cell[12562, 471, 75, 2, 51, "Section",
   CellTags->"Member",
   CellID->666365189],
  Cell[12662, 477, 67, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->78897666],
  Cell[12732, 481, 68, 2, 28, "Input",
   CellTags->"Member",
   CellID->214901278],
  Cell[12837, 488, 75, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->184356306],
  Cell[12915, 492, 75, 2, 28, "Input",
   CellTags->"Member",
   CellID->273343755],
  Cell[13027, 499, 73, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->690055465],
  Cell[13103, 503, 72, 2, 28, "Input",
   CellTags->"Member",
   CellID->22295319],
  Cell[13212, 510, 68, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->107253525],
  Cell[13283, 514, 68, 2, 28, "Input",
   CellTags->"Member",
   CellID->366352570],
  Cell[13388, 521, 68, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->268182746],
  Cell[13459, 525, 68, 2, 28, "Input",
   CellTags->"Member",
   CellID->548189912],
  Cell[13564, 532, 73, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->58869886],
  Cell[13640, 536, 74, 2, 28, "Input",
   CellTags->"Member",
   CellID->109534840],
  Cell[13751, 543, 67, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->203683817],
  Cell[13821, 547, 66, 2, 28, "Input",
   CellTags->"Member",
   CellID->66953212],
  Cell[13924, 554, 66, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->112178573],
  Cell[13993, 558, 65, 2, 28, "Input",
   CellTags->"Member",
   CellID->35580565],
  Cell[14095, 565, 73, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->48773229],
  Cell[14171, 569, 73, 2, 28, "Input",
   CellTags->"Member",
   CellID->40700217],
  Cell[14281, 576, 80, 2, 51, "Subsection",
   CellTags->"Member",
   CellID->86731455],
  Cell[14364, 580, 80, 2, 28, "Input",
   CellTags->"Member",
   CellID->86188463]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 15537, 618},
 {"Constructo", 16328, 646},
 {"Constructor", 16436, 650},
 {"Member", 18910, 732}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 78, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->220498182],
Cell[671, 27, 104, 2, 37, "Text",
 CellTags->"Overview",
 CellID->81262326],
Cell[778, 31, 113, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->14100573],
Cell[894, 35, 80, 2, 41, "Input",
 CellTags->"Overview",
 CellID->571118763],
Cell[977, 39, 154, 5, 37, "Text",
 CellTags->"Overview",
 CellID->82711567],
Cell[CellGroupData[{
Cell[1156, 48, 128, 3, 41, "Input",
 CellTags->"Overview",
 CellID->925099932],
Cell[1287, 53, 410, 10, 78, "Output",
 CellTags->"Overview",
 CellID->433742224]
}, Open  ]],
Cell[CellGroupData[{
Cell[1734, 68, 123, 3, 41, "Input",
 CellTags->"Overview",
 CellID->616698913],
Cell[1860, 73, 335, 9, 59, "Output",
 CellTags->"Overview",
 CellID->153776582]
}, Open  ]],
Cell[CellGroupData[{
Cell[2232, 87, 76, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->155142613],
Cell[CellGroupData[{
Cell[2333, 93, 80, 2, 51, "Subsection",
 CellTags->"Constructor",
 CellID->43618401],
Cell[2416, 97, 606, 17, 140, "Input",
 CellID->34992666],
Cell[3025, 116, 387, 12, 70, "Input",
 CellTags->"Constructor",
 CellID->3033501],
Cell[3415, 130, 132, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->872718434]
}, Open  ]],
Cell[CellGroupData[{
Cell[3584, 139, 81, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->527945185],
Cell[3668, 143, 496, 13, 70, "Input",
 CellID->26262175],
Cell[4167, 158, 271, 8, 70, "Input",
 CellTags->"Constructor",
 CellID->31933029],
Cell[4441, 168, 109, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->193811385]
}, Open  ]],
Cell[CellGroupData[{
Cell[4587, 175, 80, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->38351804],
Cell[4670, 179, 846, 25, 70, "Input",
 CellID->85599462],
Cell[5519, 206, 555, 18, 70, "Input",
 CellTags->"Constructor",
 CellID->347646424],
Cell[6077, 226, 161, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->88342700]
}, Open  ]],
Cell[CellGroupData[{
Cell[6275, 236, 89, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->572471494],
Cell[6367, 240, 719, 20, 70, "Input",
 CellID->700869359],
Cell[7089, 262, 468, 16, 70, "Input",
 CellTags->"Constructor",
 CellID->644763797],
Cell[7560, 280, 137, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->219077782]
}, Open  ]],
Cell[CellGroupData[{
Cell[7734, 289, 88, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->245085922],
Cell[7825, 293, 563, 16, 70, "Input",
 CellID->194730169],
Cell[8391, 311, 338, 11, 70, "Input",
 CellTags->"Constructor",
 CellID->18054104],
Cell[8732, 324, 132, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->508161048]
}, Open  ]],
Cell[CellGroupData[{
Cell[8901, 333, 81, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->426145980],
Cell[8985, 337, 397, 10, 70, "Input",
 CellID->26194111],
Cell[9385, 349, 199, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->61831429],
Cell[9587, 357, 97, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->367362080]
}, Open  ]],
Cell[CellGroupData[{
Cell[9721, 364, 79, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->886260],
Cell[9803, 368, 398, 10, 70, "Input",
 CellID->426308459],
Cell[10204, 380, 200, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->173252841],
Cell[10407, 388, 99, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->1044434605]
}, Open  ]],
Cell[CellGroupData[{
Cell[10543, 395, 87, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->226000208],
Cell[10633, 399, 398, 10, 70, "Input",
 CellID->181958205],
Cell[11034, 411, 198, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->2640061],
Cell[11235, 419, 101, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->4522750]
}, Open  ]],
Cell[CellGroupData[{
Cell[11373, 426, 94, 2, 70, "Subsection",
 CellTags->"Constructor",
 CellID->708934115],
Cell[11470, 430, 562, 16, 70, "Input",
 CellID->29831889],
Cell[12035, 448, 338, 11, 70, "Input",
 CellTags->"Constructor",
 CellID->30104521],
Cell[12376, 461, 137, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->39206836]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12562, 471, 75, 2, 51, "Section",
 CellTags->"Member",
 CellID->666365189],
Cell[CellGroupData[{
Cell[12662, 477, 67, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->78897666],
Cell[12732, 481, 68, 2, 28, "Input",
 CellTags->"Member",
 CellID->214901278]
}, Open  ]],
Cell[CellGroupData[{
Cell[12837, 488, 75, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->184356306],
Cell[12915, 492, 75, 2, 28, "Input",
 CellTags->"Member",
 CellID->273343755]
}, Open  ]],
Cell[CellGroupData[{
Cell[13027, 499, 73, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->690055465],
Cell[13103, 503, 72, 2, 28, "Input",
 CellTags->"Member",
 CellID->22295319]
}, Open  ]],
Cell[CellGroupData[{
Cell[13212, 510, 68, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->107253525],
Cell[13283, 514, 68, 2, 28, "Input",
 CellTags->"Member",
 CellID->366352570]
}, Open  ]],
Cell[CellGroupData[{
Cell[13388, 521, 68, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->268182746],
Cell[13459, 525, 68, 2, 28, "Input",
 CellTags->"Member",
 CellID->548189912]
}, Open  ]],
Cell[CellGroupData[{
Cell[13564, 532, 73, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->58869886],
Cell[13640, 536, 74, 2, 28, "Input",
 CellTags->"Member",
 CellID->109534840]
}, Open  ]],
Cell[CellGroupData[{
Cell[13751, 543, 67, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->203683817],
Cell[13821, 547, 66, 2, 28, "Input",
 CellTags->"Member",
 CellID->66953212]
}, Open  ]],
Cell[CellGroupData[{
Cell[13924, 554, 66, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->112178573],
Cell[13993, 558, 65, 2, 28, "Input",
 CellTags->"Member",
 CellID->35580565]
}, Open  ]],
Cell[CellGroupData[{
Cell[14095, 565, 73, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->48773229],
Cell[14171, 569, 73, 2, 28, "Input",
 CellTags->"Member",
 CellID->40700217]
}, Open  ]],
Cell[CellGroupData[{
Cell[14281, 576, 80, 2, 51, "Subsection",
 CellTags->"Member",
 CellID->86731455],
Cell[14364, 580, 80, 2, 28, "Input",
 CellTags->"Member",
 CellID->86188463]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
