(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     18215,        655]
NotebookOptionsPosition[     10362,        384]
NotebookOutlinePosition[     14290,        511]
CellTagsIndexPosition[     14100,        502]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["OvernightIndexedSwap", "Chapter",
 CellTags->"Overview"],

Cell["functions to construct and use OvernightIndexedSwap objects.", "Text",
 CellTags->"Overview"],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview"],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview"],

Cell["\<\
Within the OvernightIndexedSwap part there are several constructors and \
member functions available \
\>", "Text",
 CellTags->"Overview"],

Cell["Select[Category[OvernightIndexedSwap],QLConstructor[#]&]", "Input",
 CellTags->"Overview"],

Cell["Select[Category[OvernightIndexedSwap],QLMember[#]&]", "Input",
 CellTags->"Overview"],

Cell["Select[Category[OvernightIndexedSwap],QLProcedure[#]&]", "Input",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor"],

Cell[CellGroupData[{

Cell["OvernightIndexedSwap", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Schedule", 
     RowBox[{"Schedule", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"FixDayCounter", 
     RowBox[{"fixed", " ", "leg", " ", "day", " ", "counter", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Actual"}], "/", "360"}], ")"}], 
       "."}]}]},
    {"OvernightIndex", 
     RowBox[{
     "overnight", " ", "leg", " ", "OvernightIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PayerReceiver", "\<\"Payer\"\>", 
     RowBox[{
      RowBox[{
      "PAYER", " ", "to", " ", "pay", " ", "the", " ", "fixed", " ", "rate"}],
       ",", " ", 
      RowBox[{"RECEIVER", " ", "to", " ", "receive", " ", 
       RowBox[{"it", "."}]}]}]},
    {"Nominal", "100", 
     RowBox[{"Notional", " ", 
      RowBox[{"Amount", "."}]}]},
    {"FixedRate", "0.0", 
     RowBox[{"the", " ", "fixed", " ", "leg", " ", 
      RowBox[{"rate", "."}]}]},
    {"Spread", "0.0", 
     RowBox[{"overnight", " ", "leg", " ", 
      RowBox[{"spread", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Schedule", "=", "OisSchedule"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FixDayCounter", "=", 
   RowBox[{"Actual", "/", "360"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OvernightIndex", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor"],

Cell["\<\
obj=OvernightIndexedSwap[Schedule,FixDayCounter,OvernightIndex]\
\>", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeOIS", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapTenor", 
     RowBox[{"swap", " ", "tenor", " ", "period", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "5"}], "Y"}], ")"}], "."}]}]},
    {"OvernightIndex", 
     RowBox[{"OvernightIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"ForwardStart", 
     RowBox[{"forward", " ", "start", " ", 
      RowBox[{"period", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FixedRate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Rate"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"the", " ", "fixed", " ", "leg", " ", 
      RowBox[{"rate", ".", " ", "If"}], " ", "missing", " ", "atm", " ", 
      "rate", " ", "is", " ", 
      RowBox[{"used", "."}]}]},
    {"FixDayCounter", "\<\"Actual/360\"\>", 
     RowBox[{"fixed", " ", "leg", " ", "day", " ", 
      RowBox[{"counter", "."}]}]},
    {"Spread", "0.0", 
     RowBox[{
     "the", " ", "spread", " ", "in", " ", "the", " ", "overnight", " ", 
      "leg", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SwapTenor", "=", 
   RowBox[{"5", "Y"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OvernightIndex", "=", "Eonia"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ForwardStart", "=", "\"\<0D\>\""}], ";"}]}], "Input",
 CellTags->"Constructor"],

Cell["obj=MakeOIS[SwapTenor,OvernightIndex,ForwardStart]", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeDatedOIS", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OvernightIndex", 
     RowBox[{"OvernightIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"StartDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"ois", " ", "start", " ", 
      RowBox[{"date", ".", " ", "If"}], " ", "missing", " ", "first", " ", 
      "ECB", " ", "date", " ", "is", " ", 
      RowBox[{"used", "."}]}]},
    {"EndDate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Date"}], 
      RowBox[{"(", ")"}]}], 
     RowBox[{"ois", " ", "end", " ", 
      RowBox[{"date", ".", " ", "If"}], " ", "missing", " ", "first", " ", 
      "ECB", " ", "date", " ", "after", " ", "start", " ", "date", " ", "is", 
      " ", 
      RowBox[{"used", "."}]}]},
    {"FixedRate", 
     RowBox[{
      RowBox[{"QuantLib", "::", "Null"}], "<", 
      RowBox[{"QuantLib", "::", "Rate"}], ">", 
      RowBox[{"(", ")"}]}], 
     RowBox[{"the", " ", "fixed", " ", "leg", " ", 
      RowBox[{"rate", ".", " ", "If"}], " ", "missing", " ", "atm", " ", 
      "rate", " ", "is", " ", 
      RowBox[{"used", "."}]}]},
    {"FixDayCounter", "\<\"Actual/360\"\>", 
     RowBox[{"fixed", " ", "leg", " ", "day", " ", 
      RowBox[{"counter", "."}]}]},
    {"Spread", "0.0", 
     RowBox[{
     "the", " ", "spread", " ", "in", " ", "the", " ", "overnight", " ", 
      "leg", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OvernightIndex", "=", "Eonia"}], ";"}]], "Input",
 CellTags->"Constructor"],

Cell["obj=MakeDatedOIS[OvernightIndex]", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFromOISRateHelper", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OISRateHelper", 
     RowBox[{"OISRateHelper", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OISRateHelper", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Constructor"],

Cell["obj=OvernightIndexedSwapFromOISRateHelper[OISRateHelper]", "Input",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFixedLegBPS", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFixedLegBPS[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFixedLegNPV", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFixedLegNPV[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFairRate", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFairRate[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapOvernightLegBPS", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapOvernightLegBPS[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapOvernightLegNPV", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapOvernightLegNPV[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFairSpread", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFairSpread[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapType", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapType[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapNominal", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapNominal[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFixedRate", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFixedRate[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFixedDayCount", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFixedDayCount[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapSpread", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapSpread[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapFixedLegAnalysis", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapFixedLegAnalysis[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OvernightIndexedSwapOvernightLegAnalysis", "Subsubsection",
 CellTags->"Member"],

Cell["OvernightIndexedSwapOvernightLegAnalysis[obj]", "Input",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],

Cell["Procedures", "Section",
 CellTags->"Procedure"],

Cell["Enumeration Member", "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
},
WindowSize->{716, 867},
WindowMargins->{{278, Automatic}, {Automatic, 42}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[579, 22, 62, 1, 99, "Chapter",
   CellTags->"Overview"],
  Cell[644, 25, 99, 1, 37, "Text",
   CellTags->"Overview"],
  Cell[746, 28, 94, 1, 53, "MathCaption",
   CellTags->"Overview"],
  Cell[843, 31, 60, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[906, 34, 148, 4, 37, "Text",
   CellTags->"Overview"],
  Cell[1057, 40, 96, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[1156, 43, 91, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[1250, 46, 94, 1, 41, "Input",
   CellTags->"Overview"]},
 "Constructor"->{
  Cell[1369, 51, 57, 1, 77, "Section",
   CellTags->"Constructor"],
  Cell[1451, 56, 71, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[2851, 98, 281, 8, 82, "Input",
   CellTags->"Constructor"],
  Cell[3135, 108, 114, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[3286, 116, 58, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[4690, 157, 261, 8, 82, "Input",
   CellTags->"Constructor"],
  Cell[4954, 167, 93, 1, 41, "Input",
   CellTags->"Constructor"],
  Cell[5084, 173, 63, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[6828, 222, 110, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[6941, 227, 75, 1, 41, "Input",
   CellTags->"Constructor"],
  Cell[7053, 233, 88, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[7397, 244, 116, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[7516, 249, 99, 1, 41, "Input",
   CellTags->"Constructor"]},
 "Member"->{
  Cell[7664, 256, 55, 1, 77, "Section",
   CellTags->"Member"],
  Cell[7744, 261, 77, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[7824, 264, 74, 1, 41, "Input",
   CellTags->"Member"],
  Cell[7935, 270, 77, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8015, 273, 74, 1, 41, "Input",
   CellTags->"Member"],
  Cell[8126, 279, 74, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8203, 282, 71, 1, 41, "Input",
   CellTags->"Member"],
  Cell[8311, 288, 81, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8395, 291, 78, 1, 41, "Input",
   CellTags->"Member"],
  Cell[8510, 297, 81, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8594, 300, 78, 1, 41, "Input",
   CellTags->"Member"],
  Cell[8709, 306, 76, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8788, 309, 73, 1, 41, "Input",
   CellTags->"Member"],
  Cell[8898, 315, 70, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8971, 318, 67, 1, 41, "Input",
   CellTags->"Member"],
  Cell[9075, 324, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[9151, 327, 70, 1, 41, "Input",
   CellTags->"Member"],
  Cell[9258, 333, 75, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[9336, 336, 72, 1, 41, "Input",
   CellTags->"Member"],
  Cell[9445, 342, 79, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[9527, 345, 76, 1, 41, "Input",
   CellTags->"Member"],
  Cell[9640, 351, 72, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[9715, 354, 69, 1, 41, "Input",
   CellTags->"Member"],
  Cell[9821, 360, 82, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[9906, 363, 79, 1, 41, "Input",
   CellTags->"Member"],
  Cell[10022, 369, 86, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[10111, 372, 83, 1, 41, "Input",
   CellTags->"Member"]},
 "Procedure"->{
  Cell[10221, 377, 53, 1, 77, "Section",
   CellTags->"Procedure"]},
 "EnumerationMember"->{
  Cell[10277, 380, 69, 1, 51, "Section",
   CellTags->"EnumerationMember"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 10662, 394},
 {"Constructor", 11187, 411},
 {"Member", 12108, 438},
 {"Procedure", 13907, 493},
 {"EnumerationMember", 14000, 496}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 62, 1, 99, "Chapter",
 CellTags->"Overview"],
Cell[644, 25, 99, 1, 37, "Text",
 CellTags->"Overview"],
Cell[746, 28, 94, 1, 53, "MathCaption",
 CellTags->"Overview"],
Cell[843, 31, 60, 1, 41, "Input",
 CellTags->"Overview"],
Cell[906, 34, 148, 4, 37, "Text",
 CellTags->"Overview"],
Cell[1057, 40, 96, 1, 41, "Input",
 CellTags->"Overview"],
Cell[1156, 43, 91, 1, 41, "Input",
 CellTags->"Overview"],
Cell[1250, 46, 94, 1, 41, "Input",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[1369, 51, 57, 1, 77, "Section",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[1451, 56, 71, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[1525, 59, 619, 17, 99, "Text"],
Cell[2147, 78, 701, 18, 141, "Text"],
Cell[2851, 98, 281, 8, 82, "Input",
 CellTags->"Constructor"],
Cell[3135, 108, 114, 3, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3286, 116, 58, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[3347, 119, 553, 15, 99, "Text"],
Cell[3903, 136, 784, 19, 124, "Text"],
Cell[4690, 157, 261, 8, 82, "Input",
 CellTags->"Constructor"],
Cell[4954, 167, 93, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5084, 173, 63, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[5150, 176, 252, 6, 64, "Text"],
Cell[5405, 184, 1420, 36, 206, "Text"],
Cell[6828, 222, 110, 3, 41, "Input",
 CellTags->"Constructor"],
Cell[6941, 227, 75, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7053, 233, 88, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[7144, 236, 250, 6, 64, "Text"],
Cell[7397, 244, 116, 3, 41, "Input",
 CellTags->"Constructor"],
Cell[7516, 249, 99, 1, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7664, 256, 55, 1, 77, "Section",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[7744, 261, 77, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[7824, 264, 74, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7935, 270, 77, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8015, 273, 74, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8126, 279, 74, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8203, 282, 71, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8311, 288, 81, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8395, 291, 78, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8510, 297, 81, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8594, 300, 78, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8709, 306, 76, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8788, 309, 73, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8898, 315, 70, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8971, 318, 67, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9075, 324, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[9151, 327, 70, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9258, 333, 75, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[9336, 336, 72, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9445, 342, 79, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[9527, 345, 76, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9640, 351, 72, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[9715, 354, 69, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9821, 360, 82, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[9906, 363, 79, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10022, 369, 86, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[10111, 372, 83, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[10221, 377, 53, 1, 77, "Section",
 CellTags->"Procedure"],
Cell[10277, 380, 69, 1, 51, "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

