(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26951,        817]
NotebookOptionsPosition[     19237,        544]
NotebookOutlinePosition[     22666,        649]
CellTagsIndexPosition[     22089,        632]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["QuantLib", "Subtitle",
 CellChangeTimes->{{3.434947043421875*^9, 3.434947050171875*^9}},
 CellID->163299686],

Cell[CellGroupData[{

Cell["Payoffs", "Title",
 CellChangeTimes->{{3.43494703740625*^9, 3.43494703928125*^9}, 
   3.434951659765625*^9, 3.43503746765625*^9, {3.435308085953125*^9, 
   3.43530808640625*^9}, {3.43531829871875*^9, 3.435318332828125*^9}, {
   3.4353231705*^9, 3.435323174234375*^9}, {3.435323225703125*^9, 
   3.435323232984375*^9}, {3.435323275*^9, 3.435323275609375*^9}, {
   3.435323310703125*^9, 3.435323311484375*^9}, {3.435323371984375*^9, 
   3.43532337584375*^9}, {3.43537974459375*^9, 3.435379746796875*^9}, {
   3.435382106703125*^9, 3.43538211221875*^9}, {3.435382604578125*^9, 
   3.435382608546875*^9}},
 CellID->22638718],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "Payoffs", "]"}], ",", 
   RowBox[{
    RowBox[{"QLConstructor", "[", "#", "]"}], "&"}]}], "]"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->104966102],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "DoubleStickyRatchetPayoff", ",", "RatchetMaxPayoff", ",", 
   "RatchetMinPayoff", ",", "RatchetPayoff", ",", "StickyMaxPayoff", ",", 
   "StickyMinPayoff", ",", "StickyPayoff", ",", "StrikedTypePayoff"}], 
  "}"}]], "Output",
 CellLabel->"Out[7]=",
 CellID->204847835]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "Payoffs", "]"}], ",", 
   RowBox[{
    RowBox[{"QLMember", "[", "#", "]"}], "&"}]}], "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->315954608],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "PayoffDescription", ",", "PayoffName", ",", "PayoffOptionType", ",", 
   "PayoffStrike", ",", "PayoffThirdParameter", ",", "PayoffValue"}], 
  "}"}]], "Output",
 CellLabel->"Out[8]=",
 CellID->204432843]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
PayoffName, PayoffOptionType, PayoffStrike, PayoffThirdParameter\
\>", "Subsubsection",
 CellChangeTimes->{{3.427194427703125*^9, 3.427194438765625*^9}, {
  3.43538225059375*^9, 3.4353822546875*^9}, {3.435382758125*^9, 
  3.43538277353125*^9}},
 CellID->384465269],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"?", "PayoffDescription"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->43738917],

Cell[BoxData[
 StyleBox["\<\"PayoffDescription[ObjecctId_Symbol] returns the description \
(e.g. CashOrNothing, strike 32.2, cash payoff 2.5) for the given Payoff \
object.\\n      \\nObjectId: id of existing QuantLib::Payoff object\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3520926597-2470867",
 CellID->107862887]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PayoffName"}]], "Input",
 CellChangeTimes->{{3.435382653546875*^9, 3.43538265890625*^9}},
 CellID->73108283],

Cell[BoxData[
 StyleBox["\<\"PayoffName[ObjecctId_Symbol] returns the type (e.g. Vanilla, \
CashOrNothing, etc.) for the given Payoff object.       \\nObjectId: id of \
existing QuantLib::Payoff object\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.43538265946875*^9},
 CellTags->"Info3435386259-3736068",
 CellID->50460184]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PayoffOptionType"}]], "Input",
 CellChangeTimes->{{3.427173443890625*^9, 3.42717345140625*^9}, 
   3.435382715640625*^9},
 CellID->252149515],

Cell[BoxData[
 StyleBox["\<\"PayoffOptionType[ObjecctId_Symbol] returns the option-type \
(e.g. Call, Put) for the given Payoff object.       \\nObjectId: id of \
existing QuantLib::TypePayoff object\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.435382717203125*^9},
 CellTags->"Info3435386317-1593824",
 CellID->459569538]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PayoffStrike"}]], "Input",
 CellChangeTimes->{{3.4353827413125*^9, 3.435382745484375*^9}},
 CellID->759234498],

Cell[BoxData[
 StyleBox["\<\"PayoffStrike[ObjecctId_Symbol] returns the strike for the \
given Payoff object.       \\nObjectId: id of existing \
QuantLib::StrikedTypePayoff object\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.43538274615625*^9},
 CellTags->"Info3435386346-1862257",
 CellID->399277725]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PayoffThirdParameter"}]], "Input",
 CellChangeTimes->{{3.435382778265625*^9, 3.435382784765625*^9}},
 CellID->212576841],

Cell[BoxData[
 StyleBox["\<\"PayoffThirdParameter[ObjecctId_Symbol] returns the third \
parameter of a StrikedType payoff.       \\nObjectId: id of existing \
QuantLibAddin::StrikedTypePayoff object\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.4353827853125*^9},
 CellTags->"Info3435386385-4291768",
 CellID->854898637]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PayoffValue"}]], "Input",
 CellChangeTimes->{{3.435383122921875*^9, 3.435383126625*^9}},
 CellID->331647364],

Cell[BoxData[
 StyleBox["\<\"PayoffValue[ObjecctId_Symbol,Underlying_?NumberQ] returns the \
payoff value given an underlying reference level for the given Payoff object. \
      \\nObjectId: id of existing QuantLib::Payoff object\\nUnderlying: \
underlying reference level.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.435383127140625*^9},
 CellTags->"Info3435386727-8328394",
 CellID->151415985]
}, Open  ]],

Cell["Construct a simple strike paypoff", "Text",
 CellChangeTimes->{{3.43538349003125*^9, 3.435383509265625*^9}},
 CellID->155736813],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "StrikedTypePayoff"}]], "Input",
 CellChangeTimes->{{3.435383531203125*^9, 3.435383545921875*^9}},
 CellID->22595957],

Cell[BoxData[
 StyleBox["\<\"StrikedTypePayoff[ObjecctId_Symbol,PayoffID_Symbol,OptionType_\
String,Strike_?NumberQ] Construct an object of class StrikedTypePayoff and \
return its id       \\nObjectId: id of object to be created\\nPayoffID: \
payoff ID (e.g. Vanilla, PercentageStrike, AssetOrNothing, CashOrNothing, \
Gap, SuperShare).\\nOptionType: option type.\\nStrike: \
strike.\\nThirdParameter: the 3rd paramenter for the payoff definition of \
CashOrNothing (cash), Gap (determines the size of the payoff), SuperFund \
(second strike). Default value = 0.0.\\nPermanent: object \
permanent/nonpermanent\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.435383546375*^9},
 CellTags->"Info3435387146-8077027",
 CellID->34083894]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "StrikedTypePayoff", "]"}]], "Input",
 CellChangeTimes->{{3.4353835676875*^9, 3.435383576578125*^9}},
 CellLabel->"In[4]:=",
 CellID->158230386],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ThirdParameter", "\[Rule]", "0.`"}], ",", 
   RowBox[{"Permanent", "\[Rule]", "True"}], ",", 
   RowBox[{"Overwrite", "\[Rule]", "True"}]}], "}"}]], "Output",
 CellLabel->"Out[4]=",
 CellID->69699848]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"K", " ", "=", " ", "40."}], ";"}], "\n", 
 RowBox[{"payoff", " ", "=", 
  RowBox[{"StrikedTypePayoff", "[", 
   RowBox[{"\"\<Vanilla\>\"", ",", "\"\<Call\>\"", ",", "K"}], 
   "]"}]}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->392052021],

Cell[BoxData["StrikedTypePayoff65"], "Output",
 CellLabel->"Out[8]=",
 CellID->74703751]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PayoffDescription", "[", "payoff", "]"}]], "Input",
 CellChangeTimes->{{3.43538345409375*^9, 3.435383464875*^9}},
 CellLabel->"In[9]:=",
 CellID->206443933],

Cell[BoxData["\<\"Vanilla Call, 40 strike\"\>"], "Output",
 CellLabel->"Out[9]=",
 CellID->232820287]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PayoffName", "[", "payoff", "]"}]], "Input",
 CellChangeTimes->{{3.435382815875*^9, 3.43538282065625*^9}, {
  3.435382907234375*^9, 3.435382911546875*^9}},
 CellLabel->"In[10]:=",
 CellID->836430],

Cell[BoxData["\<\"Vanilla\"\>"], "Output",
 CellLabel->"Out[10]=",
 CellID->90063255]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PayoffOptionType", "[", "payoff", "]"}]], "Input",
 CellChangeTimes->{{3.435382815875*^9, 3.43538282065625*^9}, {
  3.435382907234375*^9, 3.435382911546875*^9}, {3.43538303871875*^9, 
  3.435383046453125*^9}},
 CellLabel->"In[11]:=",
 CellID->127929768],

Cell[BoxData["\<\"Call\"\>"], "Output",
 CellLabel->"Out[11]=",
 CellID->238005826]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PayoffStrike", "[", "payoff", "]"}]], "Input",
 CellChangeTimes->{{3.435383104328125*^9, 3.435383105375*^9}},
 CellLabel->"In[12]:=",
 CellID->558198674],

Cell[BoxData["40.`"], "Output",
 CellLabel->"Out[12]=",
 CellID->261133809]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PayoffThirdParameter", "[", "payoff", "]"}]], "Input",
 CellChangeTimes->{3.43538306328125*^9},
 CellLabel->"In[13]:=",
 CellID->770371745],

Cell[BoxData["0.`"], "Output",
 CellLabel->"Out[13]=",
 CellID->185561]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PayoffValue", "[", 
    RowBox[{"payoff", ",", "S"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", "30", ",", "80"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.435383113328125*^9, 3.43538315846875*^9}},
 CellLabel->"In[14]:=",
 CellID->27754211],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN1H801Xccx/GrG5UhsrUbhbRFicKlEr6v63tdPyI/vmw3s61EUZREWzeV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{30., 0},
  PlotRange->{{30, 80}, {0., 39.99999897959184}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellLabel->"Out[14]=",
 CellID->541882806]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RatchetPayoff, RatchetMaxPayoff, RatchetMinPayoff", "Subsection",
 CellChangeTimes->{{3.435383707171875*^9, 3.435383707640625*^9}},
 CellID->19050335],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"?", "RatchetPayoff"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->58158592],

Cell[BoxData[
 StyleBox["\<\"RatchetPayoff[ObjecctId_Symbol,Gearing1_?NumberQ,Gearing2_?\
NumberQ,Spread1_?NumberQ,Spread2_?NumberQ,InitialValue_?NumberQ,AccrualFactor_\
?NumberQ] Construct an object of class RatchetPayoff and return its id\\n     \
 \\nObjectId: id of object to be created\\nGearing1: gearing 1 (for strike \
1).\\nGearing2: gearing 2 (for strike 2).\\nSpread1: spread 1 (for strike 1).\
\\nSpread2: spread 2 (for strike 2).\\nInitialValue: initial value for strike \
(forward rate or coupon/accrualFactor).\\nAccrualFactor: accrual \
factor.\\nPermanent: object permanent/nonpermanent\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellTags->"Info3520926722-2470867",
 CellID->172926421]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "RatchetMaxPayoff"}]], "Input",
 CellChangeTimes->{{3.43538371540625*^9, 3.435383722921875*^9}},
 CellLabel->"In[4]:=",
 CellID->182229675],

Cell[BoxData[
 StyleBox["\<\"RatchetMaxPayoff[ObjecctId_Symbol,Gearing1_?NumberQ,Gearing2_?\
NumberQ,Gearing3_?NumberQ,Spread1_?NumberQ,Spread2_?NumberQ,Spread3_?NumberQ,\
InitialValue1_?NumberQ,InitialValue2_?NumberQ,AccrualFactor_?NumberQ] \
Construct an object of class RatchetMaxPayoff and return its id\\n      \
\\nObjectId: id of object to be created\\nGearing1: gearing 1 (for strike 1).\
\\nGearing2: gearing 2 (for strike 2).\\nGearing3: gearing 3 (for forward \
rate 3).\\nSpread1: spread 1 (for strike 1).\\nSpread2: spread 2 (for strike \
2).\\nSpread3: spread 3 (for forward rate 3).\\nInitialValue1: initial value \
for strike 1 (forward rate or coupon/accrualFactor).\\nInitialValue2: initial \
value for strike 2 (forward rate or coupon/accrualFactor).\\nAccrualFactor: \
accrual factor.\\nPermanent: object permanent/nonpermanent\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3520926729-2470867",
 CellID->50178438]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "RatchetMinPayoff"}]], "Input",
 CellChangeTimes->{{3.43538373615625*^9, 3.435383740953125*^9}},
 CellLabel->"In[5]:=",
 CellID->94957689],

Cell[BoxData[
 StyleBox["\<\"RatchetMinPayoff[ObjecctId_Symbol,Gearing1_?NumberQ,Gearing2_?\
NumberQ,Gearing3_?NumberQ,Spread1_?NumberQ,Spread2_?NumberQ,Spread3_?NumberQ,\
InitialValue1_?NumberQ,InitialValue2_?NumberQ,AccrualFactor_?NumberQ] \
Construct an object of class RatchetMinPayoff and return its id\\n      \
\\nObjectId: id of object to be created\\nGearing1: gearing 1 (for strike 1).\
\\nGearing2: gearing 2 (for strike 2).\\nGearing3: gearing 3 (for forward \
rate 3).\\nSpread1: spread 1 (for strike 1).\\nSpread2: spread 2 (for strike \
2).\\nSpread3: spread 3 (for forward rate 3).\\nInitialValue1: initial value \
for strike 1 (forward rate or coupon/accrualFactor).\\nInitialValue2: initial \
value for strike 2 (forward rate or coupon/accrualFactor).\\nAccrualFactor: \
accrual factor.\\nPermanent: object permanent/nonpermanent\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3520926730-2470867",
 CellID->361964558]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StickyMaxPayoff, StickyMinPayoff, StickyPayoff", "Subsection",
 CellChangeTimes->{3.4353837795625*^9},
 CellID->183240963],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"?", "StickyPayoff"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->246020155],

Cell[BoxData[
 StyleBox["\<\"StickyPayoff[ObjecctId_Symbol,Gearing1_?NumberQ,Gearing2_?\
NumberQ,Spread1_?NumberQ,Spread2_?NumberQ,InitialValue_?NumberQ,AccrualFactor_\
?NumberQ] Construct an object of class StickyPayoff and return its id\\n      \
\\nObjectId: id of object to be created\\nGearing1: gearing 1 (for strike 1).\
\\nGearing2: gearing 2 (for strike 2).\\nSpread1: spread 1 (for strike \
1).\\nSpread2: spread 2 (for strike 2).\\nInitialValue: initial value for \
strike (forward rate or coupon/accrualFactor).\\nAccrualFactor: accrual \
factor.\\nPermanent: object permanent/nonpermanent\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellTags->"Info3520926745-2470867",
 CellID->48343570]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "StickyMaxPayoff"}]], "Input",
 CellChangeTimes->{{3.435383804109375*^9, 3.435383804953125*^9}},
 CellID->398836986],

Cell[BoxData[
 StyleBox["\<\"StickyMaxPayoff[ObjecctId_Symbol,Gearing1_?NumberQ,Gearing2_?\
NumberQ,Gearing3_?NumberQ,Spread1_?NumberQ,Spread2_?NumberQ,Spread3_?NumberQ,\
InitialValue1_?NumberQ,InitialValue2_?NumberQ,AccrualFactor_?NumberQ] \
Construct an object of class StickyMaxPayoff and return its id       \
\\nObjectId: id of object to be created\\nGearing1: gearing 1 (for strike 1).\
\\nGearing2: gearing 2 (for strike 2).\\nGearing3: gearing 3 (for forward \
rate 3).\\nSpread1: spread 1 (for strike 1).\\nSpread2: spread 2 (for strike \
2).\\nSpread3: spread 3 (for forward rate 3).\\nInitialValue1: initial value \
for strike 1 (forward rate or coupon/accrualFactor).\\nInitialValue2: initial \
value for strike 2 (forward rate or coupon/accrualFactor).\\nAccrualFactor: \
accrual factor.\\nPermanent: object permanent/nonpermanent\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.43538380553125*^9},
 CellTags->"Info3435387405-6497012",
 CellID->445303033]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "StickyMinPayoff"}]], "Input",
 CellChangeTimes->{{3.435383804109375*^9, 3.435383810171875*^9}},
 CellID->270342900],

Cell[BoxData[
 StyleBox["\<\"StickyMinPayoff[ObjecctId_Symbol,Gearing1_?NumberQ,Gearing2_?\
NumberQ,Gearing3_?NumberQ,Spread1_?NumberQ,Spread2_?NumberQ,Spread3_?NumberQ,\
InitialValue1_?NumberQ,InitialValue2_?NumberQ,AccrualFactor_?NumberQ] \
Construct an object of class StickyMinPayoff and return its id       \
\\nObjectId: id of object to be created\\nGearing1: gearing 1 (for strike 1).\
\\nGearing2: gearing 2 (for strike 2).\\nGearing3: gearing 3 (for forward \
rate 3).\\nSpread1: spread 1 (for strike 1).\\nSpread2: spread 2 (for strike \
2).\\nSpread3: spread 3 (for forward rate 3).\\nInitialValue1: initial value \
for strike 1 (forward rate or coupon/accrualFactor).\\nInitialValue2: initial \
value for strike 2 (forward rate or coupon/accrualFactor).\\nAccrualFactor: \
accrual factor.\\nPermanent: object permanent/nonpermanent\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.435383810859375*^9},
 CellTags->"Info3435387410-5926976",
 CellID->83207899]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{984, 756},
WindowMargins->{{80, Automatic}, {21, Automatic}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
ShowSelection->True,
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3435386259-3736068"->{
  Cell[3488, 116, 336, 6, 56, "Print",
   CellTags->"Info3435386259-3736068",
   CellID->50460184]},
 "Info3435386317-1593824"->{
  Cell[4034, 133, 336, 6, 56, "Print",
   CellTags->"Info3435386317-1593824",
   CellID->459569538]},
 "Info3435386346-1862257"->{
  Cell[4549, 149, 316, 6, 56, "Print",
   CellTags->"Info3435386346-1862257",
   CellID->399277725]},
 "Info3435386385-4291768"->{
  Cell[5054, 165, 333, 6, 56, "Print",
   CellTags->"Info3435386385-4291768",
   CellID->854898637]},
 "Info3435386727-8328394"->{
  Cell[5564, 181, 411, 7, 71, "Print",
   CellTags->"Info3435386727-8328394",
   CellID->151415985]},
 "Info3435387146-8077027"->{
  Cell[6297, 202, 743, 12, 146, "Print",
   CellTags->"Info3435387146-8077027",
   CellID->34083894]},
 "Info3435387405-6497012"->{
  Cell[17049, 499, 982, 15, 221, "Print",
   CellTags->"Info3435387405-6497012",
   CellID->445303033]},
 "Info3435387410-5926976"->{
  Cell[18215, 524, 982, 15, 221, "Print",
   CellTags->"Info3435387410-5926976",
   CellID->83207899]},
 "Info3520926597-2470867"->{
  Cell[2981, 100, 330, 6, 71, "Print",
   CellTags->"Info3520926597-2470867",
   CellID->107862887]},
 "Info3520926722-2470867"->{
  Cell[12786, 399, 700, 11, 191, "Print",
   CellTags->"Info3520926722-2470867",
   CellID->172926421]},
 "Info3520926729-2470867"->{
  Cell[13693, 421, 944, 14, 236, "Print",
   CellTags->"Info3520926729-2470867",
   CellID->50178438]},
 "Info3520926730-2470867"->{
  Cell[14843, 446, 945, 14, 236, "Print",
   CellTags->"Info3520926730-2470867",
   CellID->361964558]},
 "Info3520926745-2470867"->{
  Cell[16168, 478, 697, 11, 191, "Print",
   CellTags->"Info3520926745-2470867",
   CellID->48343570]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3435386259-3736068", 20377, 577},
 {"Info3435386317-1593824", 20507, 581},
 {"Info3435386346-1862257", 20638, 585},
 {"Info3435386385-4291768", 20769, 589},
 {"Info3435386727-8328394", 20900, 593},
 {"Info3435387146-8077027", 21031, 597},
 {"Info3435387405-6497012", 21163, 601},
 {"Info3435387410-5926976", 21297, 605},
 {"Info3520926597-2470867", 21430, 609},
 {"Info3520926722-2470867", 21561, 613},
 {"Info3520926729-2470867", 21695, 617},
 {"Info3520926730-2470867", 21828, 621},
 {"Info3520926745-2470867", 21962, 625}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 114, 2, 23, "Subtitle",
 CellID->163299686],
Cell[CellGroupData[{
Cell[684, 26, 626, 10, 51, "Title",
 CellID->22638718],
Cell[CellGroupData[{
Cell[1335, 40, 305, 8, 47, "Input",
 CellID->104966102],
Cell[1643, 50, 311, 8, 54, "Output",
 CellID->204847835]
}, Open  ]],
Cell[CellGroupData[{
Cell[1991, 63, 223, 7, 28, "Input",
 CellID->315954608],
Cell[2217, 72, 246, 7, 36, "Output",
 CellID->204432843]
}, Open  ]],
Cell[CellGroupData[{
Cell[2500, 84, 274, 6, 30, "Subsubsection",
 CellID->384465269],
Cell[CellGroupData[{
Cell[2799, 94, 179, 4, 47, "Input",
 CellID->43738917],
Cell[2981, 100, 330, 6, 71, "Print",
 CellTags->"Info3520926597-2470867",
 CellID->107862887]
}, Open  ]],
Cell[CellGroupData[{
Cell[3348, 111, 137, 3, 28, "Input",
 CellID->73108283],
Cell[3488, 116, 336, 6, 56, "Print",
 CellTags->"Info3435386259-3736068",
 CellID->50460184]
}, Open  ]],
Cell[CellGroupData[{
Cell[3861, 127, 170, 4, 28, "Input",
 CellID->252149515],
Cell[4034, 133, 336, 6, 56, "Print",
 CellTags->"Info3435386317-1593824",
 CellID->459569538]
}, Open  ]],
Cell[CellGroupData[{
Cell[4407, 144, 139, 3, 28, "Input",
 CellID->759234498],
Cell[4549, 149, 316, 6, 56, "Print",
 CellTags->"Info3435386346-1862257",
 CellID->399277725]
}, Open  ]],
Cell[CellGroupData[{
Cell[4902, 160, 149, 3, 28, "Input",
 CellID->212576841],
Cell[5054, 165, 333, 6, 56, "Print",
 CellTags->"Info3435386385-4291768",
 CellID->854898637]
}, Open  ]],
Cell[CellGroupData[{
Cell[5424, 176, 137, 3, 28, "Input",
 CellID->331647364],
Cell[5564, 181, 411, 7, 71, "Print",
 CellTags->"Info3435386727-8328394",
 CellID->151415985]
}, Open  ]],
Cell[5990, 191, 134, 2, 30, "Text",
 CellID->155736813],
Cell[CellGroupData[{
Cell[6149, 197, 145, 3, 28, "Input",
 CellID->22595957],
Cell[6297, 202, 743, 12, 146, "Print",
 CellTags->"Info3435387146-8077027",
 CellID->34083894]
}, Open  ]],
Cell[CellGroupData[{
Cell[7077, 219, 183, 4, 28, "Input",
 CellID->158230386],
Cell[7263, 225, 252, 7, 36, "Output",
 CellID->69699848]
}, Open  ]],
Cell[CellGroupData[{
Cell[7552, 237, 274, 8, 47, "Input",
 CellID->392052021],
Cell[7829, 247, 88, 2, 36, "Output",
 CellID->74703751]
}, Open  ]],
Cell[CellGroupData[{
Cell[7954, 254, 180, 4, 28, "Input",
 CellID->206443933],
Cell[8137, 260, 101, 2, 36, "Output",
 CellID->232820287]
}, Open  ]],
Cell[CellGroupData[{
Cell[8275, 267, 220, 5, 28, "Input",
 CellID->836430],
Cell[8498, 274, 85, 2, 36, "Output",
 CellID->90063255]
}, Open  ]],
Cell[CellGroupData[{
Cell[8620, 281, 277, 6, 28, "Input",
 CellID->127929768],
Cell[8900, 289, 83, 2, 36, "Output",
 CellID->238005826]
}, Open  ]],
Cell[CellGroupData[{
Cell[9020, 296, 177, 4, 28, "Input",
 CellID->558198674],
Cell[9200, 302, 75, 2, 36, "Output",
 CellID->261133809]
}, Open  ]],
Cell[CellGroupData[{
Cell[9312, 309, 163, 4, 28, "Input",
 CellID->770371745],
Cell[9478, 315, 71, 2, 36, "Output",
 CellID->185561]
}, Open  ]],
Cell[CellGroupData[{
Cell[9586, 322, 318, 9, 28, "Input",
 CellID->27754211],
Cell[9907, 333, 2471, 48, 143, "Output",
 CellID->541882806]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12427, 387, 156, 2, 51, "Subsection",
 CellID->19050335],
Cell[CellGroupData[{
Cell[12608, 393, 175, 4, 47, "Input",
 CellID->58158592],
Cell[12786, 399, 700, 11, 191, "Print",
 CellTags->"Info3520926722-2470867",
 CellID->172926421]
}, Open  ]],
Cell[CellGroupData[{
Cell[13523, 415, 167, 4, 28, "Input",
 CellID->182229675],
Cell[13693, 421, 944, 14, 236, "Print",
 CellTags->"Info3520926729-2470867",
 CellID->50178438]
}, Open  ]],
Cell[CellGroupData[{
Cell[14674, 440, 166, 4, 28, "Input",
 CellID->94957689],
Cell[14843, 446, 945, 14, 236, "Print",
 CellTags->"Info3520926730-2470867",
 CellID->361964558]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15837, 466, 128, 2, 51, "Subsection",
 CellID->183240963],
Cell[CellGroupData[{
Cell[15990, 472, 175, 4, 47, "Input",
 CellID->246020155],
Cell[16168, 478, 697, 11, 191, "Print",
 CellTags->"Info3520926745-2470867",
 CellID->48343570]
}, Open  ]],
Cell[CellGroupData[{
Cell[16902, 494, 144, 3, 28, "Input",
 CellID->398836986],
Cell[17049, 499, 982, 15, 221, "Print",
 CellTags->"Info3435387405-6497012",
 CellID->445303033]
}, Open  ]],
Cell[CellGroupData[{
Cell[18068, 519, 144, 3, 28, "Input",
 CellID->270342900],
Cell[18215, 524, 982, 15, 221, "Print",
 CellTags->"Info3435387410-5926976",
 CellID->83207899]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
