(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      7064,        268]
NotebookOptionsPosition[      3847,        152]
NotebookOutlinePosition[      5726,        218]
CellTagsIndexPosition[      5501,        208]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Prices", "Chapter",
 CellTags->"Overview"],

Cell["Price utility functions.", "Text",
 CellTags->"Overview"],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview"],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[120]:="],

Cell["\<\
Within the Prices part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Select[Category[Prices],QLProcedure[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[121]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"MidEquivalent", ",", "MidSafe"}], "}"}]], "Output",
 CellChangeTimes->{3.563182023171875*^9},
 CellTags->"Overview",
 CellLabel->"Out[121]="]
}, Open  ]],

Cell["Constructors", "Section",
 CellTags->"Constructor"],

Cell["Member function", "Section",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["Procedures", "Section",
 CellTags->"Procedure"],

Cell[CellGroupData[{

Cell["MidEquivalent", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Bid", "0", 
     RowBox[{"bid", " ", 
      RowBox[{"price", "."}]}]},
    {"Ask", "0", 
     RowBox[{"ask", " ", 
      RowBox[{"price", "."}]}]},
    {"Last", "0", 
     RowBox[{"last", " ", 
      RowBox[{"price", "."}]}]},
    {"Close", "0", 
     RowBox[{"close", " ", 
      RowBox[{"price", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[CellGroupData[{

Cell["MidEquivalent[]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[122]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"QuantLibError", "::", "msg"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Error: \[NoBreak]\\!\\(\\\"\\\"\\)\[NoBreak] \[NoBreak]\\!\
\\(\\\"all input prices are invalid\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5631820308125*^9},
 CellTags->"Procedure",
 CellLabel->"During evaluation of In[122]:="],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{3.5631820308125*^9},
 CellTags->"Procedure",
 CellLabel->"Out[122]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "MidEquivalent"}]], "Input",
 CellChangeTimes->{{3.563182056859375*^9, 3.563182062671875*^9}},
 CellLabel->"In[123]:="],

Cell[BoxData[
 StyleBox["\<\"MidEquivalent[] returns the mid price if available, or a \
suitable substitute otherwise.\\n      \\nBid: bid price. Default value = \
0.\\nAsk: ask price. Default value = 0.\\nLast: last price. Default value = \
0.\\nClose: close price. Default value = 0.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.56318206375*^9},
 CellTags->"Info3563185663-2091669"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MidSafe", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Bid", "0", 
     RowBox[{"bid", " ", 
      RowBox[{"price", "."}]}]},
    {"Ask", "0", 
     RowBox[{"ask", " ", 
      RowBox[{"price", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell["MidSafe[]", "Input",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],

Cell["Enumeration Member", "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
},
WindowSize->{716, 867},
WindowMargins->{{Automatic, 196}, {-1, Automatic}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[579, 22, 48, 1, 99, "Chapter",
   CellTags->"Overview"],
  Cell[630, 25, 63, 1, 37, "Text",
   CellTags->"Overview"],
  Cell[696, 28, 94, 1, 53, "MathCaption",
   CellTags->"Overview"],
  Cell[793, 31, 85, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[881, 35, 134, 4, 37, "Text",
   CellTags->"Overview"],
  Cell[1040, 43, 105, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[1148, 47, 181, 5, 39, "Output",
   CellTags->"Overview"]},
 "Constructor"->{
  Cell[1344, 55, 57, 1, 77, "Section",
   CellTags->"Constructor"]},
 "Member"->{
  Cell[1404, 58, 55, 1, 51, "Section",
   CellTags->"Member"]},
 "Procedure"->{
  Cell[1484, 63, 53, 1, 51, "Section",
   CellTags->"Procedure"],
  Cell[1562, 68, 62, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[2107, 89, 81, 2, 41, "Input",
   CellTags->"Procedure"],
  Cell[2191, 93, 375, 9, 33, "Message",
   CellTags->"Procedure"],
  Cell[2569, 104, 123, 3, 39, "Output",
   CellTags->"Procedure"],
  Cell[3328, 130, 56, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[3685, 143, 50, 1, 41, "Input",
   CellTags->"Procedure"]},
 "Info3563185663-2091669"->{
  Cell[2879, 117, 400, 7, 138, "Print",
   CellTags->"Info3563185663-2091669"]},
 "EnumerationMember"->{
  Cell[3762, 148, 69, 1, 77, "Section",
   CellTags->"EnumerationMember"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 4166, 163},
 {"Constructor", 4631, 178},
 {"Member", 4713, 181},
 {"Procedure", 4793, 184},
 {"Info3563185663-2091669", 5297, 199},
 {"EnumerationMember", 5402, 202}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 48, 1, 99, "Chapter",
 CellTags->"Overview"],
Cell[630, 25, 63, 1, 37, "Text",
 CellTags->"Overview"],
Cell[696, 28, 94, 1, 53, "MathCaption",
 CellTags->"Overview"],
Cell[793, 31, 85, 2, 41, "Input",
 CellTags->"Overview"],
Cell[881, 35, 134, 4, 37, "Text",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[1040, 43, 105, 2, 41, "Input",
 CellTags->"Overview"],
Cell[1148, 47, 181, 5, 39, "Output",
 CellTags->"Overview"]
}, Open  ]],
Cell[1344, 55, 57, 1, 77, "Section",
 CellTags->"Constructor"],
Cell[1404, 58, 55, 1, 51, "Section",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[1484, 63, 53, 1, 51, "Section",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[1562, 68, 62, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[1627, 71, 455, 14, 117, "Text"],
Cell[CellGroupData[{
Cell[2107, 89, 81, 2, 41, "Input",
 CellTags->"Procedure"],
Cell[2191, 93, 375, 9, 33, "Message",
 CellTags->"Procedure"],
Cell[2569, 104, 123, 3, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2729, 112, 147, 3, 27, "Input"],
Cell[2879, 117, 400, 7, 138, "Print",
 CellTags->"Info3563185663-2091669"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3328, 130, 56, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[3387, 133, 295, 8, 80, "Text"],
Cell[3685, 143, 50, 1, 41, "Input",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[3762, 148, 69, 1, 77, "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
