(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    348121,       7473]
NotebookOptionsPosition[    316341,       6430]
NotebookOutlinePosition[    330062,       6835]
CellTagsIndexPosition[    329900,       6827]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["PricingEngines", "Chapter",
 CellTags->"Overview"],

Cell["functions to construct and use PricingEngine objects.", "Text",
 CellTags->"Overview"],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"Setting default values:\"\>"], "Print",
 CellChangeTimes->{3.520943075765625*^9},
 CellTags->"Overview",
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Setting Valuation Date = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2011", ",", "7", ",", "29"}], "}"}]}],
  SequenceForm["  Setting Valuation Date = ", {2011, 7, 29}],
  Editable->False]], "Print",
 CellChangeTimes->{3.520943075765625*^9},
 CellTags->"Overview",
 CellLabel->"During evaluation of In[1]:="]
}, Open  ]],

Cell["\<\
Within the PricingEngines part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Select[Category[PricingEngines],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AnalyticCapFloorEngine", ",", "BinomialPricingEngine", ",", 
   "BlackCalculator", ",", "BlackCalculator2", ",", "BlackCapFloorEngine", 
   ",", "BlackCapFloorEngine2", ",", "BlackScholesCalculator", ",", 
   "BlackScholesCalculator2", ",", "BlackSwaptionEngine", ",", 
   "BlackSwaptionEngine2", ",", "BondEngine", ",", "DiscountingSwapEngine", 
   ",", "PricingEngine"}], "}"}]], "Output",
 CellChangeTimes->{3.440748934078125*^9, 3.440749619921875*^9, 3.520916296*^9,
   3.52091681321875*^9, 3.520942714171875*^9, 3.520943076828125*^9},
 CellTags->"Overview",
 CellLabel->"Out[2]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[PricingEngines],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "BlackCalculatorAlpha", ",", "BlackCalculatorBeta", ",", 
   "BlackCalculatorDelta", ",", "BlackCalculatorDeltaForward", ",", 
   "BlackCalculatorDividendRho", ",", "BlackCalculatorElasticity", ",", 
   "BlackCalculatorElasticityForward", ",", "BlackCalculatorGamma", ",", 
   "BlackCalculatorGammaForward", ",", "BlackCalculatorItmAssetProbability", 
   ",", "BlackCalculatorItmCashProbability", ",", "BlackCalculatorRho", ",", 
   "BlackCalculatorStrikeSensitivity", ",", "BlackCalculatorTheta", ",", 
   "BlackCalculatorThetaPerDay", ",", "BlackCalculatorValue", ",", 
   "BlackCalculatorVega", ",", "BlackScholesCalculatorDelta", ",", 
   "BlackScholesCalculatorElasticity", ",", "BlackScholesCalculatorGamma", 
   ",", "BlackScholesCalculatorTheta", ",", 
   "BlackScholesCalculatorThetaPerDay"}], "}"}]], "Output",
 CellChangeTimes->{3.440748935421875*^9, 3.440749621390625*^9, 
  3.520916297140625*^9, 3.520916813296875*^9, 3.52094271421875*^9, 
  3.52094307728125*^9},
 CellTags->"Overview",
 CellLabel->"Out[3]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[PricingEngines],QLProcedure[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "BachelierBlackFormula", ",", "BachelierBlackFormula2", ",", "BlackFormula",
    ",", "BlackFormula2", ",", "BlackFormulaCashItmProbability", ",", 
   "BlackFormulaCashItmProbability2", ",", "BlackFormulaImpliedStdDev", ",", 
   "BlackFormulaImpliedStdDev2", ",", 
   "BlackFormulaImpliedStdDevApproximation", ",", 
   "BlackFormulaImpliedStdDevApproximation2", ",", 
   "BlackFormulaStdDevDerivative", ",", "BlackFormulaStdDevDerivative2"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.440748936765625*^9, 3.440749622359375*^9, 
  3.52091629815625*^9, 3.52091681340625*^9, 3.520942714265625*^9, 
  3.520943077328125*^9},
 CellTags->"Overview",
 CellLabel->"Out[4]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor"],

Cell[CellGroupData[{

Cell["BlackCalculator", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PayoffID", 
     RowBox[{"payoff", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{{3.440749018234375*^9, 3.44074903671875*^9}, {
  3.52091631946875*^9, 3.52091632003125*^9}, {3.5209163735625*^9, 
  3.520916378515625*^9}, {3.5209165990625*^9, 3.520916599375*^9}, {
  3.520916895171875*^9, 3.5209168961875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[5]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obj", " ", "=", " ", 
  RowBox[{"BlackCalculator", "[", 
   RowBox[{
   "\"\<Call\>\"", ",", "Strike", ",", " ", "AtmForwardValue", ",", " ", 
    "StdDev"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.520916426890625*^9, 3.52091656078125*^9}, {
  3.5209169010625*^9, 3.52091690215625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[9]:="],

Cell[BoxData["BlackCalculator3"], "Output",
 CellChangeTimes->{
  3.520916475953125*^9, {3.520916515484375*^9, 3.520916561671875*^9}, 
   3.52091670409375*^9, 3.520916813453125*^9, 3.52091690496875*^9, 
   3.520942715421875*^9, 3.520943077390625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[9]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculator", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PayoffID", 
     RowBox[{"payoff", " ", 
      RowBox[{"ID", "."}]}]},
    {"Spot", 
     RowBox[{"spot", " ", 
      RowBox[{"value", "."}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Growth", "1.0", 
     RowBox[{"growth", " ", "discount", " ", 
      RowBox[{"factor", "."}]}]},
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Spot", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.440749656234375*^9, {3.52091691634375*^9, 3.52091692240625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[10]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obj", " ", "=", " ", 
  RowBox[{"BlackScholesCalculator", "[", 
   RowBox[{
   "\"\<Call\>\"", ",", "Strike", ",", " ", "Spot", ",", " ", "StdDev"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.52091692896875*^9, 3.520916953625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[13]:="],

Cell[BoxData["BlackScholesCalculator4"], "Output",
 CellChangeTimes->{3.440749660984375*^9, 3.520916813578125*^9, 
  3.52091695459375*^9, 3.520942715546875*^9, 3.5209430774375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[13]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PricingEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"EngineID", 
     RowBox[{"engine", " ", 
      RowBox[{"type", "."}]}]},
    {"ProcessID", 
     RowBox[{"GeneralizedBlackScholesProcess", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]", "=", "0.20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", " ", "=", "0.06"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", " ", "=", " ", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"settlementDate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1998", ",", "5", ",", "17"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EngineID", "=", "\"\<AE\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ProcessID", "=", 
   RowBox[{"GeneralizedBlackScholesProcess", "[", 
    RowBox[{
     RowBox[{"BlackConstantVol", "[", 
      RowBox[{"settlementDate", ",", "StdDev"}], "]"}], ",", "Spot", ",", 
     RowBox[{"{", 
      RowBox[{"1998", ",", "5", ",", "17"}], "}"}], ",", "r", ",", "q", ",", 
     RowBox[{"DayCounter", "\[Rule]", "\"\<Actual/Actual\>\""}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.440749690515625*^9, 3.4407497749375*^9}, {
  3.440749809078125*^9, 3.440749839015625*^9}, {3.4407499748125*^9, 
  3.440750006578125*^9}, {3.44075124109375*^9, 3.440751242390625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[14]:="],

Cell[CellGroupData[{

Cell["obj=PricingEngine[\"AE\",ProcessID]", "Input",
 CellChangeTimes->{3.440751226640625*^9},
 CellTags->"Constructor",
 CellLabel->"In[20]:="],

Cell[BoxData["PricingEngine7"], "Output",
 CellChangeTimes->{3.440749843703125*^9, 3.440750010484375*^9, 
  3.440751228109375*^9, 3.520916813921875*^9, 3.520942716125*^9, 
  3.520943077515625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[20]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiscountingSwapEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{
     "discounting", " ", "yield", " ", "term", " ", "structure", " ", 
      "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", ".04", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.520916972171875*^9, 3.520917021984375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell["obj=DiscountingSwapEngine[YieldCurve]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[23]:="],

Cell[BoxData["DiscountingSwapEngine9"], "Output",
 CellChangeTimes->{
  3.5209168141875*^9, {3.52091699059375*^9, 3.5209170233125*^9}, 
   3.52094271634375*^9, 3.5209430775625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[23]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BinomialPricingEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"EngineID", 
     RowBox[{"engine", " ", 
      RowBox[{"type", "."}]}]},
    {"ProcessID", 
     RowBox[{"GeneralizedBlackScholesProcess", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"TimeSteps", 
     RowBox[{
      RowBox[{"#", "/", "time"}], " ", 
      RowBox[{"steps", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EngineID", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ProcessID", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TimeSteps", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[24]:="],

Cell[CellGroupData[{

Cell["obj=BinomialPricingEngine[EngineID,ProcessID,TimeSteps]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[27]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"QuantLib", "::", "arg"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\\"BinomialPricingEngine\\\"\\)\[NoBreak] \
called with invalid arguments.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.52091681421875*^9, 3.520942716609375*^9, 
  3.5209430776875*^9},
 CellTags->"Constructor",
 CellLabel->"During evaluation of In[27]:="],

Cell[BoxData[
 RowBox[{"BinomialPricingEngine", "[", 
  RowBox[{"exampleValue", ",", "exampleValue", ",", "exampleValue"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.52091681421875*^9, 3.520942716625*^9, 
  3.520943077703125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[27]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackSwaptionEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{
     "discounting", " ", "yield", " ", "term", " ", "structure", " ", 
      "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"VolTS", 
     RowBox[{"SwaptionVolatilityStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", ".04", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"VolTS", "=", 
   RowBox[{"ConstantSwaptionVolatility", "[", "0.15", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.520917057046875*^9, 3.520917115484375*^9}, 
   3.520917187734375*^9},
 CellTags->"Constructor",
 CellLabel->"In[28]:="],

Cell[CellGroupData[{

Cell["obj=BlackSwaptionEngine[YieldCurve,VolTS]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[30]:="],

Cell[BoxData["BlackSwaptionEngine12"], "Output",
 CellChangeTimes->{3.520916814265625*^9, 3.520917190609375*^9, 
  3.5209427169375*^9, 3.520943077765625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[30]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackSwaptionEngine2", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{
     "discounting", " ", "yield", " ", "term", " ", "structure", " ", 
      "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Vol", 
     RowBox[{
      RowBox[{"cap", "/", "floor"}], " ", "term", " ", 
      RowBox[{"volatility", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", ".04", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Vol", "=", "0.15"}], ";"}]}], "Input",
 CellChangeTimes->{{3.520917203578125*^9, 3.520917214765625*^9}, {
  3.520917291171875*^9, 3.520917292453125*^9}},
 CellTags->"Constructor",
 CellLabel->"In[31]:="],

Cell[CellGroupData[{

Cell["obj=BlackSwaptionEngine2[YieldCurve,Vol]", "Input",
 CellChangeTimes->{{3.520917280515625*^9, 3.5209172968125*^9}},
 CellTags->"Constructor",
 CellLabel->"In[33]:="],

Cell[BoxData["BlackSwaptionEngine214"], "Output",
 CellChangeTimes->{
  3.520916814328125*^9, 3.5209172168125*^9, {3.520917282875*^9, 
   3.520917301359375*^9}, 3.520942717*^9, 3.520943077828125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[33]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCapFloorEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"VolTS", 
     RowBox[{"OptionletVolatilityStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", ".04", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"VolTS", "=", " ", 
   RowBox[{"ConstantOptionletVolatility", "[", "0.15", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{3.5209173101875*^9, 3.520917341546875*^9},
 CellTags->"Constructor",
 CellLabel->"In[34]:="],

Cell[CellGroupData[{

Cell["obj=BlackCapFloorEngine[YieldCurve,VolTS]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[36]:="],

Cell[BoxData["BlackCapFloorEngine17"], "Output",
 CellChangeTimes->{3.520916814359375*^9, 3.5209173451875*^9, 
  3.52094271715625*^9, 3.52094307803125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[36]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCapFloorEngine2", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Vol", 
     RowBox[{"Term", " ", 
      RowBox[{"(", 
       RowBox[{"i", ".", "e", ".", " ", "flat"}], ")"}], " ", 
      RowBox[{"volatility", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", ".04", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Vol", "=", "0.15"}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091735528125*^9, 3.520917363375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell["obj=BlackCapFloorEngine2[YieldCurve,Vol]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[39]:="],

Cell[BoxData["BlackCapFloorEngine219"], "Output",
 CellChangeTimes->{3.52091681440625*^9, 3.520917365296875*^9, 
  3.52094271721875*^9, 3.520943078078125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[39]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AnalyticCapFloorEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"HandleModel", 
     RowBox[{"affine", " ", "model", " ", 
      RowBox[{"(", 
       RowBox[{
       "providing", " ", "a", " ", "discount", " ", "bond", " ", "option", 
        " ", "pricing", " ", "formula"}], ")"}], " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", "0.4", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Kappa]", "=", "0.03"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HandleModel", "=", 
   RowBox[{"HullWhite", "[", 
    RowBox[{"YieldCurve", ",", "\[Kappa]", ",", "\[Sigma]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.520917430390625*^9, 3.520917472515625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[40]:="],

Cell[CellGroupData[{

Cell["obj=AnalyticCapFloorEngine[HandleModel]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[44]:="],

Cell[BoxData["AnalyticCapFloorEngine22"], "Output",
 CellChangeTimes->{
  3.52091681446875*^9, {3.520917446609375*^9, 3.520917474171875*^9}, 
   3.520942717421875*^9, 3.520943078140625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[44]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BondEngine", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{
     "discounting", " ", "yield", " ", "term", " ", "structure", " ", 
      "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", "0.4", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.520917483265625*^9},
 CellTags->"Constructor",
 CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell["obj=BondEngine[YieldCurve]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[46]:="],

Cell[BoxData["BondEngine24"], "Output",
 CellChangeTimes->{3.5209168145*^9, 3.52091748878125*^9, 3.5209427175*^9, 
  3.520943078203125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[46]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["BlackCalculatorValue", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{
    "\"\<Call\>\"", ",", " ", "Strike", ",", " ", "\n", "   ", 
     "AtmForwardValue", ",", " ", "StdDev"}], "]"}]}], ";"}], "\n", 
 RowBox[{"BlackCalculatorValue", "[", "obj", "]"}]}], "Input",
 CellChangeTimes->{{3.520917519296875*^9, 3.52091757696875*^9}},
 CellTags->"Member",
 CellLabel->"In[47]:="],

Cell[BoxData["7.965567455405804`"], "Output",
 CellChangeTimes->{
  3.52091681453125*^9, 3.520917495015625*^9, {3.520917558765625*^9, 
   3.52091757859375*^9}, 3.5209427175625*^9, 3.52094307828125*^9},
 CellTags->"Member",
 CellLabel->"Out[51]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorDeltaForward", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AtmForwardValue", " ", "=", " ", "100."}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"StdDev", " ", "=", " ", "0.2"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"obj", " ", "=", " ", 
    RowBox[{"BlackCalculator", "[", 
     RowBox[{
     "\"\<Call\>\"", ",", " ", "Strike", ",", " ", "\n", "    ", 
      "AtmForwardValue", ",", " ", "StdDev"}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{"BlackCalculatorDeltaForward", "[", "obj", "]"}]}], "Input",
 CellChangeTimes->{{3.520917590390625*^9, 3.520917612171875*^9}},
 CellTags->"Member",
 CellLabel->"In[52]:="],

Cell[BoxData["0.5398278372770291`"], "Output",
 CellChangeTimes->{
  3.5209168145625*^9, {3.5209175918125*^9, 3.52091761346875*^9}, 
   3.520942717609375*^9, 3.520943078328125*^9},
 CellTags->"Member",
 CellLabel->"Out[56]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorDelta", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Spot", 
     RowBox[{"spot", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{
    "\"\<Call\>\"", ",", " ", "Strike", ",", " ", "\n", "   ", 
     "AtmForwardValue", ",", " ", "StdDev"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091762071875*^9, 3.52091763353125*^9}, {
  3.520917802171875*^9, 3.52091780284375*^9}},
 CellTags->"Member",
 CellLabel->"In[57]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"BlackCalculatorDelta", "[", 
    RowBox[{"obj", ",", "Spot"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Spot", ",", "80", ",", "120"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.52091777884375*^9, 3.520917797625*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj30w1AkYxzeZbXPSZiqU8nLU6s6diOlUnidXEqG0y67dHycUEhN6oa1z
1+T2nCba7bY655yI641oEtKQErfLobzEz9p35S4vKadtcb/745nvfOb7nXnm
43AgJTTOhEajBVH3fzpkJy2k0dgovJG+s1eqA3p0nUkbxVgxHTj7sw7+2cIw
ubiAjcYzWTFOFD+YvEZzWsjGzsxrT1MlOthLDM7uorOR3TPGYebr4MymgJkL
5mwU/DFYEpyjg0H1+jd2NmyUyx3H+oQ6uASaXnBnY2yVZaPtAR08WpdcXRvP
RtYXxFeLXXRg+LEjVvoLGxnWVw91vNPChhCbsmPtbCxY1dqd/1gLS31Pvj2/
kIMl5qpO+/NaWHT3lqWZFwdp8foaL4EW7gW939KYxEHTK+pzm1la4OxhTR8v
5iDLapfm82kNLH7mdi7/BQf9ZawQQasGUlOC1ujNwrCAUXz3ilQDY2LIKdwW
hlkRR777O1EDkatsReEpYXgyUpyiBg2c7TC/EFAahrZJFoV0Sw3Uz3Un/t4X
hjvaBurnR9RQLrgd4m4RjnvFbU+xXg0i29SnzV+H4/J5aZpdnhqEXHNm7bFw
5CY610rj1eD8uC7m1c1wZDU9P5ruowZVmU/uKUU4ms5NZsqt1BBa39vgv4KL
knPbmorGVHDfjZe1MpCL1g9bil+3qMDV8a6V/2kuFtmKGJnFKuBtX/OgupqL
y5Mf+hWdUsFlMtL1rJ6Lbg2u4qlwFche5njst+ahycRvadmeKqg2lfkSwTw0
z7jf2sJUwZ2bynWyLB6+2LCEyRhXQmSW2fK0Gh4aFuQ3mMmUYFKz9uLqNzzs
PEH33l2uhNoEhm69XQTqT+6jR4mU4BxA357MiUC1y5KJwINKKLn+8qi1KAJN
l5kqDH5KsIqTejTXRuCEacV4HUsJsC9hrmyc2juD20GGEjJrmYUTDnxkjuTz
onqGITFE7pfG5eMeix9SRi8Nw5Fo4gnvJz4++HLAPpc/DDE9/d3YwEdjQdId
x0+HweJE/Gj0FB+LfKfbe/QKkEvae/XOAhTNR1ZGVSgAlH7yUoEAhb6SRqd0
BVw/fyM07qIAC8anPw54K8C+RnNb9ESAD4n+rZ/RFRBisdFSbxBgZUrV8f72
IchX7Q8scyWwkp8kpV0dgmcro1ckRBHIzY3JHTw0BFUZ37+KvURg1onULnf3
IajkZuQ9eUb14gFWJ20IPJtczpS2EtjatNf+/TwJdS4Dh7PbCMwdrHJaRXGz
wXuXv4zAWB8vduwsCb0FxllZB4GdLTbBHz6QYFR+e/h5D4Hy0+xbzlMk+Cdk
+6k1VJ9QYibSkdDe5bWpWUtguSjm1ztaEkK9RxxKdAR+A6NbezQk8D/xn40b
IdB8anexo5qE5NuL770eJZA54U5/pCBBMpnrMDlJ4FZpxcZ/+0iwidi2tPst
5RMUnbeW4sLHb4xVUwTSSls/7uwloUwc3J/+nsDLj6pnJC8oH0/mhZkZAhls
MsejiwSfwkbhyw/UP9nqEH4n5Uc/mlhnIDDv3SL7s3+RIO/r2ik0Erh5VDXS
3U7CPvzeg5glcIewXWGQU/7l7g4+cwRK9kSrHSmOWKaxsJsnMMmn4G2AjITh
DLFxnmL0PL007U8S/gPPflzu
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{80., 0.45},
  PlotRange->{{80, 120}, {0.4498565341244394, 0.6747847897107273}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5209177816875*^9, 3.5209178041875*^9}, 
   3.520942718171875*^9, 3.52094307853125*^9},
 CellLabel->"Out[61]=",
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorElasticityForward", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spot", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{
    "\"\<Call\>\"", ",", " ", "Strike", ",", " ", "\n", "   ", 
     "AtmForwardValue", ",", " ", "StdDev"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[62]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorElasticityForward[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[67]:="],

Cell[BoxData["6.777016707211196`"], "Output",
 CellChangeTimes->{3.520916814625*^9, 3.520917666453125*^9, 
  3.52091782971875*^9, 3.52094271828125*^9, 3.52094307859375*^9},
 CellTags->"Member",
 CellLabel->"Out[67]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorElasticity", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Spot", 
     RowBox[{"spot", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spot", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{
    "\"\<Call\>\"", ",", " ", "Strike", ",", " ", "\n", "   ", 
     "AtmForwardValue", ",", " ", "StdDev"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.520917679453125*^9},
 CellTags->"Member",
 CellLabel->"In[68]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorElasticity[obj,80]", "Input",
 CellChangeTimes->{{3.520917736515625*^9, 3.5209177369375*^9}},
 CellTags->"Member",
 CellLabel->"In[73]:="],

Cell[BoxData["6.777016707211194`"], "Output",
 CellChangeTimes->{3.520916814671875*^9, 3.5209176820625*^9, 
  3.52091773765625*^9, 3.52094271834375*^9, 3.520943078640625*^9},
 CellTags->"Member",
 CellLabel->"Out[73]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorGammaForward", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Strike", " ", "=", " ", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{
    "\"\<Call\>\"", ",", " ", "Strike", ",", " ", "\n", "   ", 
     "AtmForwardValue", ",", " ", "StdDev"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091785575*^9, 3.520917870484375*^9}, {
  3.520917918890625*^9, 3.520917933859375*^9}},
 CellTags->"Member",
 CellLabel->"In[74]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BlackCalculatorGammaForward", "[", "obj", "]"}]], "Input",
 CellChangeTimes->{{3.52091789653125*^9, 3.520917898796875*^9}},
 CellLabel->"In[78]:="],

Cell[BoxData["0.019847627373850592`"], "Output",
 CellChangeTimes->{3.520917899390625*^9, 3.520917936140625*^9, 
  3.52094271840625*^9, 3.5209430786875*^9},
 CellLabel->"Out[78]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorGamma", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Spot", 
     RowBox[{"spot", " ", 
      RowBox[{"value", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{"\"\<Call\>\"", ",", " ", "100.", ",", "100.", ",", "0.2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.520917939140625*^9, 3.520917970078125*^9}, {
  3.52091802209375*^9, 3.520918025625*^9}},
 CellTags->"Member",
 CellLabel->"In[79]:="],

Cell[CellGroupData[{

Cell["Plot[BlackCalculatorGamma[obj,Spot],{Spot,80,120}]", "Input",
 CellChangeTimes->{{3.52091798825*^9, 3.52091799584375*^9}},
 CellTags->"Member",
 CellLabel->"In[80]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj30w1AkcxhcdilBTUSfai0THlVIN8f16KTuJDbvsrv25IxpUdlK6SNJe
adVP1tq1eduNQncobxGLS4jOS2Pzkl7u1J6tFHeoRgbd3h/PPPPM549nPtRw
XkCkNoVC8dXk/6amHtWhUBh4pjb7UnarHHTDGrUfaXbM9K1ws9/l8MFFX1uk
xUBF7nNBbpMc7k3doFjpMNBI50SdvF4OB4nnC966DDS7vkFSUSGH5B37ZzMM
GSjScwwazpHD89c2E5ZrGeh1+6wkPE4OElANgSMDl3wp5TOt5NCyKbamIYqB
PC9Z70yyDObS+iKkeQy0ckqYor4rADv62tL4Xs3f5GHvw5wCMPY4PZ2uw0SJ
VuoX/fZ80KsqX7lsJxMd301FNbvkQ63vJ5f7R5lo7py4y7M8D5gHNn8+VcRE
ZWOv/MLGPFjaufVi5gATd4/OnUspzYU4nu969bIgXLH5BbvZKhcms+CyzDUI
zY2seXq3cyB0nbkgmBeE7meViVV7cuCXPsOM/cVBuKesq1Or4xooFpUxhcNB
uJt+qtOXdQ1ucSvojkbBeLBS63HOmBQE5nEdbZ7BSKnqohuelkISy9CkIT4Y
z9V9RP4qKVg/aDz0tiwYP0/xi/3LsuFVqRt55s9gPD0d3l7ikw0BiqFm2moW
mqpCU4vUEqjbyk5Z48PCJF73AYNUCdh/V2VKO8vC+/aqfjsHCbDd19+rqWHh
Rb/acrd+MVx7EWr/i5qFTeaWnteTxNA9cnl7oBkbSzpM3PK3iKFmSbcH4cfG
0J8Kdz0ZzILbZaObulPYmHixYNedS1kQmrJs1Yl6NgpNOVIdpyzQrrcQfTvB
Rv6E7cuBMRE0ROuP2VhysKnabnllgQis9+u6xzI56KC0kHj4i+BmychxMwEH
PxXZbhIaiMA0Urq9rYGDk+qnx5u6MgH8oxdL/+Fg3V2z+JHzmZDYYCL7lxqC
FIVCsM09E2LoPftOsEKQYTBaUTYvhGNhRDv7SghGvwxLWd8ihEODT5XYHIK1
hfXcNXwhGP0cNR42E4InI9L7D3kIoUfcO6S25qKxUmDloi8EGN3XU8zl4sBd
2kMrSQaUpP8WECni4qKNd1WrRQZsqFdVCNq5aLLbmlFSfRXoRttWque42NZr
c2cMrkLmq0CfUnsCiyJ4lUuG06FzTdjq6B8JNHFo4bvHpUN1Av9thITAC1Qj
m+/10qGSlSBs7yTQJbY8zqeYBKdW2+TiLgLF39D6cm+Q0Gj77EjqIwLvvt9y
cLyQhLY5Z29at4aLGx+myUgYyp9f6O4j8IpxfPIfUhLmR88deTJIoOJq7KrA
yyTQolP3vVYR+CxttSKFR0Jv/84dbX8TOD6iNzxwjIQA5zfUm2ME7nStMbM9
SkKIAW0h8g2BFvyNy5VRJMRWLK19N06gx9LJButwEsRTJHVqisABuq/lAIOE
tRxXY+U0gd47WsR2gSTIHkzMV88QGJ1W+MN5fxJKs/yenvxEYOtMxaCDn8bH
ySRjdpbAXyfDX1/xJsFNdj9p5AuBlokf+Kq9Gj/d4zGNcwTOhnfQXLxI6Bnu
35s0T2DM40Cv90iCP/K3EwsEqiWURE/Q+N9ypLotEhryfiDPlQTOCpWR5VcC
I3jGzI8uJPyVkDX/VbPXPYqaO+BMwn+G/Tk/
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{80., 0.014},
  PlotRange->{{80, 120}, {0.013783074752698844`, 0.031011917138745276`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.520916814734375*^9, 3.52091799634375*^9, 
  3.5209427185625*^9, 3.52094307884375*^9},
 CellTags->"Member",
 CellLabel->"Out[80]=",
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorTheta", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Spot", 
     RowBox[{"spot", " ", 
      RowBox[{"value", "."}]}]},
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spot", "=", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{"\"\<Call\>\"", ",", " ", "100.", ",", "100.", ",", "0.2"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5209180316875*^9, 3.520918032171875*^9}, {
  3.520918151515625*^9, 3.520918159234375*^9}},
 CellTags->"Member",
 CellLabel->"In[81]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BlackCalculatorTheta", "[", 
  RowBox[{"obj", ",", "Spot", ",", "TimeToMaturity"}], "]"}]], "Input",
 CellChangeTimes->{{3.520918147296875*^9, 3.5209181473125*^9}},
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{"-", "1.6539689478208832`"}]], "Output",
 CellChangeTimes->{3.520918160796875*^9, 3.520942718640625*^9, 
  3.520943078984375*^9},
 CellLabel->"Out[84]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot3D[BlackCalculatorTheta[obj,Spot,TimeToMaturity],{Spot,80,120},{\
TimeToMaturity,1,10},PlotRange->All]\
\>", "Input",
 CellChangeTimes->{{3.520918037484375*^9, 3.52091810725*^9}},
 CellTags->"Member",
 CellLabel->"In[85]:="],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nXk4VV3Y8I95liFDSc5Bs0qzxrM1SRNJiGYJRXMqkrEJJZIGQyUNkjRI
hnROQiGVRHKUeZ7nmfd5n9Z97/c53/U9/zzX9bvWtaz92+vce+97rXXH2nPI
xEaQwWC0izAYQv/8/1j+gBSDYUqd+HL1KYPRyi6/Z/upXUiX+81x8CQvnuad
40TOM5bpcKeLDlXEO25BvnPmqfyhoMlcn/Aho0BtM+TnBLo2vZacwK2ZP5zs
yKN5xoG79nPCWNyVX4cnGQaaI8/MczO3uT6Oe8925Jq2oQXyN37L/HS0lLnD
I//7H80nZXUtvv5+FNfqJsOBF78V+VznJxVjbwhxE3QFCuMdLZF/P2249rdY
C0cpU2BloLYVcuuySYnKin/YR3cLPnfk0fzeiR+G6zuH2F/7BMcZBm5DXqA8
3mNOnQSlEyh0UdtwO3IjmzTNAEMF6vJU4c6REZoLOrlH3XdVocCzWv/siRMM
+9li6ycuWOamhZ6BP6xRXF2iy0LPwO9zn6pKNKmjZ+AHf2cUJ4eNQc/AGxfu
f+p0RAk9A9+5odRLfp88egbuliT9YFqHJHoGbiOn6HrEVAg9A5/Ur/zH4lcP
BzwDTxGWfG5TUY6ega93OrTMduN39Ax84LHi0qjF7egZeETXh7lzfUfY4Bn4
/KC53etXiKJn4EqLks06b0qj59LA+q/ahoIUI+f8szrRcegZuN4MDx39eFX0
DHzjmdVJOzyV0DNwu2eLdXfaK6Bn4LNe2P0emyeLnoEfCRTalygogZ6Bq8Sb
+3zcIYSegRsbue+xzhzggGfgOS5GonrabegZeHOQ6f7yiTz0DLxSTutBnHEW
egZesr7d88O8evQMXLxTOVHmaTd6Br5vgsKJnQwGegYeuyrxc8tlYfT86nGy
9BtHMWr/UZvnzSVK6Bm4lqTsnauGiugZuG1+2dNHmXLoGfhqETvPEynS6Bn4
JKXxu+tkxdEz8NfTLtxlnxNCz8APfVr9+eKSYQ54Bn6KOZxeF9uFnoF7VvXM
qnlfj56BD1x+lzB6Vj56Bn5Ay5JbfykNPQOvfrjpTsXxSvQMXMX5qNHwizb0
DHy6eM1zs/5eNngGfrJTJa5UkoGez7/zMzQMlKZOLwgvbmuRR8/APSQbrELu
jULPwCvMhi9PuiiFnoHbvt5Yoh4ghp6By5ZoZW9MEkLPwFnujJPvBBjoGbhN
mZfM0uxe9Aw86lRkdMCnNvQMfLoBN6mhtQo9A89b0isVsCsXPQPvMV435PqT
i56Bt//O+s7OKEXPwF+c3nxOV6QJPQNfc+fRPSuXTvQMXK5R/r6BUT8bPOvU
z/jgyJOjRDTrxnftk0XPwCWa/gjs/iKJnoGvuCI2R2iLGHoG7uaUevNrrxB6
Bv78joB44xsGegbePz59iSlrgAOegaeMCZEVFupCz8CFCwqk9bSb0TPwKX9u
UmNvlqNn4CPmFgFtx3LQM/Awm0uzw3zfomfg+qxN/tYHi9Ez8IdPnB0bb9Si
Z+BxZavHnLdqQ8/Ax1sNrv+9rhs9K5+4URbvqEi9z1GhindJomfguxd0uWks
F0PPwKWZb7xOLhNGz8ALqpz91U0F0DNwh/f6xxsFhzjgGbjPZ/uZqj496Bm4
VJTXTuXF7egZ+O2CTYc7J9ajZ+AWspk5ypql6Bm4v9XANcErmegZ+I9xeqMP
piWgZ+AL3Y88VoguRM/AU9Smp943q0LPwNtkV0/5Pr4ZPQMfubbguL1FB3pm
/PufMqXouvvJ1XVi6Bl4k2VE1kwfYfQMfOJz+W2JpQLoGXnCh8AFIcMc8Aw8
fsUBt5/hfegZeI7w+rZ3mZ3oGXh3Y9Lh62Na0TNwTbMsD0fVGvQMfMjtZ/ur
s8XoGXhS1SSFbQEZ6Bm4c77QSvOS1+gZeIyu8PX2T/noGbiYwQFqYmE5ega+
aFWy3ZVb9egZuE/xoLC/Uht6rvexG28YqEqNYX4KO8UTRs/Al/4u2lRnLYie
gddfiHj34Z+4Cp6BsytEoinbAfSM7fvvBh5r7UbPwMeWK8XkhrajZ+AHzU1f
ef5oRM/AfSv2O8XGVKJn4HKnhrI2eP1Cz9h///qb3Llp6Bm45zJKYvv1V+gZ
OGtr3hpjjzz0DDwu1Kt1XUkpegYukjMzuulbDXoGHmy59UXCjWb0/EMpd0mg
thrFuHDF9m6ZIHoGHi59Q6X6AQM9A18cZ7Ft3MAgBzwD15LI2frwSy96Bv7Y
SVxXPa0TPSNPKjPc/6sVPQMvShFq2DCmHj0Dd8kZeDo9oRw9AxeOmebhp/oT
PQP/czKL+2ptKnoGvlRhY7Z90gv0DPz8o1sbVjzORc/AraRc18zx+4OegbfK
vWJu9q9Cz8Cf+isUp71oQM/v7i604sWrUw5O4iOmbAH0DPxKNGfDlP3DHPAM
PFpfwkfhdD96Bv5o/rCUYlQ3egauJjyUJ9fbjp6Bz2n6qWHwqRk9A7+lvtBC
/WcNegZ+4niF+6kxZegZ+DmfSd/LVfPRM/D9ySHVJ19z0TNwO52qs09mPUfP
wE+9zRurzPqGnoEXzd6ReayGh56B+49K+PP8RQV6Bv47JHjh4vV1fPOZSZ1T
DV1qxhnh/Hc+MynXCVLGosMDnP/OZybF3HNu2cbtvXzzmUlN9njxTpLXyTef
mVRP5p4n60+08c1nJlUWrDb5gWkj33xmUr97TO6JtlXxzWcmVfONOevB6RK+
+cykMtO8xiXtz+Obz0xqxdzNXQHv3/HNZyblsc+pvOtLDN98ZlKXE43mHHme
wzefmdT+yLzFHs9+8c1nJhWwYbhRi1nON5+Z1AjrVKXDmhr0bGgl8jnekUXp
b3jv9tF2CD0D//CofOaepj70DNy2b/Hc6QHd6Bn4qYCpEdM3daBn4A8/exfd
nNaKnoGXiobMCFtaj55pfjTxkUklegauJVZwY9Gk3+gZ+OoNvDfig7noGfj+
61+iks+8Rc/AUycrbREJjUbPwNeY7x7mumWjZ+A/UnPGumf+RM/AXybKvsvP
LEXPwFcW5eYkXK3iixuaVNikE5du7xng/DduaFKMS5uNd0/o5YsbmlS47KKT
q4S7+OKGJlUrIVdzcKiNL25oUubud0RsxjfzxQ1NinvwzuIxh2v54oYmlSft
5qvXVM4XNzQpA1Wx5jP/fEf/N25oUh+OrOpK5Hzjixua1L7DXyLjLiTxxQ1N
Ktbhq/vB+Ci+uKFJjTu6epNaaCZf3NCkgiTnr9GaVMAXNzQp0SSnF8xVJXxx
Q5Pasl710iGlSvQ8q9qxfmREizrnqy/ZeKcPPQO/IrXypMDNbvQMXFVcOcjm
SQd6Bp5OlUbsyG9Fz8CFTa16Emc0omfgmi7Pkxt+V6Nn4DfCx45697oMPQNf
I5j+Idr2F3oGfts2+bSOxVf0DHzrmgnXVfMS0DNwRtj2s6tHPUbPwJuWXPWJ
7P6InoHPatx/9WrSD/QM/PrHbTpey3+jZ+ARFZZz6rPK2T6VDE1DBUtqTeXu
ukDtLnZq1zhzu4hOTvUZgSvamTRfciZs49eUj5yVSoL9I25WyC+1RyYWnmzE
fppHCVu/cRxhd45/ELr0QwP2A1x37sVxB9o42A/wX5zQ5uSJFewI1uB7RytT
7L/g8rpZGtkTuTAfgL+epa9kunQyV9lr+AhvvjnyK2uq7k5hqiKH/vOlC1+V
LJLjHlUb+R3fRLd/Ebyx5oCOInJo31BpPmPUZwnut1cjhoGRFtieV/C6oC1Z
Gjm0t1xn/MTXVIirs54R72i1FdvvPiQhv8OG5tBe6GjG4RjVf94fiDfI78U9
9uBU3mxFb8AfnZpz4qnqB862P0LLAiO3Y/+/llkcfnd/FOavgK8Ov9NanCFP
bTMZuqWduQX/7vI1Knns+Spc4Fnqm5sdecJUaV7jHQlXeW5C/ZAIw90M2z+v
nBa184kicmh/ZluVolSEDHoGrptt3pt2XBx9At8zwtoZdUgIvQFPzL8YHM8c
4oAf4Odv7F1qHdWBfoC/svLcml5fiX6Ay1MByfLyCegHxs9aeuZwwxoRajhx
cLqhAn2958wiXvPYo7nAQ+doT2MwJKmic2K/nZfJoR/giX1LQlplpdED8LbU
Ne0e6WLoAfjZDOnZu8KF0APwN04GY5tn/PP+QzwAp76qW6du70EPwHtswx/6
+rZw4Hdx6kNehKOVFnUtwuTBgapeDvwugB/5/uv0x3/eS8ED8CVLPS86G5Sx
gUMcKFFbc3ddYin+7iCfH3plaODF+Bl4XTAPx5ncDP5kS/9egM+IG6EmF8ri
/QVelTBZM2WcGM5/4F4S55XS5ozgOOHvPp9ifjWsZjTOW8jHyuotbgxvp+ch
8Mn3TVftr5bDcQLfEHLwhm6VFI4TuJUzh7l9miiOE3ijkaTy41AGjhN5+GjN
eY7dOA+BpzSxJDJ5NTgPgU9hOE48dSyZA79HmIc7b88WHagXw3kI+c/vlty+
KlEFnG/A34U8jjTSGoXXC1wubMN3x92SeL3AS0OSnoSmi+D1Aq95NuH45Q0C
eL3Ap4i7665r7sP5Bpy97OS2Nvc2nG8wTyYay3n4q/bidcG8OqZ7/lfs/gq2
z8BAdfx0U2rH1r4sw8B29tojpqHFaVO5x4WFxxh+34589OsKqcdMRQra//hx
NyM+RouyWu3naryijwPtgWfdtn42VaacDc9HiG8fQ4KizVIL2MMRAva8bktq
9qEsseL4Hnbr4FuL1+Gv2PB8gfm21XV1YXdVNRuev9DP91wZxjWXGry/MA8v
TO+NMVlJr1NAe4nLossPPhziHH3HMAis3Ip/13aXrkX7vm6cD9BP0LJr+dY7
v3K+mgm8cgyxRA9BzQkhRvGlHBg/cLvZh8+GyiSyoT30L3aIZdyrU4TPTei/
f9rcrhlf29k6LQIahiZW2I+ncXrYn/hqfI8CfkNIpPv8zWl4X6Afm4Yhk/A5
ynhf4L5rf+kft4tH33e4L6q3rg6cHUPfd+gn5eatV/MVZnKhPfxd5yEth4El
ozHPD/2EqKxYrSDVj/cd32f21pVVpZax78YI7uPN34b+k+S6HB4MD+N7EfBN
nUbXJaK72VaLBfPjY6zQ28rVU+7sc2pl35MUGPrnKY3jWdGe/OqMfTsH2uM4
l6eInBTpwr8L1zXbN/TURWdh6tIFQV9tiW3YfqD8bXiG/zA73fKMJOMuvb6p
O3e+drQzi6tcOijOoOh15A/7QzyWuU1BjuuG3r4n5ktqcO1sXMUYpXT7l7NX
e13dMRE5tA9TWJp3arEaN4nEB2gfHp+1vXOzFnJoH+l7c+WtCypcqcNnhRlM
ej1aerGD5oodTO72rmFBBpfmXR6x2j97x3KfObsJMHb9n3VqFaeNpZZK3L/5
QXo9WoSsU5uccx8euUNz0cpXM/aPE0EO40lPaY/uiO3j3Cf3BXjqk/M3bkjW
c7r8PQZGSmh+5ERy+fyYSM5qvt/1A/K7vnnbs3dEg75fxj2xFYfGClHAoX1n
etdW14U97HoNoZ5/nj7YnpGmNzv2mjQFHO/LPbNcURsBavEDr66RnfTvxVV5
yrLRbQrIob2U/apyAVkxCuYDPr/K3y8xY47B+w784+R8M3MjZby/wCO2LB7a
eFUR7yNwJnnegU/gDmnUhpNO7egTeKnaRI2wN+XoE9dh8xhTRhLC0Cfw3Ivq
Zr17S9En8FebTZeZvGhFb8DrDS1FFgn0scEDcA8JMXf5QAZ6gOfL1B693dtC
FdEDcDXVTXmr7eTRA3B1J9Vxvy7JogfgQuQ5CB6AC/i+VqzObUQPwH8W+2h9
WPUbPQAvux0XWH38JnoArqNrZ7Tjxi/0AFyzcvKIn2w9egD+Ieyr7WjvDvQA
fI/2N7G0330YH2A97nxI1pyXo+XQA/BMr9Me3lek0QPwtoBv7u9lJNAD8Nlr
F26JfyCCv2vgh0KCo1W3COLvGtdVE8q6HOYNc+B3DZzqNLhXU9/Dgd818GCy
vgmesf22Tc/aI2vQM/AyY8uH5YxC9Aw8ItdiS6tMEHoGfvGluonG4A/0DNxf
9Z1S0fYq9Aw8aJ792Mx/fn/gGXhv7Q/Wr3ld6BnW4x7McT93TF8KPQPvsEl5
aDlHHD0D37sztH3PYhH0DFxeas+37RaC6Bm4bkf23X0KIxzwDDw0bNEs7q0+
9Ay8SOu6TM3KTvQMvDL/7/omeMZ10lBmf5hEJXoGnuOfE3/B/Ad6Bn7C+8Xr
7OGr6Bn4nZQ+xwefctEz8KuWP9NPqpWjZ+DSRzg74jQa0DPwrqspI1f72tAz
rMdN9elT6Xkghp6Blz7I8Nw9IoyegT9ykV83ckAQPQN3zwjJvJY/wgHPuM6Y
frgotKsfPQMPW3E42Xx+N3oGbrjpZpFmcBt6Bn6WrG+CZ+CLJ431fLmnDD0D
X5m5Z8f6h7noGXi0b7ZCnetl9Ay85YLb9BnFX9AzcCq91rn6QAl6Bp5g0WEV
e7EGPQOfN3uavsKsFvQM63Ez2berrcqF0TPwn0Wve5R9BdEz8BvZ1qUZKxno
GXilq8olMfVB9AxcxU9jbfOXHvQM/PO7SQFxYR3oGfhue/d5eaNa0DNwCbK+
CZ6Br5rQ8qM37g96Bv4nWkJsp85X9Azcb0ax6nEpH/QM/OxEkX2fqGz0DLxH
8diGOA4PPQN/u9ptrfunSvQM/IdixTaubwN6xvW4cxaLeS8F0TPwZWGHtTbc
ZqBn4G3Xfi/ksYY44Bm41KG88UXT+tAz8Ou5fsXKm7rQM/CTnYtuTr/ahp6B
l09+s+7x1wb0DPwEWd8Ez8DfeOi1GJ3loWfgi04mmC+oy0bPwM+H+lm/3HQB
PQOfbK/l+2jfJ/QM3DmnmrWusBA9A296PGNnXEg5egb+fbhT6mNULXqG9bja
geu7tzcx0DNwZxnZTWtGDXPAM3AD+/e3TXb2o2fgvzn1abszu9EzcM3WxDFj
13egZ+C7LlyrO/q5BT0D53KWV0yZXoeegduS9U3wDPzK1FXbzlcUomfg8s+n
y29YmYmegc9w1PObMO4cegZ+VMeR+1s5Az1j+6Zn61JcC9Az8DuPrYTsCkvR
M/BShobFvc3V6BnW4+LyMq0TG4c54Bm4ZnH3IosTA+gZeJrlcp6CSi96Br41
bKgl4FsnegYucsep6MbdNvQMfPHC1phBqSb0jOuPdhtT7Eaq0TNwa7K+CZ5x
nE5qN7XfFqBn4J4B4ma+oz+iZ+AL3HWanNd4oWfgNWKXk9ynp6Fn4HJRBktO
+/5Az8AnPduz+lDGH/QMfGaZ4lRBm0q++cykeCtSNug6DXL+O5+ZVPf36uVn
VvXxzWcm5dF1V7ZyWjfffGZSFyf4xE2b3ME3n5mUW71g+YyFrXzzmUnJHbI/
n5JczzefmVTlg0VM96lVfPOZSaWT9c3/zmcmxdyn4naj8QfffGZScUr6WR1L
0/nmM5P6FJw7xYjjwTef//m7Ud1bVAJT+eYzk8ozOFVwrfY733xmUkbl2yva
TYr55jOTmnuxSWp6ejl6hvW4w2f+/Hq2rR89Ax+KnHBskV0PegZ+ULXt1PRL
negZuHis+TLrd23oGbil5l3B2zLN6Bn49wzj3JLUWvQM/MDE9wcyblegZ+DC
ZH0TPAPfGlnUcXB3HnoGvm98SHLW0w/oGbhYfvzjCYfd0TP2vylvyu4579Ez
cM8g361nvHLRM/BpsawOySVF6Bn4T3Ux5j/vP3xxQ5PKfXvypPjlXr64oUnN
c3R39PvcxRc3NKmobI3tIxodfHFDkxKuaokzPt/KFzc0qdenS26JDzXwxQ1N
aoHZjVG7R9XwxQ1N6lVoy5o+/XK+uKFJTSXrm/+NG5qU48PtpoHS3/nihib1
SfNwAtcklS9uaFLypzMtFMPP8sUNTapmYsr/bnfiixuaVKaBc9oJo298cUOT
ujv/fETEwUK+uKFJjfRnLGvULUXPkO96Oe5Nn3ZvN3oG3nmxzO+zTSd6Bu5x
wHSpflUbegaeXH85PLmxGT0Df7R84K6Dbj16Bt4h5Gtceq0KPeO6wO1jEh5K
ZegZ+HSyvgmegZ8OS2q6WPENPQP//GOb2dwJ79Ez8NwbUmJzHp5Bz8CjIydN
depPQc+4/mtev1zx/Bf0DHyBte2Cy8UF6DMmbjiYwehjT80tow7d0MT3inkk
H3hiVKqP9RpNfH/LnBJ86o1jN7t2vlTVlIUsfE/eQfKKxuOnPj78QQPzDF9I
/7x2pdgX1wfwejeS/u/3sGaqjW7mwDiDSJ5QLd76T+KIOOZDph42vhgYKUDt
C0kKWuM2FsfpuCH+n3dTAUoi992z+UmqOM7XU8f1OVoxqPTdu56ICSnjOKXk
/q4v3CTrdDDORaR/5YVNu7bs7sBxOpP+98XV2JlHV+J9yST9714QJeJw6wHe
F+hfgPt3fRbuy8Osr3mB2sPsOVVBDV+qOvC+LDoXsvIgb5DdIjmuPPjxCN6X
oXOsdO1MUeqk5hB38e7ReL3LrS+4BmqLUm1Ky1+891bA671INc1juItQfneW
1Z54LYfXW0jW77aT9Ue4Xpnzf/v3XqAjrFHdhNe7gfS/NKLstZFXCV5vKOl/
7OGRFzs17uD1FpP+3Q/c/iQnwcPrnTiQ8JA3X5hKX+fYpPqoCa/3cOH4nYaB
QpR6n2TPHXYP/t5jX3urvGkSpNaUtIfGCtB5sG8h7QJvmqSoUs8VX14E0vkf
pdMWSdqGUtSqF6KRVwRl0YOl2bujgZGSVLidfqNLiyR6eALrlWT9ETyUkP6V
v755fc28Fj2wSP9NGt27d9kXoQcH0v8XqxFdr1P0fX9G+h9vW+aZVJuPHvrk
fCocrSQoVbPAE4zoGvSworklhBcvTh39MHJ/y9529OCZvcXUUEGcit2r87VT
m86D5RbuvqN9Se6f76ksi4BWOj9z7GOQC2++HGXsSC2dYieBHnQd/GO1M0dR
IfUJQVe/iKIHZ8Mu20DtUZTr1Mcd3trCmJ9JmWjFZLjLUjN2W0m+2C+AeTAx
4feFjjwZ6vz5SfE7Vgxh3FtbNjGAN/8f/v1uo2oQnQcLIvmlAL48WCEZv3Hp
QevFb+j8jDMZ/6KVZcdahQrQ8zIy/p2dbyNnHLuLnj3I+LVtBlbLO35Hz9lk
/IVZn/1K4yrovAEZ/1LpiMOPjjSj5y1k/FnzFX4eeN2JnpOts1Ic1RSp2Li8
OUkTxdHz3/VGBcpQUb/iSLkIehbQ13XiOSlQvZFfnx4LEkLPD2damwRqK1D+
0UfqNJcKoOc144NnGH6Xp6i4TLXniUP4fGmSzpRkuMtTdu+Pp6fV9KLnK/+u
F8lTpXmf8xRE6DzYHJJf+s2XB0sl4x/78UmXZTmdn9lLxq/+IktlY9l39CxB
xv846YzH+8O30fMTMn61IsWuvpyv6NmIjL9+5e1zg+Wl6LmTjL/Ay7H4QV8d
eg4i4xfpjfTWDKHzYA+aZxfHxyhRyyU2bRVZJYKeV/+2SXC0UqI6AiSrFBYK
oeeG7JtB2hJKlE++/szmSQLo+WpS9mFe/Ggq/IKu0SWtYXyOz44aXh+4dzR1
//YEa5emPvT888asKYYKo6lro9+59cR0oedT5/eKMLiKFPtX7IFFNnQeTJ3k
l07z5cGekvGvFwm4evtUCf1cI+OXc33VdPnCN/TcQcZvc6o2IGbgOnoOIuM3
0lMYK9tP52cWkvFH2NzYKn75N3r+Q8av9/DbgR2PqtHzWTL+1d7bHljdbUbP
/qdD+kfYqtScFw1L/jCE0LOu3ZeC+CYVKupMxPs/WgLoOf/fdVQVamx76yHF
S8P4vuS8aq6/tqEKdWrry8D89H70PG6u7QFetzIlx/Y1VhruRs/vNW8bBEYq
U6euWPuWzKLzYHvkc7QMTZQpSZfRx11Sm9GzGMkvifDlwYLJ+NfukDs6olqM
nvXI+Me7PDhQvy8HPf8m4/8pZ34n+l0gej5Lxl++8ceYiX10fkaLjH+S6bkA
uVVF6PkTGf89u3FqFsp0HsyOjL9b7OuLzWPoPNjpf9djx1KSM7fb3dQRQM9j
O+Z3jbiNpT51zWw2bKbzM5wy+9z46WOpMKmxH509B9Dz3m+hMY68MVS1zoWm
Z0q96FmU8/WS9qUx1KflW1W+PepEz9H/rruOofTLdEcy9Og82PrQecsDK1Wp
casvKfRepfNgbSS/dIQvD+ZOxi/UevdL9a5f6FmTjP/CdeX4mNNZ6PkjGb9M
yv31C9fT+XM7Mn73N3X+ty/T+RkZMv5Jgy/tbB78RM8vyfiLT/u/3SBF58FM
yPjtJ6wPEN9A58Gs/R0WBO5VpwrMG5au3zKC7//CZ+8oGiqoU5dPmnRwpw+i
5yiH7y0jnHHUmwlMnwKxPvS88d/vuHHUNdGqYKuKLvTcaqj32FFtHHU7Y+ia
BrcdPV/XO+CtnalGrS0pTateTOfB5k8K38VzUqNC4zhLN/fVomceyS/t5cuD
7SfjN/djVeRq/UTP0mT8ryN8pu8a/Qk9vyDjv1S/UrL8ox96NiHj36r/6PJz
fzo/00PG324ldKbLLR89h5LxL60tPjqyi86DLSHj3+75VatVlM6DbRibv4XX
rUFZ/8lOH/uFzs80i4vPDozUoE53bhY8V0rnZ671LJI1NNGgTOzbn2zopvMz
ev9+d4ynVrrr8maOovNgRf/uZxhP5W0UOlM3lc6Duf27T2Y89Sl2PuNkYCN6
Zr4UddOWGE9Via5k/Mij82DpJL+0iy8PZkrGrzJFp4+7Ih89d5PxX+hVmCCu
lIGeQ8j4J+44+8Iu+RJ6XkLGrzN598L7lXR+poyMP+zVHIPx8Xn0uhsZv2rO
uZzHQ7/R80Qy/gb5wzsvatN5sNDv4xcFrmRRBfm3Xtx9ROdnGv+9jyzqQNpM
F+tGOj/Dfr9J2bCdSb2487k4cV4Xeg749/4yqd8TQz5v8mpHz+Wx3u0jd5jU
QPiJjKSoFvQ899/7zqRyZh/5PMGUzoOdC3/zJX4Dk1rV98BpqwidBysk+aX3
fHmwO2T8l4aEDN5G0/mZVjJ+DcsWR629aeh5ORm/4YuVvo+X0fnza2T8Safc
FnNO0/mZajL+OYrK+1/NpvNgemT8JqrV2dmPeOj5Ihn/PI7qpflX6DyYnOrm
zPjLmpS3vr7ysxw6P7P739+jJlU9d+8Dv2Xd6DlO9PwDx8Wa1EsvxsqCODo/
I/rv71STypzsqqCrS+fBzLsSPLTrWNS6TI8LF3c1oee/8ecfLv5DxNuezoP1
VzRs5wWzKJcF2gFJznQebAPJLzH48mCjyfj1vW9IPFlP52dsyPg95ZLH1LbS
+Zk3ZPxbptkkj59B58/Fyfjt/qzafEWfzs9YkvFbxwb63Kqm8zMxZPyfGKco
u8e/0PMQGf/oxkM9a+bQeTDv7RcseAVa1PoXHwW3TetBz/lk/5Kx3QQv7Uw6
PzNpfdLcQG8tqq3JY3bXvnb6fYPsl2v6taPNRpLOg2UvapIznK1FWfypurRg
H50HG//v70uLerDo7GHP99Xo+dAUZtNIiSa1yWXdfOmJdB4sleSXJvHlwS6Q
8c8uFVS0VstFz4Vk/NxXV2eLxtL5mWlk/IUrPF42Habz52dg36lq2lRq7zv0
/JWM/63eODfXy1/RsyYZf38iW3+g6Scb+n8cPt3yIK+D7fs2a7zgwYfY/zSS
b2F1/N1PDuOs9f6bT3gUYP5w0+YaHOdakn9wiCuyirwdjP3kkv2Wi0i+Au5j
hWL64gmGbey5iQW6a8qm4vfLHzKe+TpnmhKqxyJ/SfJCDd4ZFWeO0/umvMnf
lbs5eOTcRXnkT0n+5JOGv6avqBx+b7qQ/I/4PNs7taUqyJVIvkjh6I3XywwV
kLNI/iSCLa02Zr0s8u0kb/MyefravbYSuC9rkFyXYaRIZMms0ciDSJ4qVODk
rO02Usgj2LavDQMH2CHh2x96SdH9qJN8kR1vS6DeNiEuzKtAqJeS+d/9Xank
73osEIyN9qHbD/f9t54GcD2yP2o54dCPHRmPTGGq4Az7XpzP38k+IgNSLwJ+
p0qj//7d1M3jH0dGy+P+KxdyvTPcUkztQ8Qp+D0eJffr6nSv/PHfVPC7QJrk
c7x8GMIaCfL4/QXzJ4nk04C/JXkhL5J3gvuuRPq5Lxx6xFJaErkbyS/Fbr+k
sNFKHO+jNckXZX0K3DNroShyXZKn8r3+w+24sxDel0iSR9KrCHTWmSaIvJXk
096t+7ksqGsIvTUTb5rEG8YB0s/j1NE/PNPp78EHZJ+SI6kXAb87AzLORhMz
AzV2Gf7uevuJt2uOtdkB1/C+JJP7aH82IyhOWBTvixyZVx7Rjcc8TQQoiJ+b
SP8H7DsXqJfR+UBtkke6F9O5Ut5bDu/XH5J3Cnsrlh+wSBrvyxWSp+ogeTDw
X0Paa4zNdfVMovNCm0i+K8LPpNDqgRD6nw/5q2P5ZlZX6HyREMmbnVqs7T3v
1gjGYSeS15LyGZz103sQeSrJv/3cVr/nzyF6Pr8nns2JZ7gvW0k//edYRsad
9HfNKZJ3Cid5J4hjDiT+7zW6VmW9pRf9HyVcQymmMkuKfh92JfHfOe78gzvX
6XVMyJ+n3refdXHjH4yTsL/RaqFXhU68DnqD/Y3Sn6XHza1XRD/Anyvqflew
l8P5ifshkzYLXx2SwDgA3JjEAegf9g1ymU2To+9KY//Azc7vXiF1Qwz7B+61
bWUM+5kg9g98Npn/0D/WIXHeXNhiTv/ugC93NPPZZ0//voBvVN1i0zeZ/n0B
303uI/wuYB/yhjmxQdy4KOS15DmS2O66sq44GjnEq4+NUQH3AyPwdwf9aLcE
NKjqtiKH+9J9/EoUcy89f6D9rHsSSR7/vNlA/9C+r2uu2MjAc+QQP8M0rIKv
F77E5ya019P5u58cnu8id/4+Hyv6CkXmfxxG7kOuy+DN4K7qnAE29APjqSHn
wqA98LZMqZPv6gaxvQ3hyaQ9cHiOZJL9veBBnzxPtcj+beDwnO1t+8uhH3h+
KfJd1xvy/Hp3dqhiXpkABecKH5L7YiyrcNArUBPPnQE/JhLz7MMzbTx3D3zO
befXm6cysb4BcM3l0a9fPFXDeh3A78qsehE0VQXrogCfvsx0eCBbAevPAN+e
4bw5QF0G6ykBD7dt6VQqF+bCeUDgJmcXGshICmD9LuBCahp3DWTE8XodyHvF
mYL93kyWGl4v8FT2qR1f0sbj9QLfI1O6SSJMBa8X+BTnHVZO80fj9QJv+sZ6
d6FBDq8XuNePo18UT0jh9QLX7REOKF0hgtcLPOaD/ZoVHsN4LgO4tZX+Evfc
djxfCVzuaNqj4i+/8Xwl8G9iCmrJFZ/xHAFw7SscalJGI56vBO44V9DiZ0Uv
nq8EPua9Zf7YAHr+eJPnfvSCMT9MTJTQJ/A9nS+++s2g63EBH75Ws6nxigL6
BD42Iyb/cPoo9In9j0pqcbkpiT6BL/5+fe2GIBH0CbxB8M21E/EM9Alcov3Z
rpN9PegT+Dq/bi/LoCb0CTz4mxlP3/En+gR+6swEJ6e4DPQJXKsqJmhBWDX6
BJ47SU4lzb8DfQKfLLAjIyV0AM+rAm88arpd9C3tGc7HvfzoMXHmZXn0DLz9
h8fq1hq6HhfwX4yyY8mXZdEzcPPtvOeGkyTRM3C1fqZyaKUIegbekP9Byu2D
AHpGblrVWO41gOeCgQesz01Y+rYDPQO3UN7mZL+1Fj0Dt7WxKv++Jg89A5+V
9H1H3PNU9AzcYblsYkBYOXoGfkpN1nDd2Fb0DDx5s8GUX0nd6Bm4e/3dc96z
h9jg+TVZhzruNtHZ5rsMegYufeuZxqo6OfQM/FF2WUNfpwR6Bv5NvciboSeK
noGvE+t5b39LED0D/+jrEx0zYxjPXwM/H9wYM2lXD3oG7qMYe3lCWit6Bp7t
1qYTFluJnoF7xye3q+z5hp6BG0UHHEp4z0HPwGsElqjPu1eCnoHL6OwZnL+t
AT0D17XwunLAqAM9A3+dn5k6ktOLnmvIelO42957xg0S6Bl4x+e5NQdtZNAz
8NdH5xjs8hdFz8BNAw8r3zei63EBbzt0KWjjVLoeF/Dtaw8uPLe4Hz0Dv7o0
P0J8Uyd6Bj4l+PWEGu0m9Ax8bn2l9a3+MvQMvFxV4PsJ58/oGfh+xa79ubeS
0TPwYb1bW/xdeegZeMPqR8tvf6xBz8AnNKgXnv3Uip6Bm03JNmP4d6HnY2Rd
KY+39hKrQRTrvfx7eSNKVDOpEwX+of1Tod05s4fp+wLtR5N6U3BfoP2oo6nv
OO1CyKH9JL56U9A+PO2N2QZFmkP7yXx1qKB9fNvDfPvgQeTQ/g1ffSpof03x
oZjM7B7k0P4LX90qaH8p4Il+dXcbcmjfw1fPCtr7VrsHaqXXIYf2Wnx1rqD9
2EznfWez6foq0H6Yr/4VtM9v5H5wnJGJHNon89XFgvZ112YtyrZNwHOj0N6F
r14WtF9TIPTwy8ZC5ND+GV8dLWg/saxT/odoFXJoL85XXwvaJ72e+2LKM7pe
H7RfzFd3C9rLLzWeKCtHxw1o70vqccG89SPriZ2fO5gvHwvi/ASeuM7qjssU
EZyHwNsdjI9GLKXrcQH/HTZ0gZND1+MCLrxykRy1mp4/wI88DN1yqJyuxwWc
c0E10ZxqwvkAvCS3YIHYAF2PC7hsYq9/Ujldjwu4v/lFMVN3uh4X8D0vbhqH
/qHrcQFXPL41cGUWXY8L+EiA+yLb8WXoH7j0krJUgam16Bm47T7HbRMkW9Cz
Klk3/MiYXL1PSQA9AzdoGndCeRf9eweulX1Ne0HKENYhAf6Urdb8+Xgfegae
dOPZp9lGXegZ+Pm0Z5or19K/R+D6lSrqap/oelzAGdfMNa7Mq0DPwD9p3M1b
8oquxwX8oGp09/x0uh4XcKOwrNsTZ71Ez8CbFe38zo//jp6BlwbfOfjZogQ9
A+9hm3xI1KhGz8Dtlu/N1T/QiJ4jyfrgy9GGezLOjmB9A+AP3i5aPatYAD0D
vy9do1dgP4Cegd9In2Y49WQPegYub+ThdD2yAz0DpyjjaUtKW9Az8FdjVvm3
xNaiZ+C/rjscGYyj63EBd1LJPJZaSNfjAq6y3NHi4Ib36Bn4LU+/xe1pdD0u
4Hc6f8t8fEXX4wIukyZxa3FVMXoGrqTr9CZnbyV6Br5B5VzBxtn16FmXrANe
tKv6ojJ3CD0D36rfIOvuT9eXA167yWCv7oE+9Ay8nmdeJZvahZ6BS9XM5Dyb
T9c9Ay6T2qfldKUJPQNPkcwYlK+sRs/AnZoT/SYcKEXPwKMebTn5Rf8Hegb+
8UnEYaYUXfcM+NOdzMMTxsSiZ+D6t1ziNvZ9Qc/AHzTc9OzPKkLPwANn8Gzq
a+l6XMBbd4iNMl1bi57/kPU+y+6BD58WDKBn4EbS++Pd/9D15YD/Looqev+8
Bz0DX1MznGduQNc9Az7gc2hJVB9djwt45S7fqYJ+DegZuHvYDsn7W+i6Z8D1
0yMXpNz+g56B999IC15Q9h09A399SuDW+5oU9Ax8e8uRGN7AU/QMPN7USWPm
n8/oGXj+oSNf7/YWomfgGk57QzLulKFn4Gof+6wu3a/mixssSql0uGe3Sx9f
3GBRxStmLD9TPcj5b9xgUW/ODqzsmN7NFzdYVHCLdcfSwXa+uMGiFBVnXhr+
1MIXN1gUj1k8a0lWHV/cYFE713Q1reur4IsbLOrwuj3TpR4V88UNFmVbME+s
62kuX9xgUTp+V2pPjyTzxQ0W9T5R6O4dzWi+uMGiGOFjr/0UzeaLGyzq449J
1bW7fvLFDRZ1sTxxr7B7KV/cYFHZTvfPVM+qQs/7SZ55y61ZW1539KBP4N8u
5ztL/OpEn8Az5Hz+OBTS9c2wfX/B/UOlTegTuNHVe755S+n6ZsBl3doXG2bQ
9c2A++S/+xTRXIQ+gYs6651dFUbXNwNut+6XJmsTXd8M+NvZHu6XPOj6ZsBP
Rx865WBL1zcDnvVwSdvVvnz0if245DFyhOn6ZsB3ps8J49RXsFkdZ5x4ZnT+
sHqBn9TxO0zuWV/X8ngZOk94S8avYIX/OC5P6+zGwDSay8+xnNYlosrVe3s2
ydGFzh9O82P53hityL1u6jbRcDadJ9T7eTg2+LMMt73RLVC7juZCqS7XNj0T
4T5V99jPM7NEfmj4+iGuSy1HIt6jIF7GCrnX6/Cg0fM/svdt9FwemEbzOyfH
N4ttbWN/qPZ85uhC5yHtlnzzlLMbYTPdvMYazqbzkD5pAR8lEkQpDxXv89p1
NF/tovn7oZUMdezU0HFeN51vNHWJ8vj6dTT3m9xwaXwMnVe8P77Vt/uSPHf6
v/sL6byidMGvfUveSnN99EcSHNXo/KF7jvm2A9dFuTW/RrQNv/8fvvBTTHgo
gwv1WIBHNaVMH46NxLoiwLef/5jAflbNTsgT1A/cS+cJV7GUb3f+872p5CAU
46hG5wk9531esq1ihH2C1DkBbvf+drhjgzCVNuR6jBdM5/ce+cx5tHypNJcV
fLYkfgOd3zO5bx1RoSfGPTvDbV2gMJ3Hu2lRzjS2EuTyMtzeOCbT3H7yvj1e
Kwc4RpM9bXnBdF4u8/64fcs8/rCfcj3z4jfQebnDXfZzH7W3sCW2erEDhen8
2x1G3+aBcb1s+zavaMdkmudmnFjSKsqgoF4K5JHWXjVRkEypZQ+tEvoe30Tz
WOnLvU+VO7AOFXAN58EpXyP72Lbibod5BXT+51vmottGFQOctLtuxfGX6TzP
SFzRk28Tujjts7328groPIzZFsPq8kktbONsr2/xl+l8S4JNjb7flC52wuWR
gzwnOo+hcWX4Jkvsn/fABCFrnhOdNzCQFWp9V0R/Z8H3VwtfHWn8Tuf7rgc+
le/7HXgS33c68G983+PA+/i+uzGfwPd9DVzU/b/f0cCz+L6Xge/g+y4G/ojv
+xe4MN93LnA9vu9Z4JfIdyvEPfjOWuepSeUGMjDuAa8IjGo8f3SQA3EP+DWT
Bwqfq3o4EPeAG1/ZZavg2sGBuAf8Tc6SMXscmjkQ94BbLv9csWN8NQfiHvDK
RX0e+TmfMO5he+dxH+MGH2LcA/5A+lcfk5uLcQ/4JIcPIW0apRj3gK9c8jPl
x6waNsQ94HU3Vtl1qDSzj5K4B99HeZLREX9C+jlfSdwDnpv7UbbaoZujQ+Ie
8Lc+8qE6O9s5l0jcA36Sk7PauqyRU03iHvChloDm5ewqzhCJe/id63V3zynf
S2xLEveAS3pduS7X8pn9hsQ94BnhgRedM3ns0STuAf8z55HpJutKNtR3wu/T
kl+j/BPr2RD34DtFSHRa9cXJXRwmiXvAIx92T2PZtXFcSdwDfmHYT9bzUgMH
4h5wwauxF+1OV3I2krgHvGnjo5NGZz5i3AMecLbz9vtRhWxxEveA/3TJmmwh
Uc62I3EP+HsDfd29VTVsJVKHDd7/s21F4mYFtHKgDhvwa0evlz7cVs/5Suqw
AZf7sLe3J7OCA/ET+L7nm6Oza35g/ATu/KqgtlmiFOMn8FTVm2WyrlXsfSR+
wntyPSN0fPXmOs4HEj+BrxtcxxqZXsFpI/ET+OCmFsUjkcVsIxI/8TslYsN7
q/0V7DckfsL74RK7AruciHLOChI/gW8Zn6v7NrSMzSr2eOG4mH5PGJF/mJ3Y
zWND/TR4Dq6RivhRINKCddKAC2xKvhkekMuB+mbAZbyrVOqSfrHdal1O85Tp
9VmX0NgT8020uRDnoX0iw/R21FYhrqSiuyNPeSu2134sF/HUQoirNJHBi59O
j+fJrvv24m10fU5o3+ti92BVSBvWeQPu13d5Wpd+GtZJA/5q0bbECWay1Eqd
oXeOIfT7zJryZ6uNtilzjdmuOoYv6XXA5aOnas0ylufeSxuaamhCv+f4Zb5y
KJFQ5Mb8dL2pbU+/J8SKno+tspPhwnMT+Mm1Li2yJ4S48NwEvs+kVyvadojD
Wui+JnAlvd6X2udTIjytk3M21z3OcYDmE9/d+Xp5VzWHZ+/BNHxJrwMKcF4L
toV/wOcmjHP5rI9HH0QKUh0Pz3AdB+h1T8cVQy1rBEdzXcn9gvfhvecdvm38
0I/fa8DNTK6k20we4HiSOAn89qf2Ne27K9hQ/xA8J/pP+1V6fTTWPwS+7NIc
hanb5LD+IXBrxnojH29xrPcIfP8dU+n3fgysxwjXNYmK2nkoSAnrMQJvWEH1
7F2jgPUYgbtY+o+cnC6L4wEeEes7KX5ADMeDfMP00lu9Ajge4CcvOhq2Le/F
eQjc4nyFidfXOpyHwHVuO9878jIF5yFw0dYT9ieWiGL9SXxv/Bm1OvyFIl4v
8F0vz+vMEqTrwQK/5+D2oSJXGq8X+Da31sr+T2J4vcBXNOzZq1kjiNcLfEuE
aIqa6SDWnwQ+V39K+mqNDnw/gfsSzUkYY30gD+s6An8wNtz40NparOsIXLBX
UviIBJ1nBl76R2FB+Po+jm20+6/4HJobxGiFTGD24PwH7i/8y7fBrYOTtsJj
VaA33f+yt2MLy/pKOEXkdwH8+fXtqx4V53LgPQp4brLmZg/zDrYxeR4Bb/de
L7Wnjj53A3w2Ob9sRPb5ADfq+HvuONFgMFT7Er1PI1q8c9BozTjcR4ffQeQc
8cqjjADtS/S8qu32ST4a3sWBuojAX5FzwTFzz8w0PEr/fudv5gkHXlXmSuac
CdGeQs+TZfOPvtq4R5FrS/bpAQ8g53b1drprGR6l76/ZwbWmBirtnOs97v7a
U+h4ciF44e35ZuWcdrJPCfjt03/P594j9Ujhe6HAZfrMHYUK3EvkdwG8W6Cf
p5JYhr8L4ArZs45H+yRi/UzgOfv+nm8Nlj1jGriSXtdWj11iGbVEjgtxDHh9
8vX15d7SGLeBp5SLBe57KY7xGfjynIAZ0SPCXEmyDw24HjmXCnEYOLM+o5kz
pwnnIfC3xy36j5wuxTgMvPfimfwLO7gcPUFPP217ep36ckO2/elfX9nXyX4n
4G/IeVKo2wnfO1aTdN5wwqS5NdcGTQIraf6pzzRi31QJLjy/gE/cq52V+UME
n1PApeTH6vfdFuQObxsO1pag15ejyotV7LqHOVZk3x1wV3I+FJ6/wJX2KqbE
3q/HOqvAnybsfVWjVILvCcB3LnPZbzuciu8JwJet1jGolPjIhrqdwL/vu+Y3
briEXU32qwNPIuc94b0C1uNsNexfiD6U4Ba7n6mKz6G5c8ap5PbrotyFY1w3
BXrT67+XTzpIb7srxA1+4ZriuJhetzVf6rnlwgcGt8Pw7BTDdpr/kqj4kDEw
wDEuP3tdO4pet73Veu2nWGg3J4bsSwS+npzrhPcZ4B8VT7AEntRifAN+ynx5
VErkb4xjwLNeLs5ZP5zGgfc04Ok3x3zRWcNlnz3uqW7YTvN21tmKxHVFbJ60
1yXtKHo9tLF0WFlgpIqtR/aXAp9Hzm+mkfgG3zsLyflNiG/Ab5NzkQkkvsH3
gtsmrcS1rwS4SiS+Af9CziGuIPENeMAc5XH6UTzOXRLfgIsG/z3395TEN1z3
sWCNyrzOwPiG3xcKPZNUxYc4EN+AfyDn7yC+AX97VUnk+UIeJ4jEN/yuURHc
9ONDNqeNxDfgpe1/z8FBfIP3+dkSspMslo1w4HkN/Pd5zYxk6wGOFXleAz+0
e3uk7JMeDjyvgZuSc2rwnAVeZzbBP/9LEQfiJ/AE8zNGBpmfMX7id8rKQd5x
rwjOChI/cZ1l0t9zZNdJ/ITvhdVXnBJuXx3itJP4id8Xx8Oq5nb1cYxI/ARe
t7lCKPVUN+cpiZ/AXVOYEtSYDo4EnNcgXPnO3/NfTBI/gd/lPPTy2V/EcSXx
E/iEoy552aE5+LzGdRAF7tHjKk85C0j8BL5C4Mp119YUdhCJn7jOovD33NYl
Ej/he2dRcVXHdJVBTjWJn8A9PRIE1F71claQ+An86lDr3aUOXZy7JH5inv/3
5qJnVDtniMRPXKeQjQ0+sL2ZY0niJ64XkHNYo0n8BF5RNuuQpUwR5wiJn8A1
Uvc8Flr3hfOFxE/g7wT1W95NfMmZRuIncOXJvo/9J79hXyTxE/gj0co9e159
ZVeR+Ak8iJyrKiJxEt7bGwqzCwWCezgLSJwEXv/jWajd2U5OEImTwNtT7kc9
dW/jtJE4Cfzdnd3FW+Y3cTaSOAn84w/ZgpybNZxoEieB25NzUuIkTuK6Q0OZ
iu6bXxwbEieBv+f5dscXf+GkkjiJ7T9tfJz5+jVHg8RJ4Be+DDufXvqCfYbE
SRzPDj2pJTey2b9InAQ+sTxppb/kTzbEf3ivuz500V5LXRmfm/A+dtDGT9Mx
chQXngvQPq4kedzjn/JceJ7i/lhyPgieF9A+mJwDgviM78Nn/56XgfcTeO96
Rs6tZJC4DePfQ84dLCD9AJci5w7g/Q3639L5d387PEeANwhKG9o5dLHhfRX4
t9oPezjVTDz3AXz3+XMTVO6r0/UoCLdoPaPuHzwGzxEAj5K4u2O9qhLu8wf+
M7Xiw+St8rjPH/hF4gfr2xC+SblXdB23F8+1Ac/RnjF8OkoQz7kA7yc+YTxw
X5pLZALaa+nzXMDDyP2C/erAD2tv1yxKL8P96sC3dC5S9+5rw/EAN/JZFSm0
cIAtxXcfn5D7CP0Df1W8YWrk0yLsH7/7NM91ls5vxP6Bu65znFm0uwvPjwDf
rm6gPs19EPuB92pJV4HBafPo+jDA5wblMM/cbMN+gB8IOx5ldqKHDX7gfdX+
n9k35hF9vgb4/bvVTyUjuvFcBnBnsv8T/i7wY+0Pm4YrmvDvAj8i1n/cqamD
Df3De+CXqjp1pacd2D9wGbLvEfoB/vGMXGX4JroeCOS9dfnqtQIv5KvXCvwm
X71W4NV89VqBq/LVawWew1evFbg1X71WeE87RvbvAYf2knz1K4Ab8NVxBV7G
V8cV+B2+Oq7A3fjquALv5avjCjyFr44r8HxSxxU84744v0vtSiV0vVbgAjsW
3rt5i67XCjxqSvaARSBdrxV47NiJlhUP6XqtwL8kvKey8+k6FcDnbHXZ5Lq4
EX0CzyT738AbcL2+Z2Vyjz+jN+B5x5ab10nSdRKA34z4OsPAl677Adyh1uEA
m/ULvWH/4dOivhbR9SiAFzk+1OIJ1rHBD7wnz3Qf3OPIout4AN/Xrbf14qEe
9AN8rvyulzN/0nVWgV/JCd6gaN6KfoBPrDZT6uHR8w14Y+DffWvgAfgcp+X1
Fmm0B+ADR6ZNXmJC1+UAHrzV1YfRSddNBb6n2SE4blkZegBeM/Ndv1hlNRuu
F97P1+pMmx4VTtfTAD5Q139m3Aa6ngZwQz+7xDatZrxe4J57LTsXFdbg9QLP
IPvH4LqAj7wsval9kq6DAXxB2aaZU8fTdTCAW7JllRekleB1AX8t8F1QQ7UK
nwu4HiH2rftqP11HFPiS2waeV7oacPzA0xJiXHzV6ToVwG3IviwYJ/BnC2Rv
CF6m60gA95miNdXhEF1HAvhc+yzvjssVGP9xXxBTP2elPF3PAbhUSszb92GV
OB7gmmT/EtYXIlxnW/qjaQfougrAVxVtG4rQK2f/936xKHahTbT0xgq++8Wi
NpN9O//1zKLOuaev3SVbxob28F50mOxLwfOb5HntfyiWSohT+3/ydVIkX4f1
B8hz1qNha6XtWyXk+O9SxT2t7S+R50I8Ab4ibtIGj+08ut4d4WbtJ7+uv3Mf
5xtwPVLnDfqH5+Nw9LdzMyxlcZyYX+rdVmI2IEnXJyTcst9qYmScGD6/gB86
Kr0+15s+hwt8NsmDwfMF+J8gT2akdTXGSeCBWeqX7QV/4nUBH/fUwWM4NQSv
C8+D9H7I/CGXh78j4A0kDwbXC8/xRRkiE6x3SOL1ArdZW5f0xlEMrxf4Qpe1
h+cHCuP1Ajfh1W3jZtF10oBfG38i7IbOMP7ugB8keTDwAFwkykFd3aECPQBn
t7J+ZhbloQfgVI7gj/50+t9ZAL4tX39u7s9v6AF4frdQyIR1Zfg7Bd5E8mDg
B94TQmcYsfo20nX+gVf05KZEvaLr/AM/ZLlRYeY0us4/8MxuxjR5e7rOP/Ab
0jEvA8LoOv/A1XRuhE1qp+ubAV9O8mDgDfhh1ys1lhPpenHAawJWdXs40fX8
gXvUubW5zaLrPgGXmRs5+aEWXc8fuKLxqbEGn/+gN+CeI2UVoqp0PX/gW/nq
mMHzdz7Jg5nw5cHMSB4M2sNzihn14KvFXroeF/AskgeDfoAfmsLrWfaMrn+F
z2VS/wr6x33Up7VcikTpeuzAy21CpwuepetQAU8meTD4u8AZ18s3vr1P14PC
56nzt8diBnQ9KODrSD0oGA8+R662VD6KH8K6K8B3Ns5VcrLtx/EAF2WExsnq
9uB7C3BDkgeDcQJffc1wqVwVXU8JeIn7qNI5++l6SsA/7f2htfDIRZwnwPVI
PSUYPzxfEkY/e98eO4DjB/5qnVRJy81eHD/we1bNWrNu0nWQgPtVB6+++JSu
gwRckOTB4LqAb1po0Tfamq7jDbxpgWqoVC5dvwi41bGKoTdSdF0d4DKr1Jfn
c+j6RcDZpH7Rf+cPi0qN67/3rL6P89/5w6I2TK3yYoj08M0fFuXnNDVr6Vy6
LjfwxgP7HxuebON772JRW5aUiSy83cT33sWijEke7L/zkEU5T5+3wkohj28e
sqiPYwaKphz8wDcPWZRMwOCZt1s8+d7HWFTKDb93J5O4fO9jLOrEwyrtqrG5
fO9jLKqQ5MHS+fIntiR/An6QN6odMb5H19PG/NL3W6ZD/XQdIeD6EVLCZrZ0
HSHgK0PK6lKz6DpCwI9+kuQeqaXrCAE3JfkxrOdG+PNnxr/V6+l6QcANr57o
cVpA12XCfiLDYsI06frkwC9yP7O33uWgN+AjFe6OFSy6LhOu+/eWt22cQdfN
xrwZyS/d51uvPE7WK/9/66dwvdC+xuWpUvpGYYy30F6crKvC+xvuJyHn66E9
9DMwudqlbwFdvxT4eXI+HcYJ/RhuMrXeOqoRvQGXafqbH7PjWz/1J+uncB+B
b9b0TtCaKozXBdw46VRtvSQDx4nnqQfzF73/SH/vA29q+3vuG8aJ57tnScYL
s0pxnLgv5dDfdVi4L3C9VJ+cdulYQazrgvtCnzQHFqrR/84XvGeuFO0Ntjg3
Ct8TgIcHRpaKXpfC9wTg1Xx1XYDvypOf1jJTGP0Av/HpmLRLDAP9AD9y7FiW
pXM/znPgF584CLZPqEc/wF3IeW0YJ1zv2+1RhzVmK+E4gVeQfSBYV5nwZ2Eh
Pkct7+PvF/wEkX0Uq/n2M3ST/Qz/AzdWZEM=
   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmgf8V9Mbx8+553uRFVp2IhHJiDRkNJBskVJJWpKiUlRIoZSiJKkQCikj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         "]], Polygon3DBox[CompressedData["
1:eJw1mgXY3VTaRZOcXBhgcHdKKe46OC0wuBV3dx0G90KhSHG3wd2tuBR3p2hx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         "]], Polygon3DBox[CompressedData["
1:eJwt12WgVNUWAOB7584I6jN44jOQZysiKgYhYREqBo1BSiqSKqWICIigSHcJ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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0jksZWEYBuCfi+G6195JjK0lCrFelURkMISIoBMNhSUaColkJISeikwz
OtHQiWZ0orHvSylqidJzonjP8365yf+d5VaMTfdPpYUQ1qRFiXqDyxtrYyEU
sIk/2cFaDrKN4+zmHEf5h8syqf/lAve4yiNu8pQ7fOAB33nMxYwQ4vam5Dza
ySr5kR7ChTmbl8zhFeO8Zi5vmOAtk7xjHvPlXi/gAwv5yCI+sZjPLOFLdIZ7
SdjZJq/mZlZLlns7M3/6/T/fuM87/uMJN3jIFe5yntvckgl9iSOcZRfHmOIA
a7huR6ldZfqM/sFWcz4bWSTDkmceYpLtHJSEXumcej1XL9fr9LheFp2v5+h9
7JVs/Xf0btkTPR+7mclftD50MhZ9c6ZH79WQTPv+j3wB+qE2VA==
       "]]}, {
      Line3DBox[{814, 1130, 1181, 1493, 813, 1298, 1031, 815, 1299, 1032, 816,
        1300, 1033, 817, 1287, 1301, 1151, 1034, 818, 1289, 1302, 1152, 1035, 
       819, 1291, 1303, 1153, 1036, 820, 1496, 1132, 1154, 1182, 1495, 1174, 
       1175, 1176, 1134, 1499, 1037, 1173, 1177, 1178, 1135, 1296, 1500, 1038,
        1171, 1126, 1172, 1522, 1180, 1039, 1179, 1297, 1304, 1040, 821, 1305,
        1041, 822, 1292, 1306, 1042, 1136}], 
      Line3DBox[{824, 1183, 1393, 823, 1184, 1394, 825, 1137, 1155, 1518, 
       1043, 826, 1139, 1156, 1519, 1044, 827, 1288, 1307, 1157, 1045, 828, 
       1290, 1308, 1158, 1046, 829, 1494, 1131, 1159, 1047, 830, 1498, 1133, 
       1160, 1185, 1497, 831, 1127, 1161, 1186, 1492, 832, 1128, 1162, 1520, 
       1048, 833, 1129, 1309, 1049, 834, 1310, 1050, 835, 1311, 1051, 836, 
       1508, 1146, 1052, 1163}], 
      Line3DBox[{838, 1187, 1395, 837, 1147, 1164, 1188, 1509, 839, 1138, 
       1165, 1189, 1501, 840, 1140, 1166, 1521, 1053, 841, 1293, 1312, 1167, 
       1054, 842, 1502, 1141, 1168, 1055, 843, 1503, 1142, 1169, 1056, 844, 
       1505, 1143, 1170, 1190, 1504, 845, 1144, 1191, 1506, 846, 1145, 1192, 
       1507, 847, 1313, 1057, 848, 1314, 1058, 849, 1315, 1059, 850, 1316, 
       1060, 851}], 
      Line3DBox[{853, 1193, 1396, 852, 258, 1510, 854, 259, 1511, 855, 260, 
       1512, 856, 1513, 261, 857, 1514, 262, 858, 1515, 263, 859, 1517, 264, 
       1516, 860, 1194, 1397, 861, 1195, 1398, 862, 1196, 1399, 863, 1317, 
       1061, 864, 1318, 1062, 865, 1319, 1063, 866}], 
      Line3DBox[{868, 1197, 1400, 867, 1198, 1401, 869, 1199, 1402, 870, 1200,
        1403, 871, 1201, 1404, 872, 1320, 1064, 873, 1321, 1065, 874, 1322, 
       1202, 1405, 875, 1203, 1406, 876, 1204, 1407, 877, 1205, 1408, 878, 
       1206, 1409, 879, 1323, 1066, 880, 1324, 1067, 881}], 
      Line3DBox[{883, 1207, 1410, 882, 1208, 1411, 884, 1209, 1412, 885, 1210,
        1413, 886, 1211, 1414, 887, 1212, 1415, 888, 1325, 1068, 889, 1326, 
       1213, 1416, 890, 1214, 1417, 891, 1215, 1418, 892, 1216, 1419, 893, 
       1217, 1420, 894, 1218, 1421, 895, 1327, 1069, 896}], 
      Line3DBox[{900, 1328, 1070, 898, 1329, 1071, 902, 1330, 1072, 904, 1331,
        1073, 906, 1332, 1074, 908, 1333, 1075, 910, 1334, 1076, 912, 1336, 
       1337, 1077, 914, 1338, 1078, 916, 1339, 1079, 918, 1340, 1080, 920, 
       1341, 1081, 922, 1342, 1082, 924, 1343, 1083, 926}], 
      Line3DBox[{925, 1435, 1232, 923, 1434, 1231, 921, 1433, 1230, 919, 1432,
        1229, 917, 1431, 1228, 915, 1430, 1227, 913, 1429, 1226, 1335, 911, 
       1428, 1225, 909, 1427, 1224, 907, 1426, 1223, 905, 1425, 1222, 903, 
       1424, 1221, 901, 1423, 1220, 897, 1422, 1219, 899}], 
      Line3DBox[{928, 1233, 1436, 927, 1344, 1084, 929, 1345, 1085, 930, 1346,
        1086, 931, 1347, 1087, 932, 1348, 1088, 933, 1349, 1089, 934, 1350, 
       1234, 1437, 935, 1351, 1090, 936, 1352, 1091, 937, 1353, 1092, 938, 
       1354, 1093, 939, 1355, 1094, 940, 1356, 1095, 941}], 
      Line3DBox[{943, 1235, 1438, 942, 1236, 1439, 944, 1357, 1096, 945, 1358,
        1097, 946, 1359, 1098, 947, 1360, 1099, 948, 1361, 1100, 949, 1362, 
       1237, 1440, 950, 1238, 1441, 951, 1363, 1101, 952, 1364, 1102, 953, 
       1365, 1103, 954, 1366, 1104, 955, 1367, 1105, 956}], 
      Line3DBox[{958, 1239, 1442, 957, 1240, 1443, 959, 1241, 1444, 960, 1368,
        1106, 961, 1369, 1107, 962, 1370, 1108, 963, 1371, 1109, 964, 1372, 
       1242, 1445, 965, 1243, 1446, 966, 1244, 1447, 967, 1373, 1110, 968, 
       1374, 1111, 969, 1375, 1112, 970, 1376, 1113, 971}], 
      Line3DBox[{973, 1245, 1448, 972, 1246, 1449, 974, 1247, 1450, 975, 1248,
        1451, 976, 1377, 1114, 977, 1378, 1115, 978, 1379, 1116, 979, 1380, 
       1249, 1452, 980, 1250, 1453, 981, 1251, 1454, 982, 1252, 1455, 983, 
       1381, 1117, 984, 1382, 1118, 985, 1383, 1119, 986}], 
      Line3DBox[{988, 1253, 1456, 987, 1254, 1457, 989, 1255, 1458, 990, 1256,
        1459, 991, 1257, 1460, 992, 1384, 1120, 993, 1385, 1121, 994, 1386, 
       1258, 1461, 995, 1259, 1462, 996, 1260, 1463, 997, 1261, 1464, 998, 
       1262, 1465, 999, 1387, 1122, 1000, 1388, 1123, 1001}], 
      Line3DBox[{1003, 1263, 1466, 1002, 1264, 1467, 1004, 1265, 1468, 1005, 
       1266, 1469, 1006, 1267, 1470, 1007, 1268, 1471, 1008, 1389, 1124, 1009,
        1390, 1269, 1472, 1010, 1270, 1473, 1011, 1271, 1474, 1012, 1272, 
       1475, 1013, 1273, 1476, 1014, 1274, 1477, 1015, 1391, 1125, 1016}], 
      Line3DBox[{1030, 1150, 1491, 1295, 1029, 1490, 1286, 1028, 1489, 1285, 
       1027, 1488, 1284, 1026, 1487, 1283, 1025, 1486, 1282, 1024, 1485, 1281,
        1392, 1023, 1484, 1280, 1022, 1483, 1279, 1021, 1482, 1278, 1020, 
       1481, 1277, 1019, 1480, 1276, 1018, 1479, 1275, 1017, 1294, 1478, 1148,
        1149}]}, {
      Line3DBox[{326, 534, 1298, 327, 1394, 541, 348, 764, 1509, 551, 359, 
       765, 1510, 562, 370, 1401, 573, 385, 1411, 588, 400, 1423, 603, 1329, 
       415, 618, 1344, 430, 1439, 633, 445, 1443, 648, 460, 1449, 663, 475, 
       1457, 678, 490, 1467, 693, 505, 1479, 708, 520}], 
      Line3DBox[{328, 535, 1299, 329, 747, 542, 1518, 349, 748, 1501, 552, 
       360, 766, 1511, 563, 371, 1402, 574, 386, 1412, 589, 401, 1424, 604, 
       1330, 416, 619, 1345, 431, 634, 1357, 446, 1444, 649, 461, 1450, 664, 
       476, 1458, 679, 491, 1468, 694, 506, 1480, 709, 521}], 
      Line3DBox[{330, 536, 1300, 331, 749, 543, 1519, 350, 750, 553, 1521, 
       361, 767, 1512, 564, 372, 1403, 575, 387, 1413, 590, 402, 1425, 605, 
       1331, 417, 620, 1346, 432, 635, 1358, 447, 650, 1368, 462, 1451, 665, 
       477, 1459, 680, 492, 1469, 695, 507, 1481, 710, 522}], 
      Line3DBox[{332, 727, 728, 1301, 782, 729, 730, 1307, 786, 751, 752, 
       1312, 790, 768, 1513, 769, 373, 1404, 576, 388, 1414, 591, 403, 1426, 
       606, 1332, 418, 621, 1347, 433, 636, 1359, 448, 651, 1369, 463, 666, 
       1377, 478, 1460, 681, 493, 1470, 696, 508, 1482, 711, 523}], 
      Line3DBox[{333, 731, 732, 1302, 783, 733, 734, 1308, 787, 753, 1502, 
       754, 791, 770, 1514, 771, 374, 577, 1320, 389, 1415, 592, 404, 1427, 
       607, 1333, 419, 622, 1348, 434, 637, 1360, 449, 652, 1370, 464, 667, 
       1378, 479, 682, 1384, 494, 1471, 697, 509, 1483, 712, 524}], 
      Line3DBox[{334, 735, 736, 1303, 784, 737, 1494, 738, 788, 755, 1503, 
       756, 792, 772, 1515, 773, 375, 578, 1321, 390, 593, 1325, 405, 1428, 
       608, 1334, 420, 623, 1349, 435, 638, 1361, 450, 653, 1371, 465, 668, 
       1379, 480, 683, 1385, 495, 698, 1389, 510, 1484, 713, 525}], 
      Line3DBox[{335, 739, 1496, 741, 785, 742, 1498, 744, 789, 757, 1505, 
       759, 793, 774, 1517, 776, 376, 579, 1322, 391, 594, 1326, 406, 609, 
       1335, 1336, 421, 624, 1350, 436, 639, 1362, 451, 654, 1372, 466, 669, 
       1380, 481, 684, 1386, 496, 699, 1390, 511, 714, 1392, 526}], 
      Line3DBox[{341, 812, 803, 806, 804, 1304, 342, 548, 1310, 355, 558, 
       1314, 366, 569, 1317, 381, 1409, 584, 396, 1420, 599, 411, 1433, 614, 
       1341, 426, 629, 1354, 441, 644, 1365, 456, 659, 1374, 471, 674, 1381, 
       486, 1465, 689, 501, 1476, 704, 516, 1489, 719, 531}], 
      Line3DBox[{343, 539, 1305, 344, 549, 1311, 356, 559, 1315, 367, 570, 
       1318, 382, 585, 1323, 397, 1421, 600, 412, 1434, 615, 1342, 427, 630, 
       1355, 442, 645, 1366, 457, 660, 1375, 472, 675, 1382, 487, 690, 1387, 
       502, 1477, 705, 517, 1490, 720, 532}], 
      Line3DBox[{345, 745, 746, 1306, 346, 762, 1508, 763, 357, 560, 1316, 
       368, 571, 1319, 383, 586, 1324, 398, 601, 1327, 413, 1435, 616, 1343, 
       428, 631, 1356, 443, 646, 1367, 458, 661, 1376, 473, 676, 1383, 488, 
       691, 1388, 503, 706, 1391, 518, 1491, 778, 779, 780}], 
      Line3DBox[{519, 707, 777, 1478, 504, 692, 1466, 489, 677, 1456, 474, 
       662, 1448, 459, 647, 1442, 444, 632, 1438, 429, 617, 1436, 414, 1328, 
       602, 1422, 399, 587, 1410, 384, 572, 1400, 369, 561, 1396, 358, 550, 
       1395, 347, 540, 1393, 325, 533, 1493, 726, 781}], 
      Line3DBox[{527, 715, 1485, 512, 700, 1472, 497, 685, 1461, 482, 670, 
       1452, 467, 655, 1445, 452, 640, 1440, 437, 625, 1437, 422, 1337, 610, 
       1429, 407, 595, 1416, 392, 580, 1405, 377, 565, 1516, 775, 362, 554, 
       1504, 758, 351, 544, 1497, 743, 337, 537, 1495, 799, 740, 336}], 
      Line3DBox[{528, 716, 1486, 513, 701, 1473, 498, 686, 1462, 483, 671, 
       1453, 468, 656, 1446, 453, 641, 1441, 438, 1351, 626, 423, 1338, 611, 
       1430, 408, 596, 1417, 393, 581, 1406, 378, 566, 1397, 363, 555, 1506, 
       760, 352, 545, 1492, 723, 338, 1499, 538, 797, 810, 809, 798}], 
      Line3DBox[{529, 717, 1487, 514, 702, 1474, 499, 687, 1463, 484, 672, 
       1454, 469, 657, 1447, 454, 1363, 642, 439, 1352, 627, 424, 1339, 612, 
       1431, 409, 597, 1418, 394, 582, 1407, 379, 567, 1398, 364, 556, 1507, 
       761, 353, 1520, 546, 724, 339, 1500, 796, 795, 794, 721, 801, 800}], 
      Line3DBox[{530, 718, 1488, 515, 703, 1475, 500, 688, 1464, 485, 673, 
       1455, 470, 1373, 658, 455, 1364, 643, 440, 1353, 628, 425, 1340, 613, 
       1432, 410, 598, 1419, 395, 583, 1408, 380, 568, 1399, 365, 1313, 557, 
       354, 1309, 547, 725, 340, 808, 1522, 807, 805, 722, 811, 
       802}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxcenk0lf/3vRJpljJkniIiQpTSqUwloSjKUGQqiiJSSIqikEShiELmeR6O
ec48Zco83/tEylT5PZ/1tdZvrfdf1nqW9dzX3a9z9tn77MtnYnPBbD0NDc0c
HQ0NLfmXP39z2KR7FL5Zeh3WM0FgYowW8+pAMjCDi8WwVwy+czVSGR0isHBw
i+MTxjRQld2dY8IVh2EbElxMuwnsVdRP9c3PgIAyWS2nB4koebHANPsrga6v
NwcPHcgB+0UfAQptKn56Femflkvg8KCx6f3mAthncmJsGjKQfuHEbc+3BEqP
bPFnTS6B4NAVegWxXLT+FPT7+iUCTUKle09GV0IqjR0zT0ExMuw7TR9eRsV1
K3d/s9I0wpHcCwuWk9WYraDfurKdgjHx2pJx+Z2gtuT368TGDvxz0nnsxtQI
vtKr4In3H4VjOlHUW4rdWDXpf0q3pQtK3CkocmMKjJveXm1/WI838FXo+6fT
MHmmyT7XrA/ynNeP344rwREFM8XHp6lg5XRXUSy9BbhbtCxlWXIx6GCLlyon
AVWWKM59uA7Ce7o296mkoxfzfbs2ewKMn1HpCesKeL2/x3b4dioWZnoc1X1I
oNebStGywxWQv6teJW1dOtpltHYK6BEYztU0FvW7CgK2t0wZL2eggMZnWjsh
Atdvf2VpY1AHzWcm7jC4ZaPelbv3ffqoKDXz5Q9LQiMI7zt+Wr8xD1mtBKJN
blFRrcLDVj66BUL8BTWenUF0Go4qEMyi4Erj5e8f73TARHuk9nhFKQ67HNlz
z24GRS+4i//GHni/sMFR52QV3qIuXk2gm8Iu75pl29RBSNQReXz3/ldk2aZ2
Km1mBGO0XhTTMI6DEv9l1YmFZpzU4X++qaINp2ctnG6Oz8CY1vN+uzMtuCux
lfHc5gq4y6nhzi1LBWOfs1WPBRuQy+4ilOYOgpv2/U3ffSYh3HLJIXZ/FV5/
RtW7Kj4BLHadI7F7RyB9/w996s5S1GLOaqpVnYbzzK/y+9kHACpesuoxF6L7
eKOP3vAM+Ck0jHr4dENEpeWlk7rZGGj9of/zWSravVFjZihvhSHO1mBzqVy8
riXCmN1HQQrbsrzzng6oDpx/rmmTjyNddF+LVSnIFuO9zWSkC1at9peICRXh
6Dquf6wOM1jU0aGuotQLBX1pra9yi1Etuuuw2Jlp/Kp/wi9PYgA4bkKpck4p
Rta3K875TGJWY40LNWkIDpjJ63IxVeDXpAsJWT/H8NFhSdvCuFF4pl2UOhtT
ha83yAaF0g/j7OypcLvNk+C894sE//Za/PEioWfwbTeO9C25ahvNQBrPM3ku
hzp8wedjG9VUiTcCHL8M5VHh3G+xSkP2OrxRmvSt7kYWPMhk9N0hRMDysB8n
bqnB3MSWxZ1i7VCU0BiH3hQQPN/sFShYifVHCk5phg4AX8yEYljNFHDKajeY
S5fhywMJhRntI+Acf0qRs3EczCxLLXRDitFQuvlAR8Y4/GQ5KbnCMgqF6uZ3
xpLy8WiTrabOlhmUHjt5+dymfmhtPiHvaVSITL923n22fxo/6CdkP3AbAA3p
7PokJcRlQ02x5i1TKPqsViZfbAiYbQMO86cUI3Xc5IjR2wkcazpxcHLLCJzl
CO4SbyvBXBvJhvT0MbSKOTn8lmMM7Ex90vfRlmFzypxz2skRVDcQ0B3RnABb
B5OdesLl2G/2Y1KbfxCpb3L+3fWZgoPs1w6bc1dgj8bBodtPutF/0f31nc8z
YLpbjjeroAJbZb6LDGk14wYV14SaC1Twe9agLdxdgW2zq2q9lwrwIvOqTKQO
iWdnwLou0wrcsHuWf/pDPDSAKGe8GwErIkuF3NbleIM3wgbnasFbsIeZto8K
cOSfwl+2MhyZjEzw0O8Al/7kwrlgCnw7rnp7JKQENcOEg7qa+2DVQ7rz0uI0
RAT9CBBnK8bBJ90d74hBGKjLOh9ycAq+/TJTFqcUotIe5Qt7eidwfKbu3PP6
YdhiVTfhyIT40uPKY4XX4/hWXWP8qdoouL0+ktHMU4zrbv17S79xDPP1BJV+
9oyB7QjzqeWMYjzyQINzu+QIrlg5bPd0moCPb5QpB06W4EYhkc1cG4aQ+LHn
RwzrFGieVK0tyCvB5zduJiYt9+O2F2d2z0dNQ3Hxh5mrLKWo9LUlb8vhb+ia
v/wtfgcF+ghrhpzTpXgaa/kiW1pQS+l2TrEC2e8Xk+oek8+X/3gqVA5VIX25
Z1MgOwHb7nuoLTCWIvurmNYLsun4OShxOCaIgC7aE96XPpWgsrGM4Kv4SJC6
IT17OYGAUafy80hPnvN608cz1qVwUJtLlt+YAG0TXktrlWKMbu5qVINGcGRW
0HtdRoVdgrq3TvUXoZ8pX0eHTTtIOpzh0BmnQEoi7d/0PYWYzKK8NeNtN/Bd
qgsgBmZg+UdY1W35Isww6+tJUR1FRymlFfHgcRh75F9IU1KEJmd+rl6vGMYJ
3ZUTRX0TML9DIUX3CKKK3twSza4hnKeZMJ/gmoKOP/P3JN8jDln0ualKDKDv
RHeNzAWStw6In6MMIhpI3t7HJ9uLhZ4QvOXuDFzpZFgMXVeMXNlatOnpnWjk
vveegj0F+PYuPmlaQnz1mEZo30gLfr7YrNqsSYVunVdF5iWINj4S/FoZdTjD
aaO++ocKL0IWxc7pIfrtxp1brpSgpGlCtYgDAfY3Og+0YhG6Z+4UF8+KR/nW
cqV3OQRcN3Fv2venEOG77MHh0RAYPZXHVF5OwM/FuZrGXYX4VtDStjI2D0b5
pj4LhBFwoJuboXh7AX59sWvqZmslnJa99OK5GgEWLkd9HX7lYcjOq/K38htB
4S7/AjRTobh/51G+ply8/7Bf8PHfVhDmUM8Xk6dCtBczX8TRQtTr9E7f1DOI
r/kuydufmwJF8yXXc8qFeLrv4mKG9gC+Oso7N6cyDdcLPOWmjheiQVuWxJNr
fTjhy8EceHAGGl7XLxfsLUS3Pd27Yke/YUt000eWTRSofKJe67tQgEoFl+wV
FDpwmVe94VoNBcLvzPd+SytAUy3Ofx9tWtCrUJmh6TYVlJQcmahknwsbtu5t
2PYVLfiF+hx/U4GhjU5mw0g+ei9TjdI5K7DDf0BH34iAqyE1NAr6+SjBm/PW
QjUPI6LMZl9FEXBCT5LVuygPbYLMjL0mP+MVmYA29XoCdCceCnow5mHXiFy6
4Zk3oOWYLNnUSkBIUnOVvE4uhsn5G08KZcC6WPP+k0UEWHLLPpp9mYOtDUGc
6jol4DsgbOfoS4COutP3n4XZeF/QT1cBqqG1MzQ+W5WA6BXhyOtTWdh9tkY2
sK4BDrdNmblSqHD79q/t79/lo3kr0w6nij5kuPF4Vz7XDBw0EJa7dCEfr91m
OlQ21Y3HnKwcP7XNQO3+b3cS1+XjlWuFiyvznbgvrYSX7SEFrnEcS2SOzkMu
0WrD/ok2THj+rkZvBxWaSiguhpCHm5hmVivqmjF64brOsh8VvkW9tEr6movL
bwtdaFW/4uq6yuqFFSqoZr6pf34+F6O23PE6NlOJHhe32BReIOCx3BXzvLoc
fLvrR8flgGKMnCmgFX9DQJL4oeTzCjm4bgNzw4FXGfivobwupJiAFsvxBp+Y
bGzuty59e/Ej5nXz8Jd3EbCkKlLzdUs21hz2crub5AduIkGVxX0E7Gt7eP+R
VRaqa3r1X3icDM4WO2J+NJGfq3VnO2N1JlbXF/8tE86HqHbi33g6eS8qc6P9
/JlICQo23MVYBnxPdnjpPydg04SlhLRLBhoz5+ZMaFWD+c1d4tu1CBiZadx7
qiQXNVj5zIIGurDRh3fgiwYFtvUu5dBp5GKmUNA56QsduBrSrF3fQoGDyzz9
wR05aGFzafvZvFZUsNeLdyR1pc+Hi6rb9XPw99Xnyqc5m7GwbnzTsWQqcO64
sSO0Jxt9K44PKy/Uoxeb1qdBegLY4nfFhehl41uvuNWA7Crcrci/wVKTgHhz
289PWrLw+PLMeU63Uix9qbhpgxcBcU9s3AfPZKGjsTnDsaQ8VFA/08aRQcDq
Oh5xDczEgLx1jglPU/CTTNaek80ETG/1P2QlnYneN+/Jn5ALwfYOiZOigwQc
anPk7o3OwKdc+ppg5QWnuuy+xY0QkCp5k/8kewZKRRvsH1CLhT1JQ93xvQTo
7XlBI+2bjp48HB172zJhdxwKCNYS4E8ZKATadGSdmmivyCiCd2NPnu5MIuep
27zOhFMaqqQJuc5ElIHMDLy7S57fXeAtr+GPbLRY5xpQQG3DdZcLj91hpUK8
+MOcQPNsXM2UpIYnt2DvwECQpCMVRDpF32v2ZaF9i8IJb9smpLqbiUEdFZYi
FuOCdLJQeeGe8j6LetzCvXmqaBeJp3Vr2rP6TKTRdtvh9KsK9zReFZsh71f0
7iSnunImnp12iSr1K8NH3AVqHE8IaHjQf4kFM/CetfS90btFuPuHT1hmHAGf
6HKkuOUz8PoWJuUT05m4+umWjGw1Acl2w7JhWenY/ylFejdnPJ6L9jsvROJj
uE5ttkkmHYXoI08PPgpEraPNv/eME+B6JUmYyEjDA2+fDSx0PoVe2nK3hEkC
xjdxSB6QS8Orm6wCTuJnOB2yx92FxL9fq6WuKD8VZQte/DGdTgXXq9umxcm+
OCYveLX+VCoaP5S+ZHUsFyxB8oVhBQFMygfuO9en4CWXbWLZ+4ohIi7o5xdy
zj5d7aM+hSwMMRq+r1TRjBH8PnUhH8g5fqDriWFCJhZ9+hUnEdaIj77IdtQM
U4Hd3tGzmTMTR/e4+/jm1+Hzq0Y+rbwESGjybUKyb9V/7aaZHanCfx83XNt6
kXy/0LT2doYMfHn7QboVZzn2Ti1wt5A6qo5HSjjZPR3dFG21u68XY8/4o4Pe
nwmgZdhQFkSTjoIi+zsKnHIxQDewLpzkAeK44Xjh4zR8xCQIeD4NpaTfS7m3
EzD/lT2Uhz4Nz+n89ZT+HI2RuRs5Pw0TkDLF25Ptk4rSPOwb5uf8caOsgMS9
aQI672VNubOl4h39SD8b88ew9fBc4k0KAQWNBcHO0SkYFpU4XHghApjCPdXm
Sfw9T/u1hcul4IYAlQyNH4kgqf9gnxvZF79yz2bWv03Gp49yGePYMgE8CzY7
tRGwuOOOsH9lEv7tq3uVvjkfamlF4pXLCLj0JDVpR3YGLj+ymeyxb8DKk0+S
dixR4TOr9oMZvgwUGvquO72xDpc/MBxSEyfPCckvz71OR3+bqs59sVWoN/gt
6dYV0l8OHWcZ3piOnziFMOZyOfIsNcl1kXjqSJ/NtHBPw/tiC7w67CW48EM4
aeIjeR6WWJ2wdWmon7HffqIzHx/vWxz4m0fAlQqaHC2PVNRm3u+iE5aJotyx
TfcaCbirKfD73LZUXB7+9vPbzmS0fydMl9hPgHdJZMiN4BTkHknNHJP8hLmV
9Mt/Jwh4Vv334wORFJzKf2vgYOWLx6tYIoupBCjuYxzOfJCMOxz80mecXYCm
w4NG7QcBDEcevf4am4SHDrwM9TX4AP/OhHdOk/jfuDkUs/g9EWWEFoykjGPh
zTMpq3myL3LZegp/cybizslC/qsjqSB0ckQniTzPry8Dx7yvJaCifelU5VwW
lD8Lt7zWQkAPy70ZLd105LFO5k28VIspnjlW5YcJ8Eq7kSlTnobnt/iuelyq
wrtUGQGlayQ+0dkyOWR/SUn9Yz9qXo68so+0TrkT4Pij1NsyNRUD3wRp83mW
YMktvnGWcAJkbvE++S6ZiulPHbNmrAvRHFaRJZuAWyzpz0oyU3A4XiW+gpqN
Z9qFbQNI3lvoPSRUACk4k1O+e9E/DQdP8Iv1fCPrzfjdnk0fklG8xjSBNTEO
dbz50w6Pknxy/trRxLIk5I9lM2y9/xG/Hf6p8HOGgL+H7fPG5xLxcrZG9S92
bxQO0PLQmCWgUfhsgrJoIiodvTFDq+EEjOFi+d5zBOx5d7/F4EYCciTe/dAg
FQwOzKvBIyT+Riu7g2qT43H6uqMbZ00UeLcH2QWS73/pOCMh/TcOK9JZm0Zy
k+CwZ7lyK3keXfX8nyfOx+HuP4KxNlnpEC0739JE8hgIVsSd40rDU79eXpZa
qkSpLb+W9piT30voisE531Ssnl+lEbxYjp6v9ybaPSUgIS+c4yl9Kk5dcjAX
LynBv0NFex+ROpPpiIKMhUcKOrSLOZk9KMIfrsePeJFzamGvzeqDzSk4+Pzl
BY7Xueioyi3ZXUnygMGCUoRoMq5mP1TiqsnAJ1fr/mSSPOBqbNjHcDYJab0G
jP5wpyDPyj8bA7JPe6rYrO7fS8QqCW+L+0IxWGHOaL1pigCqqKSFemwCTiul
VmsHvsf+GEuWXwQBfi6hucRoPH6rkOuOi/LE0JeSDDo/CdD6lCbXLRqP679O
seX8vAdHjRRddOcJEK5w3uDnGIcd7GKxd3sDQblY1F2c/P8dkoPnQutisWbX
ni8C45FAV/KFdx2J/1bp0/KBQrHIcCT26NO4OKh63OK9TJ7n4u+LK+zPv2CQ
ZMfPDs5U4PRLUAKS52ULLLx+b0jF/q4BLlupcmT7mD9O94wAvMXMwvgwBRnM
wj4c7y3BiYiSujQSz1MvK6LPzCbjQHeFo/p+xGdiDqVLaQS0rVO+IbuchOG8
WVcCC/LQ2XbrCgep/2usliTbdyShkr67fyipm/bPv228SPYRS5tezMGDiZiZ
cPXOR7I/YmXahb+T+orV8Vq+rWECapf8nauCBCzhjWiZHiOgOc5itT4gHv8Z
8FafVf2MXOv3dsaTfU0fPyb8pjUOZXfNlQYzBKPQ1oiis2R9ilysuynIGYdM
/+L2HWl/gnLBYl3zJJ6hO+4UTFnHoqu1s+2ZI3ZQXXrX4esvcp6mW61cq/iC
E1Mfyjn2BsDOrqR9S+T/fyxkdt269wumi9x30PD9CLma64l35Pt7dja3Ob+I
QR0TI9ZW/Rj44JF6s47kpdP5L7PVFqPx1nR0v/OfRLDl/bI58X9zliagJk6F
1GEh9yPUPEax6gSt49ZtY/Dtovtfl9AO/KESwikQVYzM0TOjD6Mo0KSyZyWj
swW5pdLmxXYPgvgf63PqRpPw6e+6FzyrX3Hl69lVaYFvuC0g2+eH/QwUvnn/
l7GoEWN3cl6tvZOMrUIPRgR/UGFwwyGXkuKv2Fpqsd1AsAXUpWu7MyooYCxy
+A6bVyI+++bpRM0n8H1109Inm0IYpxtL9TybgHqTIoNqZQS2TltyuGTkg8ad
AFad1Ww0rDM3+8VNoDNhzLGgXAeFb+tfs18txqq4S0pdr2YwX/TaXpcvPTDB
vEnvdncBRs8IKu+OoaJi8m/n52NNoNizk25yohS1XOIGbm6cxozgb4a/HAZg
r5AOUzZfKVJZNH/F5VEwSiLYimagHUr5Z0TK91ei9HapgYf2E0j5JdViPDgM
xwaGvXqPVGPFg8LDf4Omkc/7rjL3rn5oYooo+s1di7KJRd3ctCO4eSW1cWLP
BMS3bGWlOjXhld/u7OA+gAz/bh5Q3TsFWxhjaAZTSZ1n1xX7XDALe1g9y0Me
kDpw+tEse00+FrNYOA7spwLHhIKfhUgb7DGwc5zKycG6220F3s+ocO7x44NZ
wi1gG995cBep290/bhHfu4+KGdnWKw9utsGVc6PbZmaK8BZ9o4bT6WkMYXbX
oyoNQJBi/Lqo5gL8Gfq7mOpJwXhjx0jxd51g8lJXwOtrMV4287y7eXYS037u
uqh2agg4Dfb7uOmUYsXv9xEtbBPoEcD1jNZnBL5fEWc/sr4cg3td1sm+HEUP
LVf3RzzjwCDDEv4xtwIffIik+bltCP/eKKsS7pkEqTitEYXjVTjJuLRTsb0b
NWz5hykOM5DdFBzQKlONs+3einv8G5At8whDEokD4w+jb++Uq/HUatjIc65I
NMrZELiX5GGH0yYXOuxLsKfLz3zUbRLUS/lvSrYNwabXTwPZPhSgSt6uXyrK
M7hBuojFibsPOFosn2j8b298cUKSrn4Cd01oTyh3DQPKjM1tvluM7ErXmuhV
x5FBhzPsu/8oaBTMbLJWKUHp4zKae81Gcaucn12o+TjINn+vn2EtxR13bD7m
7x5GPjGek0FnJmFFiCE4tbMUnVmDDQ6qDuCST+yjTXunQa5t5TXb3TLsVqXz
N6d8w8CWHbwvvs2AjnGR78HmMpxNEFNTudKCCm8StOpOUOHwJmXb38qpqEFb
026tXI7F33PcMj0IsJ1u3iNJ6r3XxtFO4h4V+LPcJ6fdkYAwejNrebovSM/T
5nPYJQHi1GTFVUi+1cwdkeM+GYMPD2x4mZgaB75cGz+bknNw73zriQjHaFQL
5FLiHSNQp7w6kTqbAhhrP73aX4BnF/4cT+Ci4gmRLN13Zm3gZv6j6ApTCbrB
z1J6cQqeeyhrItjXBdEPKjyKG8sxK9W1/Prdafy95YLHPrnvkPuws2SfcC2a
cvxjXZ4fxw8D1Jb3B0bg2ZWnNP9aMjFe1UWvkPQhTtH8Ra0LVWD9eovC19wC
9NaiT1s3MYPv1/lF3n3UDeVNoo67chCrNL6Vx1KmcbOlT953uX5Qaj4WdDqx
BDs3PXjw+vEU9m12EWK4NgjrQqxGnnWXoZ7818n91yfQ/v7bGw+5RsBKy/nF
yOVK3P8ruKZVYhTbOS9+Pn9hHP4qGbRNTFfjTvu8D08tBzBccKmgp2QKXh76
sX/TbC0+/1cytcGiFQXLtN/GF1LAM3f5gpZnHer8ShQNuh2DR44bHvKXI3UX
2/GEfz8Qb/69tn6D1xSkcdIQu2wG4TWNybU8tSI8cFnkYfvnKfRV099zQWsQ
ChpSLm0XKkap18/pMw0nsTriq+sc8zBYucppD0IJDp19On0ucxyZH0ys37t9
FKqY7E5esyrFQ193DXj6jqKtp4WirdQ4NOR8NLR7V4b7/m6jN6oZwlGhrZL/
bCaBtbhshDu+HD+N+U8wBvaj/JauvDcR0yAqXyFh/7ACqTqOWvS7O7DRbfqR
tA8Fxjc+CtiEKfi7LdPXiK4MQ96/NDwXQEDF5RdiWbkxyElTK76PJgX2ug46
iJJ6Ve2hj9n6e7HIlvrwiEongf4Kac7MrFnwPPpa//c72Rj7lvreeIEKocKb
b40yNoB+7M3dgYKp+OeY04nTx8qx5O7hawaeBNx8Vs10yTkGd3qw9VipJMIm
qt3yL3JOXdao1WfpacdY8SdfjRQbQcL0ozrNFgo8yXhtHmzXhqfiw36kbIsF
f/vDOVynqeAq4pWfPN6E4Ucf34LoLnjqPJtcdHYGuheu2P562Ibc7mIrkzZ9
6L14sZv+8RQYvpcw4zjchM6WJWzlaVNY93irz4GL3+FsUrdba2k9hmvGfLly
fRKlqrp/vmQfAlqXj/af0xvRfL/Tz5Nqo3ghSqTd1WsM7FrFLvnw9eLNGeaj
fkZ1WDOytC1pahpo5+/4qqd2Yuvv0kkmsy7MEXFT6+WYhjBeYb9NSt9w4ZdO
VVNpOjTppWxYr06Bfek2W7q3tmFpQvBkl2gT1vtYbL1wlgKJfOmZaNqKypzr
Pe7Kj4NxQdLiudJhcCzXUjvR2Y7CW7MUY0y+g1uU0YJ07CSMnZ24TJn+gluz
UvNcvhEoMXeoWMAmE7okLPuoThk4fsmO39CUgDO3Vvl9wiuhfi+7SvFgCu4/
6XTLMrQMDY5x3lHxISDpXmGRvW4M2hxKFxJYTAL6XTcjHUkf9NeRTqZvKQrn
2WoPvRwncH3Yn5qeWymw5fBjiix7Fi7sWAwrZyLAkv1JXMSTerj2W06U53Qq
Do8tco10lmN+1oep7Eek7pJYrHvCGYOmmTTTdnoJsP+uaCET6Vt59MH+SGAN
3nxwNHZwbBJGTWO+y8UPwum/n1gVtzVi2geryxnpY4B6t6y+iI2CE8s3+zNp
TTjAxP6m4cMgzEgyR5hemwSNzywnOGVasfWagmKnyyiyjMwZOCaOwnvzM0P7
hZrRyPr1jgb2cfj8+f7z+zdG4MZS62T9XAXu4DkeftOQAu07+SqvznZAsWIF
3caftfjq6hHt7vwpiGZjYGo+PgCjmmf3PmxMwxJBEZFyAwJdg7aKModXwfri
43Tv7sei/WtD7vBeAtvkJZ73MmZAvmx8bYhzBkadY8m+L03gx3JwfPSkFmrw
KnOpXALauY13JLcQKLCOc3fdcBZ4v9Pf9dU3C63jRI05lqnob79cZL6jAbau
H5EKLElGqdANVrzlBBq/+Mr7zC0PMhbsNb1EyLk/LmadReqcJr0XPObQDAEq
jRyD8qQv/hStl5BI4NNjwikbVBFcErbT0jhn4iU2Xq3M5wQaCC17lVFKoce5
gKlBLg8JQSUVdxUCdQ22FV1Jr4KatZyabi2nPriWU5u892f/MF2FpVsLJKU1
KTj0OLMnOb8DpsUTNhuk1KMe4zHljTmjqJ+7Y0HKeAyWvq5qZ5xvRibhcOH7
W3rQnbY25lfiNCwmc1zbl9GCRpeGY/e7vsPV8YmYybdUcFjr6761vr6/1tfX
fhhdkgqrwsD95iduzs3Awgr/3uW3XTAU6j3nU1aHLM4jbWfOj4C1i8ZOk7xx
2LCexuCPWTE+VG+mwydUyH8/Z//PthluJh1Pu/OzAg1lDpuJb5gEmke9b69L
DINrwsXeMeUcDNE/7rRRlIBlgvVUoGUt7ND90FH2qQRPDGm6uT+ahltDM/7v
Pb5D3qGpYp+FHDSw2H+Zc4aC91+FdKo2toODW05JwGAeCkWq8w3epqCBE98o
jXQXvNhYlx7IXIhXNFW5ZOtn0GZhnO/sbDc0rM27srV5x7I274zNl9m3f63B
5c03vS8d6MVt9WwVF1anQcU0IWbrqTrMFX4YVfC9AVeOtQ8YqlPh6Ym61R2O
dfhAd8P9nU+8cFV7UP/FCXLeun7nNVCtxVvn97yX/1MLcx6RTiqBVNjb6/bc
Znc1Hu2dbYhr/gZ3xW7IxsbMgIqPGjA4VGBdEksBZA6CZ8+XjVkcU2C5+tXK
aqQU7/nXzZyUHYXTpzplT7qMw+TNtqcVIoW4vYbx6UdSZ94krIUSzg9Ajsrx
lsrqImQU6Nxy/PIUvv1kViSIgxB3W3Be5Ewx3h/jkWEQn8R7C9Rf/DrDcHtt
DvauzUGOtTmokv36c2ByBd4+s3/x+tMWPPDzjVfLXip8fFExggMVKPd3Pe3l
i2V4mb9AZus+AuhoRdMeRlbgvrbl4R56N6zqECYGvQhI/xFUp7xUjgEdTBMZ
y8VQnzQyOKhKwGH73iS3pTJ8Tt3BWtHVBEw/rWNoHalwZ6/wQnNxKdqaJimG
neqCH1+57tEqkPz8r+Glx60SXL/56M/cd/1wiMmAVb58GhjsBxLuEUXIYOMX
UVgwjmW3JjeOcYzCROj61L8LiJnuUd0m1mP4ylG0SvjBGIhhXNHPR8VYrRl8
+MrICKnHfm2KGhoH0yM80X/+FaPBv40+D7iHUeQ0MFhqTEJB5ztUsStBHYHh
G3+ZB9HY6/356fQpqLN7rDXfXoJqvtarIv59OGL7ZlpoI9kv7EFmL3lK0cLH
rOGETRcebH9fuEueAv1r+absWr6ps5Zvth9QlE86W4pA5dd0Da/Blm0KtOc3
kP7XenjiqmApjl+XeyVikocM2Tu75R8TsG1lXxdnawnuCuzwvjh/D4uZOrcy
phBQdaXKzUO/BM3cjJUbebJBIJm0Ga8JaI9Y8RssK0b+D9yfMk5VgbrB0vcW
CQKs961L3r27GG/wrF82ZW0GX6VbJ/gCqPAiLnmQ+FKECnEsN0RYO0BN75tw
cg0FRu/qazalFuEvrcYrhb+HsXfB+L1z1gSI+rOZu3Ej0jvYBj57PIQcIVUl
vk2T0EfNeVPyEFHy/gs60fEB3EQ5r+QzNAWQbGsSWo545m+q7SfNfuSwk+5a
HZsGJpZ363jnEXs73mX89urGV9Yfv9B3zcDu5Kt5g+uL8YgPq/3JJx3IwbpR
LyGZAhvipeoLfiHq6PFZhiq14LzS4xdnLanwbS3fvLCWb1LW8s3bwkLVNywR
tSWKR1hjSlHIxoLh3w0CTlQkXJ2eKiL95CkXy93p2Cw9HcicSEAp3Pe0OluE
m804/tZ/tUE1UwrbtUoClK47UUt8ClHpoMXUUEYK1F53iovKJkA63YuuNKsA
PzrfFJQcL4aH71yi2J8S8DqWVqm5Lh8zu6mtTow1oOqKPbSSBKB/UbFLSx4+
E+1fyjFpAqvd+5Y1iqkwIhSdbKlciIsjLmGGHgPI5vzQd2XfNGhcXp6nnCrE
Cx8YKvNl+nH3u3vyx5amoUe8+9Q1qUJs1f0ekinbg6s2H3Wt8mdAcpvBdWkm
8j02u9+b7u7COdPcs23WFAj7F8B4aLAAd0M/Q3BLGzq5dXcubKbCYpvph/Cw
AuRw+uTH69iMBeH5g3FkPcxL/W4SViP9XZDXm+M76/HL61FfKTqy39fyTbu1
fLN9Ld9Mbd8r2XMrH7camrQcVi1A4ZF1f2+GkTg80uOWnshDA8PM9KftCeiT
niflU0FA4JRZYYpOHu7XvDS/dZsl5k0+s37aRoCY3kme45m5mDyx3m7nsVi4
NlknEFhPQNCuR1azW3Jx1clvdnNILvBcEt10O5mAlKgbgz+v5GCo1k8XS8Yy
kKHeFdtG6p8lmj3VNz9n4/ffctq4swYOsNRofVYg4OhrPZpdBvm44xqt4jbV
Hry3V7K9smgGOP/657ux5qOq8WnT2fQunLJ2YVfVpsBX/iziaS15/pBXNnw7
OrD1+HZiVzcFMv84Rv6wz0PviBGOWf1WPExfdVv6AhW2ZNctVLLkYXPGRMjS
hyakKJ5+NZhHhTw9/4vHUnLxTI36KENaHUbfV/0ZuIvkw7ZxTD+ZixsvO8VM
8FXiPu4ai40GBLit5Zuea/nmp7V800kx8M68Zg62Jl77WyKQhaZXOJYFCgjQ
m+2v023IRpNvOd1+XtHIUhvI+YzEc25rmki1ajYepAs3yGwwQVampSaGfgKs
GFaeSBdm4VevivHG7E+wc69M2NNvBLzse7bkLZGFtarH/J8xZADXvj3qv6sI
GAmlNygIz0SuY2/uyowXQr79zSnbOAJ+/mYJTdieiScU7Ia+5JTBQLaJAIs7
AT6pf+VZDHNxe+1lj6DPHag5fkBoexkFDn1RbHj1Kwc9dib/ETNuQ8/iUT5T
MSrEXJ6QKvDOwW4GU57nbC2oNlpve82bCvF/82lyOXOwSfeJbFFwI75X1qZ2
9FIhdlUqND8+G98s69I109Rh5HHFyVwBAq6eUXm+6XA2toZ+hciblVjqoeu1
5yoByccdX/4uycJLcg3vzHtKcNR3nQO/HwFf1vJN/f/km06brYW5mjNxUv/s
imJtKnq+qmK40EA+Z/iWtl83Ez8PmcVls0aismX8ySsknsLCKkwPejPQmSlS
JFDGCK9QxcoLRwjgG1T9a2ecgRT5ONndMeGQp+4pwjRE9sUQx8LjsXTseVNm
/4Y1BQQ0fvz61UFAZCdnxEbrdAw9tmV23bYceD/AY7itnLyvDNVrJnNpmGBY
pyVahfBHPk55NZb0d6F8+07dz8ZSvd6+gYUWLKULMm2wosI5qf5SI5psLGcO
7+qhacbjFFU8nE2FTXQ3/xU+z0JnuyG/7SwNWCBfFFmxRIWNnykrdjuzUM3V
WeiaRC1W805tCpYm4OCiLPf7kEysCpHcJaRViXOrnK4jpL+ROGZopiuYiaxW
SfsyHpRi3m+F5lHS15hFCg3XJmWgZJDmcwuTQnxsyZcxmkR+r7V8U/0/+eaJ
jRxvr1SlY46g0pMW6URsK2fWEOgm4IeG/dGii+kYds1bMynpA247J3tKaJQA
42rRW3dG09Aw6iudaLUeCrpzpH4m/Wwqo8mrEIc09KraCBt+BwPfz95ietJP
/XQdf2O4KQ3zGwb4Ky3jIDZCoTFzgACNjvUvej6k4uuj73FzcTqoxxKnOMh+
MaHWXpSSScWjtYEeOjx5sO6BuGt4KennZOcqd2ImBl3V+MO6vQn3/wh6Zt9D
Ba+hXzkyJzPR66P58nBGPTbwpDxXJ/2Z8v6OqN6KDJT/sb1P4FIN6motNlw+
RZA4n7/7Vz0DlxjXVZ5fV4n02THBXVYEcOfemPHtSMf3Bl2rqdml+MRa/u0m
sj6zg2VGX5iko5dOr1fbfBGysXKwHEwgwPXuotnsjzSUvMIxvD4wB0Xu7TgS
VPb/803rtXxTei3fHPqWc6qcOQ2rO742GJl+wdN1P/YeIuvQouDWR56EVJRX
1qQWVr/DJ/cOHtk2Req3BraNzUqpyCWgcO93qg4atvS4XKQQ4FyfP9/1PQX9
zyhfqU8IhGduvfJ6MwR4cGcclHNJwY2ZOulHt0fDdYFcB6NxAh5PSKdMcaZg
Y3T4J3e3FJjifeWfTPbL0SPmlCGXZPz2w2sDS2cmsMnbUF+1EMDunstYLZOB
X10HbrTdq8OUzpwlVmEC9vQHPPbJInEYthBQfVyNjx22zKVokucpLyo8eCwd
Fy53Ppx+W4Ev+2KOstkRIPPe5eqLijTUHhBPvJ5XiuoS52df+BOgyUDdde9C
GlYuDWU+aEE04jmkpBZPQL2t95/6oVR0Y9zvO3ImD3V9b/D7FxOwfjfPXnuH
VAzdNavS0pOB/uUdIx+aCbizlm9++0++2WF94BX9lxQsdrp2RTzxM/Jt6Zyb
JXEoY16ZiFVOwXV/ihTXrwtEmcO0bJkkntTLEqzK9cm4xdtF7qL3eUxSfmZ/
4AcBg1a91dlMyRi0/C9B1Og1OHkonnxDEFCoo3/iqVES5twa8wtLjQTnI7St
7CT+lqFa/E+TE7Hb5MWswUo8rP6ZeDJP9sv2mw9lXtMl4u5nYWdVPNPgpftg
5Pk+cp6+nQPsSEO2rL7V/KwqNDmzyBmoT8DkB/NjzPpp2MMizBHIX4FpMtwU
sQcERK3WMmwfScUrfzoc7oWU4nfOwJAKch7VG/7Ku3knFbvVBsR9uIvxSlii
1FsSz6fUDWGz61NxKYdSRmOUj7/qav52FpH3aPLw/a13KSjwKoir6W0WNhfx
2RaQvBodaZuXeDAFhfVPp0RNpWJTfS+XYw8B+Wv55s61fPPiWr6pe3WVke57
El6Yu2x+DyMwSXClWoTEQSB16PlV4SQ0iDgyn0z/Gg9vvHHOncQTeflo2+4l
4vSz23fWc2og9whzqPUcAbM97wf4ahOQ5V7mcIynHxwtesW/k3wu3Xtk21bB
BOxq9Zax2/IRKndvtg0i8U9wb8/UexKPumocvx7SfYHisO/SfNNkf8Xv2Ng8
Hod80uevmTUlg2Jqjnobyf/3Tmy7d+ZjKlqe/5BSGVuOLhqN77vdCGg1ks2I
3JeK0RoOXlfMS/GNWWrzuXcE1BJHN9NlpeDYODfP0IFi/CHEzBFN9nuf6bkT
AqdTcNg1IieIvgBzdu9/sIvE85O78pJ1YTLuO7R+89/KbFScmvAsI/VS3vb5
YytzSdig/fdLYVg6Xg+/8Wywi/QLFOpFJ8kkPBcKKmIcyXjWpNMziOSB7rV8
M3kt36xcyzdbnFR2zpYmIFc9S7VlfRguT8zKXyFx+OD++dIiSwIe8FRk4VP1
Q+qp9c8zSNw+VAx5HL0Tj0E7/3GF86ihJePPzsPzBJi2Wknfao5DhWtbTUMu
vwCnMxlTdORzi+DLzUpycVjPMRh1qTMUrJlDGg+T72F/U37ONTIWPYOTXPd0
fYbDkvRLM1SyruJP5n1jisUjR58cefQ+Hh6d9Nc8Rp4zISabh/VlClbT8XC8
EipFOuvIv5OhBNxWWBm/uicF6Q+YZ1gLF6PN+yF3YXIeyU7ZpgrrJqNfWZSA
oXkBFnwmRJYLSf2gOHVbwyMJrWN15i+8yUHKWSu/p3VkXW2r8AoqSET5wbM6
Z7oycJt5qtUMOa8p7yrDbf4koDH9rfz6g6l4m1Dmu0jOlzqf87wXlRKwxKzF
rOlEPEpzEUPfSR5oWss3J9fyTe61fPPWVZmE1Ok4XO9wc9ZmKQSzWMsvt8yS
fFViMiygFocP4ysrDUxfYJS4d9k9EreamPOuNUmx2N2ba7p1UAVdnWssk38R
cH3L+ycae2Ixzu3zzJufz8B6N+Put+Tz4GdnY0y9viAuExd3mLyDrFVabkXy
PUe97neU/otBv91ZwWUnIyHmbvWTavJzR0eTeDrnU3EuObZd7x6BZto9Fd9j
K+D3+u6JHdlpuCQ9+MbCnMDSzS9jI1srwefBiVXbmHR8vn/zeUKPwCqds8PG
5VVQ6Bt7ccNwBobXCfH6nyYw1fvqIktbNRRdjOcYvluPuR8KXme0jGHVTWOV
WuVRoLOfuvyKpgWdx93OL5wdQInFb9R++ilynp+5qkDqNpsM1x93kijA69nh
oinZAX6PBB3YVXLwzYenLc68VGSRF9sok9EGnE4jYrS2udiwyXpicoaCZSsH
Q/aVtoMsv3/UrrE8/DxfMvWhmoKPuxJi0292QNpaTjexltP1reV0BiN3/Q2P
1CJTwuF353j78VrcaxMWh2lYEl7cZTpVj8FM5s17TVuw54WyKg/pl0X6PAMf
RjegWgnd3EzDO/xhpycttYPsu7V8dmQtnz27ls/6iy36U0Tq8OzSGFSdHwQL
dsW+O5umgJHFapAqX4k/7YeHXMzGod7JoiuFcxTOxPcaj6QVoGhUFPOmz9P4
JCisLtr2O6yA0KWJdUUYWWDcsiI3jYHHdazOWAzAsf6Tu6qCETe1aCdkxU5h
Ss/EZSsYhBtr+ePptfyxZi1/PEsx0S0SrUQXqY6n/EWtuLF4qfUElQLXHc97
mu2uwquqfUQ9qaunY67wLy9SoaVZUFnudRX2jW7bL1jsjUrTx2YlyfkbC+9+
TTdV4XS0/a+v3GXQ3tJoaUL6naPrDbNutVTiaC0EuoS3g/fTw0wJrykwP7Ry
aHxDBb62EDvcKjkAxomiF9vZpmFZtFGxurUU1aL+6OxwGYHj39wUlHknAFN3
f2PBIpRYaM/hPDSBEtuxzff1CHy2sDgt1o4YO3UR2+6N47be/eKXzEYh0s9a
tcSrGP85u+XUeY+haF5d2qGLY6C5lj/yreWPnGv542mG7Jd+yaX4SiTnyznu
OtQ4T/dQboYKHb+v0T3ZXobdr18n5nYh2u61261H6mG9fbd+8yiX4QOHfpZN
RwKwaoE7UiyCgOVoLQn3o2XIs5khSl0/F/Iexl85Qc5TLo/iucPfS9G7yihF
278eCLOT313bSZ9o7dG1XqIU/wRuDzvI1wH+WbsesJD1Lmycy8QsX4IS3c9O
HLTuAxGF+jvzLDPw1rqvX76gCDlqaI4lOYxg1cZ/YcXqE/B95V8YnS6pbwzF
5oxfDGPtdFP9M4ZJ6Biil5CiL0Z3NgEXX5chFHDR0uxpmISX+toWoreL0cFv
PS/vqUGMGdEO6YuYglP/FNS+DRZjs+eD68ZB37G44KCVhvs0RCg3u+81LMHA
MfstxM5epLOtroi/NQMarxRYvbpKULHohbJIVydSW7f/oehToGttD3ZgbQ92
aW0PFue4o6marhhDM0cCV6bKcNrZdXrpCgGJRSpJMnzFeDtkhOvDVdLnMpqY
7gkneQ+unLYVLcb3t5M+39vyHCv8EmrbSd6OPdd7/cyeYrw873m3dH0aNB77
996Z9Ke3Mow4PjYi/k2purB+dznodbRZniXfz8d+utNIGPGrG01cmlEjmB9Y
lNavosKSwOZ/U8eK0NeD2afrZDvoBp/9xj5HgZSHZ/rU7Aox5u2OP9tWBlDU
7NPzo9+nwOf5+IJsbiFunLxue4t2AG2Y3Rtv20/DTlo7mo4tRXiwkaOZtGbI
fubMgZBtM9AuoZYtaVmEXwzKI+Vv9KDb5DvTq3EzEBlhLO1fU4QxRlLCM+Fd
WF/w4ObIaQpELbz9d1kEkSXthLuefTtaUJ7GnRulQPgOjSDRR4gCdicUaPub
EaU0N9k5UaFhbQ+msrYHo67twWS+LIddoeTjfPef1jOzhSgQY/zUO4gAuVOB
X09P5+Ouo8fLdJ6nIFszLw1B4jmpx/SOqzMfu3w4Z00Ou6Fkr16kcCMBos5Z
wTNx+fhpuvPUpuE44Ez4eSmK9KdVjKE86ib52Hvc/s7DuEJgD1V+6xxMwENr
Od+mZZJvl7YFBB+oAoHvEUn8agRs3Sq6Vco+D595F08EfmiEdHNt/6k2KvRk
6FccDc7HSJ+tn5i29+LGlWD6Jp8ZsEh/b7Alkjz/ehXH45Ld6HQy87Xqvxmo
5Y4L60/JR7bxK+6Lgl1IV8m9rvQ2BY7LDM38KM0njfKRqc+j7Rhfs8VdtJ8C
Na5s+j/a8vHi+zFKjnUrGm26L/RWjQqru7u1OIfzUWmL8YpZVhMWlWioQCoV
IpwedztM5qObtt35a+516FFrf8xvOwH/Wv9vD2a9tgfrXNuDXdp7oLU4Iwdn
R5RP/W/vImfOZvAlm4ClE/5BAW9zsCOOpmKPRSxWTKXeXibxzMmu6ta8k4Mj
p6mZY4KOeHPl1o07pP89dLXT+inkoGZWiZd622dgcXqoqE/605dpJjf0aHLw
TpHDgYGqLEBpB1TOJ2CfQvjziLRsbDo3cdOsrATybW6GyZJ+fOTckPnkxWzs
fxMw5XayGiQ+OBS0nSb9y/WAyZMfcnE0aphjRbkTVW7rH133iQKS6wbevHHN
xcOvvo5u923H0ZXBZYHfFKh4EbHF+nouNvccjpbLbMUk56gt91WpsJgfl9x1
Jhe/2P+z9MtpxuBmo+M0QWQdzj3O65LIRdlRLZnjYo14PvTSM8MBKkQpLnfe
3JWLEvIp+qwhtajB0X+vW5DUaQ4vj0fO5SDj+0n56/kV+PjXH61HxgTcX9uD
uf1nD1Y5LqAqz5+F4vR/V3eFpKFcpsDBIFKnHX55R853IRMPH/bYfZH7M35q
b1O3IX0EC7t4mmt1Jjq2Cb9pOHoHs5oHHeRI3bv/UsPlqYBMbOCq2UwJ/QjC
4zFWHqSP47SB+p96mcjaZuety5AGaQE7dbeS98XGZMG3gTUTp7pluo5sKYAY
dsxNSiPAToE3tOZrBs4XHVTW5S8DClW79+VzAtToJ5RcMrNxaibkauL9Vjy4
fqd06iUq5EhElLW4ZiPb43XW9JRmlLN+ULnrDRXe+X1O3HY2G93Cn6xjVWtC
7ln3+J2NVEjnFNOZYMtG9SfBqo5cX7HO8OzSHD0BghodaeLjWcgY3ni+3b4G
Rcq7GDvkCeD2+PsaM7LQvydA/W5IBZrLHODJvUHWbRPjaqhbFu6x+Oic6kfy
dM95e4/XpI9Y24Nd+M8erKhpn3X9pgwU2T6ZrW6WhDvYtC5fJX1E8w/GA6Zd
6Rgvsc5ol/ZH5N5wL3X/MAHzfV1a4lHp+KdFwIvifRO9LEKH6kndm6kubepv
k450An+W2thDQeTyWe0HpI9jEtLw45BLxyDRw/drIRHanx9xciLva8yd/abj
ShruDaAV1E/Kgp/nMzsFawiY053aYFOQhkpxSm8sJopAWdjzzmwiAapbyk5t
I+/dYtmmKdm+Cfd9f1uh+ZUKDI1d0Q/SMvHxpnTj+X0NeMTA9gHtChVejjcU
99pmoshx8QOtqnWonLTke16IgMALl3foHcxE9e0zw6BcjXd+jJxGDQKU2UOa
hH6Sup9+46wUXwU6yfClFJM6x6Hs9fvgzAyc3iilpdVbgkerWfmKyPqM5RgP
Yb2fgfQ7Xp3OIApwm0TI3z2ppD9a24Mp/2cPdv2wyF3mc2m4iBmneM/GYgDT
7520gwS80xM87sGWhuUDN+q56EKRNZ6LOXqCAFcurz0Rw6l4J8v+rCCNGSok
xDjMkT50+LHracakVBSMPcIm4RUEG0yb3tmR/qj4dr/8S8dUZNzZnU85+AVu
LLGaFpD3ZeKvzfYdUlEi84F/Q1YahJXnM97sJKBUzUJmiD4V47K56xUcSN2y
h0ZHqILsR3ZQ/2eegVb+1AP87PUYdvqbnBUXAY/6Lh9tZs8g+ZryceFLDV49
fmvHABDw+9C+mfbmdMw7VXK7mbcKM6YvHRO5Rt6j5amTt1+kY5n4tcY3j8tx
Z4Rt+oILWZ+5e1R2qKbjo6E6qk9dCS7677j1i/TFzhMk+W1IR7d+3v11/wqx
bOLZ1eoU0n8NZHa/LU1DXqWoTWLHchDjHpxmJs85vbYHs/zPHmwHk+Z0YUcK
sr7/p/32ahSeVrQ9zU7Wp2z6q6B1ESk4oPsKxvKC8Dhl/f7EGQJ0+LapNlul
YI6Q8MvNf6/ho+lgP07S/35clleYlU3Boo2/mUQZAqCrw02cn/Sn0BhhJ7k+
Bc+1nFDU1fsMX9merHeeJCD3cTLREJKMWzf7Dr0wT4aWPPVHFNInZvwbjKNK
JmOTpVnqvHYmVGkP2J4gv2ralU/hd2jTMUO1WcL2aDXma/5QaNYheQyzPF+m
p2FW1bPjIoyV2La97LKoDQETpokDuy3SsO2k3oHMtjLUviwnGfmMgLzfG6/5
caXh+99RDtJeJRgw2ZVOH0aAyJa9l151pGIEN4PuH/0idK0/yiRA8phLe9i2
PP9UnOqqrVN8lou+fuxKJWUk/j7VWvkaqfjnho51QmAG6m5atIpvIfXV2h6s
+T97sC7e97TTB5JxudrIWUw9Erm4DBJfkvU5pfJ5u1FZEiqXLVzoMwnAL6bX
ffJIPGVat75cuJyEixwvw4tX9XFQjfrtDelDicbLTwzmEjF7oxe31JlXcP1Q
zCrxg4DW456t8DIRI+jhxj29COia0PwVSfroE5IzHteEEzEq7BiHQ3YcHHmn
j8/I++3Q99F8XpaAd4zHrKO506Do2Ne2h+Q5J6+6xK6vTsXLVo5xdCwVOL3B
WJfOmdSHNYFvqxxSMXHXnxwb4TIMFA0PuveKAHbxZF8hkVSUCm5mchQnhdZZ
qsW5T+T3WhWVzulPwfBtzH4BWkUoOHTf8RbJnzbUTwN8b1PQ58BI5W3JPNys
89U4k8Rzn9wXwd0XUpD2PErormTi1pP7n25oJkBR1cLkzI4UlH1Fa3MhLRWP
XOpIlO8l+XNtD7blP3swQRWHxxsYEpF9R0PEoaRwNFvOdhsh6/DPwXy29A8J
+OWtXE9e3it881QzZM8c6UeszhWKySbgwCOwa7fRRd2jOt9e/CSgEQ159jbH
o2z0ThkJyZfw7aVwBA/5XNEiMeXy7XjMqTfJUaJ8gPJjI8N5JP7Nv3/dfrUt
HumDzxV7rouBMvbbhspkv3ypim4PSorDhlOqRaMiySDY04pfyHNm0vAsEIkp
6FpS7JvhUIrX9qivLyD7WnqEwf6jUQrOMZ4pY68sxqL4mA93vpC8se/iY/md
KXiWNs+qZ2MRGsy+5hUndVQp/yS7kW8yLgUI2gza5SFjVnWYC6k/P/XlnLlC
k4yGBiq15U1Z6G5JY6TZRMDpUXuNbsckFGAN8ODnSUddyUcJvqS+0rIuP3V1
PhGN6N58MsEkXGAVPraP5MP2tT1Y3H/2YMdHLHT/CsejxV1j8QupoXgS7y07
kvWpbPJgfyzGYdsvt7Y2UR98zjnKukLiZv3zwKsnV+JQhTbfam5QGw0LA/35
f5F6g9OV/fRiLEapjHNIRT6HgWeHPvbOk/zfH9aV+y4WXXT8GsN2h8DRExcd
2Mj3HEsQuBV5NBanL944pL/hM9BvldWvJPtlm5nMqAFTFza6Z3BulA3FC/VD
B/VI/Va29ntyi7Xfk/9b+b/fk9+4pWhq86gJXyn9oVFZ6kAd1Bz9kDED3uGx
T3J8m1DyiNxno7v2uBAyS/yboMLU2r7iSNn/7SuOru0rFh1nBxc3x2K3PitT
TTeBx3LvxxlOZkCc76LgfZUsPLPvnjyjBoHUvePv+ZmroWuPvb12dg5Gl6p9
erVARbn/V9d7h3P5vv/jhWyhUBGiISllJqMro4WKomEkQkVIokKUUUlFETLK
3nvv0957773H8y4jW7/7dbzu1/dzvB3H79/7eB5P9/O8zuu8zsfjOh8PzgYn
DGtqUXtu7wctNYD6w82hX/fOAs+x6QZzq070Z7JR8vWLAmjRopZJkZ+Bo+vk
SezdPejEo2qts36Z0GeR8YBXCIMT2xLFW2oq0X72GSce9nxwDPZarBIngfDi
noZHSc3IMyF6+h89s5K0MMUNuxnImjE2+VzXjUqOC18sbSkCFbH1QGeVKYg8
EynX6TWIzC/PXblGlQt+JWL3yagwSG9Sd5nfXoNeqUTV3AkqAv2pa9vEambg
yl8jJdWrXShqxyOG+oxiiL+lmDD+bRow59zaP2N96NOeSD0lzVIg/R5iId0c
Bx7e22lHpEZRPzHftcH373xXDDHfdcOFBQsqqYCfN05NSWbNwPF8usba250o
mPDTeE74aVQRfhpJxHNV4vk213+fa9llu7eE1MCCzbaFLykjsF3Q0nbixjj6
RvhF+BB+ETOEXwQPv7UiVVUW7MmKWo/D1zv+5NHGk+/qUJRHHcXC3kLYURAQ
t4N7BlE/m7/Ld70XDZm+i5IVzYLzGeoqoXdIEBv+Xnj7pWbE2mdP9R7yQZvq
0FSO9zRQOTbf7rXtR64En7ZM8GluW+bedQneKZzgnfaItMTzrxaChXtQG9ef
CZDP+Kx82HEYDR3skVASL4LI1nPS64Xj0FTWtF4/N4KUi6qa91oUwx0D84nw
iHFYWK+crtkcQS1FGul+TsVgQf+LiWxyBKI9Q79QZo+jgVens6pVSiGnTYna
rX4ULr7OzdtbO4Z+5Um9DvpYAu45V7zbtAfhcBqVY7Xu1P/z2bAk4kY592/c
fCn9h59rVMIBzeXVjxFdIGUsq9qkP4POEn4RfVv8Ir6+yBDe01kJzuI1I/6p
VdC/2qq46ycJedR5nRehqITonFkxYWYL4J0N0iDheOd15M1vnFghpDPu68jv
mUJB782079UOoPQf92JedBTBhq2UV+XeMeTmUFN+KWoMvVpa5KGmw/M29QDb
y+oZ+Hu+NJ2FshvxHIYxpARgXnPf/p7ZJHyxuefJtmMYlVlzcvI64nl481CY
RsA4VOqtSxgIjyJVggeTJHiwHQQPNqVx4kYrUxHcVzaouU81AmU+VyqsXCeQ
jIKJyvbhQtApFDqm1zgEzV26f4XsJpGA29t1n7Ui2M0sfZb7+hAcMQ1Uyq6d
RDoHvbyLLhfBaw/9fuvSfnhnoxdyzXAaDR21jEyiKIE4a857ZAcG4Dutqtm8
4DTSfBcebmJSBLq3Wn59MuiEmsRtWupks+g4EecEIs4BRJynxILPs8qVAqc+
xZ0nHo1w7hNZXthVEhoneKcLBO+kSvBOf1BD5WnbJLDeL20grloCrhfIjUuc
MPR5X5CYbF8k3GNQkBHljkEvJWZGGvD6n87+6O9qVASYNPa0SoVGIgXrJ9T5
eL/Rm3RPc/pFBEzn9+xSwfvqkN6GA5L4+XteMxbdPB8BD+LVIzOHMUg8+axr
oCIJ9fuTLFM1c+GmXU2JrDAJxBdS+0/+aUa3Shz2Omvh+Pahp5aKxSxQO98X
LYtsR1Tx+hTKisVwbHO+klx8BvST8y0DA3tQHFEH9Ig6ME7UBzlfZzZR80Lg
Ge9rL02dAsEgh6RK/By4zZG200GpGA67Opy9vDYBLIrGajceDqMd7RrC9A9K
4fYDJsZh5zGwVPYVz9wzhj4T+e9I5P8aUTeGClg2Iy4UgdAdFcv9naOwsrg4
wEIaQ2tXjZeHrhVD+a42kZB3w8D1rurvz6EJFMn1YOdzxRKQY5cQEIgfgLQL
moZarVNIlFjHEmIdfYh1XFPM+OWW2QZDIs78KjPBcMr2toT+yCx69ySHp+FH
K3i8oj7b1xkKD8zkqwX3kNBNdcv54h/NsMdT2VLoogd01b4epnxGQhdTZd/d
pm2Gz9y72bdfGIKCs6OUtTYTqNdl2UXwajOoV78ItqaegC+8Aa6G1UPoyZ4y
u+joaqAO3Xkpe2USeD893BakNYg0K5K0v0f1AJXUg7dWjYng1t9em/N+Bq0k
fGPK+dsFiYPjDh8TkiBw9sOr8tkZ5EHMk+sS8+SXiHnyWAdGuWcXqqDIOf9k
yo0pVLOiL+v8ZwBNBnfX8NNXw/qZ3vK6wxPomZa08vLAMALiHEfEOb6P0IXx
PB2+kUxWDUbj1TdeHZ1EXarT86e9hlAm8flDW3Rkr4n5Xg7pf+d7HxHzvabE
/HYtMb/NSsxv3yeeuxHP1Yjn37bMyT8ifteYtprP3IcK4HeWF8ChHio3SVmC
pm5EZVD2swXHHTc218QWzDC4YJr+xJCzDPG67vag/JEIyYvc0zvcMeBN3R9X
qVeMqC7X/5EnS4UOeZs7SucxuNSgV35HvhJxit/WjzNLh26BZZ9ASgzOPWr7
hsnXIodz2VfeB2fB6vq5N5thJCjeuPXS+lwjKpPJvP1pIw/YjdjefKEiQdiy
WwdbbQtiHsieury7CCq0zc3qSTPwx0XjzmZtJ8r5deoch3cZ3FDVur5ZNQVc
hWePm7kNILVVC/ONmDI491ez2fXIJJJPoHqWuDCE9i2fzCt9WQgUc/vnqyen
EVm/jvkmfR+y/6BeTp6eAYnb719yUCHBrvCuWbKfzai7j1no10QasBlwcdFF
kqBfrGblnWMjOvPd5GL6eBY8PKrdeKdjFrYbF166w9+Grgf81PvlmwshHV+K
+wRngT2I6bi1fCeKS+K/bb0IIN5CWWIhMQN1fbULbnt7EcOJ7WcjdhWBAbLO
uFI2BXuwPxSJpAH0InXK7UVMCUyGlAVqvp8APl8D3bKhYVReefrF7/Jy2DWw
y1JiZQQkFktcNx6PI8UjxUyKB6qhcHN8iTGiD07I1I75yE2jNaqK+zJRtZAo
IVB79ms1xJg8PCSqSUJMC/r3Bd7UgtbalIaLVg7KNr/CLTBPQjDKSONjWwUF
l0JZqcc60C/u8MmqLDzfFI/G6/qXwRXaL2RPY4fQQMusm7T2JEq1PcDxZG8x
uB4W1doXideRTt/5L2xjKGOuIf7dTA6cOVPhoHJlBhxqXD7P0vQiF0PN2PtH
suHIVY4Ki80ZOOK6LbT2YhcS2mQQWl3NA576tAhlg2noerxfWotjAClxp+7b
eaIApIJTH1sITYFanBJXGGkQLZW4KR54Vwg3D5XZqnpOwFLFVY8TFCNIYkWS
zJG6GLip594GG4zBjpuXZWo1xhBfnAzP4+AS8A//1dtrPgyMc4/XE/H6ZnSj
Je/+qTJ4G+BY77O9HyZWRS2uPJlGYgxHc6xMyuFRtVtgdncLJD14pigcP4vS
chatPq+UQ2tS7fji40IQff6VRpsHx1mbTAairuXgGxBzLp42CW0rlTqWj/cD
0p0u24NFysDRv/nBhn4DerHi8InXlIRmvpxS2rxRAhGqKmYKrl1o0N1Cpzxm
BuVfj2HWVSmCzUcrWbelB9EeWo4jpC9TaE6+ptjXoACWUimvD0qPoEIdQ+1L
TyeQMw/QR2rkg1/v5KabzSQYnJwb7V4dQlqkkNOb07mQ9yaoXsJtCgy8ziwm
WQ8iplIXOzQB0P5hwwcdmYAR7QWlOf8RRDM9rsNQXgDCbY+2CduPgf1DxkXa
u2OIk0Jz2ONnIczQrbDwPxsBfiO3p+riE8jnTKC/+9Mi6DnnmuY7N4jj7+DD
0WxTKEn+wvc9J4uhpLqNz7e9F5rbRIePjU2j1aVnM575xeB0+ZRERkYb0HzO
of36ZhYtfKu8s0pVAq+XOKa4FGvBlEJQaTafhMzpo+aX/xTjuClf40JFBszH
zDL1P8cQn1SSWhveH2oIR4oFHo5A3My7SzK8MaTsIyIYm1sEpVKce81TytB4
8q7iZ4cwJKhbSEGeUQjlK/OhJjuakd/FGG5JKRLylKMYF3UvgFbVY1ziyZ3I
gbF/zJx8FqU0caq3FeSDjDUjV9WtfkQTw/pDNnga7REewjLpAQTJHtMLnB6D
gqt/D/SmjCHXiNzbZ3nzQe/ljZvXvMfBd8fNYGXFUfTsySnlsX/mnH+sBej7
jYBg2vZiRb4JxNgk+ZfGqAA4ZPaf2Jk3BIItXo/m/CdRbbaknDHeVxu0DN2Y
8BoAqh9N+47STqPtjK9cEjkLwWfCZGjySg9cn98ZIKw7gy7/KA1tv14IwlDc
9X6gDVJFBr79/TKLQHDATc2gEPKzr+9bX26AZF2Ib3IlIWGGQCqHa4Vw6F7+
/bfmpXCP/ErcP/yeo/ZEEhVjIejWL1d+FU0CzfUBBulQDMXMelUGhxUA9do1
Mt/0QPRYguX8jnQMnT5ulDG+twCe38+fdHAqQLevjmxMvsSQw6jPHMdQPrDo
2XxYZa9BFbIxWfmrJMTplefpaZoH1fMmajvvNqPUC25Hhy+QENdLa9rIiRyQ
cbxWuI2vA33JmLJ3MplFYxGqbJmm+SC8j1Kv7dcQqLboHwt1mETxkX8H+ajz
oZH0AsVajgDXPM0+LtUJdNw1u/xYWT6oqflWZp0bhKQMa9Hc2ClEmqbY9pAa
gCk/VYitqg8+BZZIZFdMI3r9u3YKJwGcFBZm0/K7gImbjlasfgZZpNl9oBQD
uD4m+XHKsA32bD5Vep05i2Rq9fN2sALQMhw8tbe+EV6nS3upvyKhqFKhucs1
+dB3X3pAmakK/PU2fb334Pmpo+BPie9H8vNP9TaUC8ByLCGP1hFD0zY+v+og
D2Kezz67RB4NAgYnojvyMMQrSJllvj0PDuXXn5w9+x3d6/FPyavA0ElV4QMO
h3LhtHkUjRdNFlpk7E1sDceQL4XhhZiTOcBRxsWb+awUwdFrTPu0MZRpN5H8
hz8bllY9bu3tr0UZzm+xuN8klMfNP83PngUhMxdtBLua0ILXCzUxYxIqOvU8
QpAuD3LJ16QdFvrhxF2R4njbaSRM+ETpET5RUoRPlEOd3nkW+jx4a21/f8Ju
EPRZLF6MuU6hJ4Tf1KMtflMX3wsWdq/mQnZc4Vxweg8cdH55VOnuDKom/Ka0
tvhNtUcXDyR05ILMgYB4v0ud8GdbgmD98VmkS/hQcW/xoXIwE78EwbnQu+98
Xk5iK0TeLXB2xPvMRsKfim6LP5XgrjiZ0lu5gCntPcSx1AgZcm2mhxxIqIvw
rdrY4lt1NNSIWW4pB5R06bx/KtZAXgXfcU5yDF0g/KzCCT8rR8LPqtot4KXL
mxzQPf/555xrCQxiHcKZBvi+IO6/vm/xubIr/HAElrKBzVyxINc9C55IvKuR
jsJQAuF/Rb7F/2pKwomtQDMb3OSuVXPcCgVrK6+sxVoMtRC+WC2EL1YO4Yul
ZP9hZD0hC1x+2z86lOOBPrMpmx9oxdAa4ZdVS/hlvSH8shLqORsuL2XC+qc9
Hsg3BX2huRVQgf9dfsJH69oWH63i6vd1MaKZ0GZ4dK9NTwFiUzl928sDryeE
v1YN4a8VTvhrJfEM9xw1zgDq9vLhX9/L0fBj/yEvFQz5Eb5b2BbfrRN6ZEqB
AenQlVmj+HijFrFFDf2ixNeFlvDj0t/ix9W6lHKhDI+jlztV9bnxNjiz0+L9
97RZJPijWaZlMwsSKH79rLHvBLZ29QkngVmUesfudQlnFuiUa59ilm8Bzz9F
bL9O4Xhz/LZCfVgm7LO4daHNqxFmxSPHF/xJyI1tUJyVPxMo2jPjPtbUgrKV
oOK1FRIabljPncXjz0EXIiphVAGqWrPPhs9jiDboRnUTbwa8ZTqotcZQDHe3
vcxsdMD3b97De3d80+HNudZBz1c5QFcicNQiEc+rYpnjxxjTgUXlJaUwZRKg
WgkGtXq8DneOF668SQNNZfL1qh1+MBrHHnp8AEM35gvC38ynws2BW33xIh+Q
Fu1KbscwhpIfuze/1E8FqZQP+0uYo9Gu5c2uq90YCmhluObRmoL3qwYixXbp
aHFNX8+7HENR8ydGLS6mgJIx6b5fMCDe9qtXS/A8PE07vT0lOxnWaKxZxSRK
kIW9aPkk/v5PNtqefB7KgEWXBedtvs1AOniiqVSFhBKoxHKFHmSCq2Ri0ofZ
VrBlDac1n8DPo6pfcoraGTBsWt4lotAIoRUtu7Jj8fqjNmDxrD0dspV53A/1
1oLPtokDKusk5GL55omwajrcXCGn+CVeCTdlCp/G4OdUY68ZWU5VGrw7KFN6
2bcEjjPzh+/E+wGhhlbG6wppUKW3v8uArgAKNnb87AjG91fe0BGF/FT4c5TV
UHJ/Bkhk8P95XYyhXWnhU0MSqTAvXn/9vXcsNJ+/g3l0Yihwl+2rN6kp0BNT
96Ykzgu221gJxY9iqK57sdVcKAVIglxyTevOiFdR1vLFBIauXNqtSpaYDA3f
cpDUUBjSXn6rGTKEoZl94aM2p5LhZ9y4XfpoMpoON3UbbsHzQTO27UBKEixn
3fra6puNUsowHGVgCNsW2C4gkQQ2ajYrt6gK0dz9/S+s8PO3+1kRR8qNdBi6
oVVlMtIATlXChTx5JHR9uWhb9nA6GHWef6H3pwnS5jwC60xISE7uozx/WRoo
HdDKFo2phfdDhzj0yDBUab9TjV4qDUz8Jx7We1VC5Ser5GYZDFWVdL6+nZwK
fZYPBy0+l8KFzY2OSjMMjRwVod59PBWCM26sxHoWgoHku31hPhjqMDsTczEy
BcSKub6+vZUD5oLPVxsyMSTFwnOAki8F4MmXjGcxKVDusJFQiNcHf7bvmvci
k8FISELprGoknM1KaP6N522Zr1rNw+PJwC4qst6C4/0ruefEBiYxtFtY74oQ
Hp/zs2M11EkO6A85cyPDDIYmwqO5q6STgOLOU2Ybv2Ck1f95ZW0cQzkL9udk
KxMhTJ1ew2J3IsKEFzOP9WFoaOXYStDtRBDcM3PtQng6ChjzM9uD76NAZi7J
ydYEWK4oLArckYeiXrfES+VgiAOk51kmUoHppRDvXbVaEO22VyDR4Pnf23HL
1jYNRNqMz5e8boDpV5xzdLUkdPGj7KsLt1Php9ZanVxKJRxpoffOOouhS/Ei
Q+01KVCZ0LdjmLsMON9IowpjDN2cipHwPZ8ClmK87Tl+RTCndvTOyy8Y+lhP
rmFYlAwnJ8hviankg3L1aduTeB0YvjwiwiGfDJvPtn+U+pgBronlNtfwfiBe
bpzevzwJaA7LCRjPJkIVc5wU6sJ/b4K7ff21JPjFlnLRdyoUuPsTA/THMBQk
q63+ozsR/OfXfLU83cF6aeDjoVkMcfYbzM0ZJYJqovqw1a7XaI+GAt8QCUOd
utg987UE8Mwj+bhsC0SG1vLUm9MY0ptzJqXzJcCf/YFXOyJj0FCcbnLrCIZe
q6WPfdaIh3cvTQKC7FJQ2LtLe4rxfeQYdbCq0SMOzOO8Kv9sZqJKijGp/dUY
+ur95eC1nylw5KPEJ7bwSsDCQgeQLP7+Cqd82kRSwe/piZ1OUzVQaGsHf5nx
ffGDWiCXKQUURbpevn9SBn8rFxwojfA8cdp2u+BdMjS+GQkJUSwGMluT8oSP
GBpw3+5OQ5EMlziFPJnECmDN6PeKF17HGBzs+q46J4H2tQL/xHvZsKMng4yt
EEN7daK2X6NLgmvWNxVqXqYCOy/7hFMznid0JybqviUCnbOVJN/jOKCT8Ll3
ZhBD/bXx9T6HEsFWiOQxJhAMiiBk9fafeyUjy5d/TBPAqP7lhFLtR/g8rS2V
i2FILOBxv7t/PLz9m0GlMW2DMoUq3Ph+Y+jFEV6XmMY4cJanVibV+KE5UucC
M/75ctdE5z8McfA2ZiJJnDoStSWeflKI74vN964fjqjGAiv/F8Ow34lIr6XL
+gX+Pobt8YYLvjHwVOJYm3xuGnJ+rLJm2Yb3IRzNxzatksHti3GTvVcZKIUd
cih6hCHrwKen+WhSoIixiLPYvhI66+6NRCrg3x8qMRQwnQT7yAbenswrhhvu
SQXRLhiqdb6PPhkmwXS4egnNQgF4MOi1p+N16YSs1aN744lQvJtcSN8qF4zP
7H0hge8j451NKekmiUBypGZ5djgD3L6pFbzC+5PitEqxp3MJ0D/JpH9+MQke
PqwXbsTPIyR1yVRodwK00KZJWVdHgS7dbNpLPG/766I/ccjEwxK5aZ9P10+4
nl3nk43n7duJCr44szi4oiK7ESbjAgc3NH404/Fk/DsXYBIdCwz76bUtnr9A
4fRt9NvnMWQ6bh8/OxMD/jTH70tp+yBOA/UiG/zzQG1zr0w8Bq5gXwVDmcLQ
5eYq5Zf496f4jO73eRcNqo4fv7Knx+F9tcCO43idsaK1mKbpjwKqb0use5hS
kDLD9hPFeJ2p9k/J3TROgqGuVfZDlCUgc+ntwMQ7DIW46G3vHkkE/sMbS/U2
hfBge32CUBCGfMbqjY31E8E3S+prCVk+fL9IyeGF46l1s2YBg5YEIN/I/65x
Igvk6y2HtfD9zt4XKvl6Oh7yKGvE/lilQulArUkFvr5Lui0r2gzxsP2GkKRU
fgJQBtetseHnTtvJj5kXz8SBxs1NR6+qcPAwnR52wPPz/J2xSW/TWBBeHaeD
g/4gV6dcJvcLQ9oPn6VnxMaAGs+20gClt2Alq1rggsdNd0P2Ked8NNCX1wob
+1si8rTMgHcLGOJeuP5HUTYabmrwCbk4f0PFGirUj/DPW8QF3KrxioK9Pzo4
6PyDEctqRtot/PvlIzfqxOcjwf7ywz/J56KRi/hND+t/dBZ6thtOapFQnrBm
HdeaiFI3vC5s4vWEKU4rwK8zBVz8xFybLmKwv6wllm9fJZKuLob3kukQXcKR
9ZQWgxOKKmz0DLVI+FhJZ71GFjxaupCxJ5YEETZLRj4cjSjB5HOe1ts8eHqa
/jTdARJkJI2wuFxqQQ6Lyode5xdCQDyrm+feWdj4zLfTkasTLZdc/si1rwwi
dGhPVe2bhjpWvWn+vQPosVNQexZLE7BZdTM1NnUB3TX96Q/+00jwUn2P84Nm
8DgpTfFQIwe1e5WXH7tCQuGxAhIypfUQ1RQ5KRA7iK563ZNIej6JptY7bW5V
l4PC46BXZ4Im0H7RSx4GrsOIu0zisuOuIhhVyRHnyptGFTrM416+fWjjluHk
1apcSGO4UR4oM4u8G6yzn611oCNvyVh8yHPhuH5H3fV7sxDf0xWxod+BYq6m
iz2TBCjuZfYgs5uBcG+W2qfMPWj4Yhr9YEAhkDOvmlkITINuU9tx8+sDKEr7
3DmxfSWQp/dO+dSBSQh/ZeglLzCMTqrEqn3cVQ5YhkIt38goLIionakLGEPD
G7SNMw61QGNH6bme/QGtxD845smL91cvbY9ZPKqGBmbfVw7Rzaiz4vf3xJhZ
FJkuvRJytAL2n2ULDBkdQL9HSU+67KbQ9I5ZuR1nS4Arc0/ytqxRlF438oJ/
bgz5bDScZqQvBLLQz6du4PHhGv+7o3l1GHHp0gfe21cIDgk9OqmnJmHXp9ar
bArDaJjizL6ij0VwKFdsslJ4HMK4+JW1Po4iRQ0zr7PsJXAm2vdR2esRyPg+
Q/2TfgLJrYY+sgouhbfrQ3H7xwdA/NTb5uzAKTSR2i0lvFoGo8LfixjZSpHG
z15NXvzc3+nM15CkXgrhZ57Xa023ItajO9deeM2iN7q/hypVi0FWKp2xen8/
Onei/8wl12mUwif6ZvlyIaTLBmud2TmMok2dL9nemkQtTcw23zSK4NP433dU
HLXovZP7BYsmEnpnTSuSpFAINswko+djrYjctGUluXAWvdDa3TvDWgA/OEJY
NSR60J2oI++Fnsyg08fLnBr4C8E2un9f9rcuyBJSOmlYNYPeOUqHTKkVQtJX
042L9K3QTZFHfw/vt+taJ6+7PMuH94Mi3VdN65FVtNbFo5UkZGp453nHSi7Q
6dcH+oy2II5sJltlKhLq3MU4y0EG0H3EdvfNtgb4zL96dziQhDI65JxH5rLg
WPj9S6n29UhpflTGtYP0//gB/S38wH+4XpvA9XwErv8Pvx8g8HsMgd+bCJzO
sAWn/4fHt/n8Lx7/D3dHbcHd/+Fr/y34+j8cTbMFR/+Hlwe24OX/cHHAFlz8
H/5V2IJ//8O5ZVtw7n94dmYLnqX9//GRNuL8Yq0ukAV61xJ2VIa2QOD8C1eh
AyQUpT4YZZmaCTVhiaI9q43gKHtOXOozCTF/OaFZIZEJlIyiA2XedTBAM5Ge
NUNCfmFtHgGZGaBnfUjn5OlKWLZ8O+MkhaH7IecvPBLNgL2XWUChuxhuxVEv
J1rjdfhkXEVObDpoH7VqYGHLg1g2Q1PXaByn542+//ktDbRZrhiyBgRCnPDq
qdf4efdte+pvT6o0WNMI6/pz2BYJxRUZceF1+5orXW3zi1QQtUpdUeGOQGIJ
nLt08bhdER0/zziVAhLajVzjzGnI6MgfOWW8D7wkG92CaaYA5ccuhwvy+ciF
hsMZi8fQgZbhUcb6ZOAVcr+U7VaMMhQYj97F+5AYsnrR8JV0KLwwmNh9qh4M
pwN9lsdIiCXsxbk/FulAvTCi8+tDFZQun7WJOoEh19dTDxZn0+AhqXRsdKYU
yuyPbtd6iPexClf7Rh6kQb6ppjCzJl4X50nW970xJHmFoY9xKBVMj1NK9ydn
wbPMYx4n8H7m2eZkm4h6CpyuM4BnQmroLM25rO847pPduwFvmpNhyp11+dmR
IJRzudpCDMeJr3ZPSvrewPFg4VLaXt9EVOeUr5CE98O87leHi1qT4Ofv4kR7
vUy0/QWdS2EZhu7FqkSc0UiC8jobV40pQKPPtunsi8PxlN6nVM/xVEiPje6O
kiqHZ+NOQexaeP9WIY6i76VC95DeSJp0MeSzBp2IwvNK9O9C+tGeFKhtUElt
8s0H1Sb577qxGKKSmEEHNFJg6ln9kYH+dJASG/6QjON96duCzNKPk8Ci3rtM
w/07CnMavvsU7xPyEiwZIpcS4eHj7VkidtFIjmGNfgPvK5482Wiac06E9B6F
9PrxFORE0fWVCe9DnF+1Th/Zkwh7C6vlTbSzkbqofxtfCYZc6ofEblOmwM/E
QMsvOwrhZbJuhl4ghuiOvisRck6Gl+ezfrSJ5gBL4+siily8zxl6QtVHlQxB
26JvGjmkgqe+ysI/PuRTz8x0Sr0SYPQw9oJfIwyxsCfXnsP74RL7zssXy+LB
6y7Zwh3TRFToOH5FAceVkeek5eXW42Dv9dekih3pSE38Tew//Xz6/TqW4DtJ
QB7o/CHjbiYkPWUmG8Dj4NPXn3VjMBG+YtZn6JyS4fffyscxeB0YuRpJsbM6
FtgL2M2+6sUgBaXNN4p4Hzgo9J0hlCkW9h2YTj/lkYzEFdQXduL7Qu6Wn83X
vARoy7j3xL8pEVj0V7/+s18etJo7LOtEA/Xcww8j3xNQ3MLdORs8T96L64hx
pzXBtx8ur87GN6BIhpyBcPNZ9PPH5ol5qhq4xu3OX9zXCTpdh8hWjGYQFfu3
B0cja8EzaA9FbE4+vO3KXTo2QkIx73/Pt36tAa8/My6/e8vRurhXaVMACfk4
3lN4VJoIT0Nbor5+wkCyYYdW0/diZLBp9S4CPwdDQ7U3+TPH4e/anaHEyhEk
leDwLM+pHA49mD+NmU1B0x2Ob0p0g+jCGr+z0GgFeFa9tZB8Owyf5G60jXpM
IP6VjODQvAZQgp3V/i2DIPv0Xi+XxCT6tssmQj6hGTzFrj+B35lQcFc3ZfIy
CSl3a3LW0eVCqY6knY/GLAKalZMz9h0o9O2zszQB2WB5iMZJK28W8uQsEj7H
tKGvhp6UPygBtGVYH3msT8GL4/dDJwoG0Iv2/a8oHPKAOYRvuzPFLNQIxBz4
Pt+JLFLy545WFID1pjZdSMAkFLQU1Y6mD6ETAu4xY8XFcPiamyOP1ChcfL98
/abJOFKVlbSqws/3E9R5g5HNg8AruNERQj2FPjyOELFKL4NfL8msKQq7gL62
v/W9wwwqNwuv9fYuB7fDw/5qXvVAI+AXlWNOQg2p2nnH4svhRp5Om29pDFwn
7bmmaojjDtKfkRdmRbAt58Buf+VxdPE+9ors6SgSj9Ywb27IhZHb+9S5yGZA
Xs37zA/2PmSfwZIRM54ErEUSn94ol8E9y23DmqYYevgi2E19JQlM13drKfiX
QeB+xaAQHP+SUj1HLB9EQljZSVZ1g0Qk9P3OaCeeV0sj8tYGCTkQwbljk/sB
Cdj93zJ/yW5Ch0KDzwk9KYDDqv6LWj54nFMyBo0m2xCXL/ktOaESuDNjmebO
NgMD6m8NqRd6kAl72upycSUw6+Vw9yxMQKVxQQ3n0hDSsVBmKr+QA5MvjR6J
fJ0Fsa+cAdtftaNDH9c06lXzocxF3NOrbAauJ9c6ucx3IZvrml/OMBbCKR3h
mQbvadh7c5t5i0I/SiRHXPtMi+HIdlmN9NJJuMLy9vOY+hBibkzTdL9eBl8U
xg5eHhoDxvsuylxRo2jDfsb+07dKyIJUd1XZIXh2V4Hz9ys8396y7zV8UwMv
kxhTDZXbYKcCuVcL7ywKkLok8zakFpxpSlwfm8dALvfmBVlWDBW0UMTdUSuA
vJdrYpUnJ1Gqybkdi9eG0ap3YdgbxjzoicG2Dw9Pw9eZqbq7b/vQ7pUmktwV
gPVvhTnsrVMgpZtu0LQxgHiuMjqIYwWwY0VYEB5Nwn33hxWLq0OIQoTUR3Gv
CFx+g0bUq3FovcRqsktmFIU431rvnC2GyheD0T2DI3B9PHW2M3scmdHVyb+w
KQXTW5SHnHUHYWL5dZnVjSl00PDIwJXGMphRkjktGNUJM9+/cksXziC/Ehm/
TuFmmH+ak5X6oxx9rHx/lnt+FmX05Jxqe9II4w4Z3KIc3cjlieopibBpdLKF
i/pOaBNEpSwldG60wbsq3l9iOjPo7mDqav2jWsi2rVFw5BkDbU4tQffJUfTA
9lR/jlcdUJFTtc5zjIKpZOpF+doxJBu04CYg3QARFmGhoWtD4G3SMoM9nUAz
Q9Vu8pTNIDlorp5h0wSzS3EvVLhnkU7/A68U82YQSX/V7lxRCoznKFjP/Z1F
B4R/HhS1q4NANvnNGbphJHjtkNfvzxNIZDftDeWBBqC9eDvu9u4+9H6PhcHU
whTqJ/TL84R++TahX/YjdMe/Cd3xJ0J3HMZr5zWvngFRZou1LDok2JswJa6j
1IzYt+iICwgdsequQbYCxSp4Hkohe7J8APhcvpUnm08h6qP/6oJHCF1wA6EL
jt2morh+MQc827iUHJ1mYJH+agXgfboCGYt41I08UDBLlf1SNA2cVF15U6t9
SILQ7TIQut1oQrdrcbdEq3W6DD7HPv6r5NABv950kv/5O4NyxiMeT0eUw77w
1B2Rb6pgJe9P5IF8Epol9LkuM//qc+UJfe7+7ryeDz55cH1Qr/HD5iRQ2xry
tisOIVY2rijlbSWQenwwWe10GeQIWLo+58SQ2rLh18WaYqDe6CN10IQA1+P2
4Qi8/6GJ+FffWkfzv/pW4SyDn31G+dCjW7+tmXUcODTz7Xpb8DxpMTmnex1A
vTYr7FLIKBy/onfVGY0jdjta7lR2HL8sO3s8WxiGtsXF3T8TJ9BhCaeAv04F
8G7J8rMI+RCojwy+H+GeQgqELnWY0KVmE7pULTPtlCG8P6NkPfq1l7sOGLAZ
t+01JJQg/k3JS7IQ/Md7PXjcCsFqlCvs8gP8fK802ZDD9+O4ndNpy/VgYAhZ
Lr+SjCHfoE/R12wLANtNaUuemICuZDX7YDEYekfoSae26EkDfrfJbe7JB2Pv
73uk9o8Az46nMuu+E+gOy8DtXOt8+JE83//KbQhC9e7JfaucRE7iAuJ3a/PB
7S/rkdX2ATjdf1BXEptC5xJ4DpFoAL43Wk1oTPdCj1jk4oUdM2iDq9DC9BjA
BVt/j8aWTvCO/tZqQTGL4gh9qAChD71P6EOVf0kmVCblQ3bQUbuveyrgz88Q
uQdCGLLNZsx1lMiHwlP7QhujcmH2wWBq+1cMafZEJ2zH86EnWzGXQjYYsiZY
51qLMSTPxFdwriUXPLG+KluBUDSxTUbtVSmG+pYFVefmciDosgyVQXQuEkjm
Nhbxw9AXQu8ZsEXvyRHflBJGnQdGOkUul9QGYSnScH9PxBR69bnsjggljh+Y
OStnffuheSKVx99rGo0fG/YWXMgFg7yLA/fu9EB02Jx1veUM6q/0DJXEz0Fy
qisURhMdQDEc2uwjO4vckqOWX/rkwuN0wx0PrrbC64Fe+xt/ZhHL3InKVKVc
aCjWbbXyaITLZCKowZ2EIgldpw+h63QidJ0f6Bu4KJ/mwBs7/kSWkmKwoOW+
N2eCoZvFWsZpY9mwVD+borkjE+wM1JuVcdxxkP7IxIPL2fDIjz7Z+FoQrL2l
fbtRj6GJ1V7TL/5ZsLldatfLoO+of1p2U7UFQyIXO9WohjOhbmKMdI0qDVmo
+ZXr5mHoqQHrei13JnD9xsh7XAuR7MjNwZ5PGPpN6Dd7CP3mCUK/aUnoNzFC
v3me0G82E7pIsy26yEa197xG5JmAvad33TzXAsncmRX9oiSUTegQOQkdojih
Q8Ro8gdLtFJhlbon5nA73pfaiz4/i79/N6H7Izv1v7o/SY57l4I/pIN0cq1j
RH4jMEbovE7F+8kIgcZB5/U00PLdLuF/tx5OCh0/tYDjL3dCfydJ6O8UCP2d
246DrEFdeJ+//1PtD594oAqu9d3Vjf9el0eT5drJcNb2xiLt559wlHFTa2MM
xwuEDk485391cK4XvGXnRNIgdc8Nvskr9VDurx0oMkVCr6p+t1EHp8L9oLIl
0YhqmBd5ZHH2IIYYpnZafWdJhR9B6tVnGSrAotmXWVcNQ8uETq2D0KkxETo1
c9OCCtnPSbDzolDLmekYeP7t+UN7HEfc/CHdrLQ3CXY9tjvegX4AK59DNg+O
j1jUGEuGwhLBLlhjKpHPErZJb5Z/JOG4g9CR3d2iIyvivdi3sJECQQdTFY/X
VENy2NRcNy+Gxq59Ns0xTgG/YZKH8qcKUO84pdx6Dd93QyhUtT8ZOprH7B20
S+HJqsCj51YYGuB4HKV9OxnCtbLdXWSKQJ9ZrYsTr9unCP1X0Rb912HJJ8aP
TRLh+bXJYLbvUeBe7xzfieP0iJuuYy/WEoDb/ZFq7JA/dNL+0sydwVBznrT/
oUMJwDASyqnsYgug+/568C8MLbZtD3dQi4cSntwHzzk/IpaDl3na8edjhG7L
cotuiz/zt//+sWQowpaMw9srwIXdet78Cv6eeVrMEerJwBdUtCk8VwrC452c
t8zx+iPLd7G7Ogme7BS7kbG/GHqu7rLhdscQ5UceIflLSeDjbupncKsArnrb
KXNHY4hvONzbsioRfBS/MWQr5IAc1+D5CMCQIKHD4tmiw9I5IXH/80A80BlW
HWn0jAB3muS7ujh+/9q5HuFJHw8Xs2KiJD74wYFPJicn8fXKKP9leVA2Dm6v
T1K1t76GnQnF2M05DBVjZU9LXsXCs9KwuyHGTqhhb8LOMfy5H02iBW1RDAxc
NjtRe8cfIYOTfnV4fIYJXdWIz//qqhq6frT+0kwCrrskGa+8Yiii9uGb+ICh
rJaxjp+tiZBzZrBnrxiOl4+9cs0PwffF0CexefVE0HHcYzH/Ig++LSyNZGZi
KK24+mRfZgJYR0VcY4nIhMTKKEPOKgy51+whv9wYD88v2fLzLaSAR0vZ7D//
B0qT0El93KKTCi6+d92YJw7yYXZZrSkMxhMYRC/g++51utvB6luxYJYRitjP
+YJPsORGHv67upT0zSa9YuDWn6tKjwMc4LdBw9WieQyJcxzGZPqiwUArcnG6
3BbJ7Nf1dFjAkJONCSidiIbdPU/ynRS80cUvfpwC+OeDKl5wBDpGQXCugm6B
ZQja/+eX0iiGIeU4Ty477mzo+8jMmP+DBDkhU017HjaiLs81ip3uBVDC7Nlz
c34aqn/cYfOj7UOBbzfdJ1LyIU3gsor98izkf77nN7erFRUT+qCLhD4ojdAH
vSZ0QPcIHZAeoQOqJvQyU/CvXsaI0MsMErqVMEK30kroVpb+f3QHAYTuQJHQ
HVgTugMJYr79cMC/8+29xHz7oGwV2n6nFiz7LwYfpBpBqwLMOW1d46iB5oH9
Q98UYP+mfqD7CgZX7a8rKMZWIAHeYpEonzQwntZzZNuPwcr3CzveLVcjzjFe
D2+OTMjaw5IZ0kICzc9LXxzpG5C6gri9xrEcUD4k/43HmgTR5z6WdV1uQhr7
9UIPmAJsO0e9oN05C45WyfclE1vRWyI+WkR8TIn42BsJa7AHVAOpzzBwGsdj
K0dDsx84jaGTVRXbgg1KQfzd5jLH/CRaUm+jL/k9iHKJeP4m4nmDiOepulLj
rvoCuCs+TMtSNg2h589700X2oSpivWSJ9con1quWbu0uNW0NqP+9ai8RVY/K
Wj7LzoqQkL935clC/UqAWmOrgCe9iPyv1uBC0jQSCz635t1VClNB0xJC2Ti+
OOP0Pd5nAg0T6xhKrGMHsY407iJrlhzloPdYOfyQVxFyQq2LnDwYOrTbI9s4
pRQ2lR/1fsxuRrDj1JerC7PInNE8UuxXMczxpRQdMuhB71JO2rbIzCB5Xtuq
F5xFUKVWIePlN4jEZGwb9NWnEJbAsn7kWRHUV7T2VTlUo9g4mdHRCRLScwhk
X7UrBJP2S742z1tQTe7p7p/bSIjd4ZL6lacFwHG56wu7ehdqy80amOifQWXB
Q19kjhSC2H4xVXn+bvDnHb5JGTmDwvQEdVnUCuGm2OfIZ+fbwN24i9cuYRYV
EPOfCcT8Zwox/+ms91A+4Hs++GTZGR25UYdUzq28UekioW63z928l/LAjX9v
/cJAM4pfvu0oJUxCQZXuPe10AOzshYsT1xvhxyxX8W03vO8i5h4riLnHAGLu
kcbnzMSnndmQLJnO55FQhyZYTlJcGiUhacKvlZnwa31G+LVyEn6tlwm/1knC
r7WO8Gu9u8WvNZ3wa/24xa+VnvBrbd7i15pD+LUqb/FrlST8WmkJv1Z+wq+1
kpjfu7Zlfu+//1P5fot/hTXh49q+xcf1DuHjarjFx3We8HG9ssXH1YTwca0n
fFx3ET6unwgf15otPq6jhI/rgS0+rguEj6vcFh9X1o7vWnqSWeBu+uHowFIL
xCkOkIUwk9C7s/kfnzdnAkwo+LwIbgIzi5fjiXhdAjNjHa+HmXAG0voFLzVA
wY3axt5qEhKPk785u5IBb4Y9Di61VcP23mjYZMPPl1ejS4XvMiB90IkjibMc
6GvSPtPdxPvksg9fTHZlwI25tXsPHxVBI9zz4XLB0Hdi/s2QmH+jJ+bfnmQ2
N96LSAMajupyGo4QkK1jsprqwc/r6R98/AJpQC0ncTf/swHcCpuJmsLPr0b3
xjiW+FRQ1xyVCdsRiKYfHikUGcQQl5WZUvCpVNDo9rb+Y52IHM5zTJm14u8j
hXKVUlKApSRc5k1GJhq8RSF6vRDHR+9WzR3FU+AAZ/CouUYBahfhePU1DEOZ
XAqcn2kzwDK0s6sD6uFy09xqdC8J/ZmS9Pb+lg4zBeV1M+HVoPpg8Hw7jq+t
hOeOsB5IhwNPxiTtcbxeK8immYL3n15mMgbi0Wmws8E2KMy5GIr3+AY/xteF
N3xFQFgUX0fjg1e/UgIY3+Wslo3A0Ctibq1/y9xasC5f5HmDFOjlLO9TbTYA
CuldnY/xfib2irTJ3vlkGHK5TfvkvS9yEnsfVYL31TyL3j57HJKhprudPNA1
BjFYSNVG4/lmM3udyXpXMlw9ikZlslOR8VgG//cGvO5ZrwyYhyZBgDXTUtCr
HJS9VkxFi+OaHiPmhcfLqaBTstfLMrUcSFN/Ey7g63uXRdDt85tU6B3/Emx2
rAT+2D+mprXH0DFXHX1V+lTIyha79yWmAHpsnEy6AvE+ebv0YrlPCvAOkseR
WWRD1/rUsc2c/5sfi9kyPyYuFu7jaI33tzJU/XuueyEVk48dJPw8FT/b6mq6
Owk4+TND+m9GIOmf1xz+0dHrhNmOmscngtpeUEv3S0KmLn3hh3HcUZ2xvt1P
KRF+S+is++pnoBAltJ+uFkOO801iUmwpYJ+dRDpuXAi2jva05f4Y+uywMTIc
kgx+LYNMCUW54CDBziybjiHjkPlJLdFkyNxdrDVYmQ4NCvKkiKr/m8taOfTv
XFY1MZelp71GsyMxAQ6NBe6vIw9FNizdUTvw9x/7wh+6dykeviTRevTJxaPp
8euikUMYOmfmqM8gHw8xiVYXnh9IRT3Xr1Ze+MenhduM4szDJHC0eJfARpsF
nSYvjsbg+D366dlbtzcSYSoB1r2aUoD/ee1RRTzPfxLzS5jT/84vPcimltEf
jIW5nzxhNgrRSIGjrfcInj9VspNVcVKxcI+JtbPDNglZ3PzWfBfHQRe0zqZQ
dSQA6x5u1YX7SRA6TMYm2IshGWJuJ3fL3M6G8fCRaotoSJjPbCeLjEdZOg88
b+HPW4m5lPNb5lLanSm1Dr3NgLXFBYrKWyRooLzSYWHZjDi28HWFBF9Hdilz
j1B6DnhSqxSF68zAGgfdx8ulPQhxCUtMHMsHcqEPRZf9J+HwxUal+voh9LBO
+u/S32LQpJvr+MNYCM+LE+s1VfH9RXZgUC+/GGI1eGkurrnDrQTnnkZ83SkJ
HkyT8HnLIngwZXdhf5XZfCD1LPBM3R+DpH2dPx69H0NMDtxT4ukApa/3Pg7e
MQquX5Glbs04CjaruewkVQCPV6x7yF8Og3JxvjM78yQS+/nV5KFnAZi7/TTT
zxkEvU8zDVIq/8eD9RA8WB7Bg2mIlHzzu1EI50Xyv6ucLIfQOsbsBgEMUY8P
X2U+iPerjJj2Jd1MsLsvOxOL46aHRgFjRi0FEDPasmnV6ACc5WOy73G8wJPh
cp7OqAB29bkZySqmoLs185KDofi5RvBgPEn/8mA3CR5M6M5X0i1dPJ4cBy8J
HhyGvprGbjHtSfT3ty8HZUI+rGS1xUskDYKr22tR5vtT6Ni46l87PD6GnRwU
2dwD4B16cMrx7jTa36R5i2YfwNFVxaXBvh5Yf+hKxqY0g3IiBXczCwLIJrrd
ZlLoBHZ+ruSTh/6PBztA8GAGBA+25JPCEGGUD/kKlnuv+BaCgORilMdzDDl/
Xxg9O50Hf/PL7I9LJUP76KPhKRz/St95qC2skgfquu1Gb52swDON89lmJY73
mw2iPvjnArMJRVrAkXhE91777d18DK36hPtRtOTALXtve1p6QOFfDnf+/Iqh
jwQPVkXwYDwED/bLTDZqmC4PIp7+3iF2fAC0507ZGOhMo3XGu8aU2/KAcRF9
/O3aC+bfMeOzfDNosTm48NdYLsiG2qjt9euCqPvfPs0PzCCvn9ohNyEXqMrZ
NWxd2kHl9A2zQx9mkQb93hWp97mgl3bpVaBmC6S/v/Au/AAJhd3vHieTzQWx
Yu2ATrZG8CAv4wkIJqEIggdz2cKDOZNqqm1oc4Dz5DvfKPcciIqXXj8fjJ+z
5mF3XjlnAytjGb2gfCy0MX0K1ML7Cr1TEjL0C1lwrLKaL8T+MRgtkEvk4/WE
tXXIZOBWFpg6WPOd4o1EfEP3Y/zqMNSZpRfUnpwJgqGtwsZRmUhav3/pdQqG
ckuPzAxQZkIHx8bq0qMiZKlwhg69xdAswYMtEzzYcYIHe0bwYNNbfMwaCB5M
ZgsPFmjSwMQ0nwH7HF9Vu842AysDz89fciSURfBg7AQPJkbwYAr+epojiqmA
IqntV3kTQHis+xR5O/7+BA+WusX/aqVCMITTMB0oF88tnznRCLbv111akknI
xob9hNNUGqQcVa4KrK0Dr2AHO/lfJORG8GDCW3iwVh3jItGsZPDgDLnD/iga
2u1vLnD3Y+hwd6yv4ZVkMJZjj8+y8gO56NunWPE6/JbgwQS2+EEZTj4j519L
hR6wzetvqoVqDNspRIah0xS5H6++SgXmDjWmR3FVcHin5AkpIQwZ2dodLCNL
BVqzJXpavA/Z8Lis/hDf10sED1azxa8pONw/yV4nCRR8leaaosNhn67+RSb8
PP3x9dSxnauJYKqYESdk5A3SgW3bm/D3Eb9gHSrhnQgKZieHmK7rwEwAz+ti
EobCCR6sfQsPJlhiynAnOQUU65WCz7BUQYgdh6C2FIbiXr5iUhJLgc09HQ/J
L5fDo2Xuv006OF7uaaV7mov3M0HU4dddSkBVnYnvB95X0Ie/4/x+MRkMH49u
urQWwsSfK99WfTF0guDB4rbwYBaD46ekRBKhg0r7sEhkCLRr3n30bhLvJxnv
5GlFJMA+dn6JOSFP0GZXjczB37NCI9N/Lyke8g78MatquAU3rr/zo/qNIfKa
+G2WkvGg3M16yrzOHb0Kk2nx/cffm+DBMrbwYJ5aqewBLsnw/ciTyNo/ZcAZ
x8d55h8dULP6Y07GZKD59vV8wssSCI0Wm259g6H6gyNl2t+ToO582hUX6iKo
WXh1LAP/XT0yhufZjyaB1htu8vELAEvkxT678D45UOZsPktOIuxMyrVa8cwG
rJG3m6MIQ8cJHoxhCw+26/0Plhe34yGpWn3sl0gQ8CkB/9IMhopoVTSPhsYB
XPl2mdbnCxQWe3ykx3+vhzZpenkxFuh8cslvPbwOv1V1mQfnMOS7r2Uh9Eos
zF8XZjXp/oQelqdS+uLPeS5qlExHxwCtzXbdxrAfqOsz86gGHp8+ggfj3eIv
tEzwJ3Zb+JPw/dKiO6iSwMCdfZOapwh2GTl67fHD0L7X8VF78H5Gu8fm/dkx
ANrwRrmGeAxpWO80mOJLBPT34tdfQTngf6rzXDrgz5N9XxvZJcDdfFu22WcZ
cNTxIvaPTkr2g/6icVo8vM/uaPt1NwVOH8TUsnCcdYvgxx5t4ccOB+sdOfse
75cWErxbNX5A5vFB5mgMQyElnLaFvTHA0btkxzr7GdyBm3MGj4OWhlvtqzMx
wM337ThLlzL4z3nce7iAx2eJPfqQXzR4B9xnLIz5gNKMl62l8ee23D7Rj8mi
ITv+A2KX9UNmgvf0nfDvuXhhNy2zWRSwr6SNSJqGIt/pHod//Lq/E/zSyy38
EhNxX5lC3Fe2EfeVA1v8nzWJ+1MGzt2P7h4tBS4+ZbYCngkYpl09XH1zBGUT
96q9xL1qEHGvWk/o65UJfT0/oa9/scd51/WMKlC3Sv/4YucANBnMsmf3TKFW
Qp9OTujTzxP69Cjhn7uX4hvhqzRVnWt3Lyxk15BdGp5Cpwl+rJTwf+gn+LEz
xP0pPXF/GkPcn5bF867vfVcMeR/ajl8IHIWwzyyu6rvHkd/SD+GlgRJw/CR1
7OzUEASpW3QeuziJHuXSx6kolEO52S73/axtcOjSm7nbz2eRGaH7fkjovn8T
um8TefcO17JyUH9M1nParhwa9NS6Sob/7x7Wf+R/72EfppcznC4pgqkQMwVs
dQxlOt5fmyoZRb/z33zNd82DPNLr2JmQaaBZj7O11u9H7fPtoWH//C5rI//J
lxPA6vh05JzUCDpmr+OY+q4A8s4KU7SxjsOFZalgq9JRpEL4uggSvi5MhK/L
PVMDElorhMfVluTNJsMg4F5kHk85icSLb9KGRhSBQJXRkXWuQWAQ+XqaPWgK
7aJRH5SWK4bbojodrgM9YCfXQb3zyAw6yPrqWNtaMZiQ7isr8tXDJ8V3QQx4
X7FO6LUfE3rtnYReuzev55RqWA4YsbAbvX85C4EVdPbbfrcjQWIOpJiYA7lL
zIF8Clc6dtu7FqxGJp6QqjyB+6SBzJ0D+P4i5ij+Lv87R2FEzFHEEPMMxxz/
nWewJuYZ/j/mc4TV
    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.520916814875*^9, {3.52091807921875*^9, 3.520918108171875*^9}, 
   3.520918163390625*^9, 3.520942720625*^9, 3.520943080703125*^9},
 CellTags->"Member",
 CellLabel->"Out[85]=",
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorThetaPerDay", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Spot", 
     RowBox[{"spot", " ", 
      RowBox[{"value", "."}]}]},
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spot", "=", "100."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{"\"\<Call\>\"", ",", " ", "100.", ",", "100.", ",", "0.2"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.520918173640625*^9},
 CellTags->"Member",
 CellLabel->"In[86]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorThetaPerDay[obj,Spot,TimeToMaturity]", "Input",
 CellChangeTimes->{{3.520918131828125*^9, 3.52091813221875*^9}, 
   3.520918177265625*^9},
 CellTags->"Member",
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"-", "0.004531421774851735`"}]], "Output",
 CellChangeTimes->{3.520918178859375*^9, 3.520942720890625*^9, 
  3.52094308084375*^9},
 CellTags->"Member",
 CellLabel->"Out[89]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Plot3D[BlackCalculatorTheta[obj,Spot,TimeToMaturity],{Spot,80,120},{\
TimeToMaturity,1,10},PlotRange->All]\
\>", "Input",
 CellChangeTimes->{{3.520918131828125*^9, 3.52091813221875*^9}, 
   3.520918177265625*^9},
 CellTags->"Member",
 CellLabel->"In[90]:="],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nXk4VV3Y8I95liFDSc5Bs0qzxrM1SRNJiGYJRXMqkrEJJZIGQyUNkjRI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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmgf8V9Mbx8+553uRFVp2IhHJiDRkNJBskVJJWpKiUlRIoZSiJKkQCikj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         "]], Polygon3DBox[CompressedData["
1:eJw1mgXY3VTaRZOcXBhgcHdKKe46OC0wuBV3dx0G90KhSHG3wd2tuBR3p2hx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         "]], Polygon3DBox[CompressedData["
1:eJwt12WgVNUWAOB7584I6jN44jOQZysiKgYhYREqBo1BSiqSKqWICIigSHcJ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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0jksZWEYBuCfi+G6195JjK0lCrFelURkMISIoBMNhSUaColkJISeikwz
OtHQiWZ0orHvSylqidJzonjP8365yf+d5VaMTfdPpYUQ1qRFiXqDyxtrYyEU
sIk/2cFaDrKN4+zmHEf5h8syqf/lAve4yiNu8pQ7fOAB33nMxYwQ4vam5Dza
ySr5kR7ChTmbl8zhFeO8Zi5vmOAtk7xjHvPlXi/gAwv5yCI+sZjPLOFLdIZ7
SdjZJq/mZlZLlns7M3/6/T/fuM87/uMJN3jIFe5yntvckgl9iSOcZRfHmOIA
a7huR6ldZfqM/sFWcz4bWSTDkmceYpLtHJSEXumcej1XL9fr9LheFp2v5+h9
7JVs/Xf0btkTPR+7mclftD50MhZ9c6ZH79WQTPv+j3wB+qE2VA==
       "]]}, {
      Line3DBox[{814, 1130, 1181, 1493, 813, 1298, 1031, 815, 1299, 1032, 816,
        1300, 1033, 817, 1287, 1301, 1151, 1034, 818, 1289, 1302, 1152, 1035, 
       819, 1291, 1303, 1153, 1036, 820, 1496, 1132, 1154, 1182, 1495, 1174, 
       1175, 1176, 1134, 1499, 1037, 1173, 1177, 1178, 1135, 1296, 1500, 1038,
        1171, 1126, 1172, 1522, 1180, 1039, 1179, 1297, 1304, 1040, 821, 1305,
        1041, 822, 1292, 1306, 1042, 1136}], 
      Line3DBox[{824, 1183, 1393, 823, 1184, 1394, 825, 1137, 1155, 1518, 
       1043, 826, 1139, 1156, 1519, 1044, 827, 1288, 1307, 1157, 1045, 828, 
       1290, 1308, 1158, 1046, 829, 1494, 1131, 1159, 1047, 830, 1498, 1133, 
       1160, 1185, 1497, 831, 1127, 1161, 1186, 1492, 832, 1128, 1162, 1520, 
       1048, 833, 1129, 1309, 1049, 834, 1310, 1050, 835, 1311, 1051, 836, 
       1508, 1146, 1052, 1163}], 
      Line3DBox[{838, 1187, 1395, 837, 1147, 1164, 1188, 1509, 839, 1138, 
       1165, 1189, 1501, 840, 1140, 1166, 1521, 1053, 841, 1293, 1312, 1167, 
       1054, 842, 1502, 1141, 1168, 1055, 843, 1503, 1142, 1169, 1056, 844, 
       1505, 1143, 1170, 1190, 1504, 845, 1144, 1191, 1506, 846, 1145, 1192, 
       1507, 847, 1313, 1057, 848, 1314, 1058, 849, 1315, 1059, 850, 1316, 
       1060, 851}], 
      Line3DBox[{853, 1193, 1396, 852, 258, 1510, 854, 259, 1511, 855, 260, 
       1512, 856, 1513, 261, 857, 1514, 262, 858, 1515, 263, 859, 1517, 264, 
       1516, 860, 1194, 1397, 861, 1195, 1398, 862, 1196, 1399, 863, 1317, 
       1061, 864, 1318, 1062, 865, 1319, 1063, 866}], 
      Line3DBox[{868, 1197, 1400, 867, 1198, 1401, 869, 1199, 1402, 870, 1200,
        1403, 871, 1201, 1404, 872, 1320, 1064, 873, 1321, 1065, 874, 1322, 
       1202, 1405, 875, 1203, 1406, 876, 1204, 1407, 877, 1205, 1408, 878, 
       1206, 1409, 879, 1323, 1066, 880, 1324, 1067, 881}], 
      Line3DBox[{883, 1207, 1410, 882, 1208, 1411, 884, 1209, 1412, 885, 1210,
        1413, 886, 1211, 1414, 887, 1212, 1415, 888, 1325, 1068, 889, 1326, 
       1213, 1416, 890, 1214, 1417, 891, 1215, 1418, 892, 1216, 1419, 893, 
       1217, 1420, 894, 1218, 1421, 895, 1327, 1069, 896}], 
      Line3DBox[{900, 1328, 1070, 898, 1329, 1071, 902, 1330, 1072, 904, 1331,
        1073, 906, 1332, 1074, 908, 1333, 1075, 910, 1334, 1076, 912, 1336, 
       1337, 1077, 914, 1338, 1078, 916, 1339, 1079, 918, 1340, 1080, 920, 
       1341, 1081, 922, 1342, 1082, 924, 1343, 1083, 926}], 
      Line3DBox[{925, 1435, 1232, 923, 1434, 1231, 921, 1433, 1230, 919, 1432,
        1229, 917, 1431, 1228, 915, 1430, 1227, 913, 1429, 1226, 1335, 911, 
       1428, 1225, 909, 1427, 1224, 907, 1426, 1223, 905, 1425, 1222, 903, 
       1424, 1221, 901, 1423, 1220, 897, 1422, 1219, 899}], 
      Line3DBox[{928, 1233, 1436, 927, 1344, 1084, 929, 1345, 1085, 930, 1346,
        1086, 931, 1347, 1087, 932, 1348, 1088, 933, 1349, 1089, 934, 1350, 
       1234, 1437, 935, 1351, 1090, 936, 1352, 1091, 937, 1353, 1092, 938, 
       1354, 1093, 939, 1355, 1094, 940, 1356, 1095, 941}], 
      Line3DBox[{943, 1235, 1438, 942, 1236, 1439, 944, 1357, 1096, 945, 1358,
        1097, 946, 1359, 1098, 947, 1360, 1099, 948, 1361, 1100, 949, 1362, 
       1237, 1440, 950, 1238, 1441, 951, 1363, 1101, 952, 1364, 1102, 953, 
       1365, 1103, 954, 1366, 1104, 955, 1367, 1105, 956}], 
      Line3DBox[{958, 1239, 1442, 957, 1240, 1443, 959, 1241, 1444, 960, 1368,
        1106, 961, 1369, 1107, 962, 1370, 1108, 963, 1371, 1109, 964, 1372, 
       1242, 1445, 965, 1243, 1446, 966, 1244, 1447, 967, 1373, 1110, 968, 
       1374, 1111, 969, 1375, 1112, 970, 1376, 1113, 971}], 
      Line3DBox[{973, 1245, 1448, 972, 1246, 1449, 974, 1247, 1450, 975, 1248,
        1451, 976, 1377, 1114, 977, 1378, 1115, 978, 1379, 1116, 979, 1380, 
       1249, 1452, 980, 1250, 1453, 981, 1251, 1454, 982, 1252, 1455, 983, 
       1381, 1117, 984, 1382, 1118, 985, 1383, 1119, 986}], 
      Line3DBox[{988, 1253, 1456, 987, 1254, 1457, 989, 1255, 1458, 990, 1256,
        1459, 991, 1257, 1460, 992, 1384, 1120, 993, 1385, 1121, 994, 1386, 
       1258, 1461, 995, 1259, 1462, 996, 1260, 1463, 997, 1261, 1464, 998, 
       1262, 1465, 999, 1387, 1122, 1000, 1388, 1123, 1001}], 
      Line3DBox[{1003, 1263, 1466, 1002, 1264, 1467, 1004, 1265, 1468, 1005, 
       1266, 1469, 1006, 1267, 1470, 1007, 1268, 1471, 1008, 1389, 1124, 1009,
        1390, 1269, 1472, 1010, 1270, 1473, 1011, 1271, 1474, 1012, 1272, 
       1475, 1013, 1273, 1476, 1014, 1274, 1477, 1015, 1391, 1125, 1016}], 
      Line3DBox[{1030, 1150, 1491, 1295, 1029, 1490, 1286, 1028, 1489, 1285, 
       1027, 1488, 1284, 1026, 1487, 1283, 1025, 1486, 1282, 1024, 1485, 1281,
        1392, 1023, 1484, 1280, 1022, 1483, 1279, 1021, 1482, 1278, 1020, 
       1481, 1277, 1019, 1480, 1276, 1018, 1479, 1275, 1017, 1294, 1478, 1148,
        1149}]}, {
      Line3DBox[{326, 534, 1298, 327, 1394, 541, 348, 764, 1509, 551, 359, 
       765, 1510, 562, 370, 1401, 573, 385, 1411, 588, 400, 1423, 603, 1329, 
       415, 618, 1344, 430, 1439, 633, 445, 1443, 648, 460, 1449, 663, 475, 
       1457, 678, 490, 1467, 693, 505, 1479, 708, 520}], 
      Line3DBox[{328, 535, 1299, 329, 747, 542, 1518, 349, 748, 1501, 552, 
       360, 766, 1511, 563, 371, 1402, 574, 386, 1412, 589, 401, 1424, 604, 
       1330, 416, 619, 1345, 431, 634, 1357, 446, 1444, 649, 461, 1450, 664, 
       476, 1458, 679, 491, 1468, 694, 506, 1480, 709, 521}], 
      Line3DBox[{330, 536, 1300, 331, 749, 543, 1519, 350, 750, 553, 1521, 
       361, 767, 1512, 564, 372, 1403, 575, 387, 1413, 590, 402, 1425, 605, 
       1331, 417, 620, 1346, 432, 635, 1358, 447, 650, 1368, 462, 1451, 665, 
       477, 1459, 680, 492, 1469, 695, 507, 1481, 710, 522}], 
      Line3DBox[{332, 727, 728, 1301, 782, 729, 730, 1307, 786, 751, 752, 
       1312, 790, 768, 1513, 769, 373, 1404, 576, 388, 1414, 591, 403, 1426, 
       606, 1332, 418, 621, 1347, 433, 636, 1359, 448, 651, 1369, 463, 666, 
       1377, 478, 1460, 681, 493, 1470, 696, 508, 1482, 711, 523}], 
      Line3DBox[{333, 731, 732, 1302, 783, 733, 734, 1308, 787, 753, 1502, 
       754, 791, 770, 1514, 771, 374, 577, 1320, 389, 1415, 592, 404, 1427, 
       607, 1333, 419, 622, 1348, 434, 637, 1360, 449, 652, 1370, 464, 667, 
       1378, 479, 682, 1384, 494, 1471, 697, 509, 1483, 712, 524}], 
      Line3DBox[{334, 735, 736, 1303, 784, 737, 1494, 738, 788, 755, 1503, 
       756, 792, 772, 1515, 773, 375, 578, 1321, 390, 593, 1325, 405, 1428, 
       608, 1334, 420, 623, 1349, 435, 638, 1361, 450, 653, 1371, 465, 668, 
       1379, 480, 683, 1385, 495, 698, 1389, 510, 1484, 713, 525}], 
      Line3DBox[{335, 739, 1496, 741, 785, 742, 1498, 744, 789, 757, 1505, 
       759, 793, 774, 1517, 776, 376, 579, 1322, 391, 594, 1326, 406, 609, 
       1335, 1336, 421, 624, 1350, 436, 639, 1362, 451, 654, 1372, 466, 669, 
       1380, 481, 684, 1386, 496, 699, 1390, 511, 714, 1392, 526}], 
      Line3DBox[{341, 812, 803, 806, 804, 1304, 342, 548, 1310, 355, 558, 
       1314, 366, 569, 1317, 381, 1409, 584, 396, 1420, 599, 411, 1433, 614, 
       1341, 426, 629, 1354, 441, 644, 1365, 456, 659, 1374, 471, 674, 1381, 
       486, 1465, 689, 501, 1476, 704, 516, 1489, 719, 531}], 
      Line3DBox[{343, 539, 1305, 344, 549, 1311, 356, 559, 1315, 367, 570, 
       1318, 382, 585, 1323, 397, 1421, 600, 412, 1434, 615, 1342, 427, 630, 
       1355, 442, 645, 1366, 457, 660, 1375, 472, 675, 1382, 487, 690, 1387, 
       502, 1477, 705, 517, 1490, 720, 532}], 
      Line3DBox[{345, 745, 746, 1306, 346, 762, 1508, 763, 357, 560, 1316, 
       368, 571, 1319, 383, 586, 1324, 398, 601, 1327, 413, 1435, 616, 1343, 
       428, 631, 1356, 443, 646, 1367, 458, 661, 1376, 473, 676, 1383, 488, 
       691, 1388, 503, 706, 1391, 518, 1491, 778, 779, 780}], 
      Line3DBox[{519, 707, 777, 1478, 504, 692, 1466, 489, 677, 1456, 474, 
       662, 1448, 459, 647, 1442, 444, 632, 1438, 429, 617, 1436, 414, 1328, 
       602, 1422, 399, 587, 1410, 384, 572, 1400, 369, 561, 1396, 358, 550, 
       1395, 347, 540, 1393, 325, 533, 1493, 726, 781}], 
      Line3DBox[{527, 715, 1485, 512, 700, 1472, 497, 685, 1461, 482, 670, 
       1452, 467, 655, 1445, 452, 640, 1440, 437, 625, 1437, 422, 1337, 610, 
       1429, 407, 595, 1416, 392, 580, 1405, 377, 565, 1516, 775, 362, 554, 
       1504, 758, 351, 544, 1497, 743, 337, 537, 1495, 799, 740, 336}], 
      Line3DBox[{528, 716, 1486, 513, 701, 1473, 498, 686, 1462, 483, 671, 
       1453, 468, 656, 1446, 453, 641, 1441, 438, 1351, 626, 423, 1338, 611, 
       1430, 408, 596, 1417, 393, 581, 1406, 378, 566, 1397, 363, 555, 1506, 
       760, 352, 545, 1492, 723, 338, 1499, 538, 797, 810, 809, 798}], 
      Line3DBox[{529, 717, 1487, 514, 702, 1474, 499, 687, 1463, 484, 672, 
       1454, 469, 657, 1447, 454, 1363, 642, 439, 1352, 627, 424, 1339, 612, 
       1431, 409, 597, 1418, 394, 582, 1407, 379, 567, 1398, 364, 556, 1507, 
       761, 353, 1520, 546, 724, 339, 1500, 796, 795, 794, 721, 801, 800}], 
      Line3DBox[{530, 718, 1488, 515, 703, 1475, 500, 688, 1464, 485, 673, 
       1455, 470, 1373, 658, 455, 1364, 643, 440, 1353, 628, 425, 1340, 613, 
       1432, 410, 598, 1419, 395, 583, 1408, 380, 568, 1399, 365, 1313, 557, 
       354, 1309, 547, 725, 340, 808, 1522, 807, 805, 722, 811, 
       802}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxcenk0lf/3vRJpljJkniIiQpTSqUwloSjKUGQqiiJSSIqikEShiELmeR6O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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.52091681490625*^9, 3.52091818109375*^9, 
  3.52094272246875*^9, 3.5209430863125*^9},
 CellTags->"Member",
 CellLabel->"Out[90]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorVega", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{"\"\<Call\>\"", ",", " ", "100.", ",", "100.", ",", "0.2"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.52091820175*^9},
 CellTags->"Member",
 CellLabel->"In[91]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorVega[obj,TimeToMaturity]", "Input",
 CellTags->"Member",
 CellLabel->"In[93]:="],

Cell[BoxData["61.49562422452303`"], "Output",
 CellChangeTimes->{3.520916814953125*^9, 3.520918206875*^9, 
  3.520942722609375*^9, 3.520943086484375*^9},
 CellTags->"Member",
 CellLabel->"Out[93]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorRho", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{"\"\<Call\>\"", ",", " ", "100.", ",", "100.", ",", "0.2"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091822565625*^9, 3.520918242484375*^9}},
 CellTags->"Member",
 CellLabel->"In[94]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorRho[obj,TimeToMaturity]", "Input",
 CellTags->"Member",
 CellLabel->"In[96]:="],

Cell[BoxData["110.44131905351301`"], "Output",
 CellChangeTimes->{
  3.520916814984375*^9, {3.520918228625*^9, 3.52091824378125*^9}, 
   3.5209427226875*^9, 3.52094308659375*^9},
 CellTags->"Member",
 CellLabel->"Out[96]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorDividendRho", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"obj", " ", "=", " ", 
   RowBox[{"BlackCalculator", "[", 
    RowBox[{"\"\<Call\>\"", ",", " ", "100.", ",", "100.", ",", "0.2"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091822565625*^9, 3.520918242484375*^9}},
 CellTags->"Member",
 CellLabel->"In[97]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorDividendRho[obj,TimeToMaturity]", "Input",
 CellTags->"Member",
 CellLabel->"In[99]:="],

Cell[BoxData[
 RowBox[{"-", "129.55868094648693`"}]], "Output",
 CellChangeTimes->{3.520916815015625*^9, 3.520918253640625*^9, 
  3.52094272275*^9, 3.52094308665625*^9},
 CellTags->"Member",
 CellLabel->"Out[99]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorItmCashProbability", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"obj", " ", "=", " ", 
    RowBox[{"BlackCalculator", "[", 
     RowBox[{
     "\"\<Call\>\"", ",", " ", "100.", ",", " ", "100.", ",", " ", "0.2"}], 
     "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.520918263734375*^9, 3.520918289390625*^9}},
 CellTags->"Member",
 CellLabel->"In[100]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorItmCashProbability[obj]", "Input",
 CellChangeTimes->{{3.520918263734375*^9, 3.5209182931875*^9}},
 CellTags->"Member",
 CellLabel->"In[101]:="],

Cell[BoxData["0.460172162722971`"], "Output",
 CellChangeTimes->{
  3.520916815046875*^9, {3.520918264875*^9, 3.5209182936875*^9}, 
   3.5209427228125*^9, 3.52094308671875*^9},
 CellTags->"Member",
 CellLabel->"Out[101]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorItmAssetProbability", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"obj", " ", "=", " ", 
    RowBox[{"BlackCalculator", "[", 
     RowBox[{
     "\"\<Call\>\"", ",", " ", "100.", ",", " ", "100.", ",", " ", "0.2"}], 
     "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.520918263734375*^9, 3.520918289390625*^9}},
 CellTags->"Member",
 CellLabel->"In[102]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorItmAssetProbability[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[103]:="],

Cell[BoxData["0.539827837277029`"], "Output",
 CellChangeTimes->{3.520916815078125*^9, 3.520918307890625*^9, 
  3.520942722875*^9, 3.520943086796875*^9},
 CellTags->"Member",
 CellLabel->"Out[103]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorStrikeSensitivity", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"obj", " ", "=", " ", 
    RowBox[{"BlackCalculator", "[", 
     RowBox[{
     "\"\<Call\>\"", ",", " ", "100.", ",", " ", "100.", ",", " ", "0.2"}], 
     "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.520918263734375*^9, 3.520918289390625*^9}},
 CellTags->"Member",
 CellLabel->"In[104]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorStrikeSensitivity[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[105]:="],

Cell[BoxData[
 RowBox[{"-", "0.460172162722971`"}]], "Output",
 CellChangeTimes->{3.520916815109375*^9, 3.520918320953125*^9, 
  3.5209427229375*^9, 3.52094308684375*^9},
 CellTags->"Member",
 CellLabel->"Out[105]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorAlpha", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"obj", " ", "=", " ", 
    RowBox[{"BlackCalculator", "[", 
     RowBox[{
     "\"\<Call\>\"", ",", " ", "100.", ",", " ", "100.", ",", " ", "0.2"}], 
     "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.520918263734375*^9, 3.520918289390625*^9}},
 CellTags->"Member",
 CellLabel->"In[106]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorAlpha[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[107]:="],

Cell[BoxData["0.539827837277029`"], "Output",
 CellChangeTimes->{3.520916815140625*^9, 3.52091833275*^9, 3.520942723*^9, 
  3.520943086921875*^9},
 CellTags->"Member",
 CellLabel->"Out[107]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackCalculatorBeta", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"obj", " ", "=", " ", 
    RowBox[{"BlackCalculator", "[", 
     RowBox[{
     "\"\<Call\>\"", ",", " ", "100.", ",", " ", "100.", ",", " ", "0.2"}], 
     "]"}]}], ";"}], " "}]], "Input",
 CellLabel->"In[108]:="],

Cell[CellGroupData[{

Cell["BlackCalculatorBeta[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[109]:="],

Cell[BoxData[
 RowBox[{"-", "0.460172162722971`"}]], "Output",
 CellChangeTimes->{3.520916815171875*^9, 3.520918342125*^9, 
  3.5209427230625*^9, 3.52094308696875*^9},
 CellTags->"Member",
 CellLabel->"Out[109]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorDelta", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obj", " ", "=", " ", 
  RowBox[{"BlackScholesCalculator", "[", 
   RowBox[{"\"\<Call\>\"", ",", "100.", ",", "100.", ",", " ", "0.2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.520918395234375*^9, 3.5209184016875*^9}},
 CellLabel->"In[110]:="],

Cell[BoxData["BlackScholesCalculator42"], "Output",
 CellChangeTimes->{3.5209184025625*^9, 3.520942723109375*^9, 
  3.52094308703125*^9},
 CellLabel->"Out[110]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorDelta[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[111]:="],

Cell[BoxData["0.5398278372770291`"], "Output",
 CellChangeTimes->{3.520916815203125*^9, 3.5209184035*^9, 
  3.520942723140625*^9, 3.5209430870625*^9},
 CellTags->"Member",
 CellLabel->"Out[111]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorElasticity", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorElasticity[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[112]:="],

Cell[BoxData["6.777016707211196`"], "Output",
 CellChangeTimes->{3.520916815234375*^9, 3.52091840671875*^9, 
  3.5209427231875*^9, 3.520943087109375*^9},
 CellTags->"Member",
 CellLabel->"Out[112]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorGamma", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorGamma[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[113]:="],

Cell[BoxData["0.019847627373850592`"], "Output",
 CellChangeTimes->{3.52091681525*^9, 3.520918408203125*^9, 
  3.520942723234375*^9, 3.52094308715625*^9},
 CellTags->"Member",
 CellLabel->"Out[113]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorTheta", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}]], "Input",
 CellChangeTimes->{{3.520918415109375*^9, 3.520918415734375*^9}},
 CellTags->"Member",
 CellLabel->"In[114]:="],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorTheta[obj,TimeToMaturity]", "Input",
 CellTags->"Member",
 CellLabel->"In[115]:="],

Cell[BoxData[
 RowBox[{"-", "1.6539689478208832`"}]], "Output",
 CellChangeTimes->{3.520916815296875*^9, 3.52091841696875*^9, 
  3.52094272328125*^9, 3.52094308721875*^9},
 CellTags->"Member",
 CellLabel->"Out[115]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorThetaPerDay", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"TimeToMaturity", 
     RowBox[{"time", " ", "to", " ", "maturity", " ", "in", " ", 
      RowBox[{"years", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeToMaturity", "=", "2.4"}], ";"}]], "Input",
 CellChangeTimes->{{3.5209184236875*^9, 3.520918424453125*^9}},
 CellTags->"Member",
 CellLabel->"In[116]:="],

Cell[CellGroupData[{

Cell["BlackScholesCalculatorThetaPerDay[obj,TimeToMaturity]", "Input",
 CellTags->"Member",
 CellLabel->"In[117]:="],

Cell[BoxData[
 RowBox[{"-", "0.004531421774851735`"}]], "Output",
 CellChangeTimes->{3.520916815328125*^9, 3.5209184256875*^9, 
  3.52094272334375*^9, 3.52094308728125*^9},
 CellTags->"Member",
 CellLabel->"Out[117]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedures", "Section",
 CellTags->"Procedure"],

Cell[CellGroupData[{

Cell["BlackFormula", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionType", 
     RowBox[{"option", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "Call"}], " ", "or", " ", "Put"}], 
        ")"}], "."}]}]},
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionType", "=", "\"\<Call\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{{3.520918434390625*^9, 3.52091843646875*^9}},
 CellTags->"Procedure",
 CellLabel->"In[118]:="],

Cell[CellGroupData[{

Cell["BlackFormula[OptionType,Strike,AtmForwardValue,StdDev]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[122]:="],

Cell[BoxData["7.965567455405804`"], "Output",
 CellChangeTimes->{3.520916815359375*^9, 3.52091843821875*^9, 
  3.520942723421875*^9, 3.52094308734375*^9},
 CellTags->"Procedure",
 CellLabel->"Out[122]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaCashItmProbability", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionType", 
     RowBox[{"option", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "Call"}], " ", "or", " ", "Put"}], 
        ")"}], "."}]}]},
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionType", "=", "\"\<Call\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{{3.520918481875*^9, 3.520918483203125*^9}},
 CellTags->"Procedure",
 CellLabel->"In[123]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaCashItmProbability[OptionType,Strike,AtmForwardValue,StdDev]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[127]:="],

Cell[BoxData["0.460172162722971`"], "Output",
 CellChangeTimes->{3.52091681546875*^9, 3.520918492796875*^9, 
  3.520942723484375*^9, 3.5209430875625*^9},
 CellTags->"Procedure",
 CellLabel->"Out[127]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaImpliedStdDevApproximation", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionType", 
     RowBox[{"option", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "Call"}], " ", "or", " ", "Put"}], 
        ")"}], "."}]}]},
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"OptionPrice", 
     RowBox[{"option", " ", 
      RowBox[{"price", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionType", "=", "\"\<Call\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionPrice", "=", "7.97"}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091850396875*^9, 3.520918505765625*^9}},
 CellTags->"Procedure",
 CellLabel->"In[128]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaImpliedStdDevApproximation[OptionType,Strike,AtmForwardValue,\
OptionPrice]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[132]:="],

Cell[BoxData["0.1997782734880907`"], "Output",
 CellChangeTimes->{3.5209168155625*^9, 3.520918507421875*^9, 
  3.520942723609375*^9, 3.520943087625*^9},
 CellTags->"Procedure",
 CellLabel->"Out[132]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaImpliedStdDevApproximation\
\>", "Subsubsection",
 CellChangeTimes->{
  3.520918688765625*^9, {3.520918747515625*^9, 3.5209187508125*^9}},
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionType", 
     RowBox[{"option", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "Call"}], " ", "or", " ", "Put"}], 
        ")"}], "."}]}]},
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"OptionPrice", 
     RowBox[{"option", " ", 
      RowBox[{"price", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]},
    {"Guess", "0.0", 
     RowBox[{"standard", " ", "deviation", " ", 
      RowBox[{"guess", "."}]}]},
    {"Accuracy", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "6"}], 
     RowBox[{"solver", " ", 
      RowBox[{"accuracy", "."}]}]},
    {"MaxIter", "100", 
     RowBox[{"solver", " ", "max", " ", 
      RowBox[{"iterations", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionType", "=", "\"\<Call\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionPrice", "=", "7.97"}], ";"}]}], "Input",
 CellChangeTimes->{{3.520918516453125*^9, 3.52091851878125*^9}},
 CellTags->"Procedure",
 CellLabel->"In[133]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaImpliedStdDevApproximation[OptionType,Strike,AtmForwardValue,\
OptionPrice]\
\>", "Input",
 CellChangeTimes->{3.5209186931875*^9, {3.520918755125*^9, 3.520918758375*^9}},
 CellTags->"Procedure",
 CellLabel->"In[137]:="],

Cell[BoxData["0.1997782734880907`"], "Output",
 CellChangeTimes->{3.520916815609375*^9, 3.520918522328125*^9, 
  3.52091869653125*^9, 3.520918758953125*^9, 3.520942723671875*^9, 
  3.520943087703125*^9},
 CellTags->"Procedure",
 CellLabel->"Out[137]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaStdDevDerivative", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Strike", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellTags->"Procedure",
 CellLabel->"In[138]:="],

Cell[CellGroupData[{

Cell["BlackFormulaStdDevDerivative[Strike,AtmForwardValue,StdDev]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[141]:="],

Cell[BoxData["39.69525474770118`"], "Output",
 CellChangeTimes->{3.520916815703125*^9, 3.520942723734375*^9, 
  3.52094308775*^9},
 CellTags->"Procedure",
 CellLabel->"Out[141]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BachelierBlackFormula", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionType", 
     RowBox[{"option", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "Call"}], " ", "or", " ", "Put"}], 
        ")"}], "."}]}]},
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "ABSOLUTE", " ", 
       "volatility", " ", "times", " ", "the", " ", "square", " ", "root", 
       " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionType", "=", "\"\<Call\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "20.0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5209187709375*^9, 3.520918772484375*^9}},
 CellTags->"Procedure",
 CellLabel->"In[142]:="],

Cell[CellGroupData[{

Cell["\<\
BachelierBlackFormula[OptionType,Strike,AtmForwardValue,StdDev]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[146]:="],

Cell[BoxData["7.978845608028654`"], "Output",
 CellChangeTimes->{3.52091681575*^9, 3.520918775890625*^9, 3.5209427238125*^9,
   3.5209430878125*^9},
 CellTags->"Procedure",
 CellLabel->"Out[146]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormula2", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", 
     RowBox[{"PlainVanillaPayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Payoff", "=", 
   RowBox[{"PlainVanillaPayoff", "[", 
    RowBox[{"\"\<Call\>\"", ",", "K"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{{3.520943244546875*^9, 3.520943262953125*^9}},
 CellTags->"Procedure",
 CellLabel->"In[182]:="],

Cell[CellGroupData[{

Cell["BlackFormula2[Payoff,AtmForwardValue,StdDev]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[185]:="],

Cell[BoxData["60.00000584876746`"], "Output",
 CellChangeTimes->{
  3.52091681578125*^9, 3.520942724078125*^9, 3.52094308790625*^9, {
   3.52094324753125*^9, 3.520943264390625*^9}},
 CellTags->"Procedure",
 CellLabel->"Out[185]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaCashItmProbability2", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", 
     RowBox[{"PlainVanillaPayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"K", " ", "=", " ", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Payoff", "=", 
    RowBox[{"PlainVanillaPayoff", "[", 
     RowBox[{"\"\<Call\>\"", ",", "K"}], "]"}]}], ";"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.5209432165*^9, {3.520943286828125*^9, 3.52094328803125*^9}, {
   3.520943375515625*^9, 3.52094337940625*^9}},
 CellTags->"Procedure",
 CellLabel->"In[213]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaCashItmProbability2[Payoff,AtmForwardValue,StdDev]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[217]:="],

Cell[BoxData["0.460172162722971`"], "Output",
 CellChangeTimes->{3.520916815921875*^9, 3.52094272415625*^9, 
  3.520943087984375*^9, 3.520943219296875*^9, 3.520943289390625*^9, 
  3.52094338075*^9},
 CellTags->"Procedure",
 CellLabel->"Out[217]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaImpliedStdDevApproximation2", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", 
     RowBox[{"PlainVanillaPayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"OptionPrice", 
     RowBox[{"option", " ", 
      RowBox[{"price", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"K", "=", "100"}], ";", " ", 
  RowBox[{"(*", " ", "Strike", " ", "*)"}], "\n", 
  RowBox[{"Payoff", "=", 
   RowBox[{"PlainVanillaPayoff", "[", 
    RowBox[{"\"\<Put\>\"", ",", "K"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionPrice", "=", "7.97"}], ";"}]}], "Input",
 CellChangeTimes->{{3.52091908375*^9, 3.520919102984375*^9}, {
  3.520937202015625*^9, 3.520937208359375*^9}, {3.520942788953125*^9, 
  3.520942795953125*^9}, {3.520943362703125*^9, 3.52094336296875*^9}},
 CellTags->"Procedure",
 CellLabel->"In[209]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaImpliedStdDevApproximation2[Payoff,AtmForwardValue,OptionPrice]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[212]:="],

Cell[BoxData["0.1997782734880907`"], "Output",
 CellChangeTimes->{
  3.520916816015625*^9, 3.520919112390625*^9, 3.52094272428125*^9, {
   3.520942781984375*^9, 3.52094279846875*^9}, 3.520943088046875*^9, 
   3.520943364375*^9},
 CellTags->"Procedure",
 CellLabel->"Out[212]="]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.52094281128125*^9, 3.520942815046875*^9}},
 CellLabel->"In[160]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaImpliedStdDev4", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PayoffID", 
     RowBox[{"PlainVanillaPayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"OptionPrice", 
     RowBox[{"option", " ", 
      RowBox[{"price", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]},
    {"Guess", "0.0", 
     RowBox[{"standard", " ", "deviation", " ", 
      RowBox[{"guess", "."}]}]},
    {"Accuracy", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "6"}], 
     RowBox[{"standard", " ", "deviation", " ", 
      RowBox[{"accuracy", "."}]}]},
    {"MaxIter", "100", 
     RowBox[{"solver", " ", "max", " ", 
      RowBox[{"iterations", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"K", "=", "100"}], ";", " ", 
  RowBox[{"(*", " ", "Strike", " ", "*)"}], "\n", 
  RowBox[{"PayoffID", "=", 
   RowBox[{"PlainVanillaPayoff", "[", 
    RowBox[{"\"\<Put\>\"", ",", "K"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionPrice", "=", "7.97"}], ";"}]}], "Input",
 CellChangeTimes->{{3.520919208640625*^9, 3.520919224640625*^9}, {
  3.5209433204375*^9, 3.520943354046875*^9}},
 CellTags->"Procedure",
 CellLabel->"In[205]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaImpliedStdDevApproximation2[PayoffID,AtmForwardValue,OptionPrice]\
\>", "Input",
 CellChangeTimes->{{3.520919260078125*^9, 3.5209192649375*^9}, 
   3.520919308046875*^9},
 CellTags->"Procedure",
 CellLabel->"In[208]:="],

Cell[BoxData["0.1997782734880907`"], "Output",
 CellChangeTimes->{
  3.5209168160625*^9, 3.52091922615625*^9, 3.520919265609375*^9, 
   3.520919308828125*^9, 3.520942724359375*^9, 3.52094308815625*^9, {
   3.520943309515625*^9, 3.520943355859375*^9}},
 CellTags->"Procedure",
 CellLabel->"Out[208]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackFormulaStdDevDerivative2", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PayoffID", 
     RowBox[{"PlainVanillaPayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "percentage", 
       " ", "volatility", " ", "times", " ", "the", " ", "square", " ", 
       "root", " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]},
    {"Displacement", "0.0", 
     RowBox[{
     "displacement", " ", "in", " ", "a", " ", "displaced", " ", "diffusion", 
      " ", 
      RowBox[{"model", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"K", "=", "100"}], ";", " ", 
  RowBox[{"(*", " ", "Strike", " ", "*)"}], "\n", 
  RowBox[{"PayoffID", "=", 
   RowBox[{"PlainVanillaPayoff", "[", 
    RowBox[{"\"\<Put\>\"", ",", "K"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "0.20"}], ";"}]}], "Input",
 CellChangeTimes->{3.52094339565625*^9},
 CellTags->"Procedure",
 CellLabel->"In[218]:="],

Cell[CellGroupData[{

Cell["\<\
BlackFormulaStdDevDerivative2[PayoffID,AtmForwardValue,StdDev]\
\>", "Input",
 CellTags->"Procedure",
 CellLabel->"In[221]:="],

Cell[BoxData["39.69525474770118`"], "Output",
 CellChangeTimes->{3.520916816109375*^9, 3.5209427244375*^9, 
  3.52094308821875*^9, 3.520943399734375*^9},
 CellTags->"Procedure",
 CellLabel->"Out[221]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BachelierBlackFormula2", "Subsubsection",
 CellTags->"Procedure"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Payoff", 
     RowBox[{"PlainVanillaPayoff", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"AtmForwardValue", 
     RowBox[{
      RowBox[{"underlying", " ", "asset", " ", "at"}], "-", "the", "-", 
      RowBox[{"money", " ", "forward", " ", 
       RowBox[{"value", "."}]}]}]},
    {"StdDev", 
     RowBox[{
      RowBox[{"standard", " ", "deviation"}], ",", " ", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "annualized"}], " ", "ABSOLUTE", " ", 
       "volatility", " ", "times", " ", "the", " ", "square", " ", "root", 
       " ", "of", " ", "time", " ", "to", " ", "option", " ", 
       RowBox[{"expiry", "."}]}]}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Deflator", "1.0", 
     RowBox[{"Deflator", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"usually", " ", "the", " ", "discount", " ", "factor"}], ",",
          " ", 
         RowBox[{"or", " ", "the", " ", "annuity"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Procedure"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"K", "=", "100"}], ";", " ", 
  RowBox[{"(*", " ", "Strike", " ", "*)"}], "\n", 
  RowBox[{"PayoffID", "=", 
   RowBox[{"PlainVanillaPayoff", "[", 
    RowBox[{"\"\<Put\>\"", ",", "K"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmForwardValue", "=", "100.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDev", "=", "20.0"}], ";"}]}], "Input",
 CellChangeTimes->{3.520943408515625*^9},
 CellTags->"Procedure",
 CellLabel->"In[222]:="],

Cell[CellGroupData[{

Cell["BachelierBlackFormula2[Payoff,AtmForwardValue,StdDev]", "Input",
 CellTags->"Procedure",
 CellLabel->"In[225]:="],

Cell[BoxData["7.978845608028654`"], "Output",
 CellChangeTimes->{3.520916816140625*^9, 3.5209427245*^9, 
  3.520943088296875*^9, 3.520943411625*^9},
 CellTags->"Procedure",
 CellLabel->"Out[225]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
WindowSize->{615, 750},
WindowMargins->{{153, Automatic}, {Automatic, -2}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 56, 1, 99, "Chapter",
   CellTags->"Overview"],
  Cell[626, 25, 92, 1, 37, "Text",
   CellTags->"Overview"],
  Cell[721, 28, 94, 1, 53, "MathCaption",
   CellTags->"Overview"],
  Cell[840, 33, 83, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[926, 37, 166, 3, 35, "Print",
   CellTags->"Overview"],
  Cell[1095, 42, 374, 9, 35, "Print",
   CellTags->"Overview"],
  Cell[1484, 54, 142, 4, 37, "Text",
   CellTags->"Overview"],
  Cell[1651, 62, 113, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[1767, 66, 628, 12, 97, "Output",
   CellTags->"Overview"],
  Cell[2432, 83, 108, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[2543, 87, 1064, 19, 211, "Output",
   CellTags->"Overview"],
  Cell[3644, 111, 111, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[3758, 115, 707, 15, 135, "Output",
   CellTags->"Overview"]},
 "Constructor"->{
  Cell[4502, 135, 57, 1, 77, "Section",
   CellTags->"Constructor"],
  Cell[4584, 140, 66, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[5895, 177, 586, 13, 102, "Input",
   CellTags->"Constructor"],
  Cell[6506, 194, 361, 9, 41, "Input",
   CellTags->"Constructor"],
  Cell[6870, 205, 299, 6, 39, "Output",
   CellTags->"Constructor"],
  Cell[7218, 217, 73, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[8520, 255, 343, 10, 82, "Input",
   CellTags->"Constructor"],
  Cell[8888, 269, 308, 8, 41, "Input",
   CellTags->"Constructor"],
  Cell[9199, 279, 230, 4, 39, "Output",
   CellTags->"Constructor"],
  Cell[9478, 289, 64, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[9890, 303, 1121, 28, 182, "Input",
   CellTags->"Constructor"],
  Cell[11036, 335, 144, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[11183, 340, 246, 5, 39, "Output",
   CellTags->"Constructor"],
  Cell[11478, 351, 72, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[11859, 364, 310, 7, 62, "Input",
   CellTags->"Constructor"],
  Cell[12194, 375, 104, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[12301, 379, 230, 5, 39, "Output",
   CellTags->"Constructor"],
  Cell[12580, 390, 72, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[13106, 408, 277, 8, 82, "Input",
   CellTags->"Constructor"],
  Cell[13408, 420, 122, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[13533, 424, 396, 10, 33, "Message",
   CellTags->"Constructor"],
  Cell[13932, 436, 279, 7, 39, "Output",
   CellTags->"Constructor"],
  Cell[14260, 449, 70, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[14749, 465, 376, 11, 62, "Input",
   CellTags->"Constructor"],
  Cell[15150, 480, 108, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[15261, 484, 207, 4, 39, "Output",
   CellTags->"Constructor"],
  Cell[15517, 494, 71, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[16277, 518, 340, 9, 62, "Input",
   CellTags->"Constructor"],
  Cell[16642, 531, 171, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[16816, 536, 249, 5, 39, "Output",
   CellTags->"Constructor"],
  Cell[17114, 547, 70, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[17573, 561, 352, 10, 62, "Input",
   CellTags->"Constructor"],
  Cell[17950, 575, 108, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[18061, 579, 205, 4, 39, "Output",
   CellTags->"Constructor"],
  Cell[18315, 589, 71, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[19084, 612, 287, 8, 62, "Input",
   CellTags->"Constructor"],
  Cell[19396, 624, 107, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[19506, 628, 208, 4, 39, "Output",
   CellTags->"Constructor"],
  Cell[19763, 638, 73, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[20264, 653, 533, 15, 102, "Input",
   CellTags->"Constructor"],
  Cell[20822, 672, 106, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[20931, 676, 239, 5, 39, "Output",
   CellTags->"Constructor"],
  Cell[21219, 687, 61, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[21589, 700, 209, 6, 41, "Input",
   CellTags->"Constructor"],
  Cell[21823, 710, 93, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[21919, 714, 189, 4, 39, "Output",
   CellTags->"Constructor"]},
 "Member"->{
  Cell[22169, 725, 55, 1, 77, "Section",
   CellTags->"Member"],
  Cell[22249, 730, 66, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[22340, 735, 626, 16, 142, "Input",
   CellTags->"Member"],
  Cell[22969, 753, 246, 5, 39, "Output",
   CellTags->"Member"],
  Cell[23264, 764, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[23362, 769, 716, 20, 142, "Input",
   CellTags->"Member"],
  Cell[24081, 791, 225, 5, 39, "Output",
   CellTags->"Member"],
  Cell[24355, 802, 66, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[24639, 812, 614, 16, 122, "Input",
   CellTags->"Member"],
  Cell[31373, 950, 78, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[32033, 972, 99, 2, 41, "Input",
   CellTags->"Member"],
  Cell[32135, 976, 217, 4, 39, "Output",
   CellTags->"Member"],
  Cell[32401, 986, 71, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[32690, 996, 617, 17, 142, "Input",
   CellTags->"Member"],
  Cell[33332, 1017, 159, 3, 41, "Input",
   CellTags->"Member"],
  Cell[33494, 1022, 219, 4, 39, "Output",
   CellTags->"Member"],
  Cell[33762, 1032, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[33838, 1035, 596, 16, 122, "Input",
   CellTags->"Member"],
  Cell[34862, 1069, 66, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[35146, 1079, 352, 9, 41, "Input",
   CellTags->"Member"],
  Cell[35523, 1092, 173, 3, 41, "Input",
   CellTags->"Member"],
  Cell[35699, 1097, 5849, 104, 243, 2060, 39, "CachedBoxData", 
  "BoxData", "Output",
   CellTags->"Member"],
  Cell[41597, 1207, 66, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[42004, 1220, 496, 13, 82, "Input",
   CellTags->"Member"],
  Cell[42953, 1252, 238, 6, 61, "Input",
   CellTags->"Member"],
  Cell[43194, 1260, 135715, 2213, 319, 95856, 1556, "CachedBoxData", 
  "BoxData", "Output",
   CellTags->"Member"],
  Cell[178958, 3479, 72, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[179371, 3492, 425, 12, 82, "Input",
   CellTags->"Member"],
  Cell[179821, 3508, 204, 4, 41, "Input",
   CellTags->"Member"],
  Cell[180028, 3514, 198, 5, 39, "Output",
   CellTags->"Member"],
  Cell[180263, 3524, 268, 8, 81, "Input",
   CellTags->"Member"],
  Cell[180534, 3534, 96007, 1560, 319, "Output",
   CellTags->"Member"],
  Cell[276590, 5100, 65, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[276922, 5110, 364, 10, 62, "Input",
   CellTags->"Member"],
  Cell[277311, 5124, 101, 2, 41, "Input",
   CellTags->"Member"],
  Cell[277415, 5128, 198, 4, 39, "Output",
   CellTags->"Member"],
  Cell[277662, 5138, 64, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[277993, 5148, 391, 10, 62, "Input",
   CellTags->"Member"],
  Cell[278409, 5162, 100, 2, 41, "Input",
   CellTags->"Member"],
  Cell[278512, 5166, 223, 5, 39, "Output",
   CellTags->"Member"],
  Cell[278784, 5177, 72, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[279123, 5187, 391, 10, 62, "Input",
   CellTags->"Member"],
  Cell[279539, 5201, 108, 2, 41, "Input",
   CellTags->"Member"],
  Cell[279650, 5205, 214, 5, 39, "Output",
   CellTags->"Member"],
  Cell[279913, 5216, 79, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[279995, 5219, 346, 10, 41, "Input",
   CellTags->"Member"],
  Cell[280366, 5233, 165, 3, 41, "Input",
   CellTags->"Member"],
  Cell[280534, 5238, 222, 5, 39, "Output",
   CellTags->"Member"],
  Cell[280805, 5249, 80, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[280888, 5252, 346, 10, 41, "Input",
   CellTags->"Member"],
  Cell[281259, 5266, 102, 2, 41, "Input",
   CellTags->"Member"],
  Cell[281364, 5270, 199, 4, 39, "Output",
   CellTags->"Member"],
  Cell[281612, 5280, 78, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[281693, 5283, 346, 10, 41, "Input",
   CellTags->"Member"],
  Cell[282064, 5297, 100, 2, 41, "Input",
   CellTags->"Member"],
  Cell[282167, 5301, 216, 5, 39, "Output",
   CellTags->"Member"],
  Cell[282432, 5312, 66, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[282501, 5315, 346, 10, 41, "Input",
   CellTags->"Member"],
  Cell[282872, 5329, 88, 2, 41, "Input",
   CellTags->"Member"],
  Cell[282963, 5333, 192, 4, 39, "Output",
   CellTags->"Member"],
  Cell[283204, 5343, 65, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[283556, 5358, 87, 2, 41, "Input",
   CellTags->"Member"],
  Cell[283646, 5362, 213, 5, 39, "Output",
   CellTags->"Member"],
  Cell[283908, 5373, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[284479, 5394, 95, 2, 41, "Input",
   CellTags->"Member"],
  Cell[284577, 5398, 196, 4, 39, "Output",
   CellTags->"Member"],
  Cell[284822, 5408, 78, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[284925, 5413, 100, 2, 41, "Input",
   CellTags->"Member"],
  Cell[285028, 5417, 199, 4, 39, "Output",
   CellTags->"Member"],
  Cell[285276, 5427, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[285374, 5432, 95, 2, 41, "Input",
   CellTags->"Member"],
  Cell[285472, 5436, 200, 4, 39, "Output",
   CellTags->"Member"],
  Cell[285721, 5446, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[286061, 5456, 194, 5, 41, "Input",
   CellTags->"Member"],
  Cell[286280, 5465, 110, 2, 41, "Input",
   CellTags->"Member"],
  Cell[286393, 5469, 217, 5, 39, "Output",
   CellTags->"Member"],
  Cell[286659, 5480, 79, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[287005, 5490, 192, 5, 41, "Input",
   CellTags->"Member"],
  Cell[287222, 5499, 116, 2, 41, "Input",
   CellTags->"Member"],
  Cell[287341, 5503, 218, 5, 39, "Output",
   CellTags->"Member"]},
 "Procedure"->{
  Cell[287620, 5515, 53, 1, 77, "Section",
   CellTags->"Procedure"],
  Cell[287698, 5520, 61, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[289387, 5569, 391, 11, 102, "Input",
   CellTags->"Procedure"],
  Cell[289803, 5584, 120, 2, 41, "Input",
   CellTags->"Procedure"],
  Cell[289926, 5588, 203, 4, 39, "Output",
   CellTags->"Procedure"],
  Cell[290178, 5598, 79, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[291567, 5638, 389, 11, 102, "Input",
   CellTags->"Procedure"],
  Cell[291981, 5653, 146, 4, 61, "Input",
   CellTags->"Procedure"],
  Cell[292130, 5659, 202, 4, 39, "Output",
   CellTags->"Procedure"],
  Cell[292381, 5669, 87, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[293820, 5713, 396, 11, 102, "Input",
   CellTags->"Procedure"],
  Cell[294241, 5728, 161, 5, 61, "Input",
   CellTags->"Procedure"],
  Cell[294405, 5735, 201, 4, 39, "Output",
   CellTags->"Procedure"],
  Cell[294655, 5745, 184, 5, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[296536, 5804, 396, 11, 102, "Input",
   CellTags->"Procedure"],
  Cell[296957, 5819, 241, 6, 61, "Input",
   CellTags->"Procedure"],
  Cell[297201, 5827, 252, 5, 39, "Output",
   CellTags->"Procedure"],
  Cell[297502, 5838, 77, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[298989, 5880, 255, 8, 82, "Input",
   CellTags->"Procedure"],
  Cell[299269, 5892, 125, 2, 41, "Input",
   CellTags->"Procedure"],
  Cell[299397, 5896, 179, 4, 39, "Output",
   CellTags->"Procedure"],
  Cell[299625, 5906, 70, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[301154, 5950, 390, 11, 102, "Input",
   CellTags->"Procedure"],
  Cell[301569, 5965, 137, 4, 41, "Input",
   CellTags->"Procedure"],
  Cell[301709, 5971, 197, 4, 39, "Output",
   CellTags->"Procedure"],
  Cell[301955, 5981, 62, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[303450, 6023, 399, 11, 82, "Input",
   CellTags->"Procedure"],
  Cell[303874, 6038, 110, 2, 41, "Input",
   CellTags->"Procedure"],
  Cell[303987, 6042, 230, 5, 39, "Output",
   CellTags->"Procedure"],
  Cell[304266, 6053, 80, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[305461, 6086, 568, 16, 102, "Input",
   CellTags->"Procedure"],
  Cell[306054, 6106, 136, 4, 41, "Input",
   CellTags->"Procedure"],
  Cell[306193, 6112, 247, 5, 39, "Output",
   CellTags->"Procedure"],
  Cell[306489, 6123, 88, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[307734, 6160, 633, 15, 102, "Input",
   CellTags->"Procedure"],
  Cell[308392, 6179, 149, 4, 61, "Input",
   CellTags->"Procedure"],
  Cell[308544, 6185, 277, 6, 39, "Output",
   CellTags->"Procedure"],
  Cell[308989, 6201, 75, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[310588, 6249, 543, 14, 102, "Input",
   CellTags->"Procedure"],
  Cell[311156, 6267, 241, 6, 61, "Input",
   CellTags->"Procedure"],
  Cell[311400, 6275, 300, 6, 39, "Output",
   CellTags->"Procedure"],
  Cell[311749, 6287, 78, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[313262, 6329, 466, 13, 102, "Input",
   CellTags->"Procedure"],
  Cell[313753, 6346, 136, 4, 41, "Input",
   CellTags->"Procedure"],
  Cell[313892, 6352, 202, 4, 39, "Output",
   CellTags->"Procedure"],
  Cell[314143, 6362, 71, 1, 47, "Subsubsection",
   CellTags->"Procedure"],
  Cell[315478, 6399, 467, 13, 102, "Input",
   CellTags->"Procedure"],
  Cell[315970, 6416, 119, 2, 41, "Input",
   CellTags->"Procedure"],
  Cell[316092, 6420, 197, 4, 39, "Output",
   CellTags->"Procedure"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 316690, 6442},
 {"Constructor", 317549, 6469},
 {"Member", 320827, 6562},
 {"Procedure", 326376, 6725}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 56, 1, 99, "Chapter",
 CellTags->"Overview"],
Cell[626, 25, 92, 1, 37, "Text",
 CellTags->"Overview"],
Cell[721, 28, 94, 1, 53, "MathCaption",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[840, 33, 83, 2, 41, "Input",
 CellTags->"Overview"],
Cell[926, 37, 166, 3, 35, "Print",
 CellTags->"Overview"],
Cell[1095, 42, 374, 9, 35, "Print",
 CellTags->"Overview"]
}, Open  ]],
Cell[1484, 54, 142, 4, 37, "Text",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[1651, 62, 113, 2, 41, "Input",
 CellTags->"Overview"],
Cell[1767, 66, 628, 12, 97, "Output",
 CellTags->"Overview"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2432, 83, 108, 2, 41, "Input",
 CellTags->"Overview"],
Cell[2543, 87, 1064, 19, 211, "Output",
 CellTags->"Overview"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3644, 111, 111, 2, 41, "Input",
 CellTags->"Overview"],
Cell[3758, 115, 707, 15, 135, "Output",
 CellTags->"Overview"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4502, 135, 57, 1, 77, "Section",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[4584, 140, 66, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[4653, 143, 775, 19, 186, "Text"],
Cell[5431, 164, 461, 11, 128, "Text"],
Cell[5895, 177, 586, 13, 102, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[6506, 194, 361, 9, 41, "Input",
 CellTags->"Constructor"],
Cell[6870, 205, 299, 6, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7218, 217, 73, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[7294, 220, 656, 17, 162, "Text"],
Cell[7953, 239, 564, 14, 145, "Text"],
Cell[8520, 255, 343, 10, 82, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[8888, 269, 308, 8, 41, "Input",
 CellTags->"Constructor"],
Cell[9199, 279, 230, 4, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9478, 289, 64, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[9545, 292, 342, 9, 80, "Text"],
Cell[9890, 303, 1121, 28, 182, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[11036, 335, 144, 3, 41, "Input",
 CellTags->"Constructor"],
Cell[11183, 340, 246, 5, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11478, 351, 72, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[11553, 354, 303, 8, 64, "Text"],
Cell[11859, 364, 310, 7, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[12194, 375, 104, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[12301, 379, 230, 5, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12580, 390, 72, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[12655, 393, 448, 13, 99, "Text"],
Cell[13106, 408, 277, 8, 82, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[13408, 420, 122, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[13533, 424, 396, 10, 33, "Message",
 CellTags->"Constructor"],
Cell[13932, 436, 279, 7, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14260, 449, 70, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[14333, 452, 413, 11, 80, "Text"],
Cell[14749, 465, 376, 11, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[15150, 480, 108, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[15261, 484, 207, 4, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15517, 494, 71, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[15591, 497, 424, 12, 80, "Text"],
Cell[16018, 511, 256, 5, 106, "Text"],
Cell[16277, 518, 340, 9, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[16642, 531, 171, 3, 41, "Input",
 CellTags->"Constructor"],
Cell[16816, 536, 249, 5, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17114, 547, 70, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[17187, 550, 383, 9, 80, "Text"],
Cell[17573, 561, 352, 10, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[17950, 575, 108, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[18061, 579, 205, 4, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18315, 589, 71, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[18389, 592, 433, 11, 80, "Text"],
Cell[18825, 605, 256, 5, 106, "Text"],
Cell[19084, 612, 287, 8, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[19396, 624, 107, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[19506, 628, 208, 4, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19763, 638, 73, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[19839, 641, 422, 10, 109, "Text"],
Cell[20264, 653, 533, 15, 102, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[20822, 672, 106, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[20931, 676, 239, 5, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21219, 687, 61, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[21283, 690, 303, 8, 64, "Text"],
Cell[21589, 700, 209, 6, 41, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[21823, 710, 93, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[21919, 714, 189, 4, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22169, 725, 55, 1, 77, "Section",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[22249, 730, 66, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[22340, 735, 626, 16, 142, "Input",
 CellTags->"Member"],
Cell[22969, 753, 246, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23264, 764, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[23362, 769, 716, 20, 142, "Input",
 CellTags->"Member"],
Cell[24081, 791, 225, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24355, 802, 66, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[24424, 805, 212, 5, 64, "Text"],
Cell[24639, 812, 614, 16, 122, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[25278, 832, 309, 8, 27, "Input"],
Cell[25590, 842, 5734, 102, 235, 2041, 39, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31373, 950, 78, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[31454, 953, 554, 15, 128, "Input"],
Cell[CellGroupData[{
Cell[32033, 972, 99, 2, 41, "Input",
 CellTags->"Member"],
Cell[32135, 976, 217, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32401, 986, 71, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[32475, 989, 212, 5, 64, "Text"],
Cell[32690, 996, 617, 17, 142, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[33332, 1017, 159, 3, 41, "Input",
 CellTags->"Member"],
Cell[33494, 1022, 219, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33762, 1032, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[33838, 1035, 596, 16, 122, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[34459, 1055, 171, 3, 27, "Input"],
Cell[34633, 1060, 180, 3, 25, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34862, 1069, 66, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[34931, 1072, 212, 5, 64, "Text"],
Cell[35146, 1079, 352, 9, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[35523, 1092, 173, 3, 41, "Input",
 CellTags->"Member"],
Cell[35699, 1097, 5849, 104, 243, 2060, 39, "CachedBoxData", "BoxData", \
"Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41597, 1207, 66, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[41666, 1210, 335, 8, 80, "Text"],
Cell[42004, 1220, 496, 13, 82, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[42525, 1237, 212, 4, 27, "Input"],
Cell[42740, 1243, 176, 4, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42953, 1252, 238, 6, 61, "Input",
 CellTags->"Member"],
Cell[43194, 1260, 135715, 2213, 319, 95856, 1556, "CachedBoxData", "BoxData", \
"Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[178958, 3479, 72, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[179033, 3482, 335, 8, 80, "Text"],
Cell[179371, 3492, 425, 12, 82, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[179821, 3508, 204, 4, 41, "Input",
 CellTags->"Member"],
Cell[180028, 3514, 198, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180263, 3524, 268, 8, 81, "Input",
 CellTags->"Member"],
Cell[180534, 3534, 96007, 1560, 319, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[276590, 5100, 65, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[276658, 5103, 261, 5, 64, "Text"],
Cell[276922, 5110, 364, 10, 62, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[277311, 5124, 101, 2, 41, "Input",
 CellTags->"Member"],
Cell[277415, 5128, 198, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[277662, 5138, 64, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[277729, 5141, 261, 5, 64, "Text"],
Cell[277993, 5148, 391, 10, 62, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[278409, 5162, 100, 2, 41, "Input",
 CellTags->"Member"],
Cell[278512, 5166, 223, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[278784, 5177, 72, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[278859, 5180, 261, 5, 64, "Text"],
Cell[279123, 5187, 391, 10, 62, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[279539, 5201, 108, 2, 41, "Input",
 CellTags->"Member"],
Cell[279650, 5205, 214, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279913, 5216, 79, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[279995, 5219, 346, 10, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[280366, 5233, 165, 3, 41, "Input",
 CellTags->"Member"],
Cell[280534, 5238, 222, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[280805, 5249, 80, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[280888, 5252, 346, 10, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[281259, 5266, 102, 2, 41, "Input",
 CellTags->"Member"],
Cell[281364, 5270, 199, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[281612, 5280, 78, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[281693, 5283, 346, 10, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[282064, 5297, 100, 2, 41, "Input",
 CellTags->"Member"],
Cell[282167, 5301, 216, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[282432, 5312, 66, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[282501, 5315, 346, 10, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[282872, 5329, 88, 2, 41, "Input",
 CellTags->"Member"],
Cell[282963, 5333, 192, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[283204, 5343, 65, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[283272, 5346, 259, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[283556, 5358, 87, 2, 41, "Input",
 CellTags->"Member"],
Cell[283646, 5362, 213, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[283908, 5373, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[284006, 5378, 271, 6, 27, "Input"],
Cell[284280, 5386, 162, 3, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[284479, 5394, 95, 2, 41, "Input",
 CellTags->"Member"],
Cell[284577, 5398, 196, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[284822, 5408, 78, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[284925, 5413, 100, 2, 41, "Input",
 CellTags->"Member"],
Cell[285028, 5417, 199, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[285276, 5427, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[285374, 5432, 95, 2, 41, "Input",
 CellTags->"Member"],
Cell[285472, 5436, 200, 4, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[285721, 5446, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[285797, 5449, 261, 5, 64, "Text"],
Cell[286061, 5456, 194, 5, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[286280, 5465, 110, 2, 41, "Input",
 CellTags->"Member"],
Cell[286393, 5469, 217, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[286659, 5480, 79, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[286741, 5483, 261, 5, 64, "Text"],
Cell[287005, 5490, 192, 5, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[287222, 5499, 116, 2, 41, "Input",
 CellTags->"Member"],
Cell[287341, 5503, 218, 5, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[287620, 5515, 53, 1, 77, "Section",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[287698, 5520, 61, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[287762, 5523, 993, 26, 203, "Text"],
Cell[288758, 5551, 626, 16, 169, "Text"],
Cell[289387, 5569, 391, 11, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[289803, 5584, 120, 2, 41, "Input",
 CellTags->"Procedure"],
Cell[289926, 5588, 203, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[290178, 5598, 79, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[290260, 5601, 993, 26, 203, "Text"],
Cell[291256, 5629, 308, 7, 106, "Text"],
Cell[291567, 5638, 389, 11, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[291981, 5653, 146, 4, 61, "Input",
 CellTags->"Procedure"],
Cell[292130, 5659, 202, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[292381, 5669, 87, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[292471, 5672, 717, 21, 141, "Text"],
Cell[293191, 5695, 626, 16, 169, "Text"],
Cell[293820, 5713, 396, 11, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[294241, 5728, 161, 5, 61, "Input",
 CellTags->"Procedure"],
Cell[294405, 5735, 201, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[294655, 5745, 184, 5, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[294842, 5752, 717, 21, 141, "Text"],
Cell[295562, 5775, 971, 27, 220, "Text"],
Cell[296536, 5804, 396, 11, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[296957, 5819, 241, 6, 61, "Input",
 CellTags->"Procedure"],
Cell[297201, 5827, 252, 5, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[297502, 5838, 77, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[297582, 5841, 775, 19, 186, "Text"],
Cell[298360, 5862, 626, 16, 169, "Text"],
Cell[298989, 5880, 255, 8, 82, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[299269, 5892, 125, 2, 41, "Input",
 CellTags->"Procedure"],
Cell[299397, 5896, 179, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[299625, 5906, 70, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[299698, 5909, 991, 26, 184, "Text"],
Cell[300692, 5937, 459, 11, 128, "Text"],
Cell[301154, 5950, 390, 11, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[301569, 5965, 137, 4, 41, "Input",
 CellTags->"Procedure"],
Cell[301709, 5971, 197, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[301955, 5981, 62, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[302020, 5984, 798, 19, 186, "Text"],
Cell[302821, 6005, 626, 16, 169, "Text"],
Cell[303450, 6023, 399, 11, 82, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[303874, 6038, 110, 2, 41, "Input",
 CellTags->"Procedure"],
Cell[303987, 6042, 230, 5, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[304266, 6053, 80, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[304349, 6056, 798, 19, 186, "Text"],
Cell[305150, 6077, 308, 7, 106, "Text"],
Cell[305461, 6086, 568, 16, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[306054, 6106, 136, 4, 41, "Input",
 CellTags->"Procedure"],
Cell[306193, 6112, 247, 5, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[306489, 6123, 88, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[306580, 6126, 522, 14, 124, "Text"],
Cell[307105, 6142, 626, 16, 169, "Text"],
Cell[307734, 6160, 633, 15, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[308392, 6179, 149, 4, 61, "Input",
 CellTags->"Procedure"],
Cell[308544, 6185, 277, 6, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]],
Cell[308836, 6194, 116, 2, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308989, 6201, 75, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[309067, 6204, 524, 14, 124, "Text"],
Cell[309594, 6220, 991, 27, 220, "Text"],
Cell[310588, 6249, 543, 14, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[311156, 6267, 241, 6, 61, "Input",
 CellTags->"Procedure"],
Cell[311400, 6275, 300, 6, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[311749, 6287, 78, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[311830, 6290, 800, 19, 186, "Text"],
Cell[312633, 6311, 626, 16, 169, "Text"],
Cell[313262, 6329, 466, 13, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[313753, 6346, 136, 4, 41, "Input",
 CellTags->"Procedure"],
Cell[313892, 6352, 202, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[314143, 6362, 71, 1, 47, "Subsubsection",
 CellTags->"Procedure"],
Cell[314217, 6365, 796, 19, 167, "Text"],
Cell[315016, 6386, 459, 11, 128, "Text"],
Cell[315478, 6399, 467, 13, 102, "Input",
 CellTags->"Procedure"],
Cell[CellGroupData[{
Cell[315970, 6416, 119, 2, 41, "Input",
 CellTags->"Procedure"],
Cell[316092, 6420, 197, 4, 39, "Output",
 CellTags->"Procedure"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
