(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     14859,        537]
NotebookOptionsPosition[      8851,        329]
NotebookOutlinePosition[     11967,        432]
CellTagsIndexPosition[     11779,        423]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["RangeAccrual", "Chapter",
 CellTags->"Overview"],

Cell["functions to construct and use Range Accrual objects.", "Text",
 CellTags->"Overview"],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview"],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview"],

Cell["\<\
Within the RangeAccrual part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview"],

Cell["Select[Category[RangeAccrual],QLConstructor[#]&]", "Input",
 CellTags->"Overview"],

Cell["Select[Category[RangeAccrual],QLMember[#]&]", "Input",
 CellTags->"Overview"],

Cell["Select[Category[RangeAccrual],QLProcedure[#]&]", "Input",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor"],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCoupon", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Nominal", 
     RowBox[{"coupon", " ", 
      RowBox[{"nominal", "."}]}]},
    {"PaymentDate", 
     RowBox[{"payment", " ", 
      RowBox[{"Date", "."}]}]},
    {"IborIndex", 
     RowBox[{"underlying", " ", "ibor", " ", 
      RowBox[{"index", "."}]}]},
    {"StartDate", 
     RowBox[{"start", " ", 
      RowBox[{"Date", "."}]}]},
    {"EndDate", 
     RowBox[{"end", " ", 
      RowBox[{"Date", "."}]}]},
    {"FixingDays", 
     RowBox[{"fixingDays", "."}]},
    {"DayCountID", 
     RowBox[{"day", " ", 
      RowBox[{"counter", "."}]}]},
    {"Gearings", 
     RowBox[{"gearings", "."}]},
    {"Spreads", 
     RowBox[{"spreads", "."}]},
    {"RefPeriodStart", 
     RowBox[{"refPeriodStart", "."}]},
    {"RefPeriodEnd", 
     RowBox[{"refPeriodEnd", "."}]},
    {"ObserSchedID", 
     RowBox[{"observations", " ", 
      RowBox[{"schedule", "."}]}]},
    {"LowerTrigger", 
     RowBox[{"lowerTrigger", "."}]},
    {"UpperTrigger", 
     RowBox[{"upperTrigger", "."}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nominal", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PaymentDate", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"IborIndex", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StartDate", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"EndDate", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FixingDays", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"DayCountID", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Gearings", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Spreads", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RefPeriodStart", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RefPeriodEnd", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ObserSchedID", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"LowerTrigger", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"UpperTrigger", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor"],

Cell["\<\
obj=RangeAccrualFloatersCoupon[Nominal,PaymentDate,IborIndex,StartDate,\
EndDate,FixingDays,DayCountID,Gearings,Spreads,RefPeriodStart,RefPeriodEnd,\
ObserSchedID,LowerTrigger,UpperTrigger]\
\>", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCouponFromLeg", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"RangeAccrualLeg", 
     RowBox[{"range", " ", "accrual", " ", "leg", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Position", 
     RowBox[{"position", "."}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RangeAccrualLeg", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Position", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor"],

Cell["\<\
obj=RangeAccrualFloatersCouponFromLeg[RangeAccrualLeg,Position]\
\>", "Input",
 CellTags->"Constructor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualPricerByBgm", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Correlation", 
     RowBox[{"correlation", "."}]},
    {"SmileOnStartDateID", 
     RowBox[{
     "ID", " ", "of", " ", "the", " ", "smile", " ", "on", " ", "start", " ", 
      "date", " ", 
      RowBox[{"object", "."}]}]},
    {"SmileOnEndDateID", 
     RowBox[{
     "ID", " ", "of", " ", "the", " ", "smile", " ", "on", " ", "end", " ", 
      "date", " ", 
      RowBox[{"object", "."}]}]},
    {"WithSmile", 
     RowBox[{"with", " ", 
      RowBox[{
       RowBox[{"Smile", "?"}], "."}]}]},
    {"ByCallSpread", 
     RowBox[{"replicated", " ", "by", " ", "Call", " ", 
      RowBox[{
       RowBox[{"spread", "?"}], "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Correlation", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SmileOnStartDateID", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SmileOnEndDateID", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"WithSmile", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ByCallSpread", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor"],

Cell["\<\
obj=RangeAccrualPricerByBgm[Correlation,SmileOnStartDateID,SmileOnEndDateID,\
WithSmile,ByCallSpread]\
\>", "Input",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCouponSetPricer", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"RangeAccrualPricer", 
     RowBox[{"RangeAccrual", " ", "coupon", " ", "pricer", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RangeAccrualPricer", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member"],

Cell["RangeAccrualFloatersCouponSetPricer[obj,RangeAccrualPricer]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCouponObservationDates", "Subsubsection",
 CellTags->"Member"],

Cell["RangeAccrualFloatersCouponObservationDates[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCouponStarDate", "Subsubsection",
 CellTags->"Member"],

Cell["RangeAccrualFloatersCouponStarDate[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCouponEndDate", "Subsubsection",
 CellTags->"Member"],

Cell["RangeAccrualFloatersCouponEndDate[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersCouponObservationsNo", "Subsubsection",
 CellTags->"Member"],

Cell["RangeAccrualFloatersCouponObservationsNo[obj]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RangeAccrualFloatersPrice", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{"yield", " ", 
      RowBox[{"curve", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"YieldCurve", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member"],

Cell["RangeAccrualFloatersPrice[obj,YieldCurve]", "Input",
 CellTags->"Member"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimpleFloaterPrice", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", 
     RowBox[{"yield", " ", 
      RowBox[{"curve", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"YieldCurve", "=", "exampleValue"}], ";"}]], "Input",
 CellTags->"Member"],

Cell["SimpleFloaterPrice[obj,YieldCurve]", "Input",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],

Cell["Procedures", "Section",
 CellTags->"Procedure"],

Cell["Enumeration Member", "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
},
WindowSize->{716, 867},
WindowMargins->{{278, Automatic}, {Automatic, 42}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[579, 22, 54, 1, 99, "Chapter",
   CellTags->"Overview"],
  Cell[636, 25, 92, 1, 37, "Text",
   CellTags->"Overview"],
  Cell[731, 28, 94, 1, 53, "MathCaption",
   CellTags->"Overview"],
  Cell[828, 31, 60, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[891, 34, 140, 4, 37, "Text",
   CellTags->"Overview"],
  Cell[1034, 40, 88, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[1125, 43, 83, 1, 41, "Input",
   CellTags->"Overview"],
  Cell[1211, 46, 86, 1, 41, "Input",
   CellTags->"Overview"]},
 "Constructor"->{
  Cell[1322, 51, 57, 1, 77, "Section",
   CellTags->"Constructor"],
  Cell[1404, 56, 77, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[2618, 99, 1038, 29, 302, "Input",
   CellTags->"Constructor"],
  Cell[3659, 130, 240, 5, 81, "Input",
   CellTags->"Constructor"],
  Cell[3936, 140, 84, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[4349, 153, 189, 5, 62, "Input",
   CellTags->"Constructor"],
  Cell[4541, 160, 114, 3, 41, "Input",
   CellTags->"Constructor"],
  Cell[4692, 168, 74, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[5559, 196, 415, 11, 122, "Input",
   CellTags->"Constructor"],
  Cell[5977, 209, 152, 4, 61, "Input",
   CellTags->"Constructor"]},
 "Member"->{
  Cell[6178, 219, 55, 1, 77, "Section",
   CellTags->"Member"],
  Cell[6258, 224, 81, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[6621, 234, 116, 3, 41, "Input",
   CellTags->"Member"],
  Cell[6740, 239, 97, 1, 41, "Input",
   CellTags->"Member"],
  Cell[6874, 245, 88, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[6965, 248, 85, 1, 41, "Input",
   CellTags->"Member"],
  Cell[7087, 254, 80, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[7170, 257, 77, 1, 41, "Input",
   CellTags->"Member"],
  Cell[7284, 263, 79, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[7366, 266, 76, 1, 41, "Input",
   CellTags->"Member"],
  Cell[7479, 272, 86, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[7568, 275, 83, 1, 41, "Input",
   CellTags->"Member"],
  Cell[7688, 281, 71, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[7984, 291, 108, 3, 41, "Input",
   CellTags->"Member"],
  Cell[8095, 296, 79, 1, 41, "Input",
   CellTags->"Member"],
  Cell[8211, 302, 64, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[8500, 312, 108, 3, 41, "Input",
   CellTags->"Member"],
  Cell[8611, 317, 72, 1, 41, "Input",
   CellTags->"Member"]},
 "Procedure"->{
  Cell[8710, 322, 53, 1, 77, "Section",
   CellTags->"Procedure"]},
 "EnumerationMember"->{
  Cell[8766, 325, 69, 1, 51, "Section",
   CellTags->"EnumerationMember"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 9151, 339},
 {"Constructor", 9676, 356},
 {"Member", 10394, 377},
 {"Procedure", 11588, 414},
 {"EnumerationMember", 11680, 417}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 54, 1, 99, "Chapter",
 CellTags->"Overview"],
Cell[636, 25, 92, 1, 37, "Text",
 CellTags->"Overview"],
Cell[731, 28, 94, 1, 53, "MathCaption",
 CellTags->"Overview"],
Cell[828, 31, 60, 1, 41, "Input",
 CellTags->"Overview"],
Cell[891, 34, 140, 4, 37, "Text",
 CellTags->"Overview"],
Cell[1034, 40, 88, 1, 41, "Input",
 CellTags->"Overview"],
Cell[1125, 43, 83, 1, 41, "Input",
 CellTags->"Overview"],
Cell[1211, 46, 86, 1, 41, "Input",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[1322, 51, 57, 1, 77, "Section",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[1404, 56, 77, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[1484, 59, 1131, 38, 287, "Text"],
Cell[2618, 99, 1038, 29, 302, "Input",
 CellTags->"Constructor"],
Cell[3659, 130, 240, 5, 81, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3936, 140, 84, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[4023, 143, 323, 8, 80, "Text"],
Cell[4349, 153, 189, 5, 62, "Input",
 CellTags->"Constructor"],
Cell[4541, 160, 114, 3, 41, "Input",
 CellTags->"Constructor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4692, 168, 74, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[4769, 171, 787, 23, 134, "Text"],
Cell[5559, 196, 415, 11, 122, "Input",
 CellTags->"Constructor"],
Cell[5977, 209, 152, 4, 61, "Input",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6178, 219, 55, 1, 77, "Section",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[6258, 224, 81, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[6342, 227, 276, 5, 64, "Text"],
Cell[6621, 234, 116, 3, 41, "Input",
 CellTags->"Member"],
Cell[6740, 239, 97, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6874, 245, 88, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[6965, 248, 85, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7087, 254, 80, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[7170, 257, 77, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7284, 263, 79, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[7366, 266, 76, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7479, 272, 86, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[7568, 275, 83, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7688, 281, 71, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[7762, 284, 219, 5, 64, "Text"],
Cell[7984, 291, 108, 3, 41, "Input",
 CellTags->"Member"],
Cell[8095, 296, 79, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8211, 302, 64, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[8278, 305, 219, 5, 64, "Text"],
Cell[8500, 312, 108, 3, 41, "Input",
 CellTags->"Member"],
Cell[8611, 317, 72, 1, 41, "Input",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[8710, 322, 53, 1, 77, "Section",
 CellTags->"Procedure"],
Cell[8766, 325, 69, 1, 51, "Section",
 CellTags->"EnumerationMember"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

