(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26495,        938]
NotebookOptionsPosition[     16016,        561]
NotebookOutlinePosition[     21792,        750]
CellTagsIndexPosition[     21504,        739]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Schedules", "Chapter",
 CellChangeTimes->{
  3.435902529037228*^9, {3.435905958318478*^9, 3.435905959927853*^9}},
 CellTags->"Overview",
 CellID->4185181],

Cell[TextData[{
 "The first step is to load the ",
 StyleBox["QuantLib",
  FontSlant->"Italic"],
 " package. "
}], "MathCaption",
 CellChangeTimes->{{3.43566408859375*^9, 3.435664090359375*^9}},
 CellTags->"Overview",
 CellID->195068211],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.43566006271875*^9, 3.435660082703125*^9}, {
   3.43566551115625*^9, 3.435665518796875*^9}, 3.435902544084103*^9},
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->41477043],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Category", "[", "Schedules", "]"}]], "Input",
 CellChangeTimes->{
  3.435903019052853*^9, {3.435905965365353*^9, 3.435905967005978*^9}},
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->542079237],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Schedule", ",", "ScheduleBDC", ",", "ScheduleCalendar", ",", 
   "ScheduleDates", ",", "ScheduleEmpty", ",", "ScheduleEndDate", ",", 
   "ScheduleEndOfMonth", ",", "ScheduleIsRegular", ",", "ScheduleNextDate", 
   ",", "SchedulePreviousDate", ",", "ScheduleRule", ",", "ScheduleSize", ",",
    "ScheduleStartDate", ",", "ScheduleTenor", ",", 
   "ScheduleTerminationDateBDC"}], "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->498557229]
}, Open  ]],

Cell["There is one function available to construct a schedule", "Text",
 CellChangeTimes->{{3.435652644703125*^9, 3.435652663703125*^9}, {
  3.435905984271603*^9, 3.435905999271603*^9}},
 CellTags->"Overview",
 CellID->23936829],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "Schedules", "]"}], ",", 
   RowBox[{
    RowBox[{"QLConstructor", "[", "#", "]"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.435652296953125*^9, 3.43565233153125*^9}, {
  3.435652380375*^9, 3.4356523806875*^9}, {3.43565263409375*^9, 
  3.435652636078125*^9}, {3.435905975865353*^9, 3.435905977505978*^9}},
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->194783854],

Cell[BoxData[
 RowBox[{"{", "Schedule", "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->7890676]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Category", "[", "Schedules", "]"}], ",", 
   RowBox[{
    RowBox[{"QLMember", "[", "#", "]"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.435906050505978*^9, 3.435906055724728*^9}},
 CellTags->"Overview",
 CellLabel->"In[4]:=",
 CellID->645846884],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "ScheduleBDC", ",", "ScheduleCalendar", ",", "ScheduleDates", ",", 
   "ScheduleEmpty", ",", "ScheduleEndDate", ",", "ScheduleEndOfMonth", ",", 
   "ScheduleIsRegular", ",", "ScheduleNextDate", ",", "SchedulePreviousDate", 
   ",", "ScheduleRule", ",", "ScheduleSize", ",", "ScheduleStartDate", ",", 
   "ScheduleTenor", ",", "ScheduleTerminationDateBDC"}], "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[4]=",
 CellID->334229803]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creating a Schedule", "Section",
 CellChangeTimes->{{3.435905166146603*^9, 3.435905172943478*^9}, {
  3.435906101662228*^9, 3.435906108755978*^9}},
 CellTags->"Create",
 CellID->217281131],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"?", "Schedule"}], "\[IndentingNewLine]", 
 RowBox[{"Options", "[", "Schedule", "]"}]}], "Input",
 CellTags->"Create",
 CellLabel->"In[1]:=",
 CellID->323748158],

Cell[BoxData[
 StyleBox["\<\"Schedule[ObjecctId_Symbol,TerminationDate_?DateQ,Tenor_String] \
Construct an object of class Schedule and return its id       \\nObjectId: id \
of object to be created\\nEffectiveDate: effective date. Default value = \
Date[].\\nTerminationDate: termination date.\\nTenor: tenor (e.g. 2D for two \
days , 3W for three weeks, 6M for six months, 1Y for one year).\\nCalendar: \
holiday calendar (e.g. TARGET). Default value = NullCalendar.\\nConvention: \
accrual dates business day convention. Default value = \
Unadjusted.\\nTermDateConv: termination date business day convention. Default \
value = Unadjusted.\\nGenRule: Date generation rule (Backward, Forward, \
ThirdWednesday, Twentieth, TwentiethIMM, Zero). Default value = \
Backward.\\nEndOfMonth: end of month convention. Default value = \
false.\\nFirstDate: stub date, if there is an irregular starting period. \
Default value = Date[].\\nNextToLastDate: stub date, if there an irregular \
final period. Default value = Date[].\\nPermanent: object \
permanent/nonpermanent\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->{"Create", "Info3519023304-2306250"},
 CellID->210052328],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"EffectiveDate", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2011", ",", "7", ",", "7"}], "}"}]}], ",", 
   RowBox[{"Calendar", "\[Rule]", "\<\"Target\"\>"}], ",", 
   RowBox[{"Convention", "\[Rule]", "\<\"Unadjusted\"\>"}], ",", 
   RowBox[{"TermDateConv", "\[Rule]", "\<\"Unadjusted\"\>"}], ",", 
   RowBox[{"GenRule", "\[Rule]", "\<\"Backward\"\>"}], ",", 
   RowBox[{"EndOfMonth", "\[Rule]", "True"}], ",", 
   RowBox[{"FirstDate", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2011", ",", "7", ",", "7"}], "}"}]}], ",", 
   RowBox[{"NextToLastDate", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2011", ",", "7", ",", "7"}], "}"}]}], ",", 
   RowBox[{"Permanent", "\[Rule]", "True"}], ",", 
   RowBox[{"Overwrite", "\[Rule]", "True"}]}], "}"}]], "Output",
 CellTags->"Create",
 CellLabel->"Out[3]=",
 CellID->105621045]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"schedule", " ", "=", 
  RowBox[{"Schedule", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2008", ",", "11", ",", "15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2018", ",", "11", ",", "17"}], "}"}], ",", "\"\<1Y\>\""}], 
   "]"}]}]], "Input",
 CellTags->"Create",
 CellLabel->"In[4]:=",
 CellID->148007757],

Cell[BoxData["Schedule3"], "Output",
 CellTags->"Create",
 CellLabel->"Out[4]=",
 CellID->460490386]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Information", "[", 
  RowBox[{"Evaluate", "[", "schedule", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.435905255068478*^9, 3.435905288365353*^9}, {
  3.435905520099728*^9, 3.435905529818478*^9}, {3.435906136896603*^9, 
  3.435906188037228*^9}, {3.435907183318478*^9, 3.435907299334103*^9}},
 CellTags->"Create",
 CellLabel->"In[5]:=",
 CellID->199191220],

Cell[CellGroupData[{

Cell["Cell$$3689`Schedule3", "Print", "PrintUsage",
 CellTags->{"Create", "Info3519023305-2306250"},
 CellID->57690570],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"BaseClass", "[", "Schedule3", "]"}], "^=", "\<\"\"\>"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Calendar", "[", "Schedule3", "]"}], "^=", "Target"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Category", "[", "Schedule3", "]"}], 
         "^=", "\<\"Schedules\"\>"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Convention", "[", "Schedule3", "]"}], "^=", "Unadjusted"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"EffectiveDate", "[", "Schedule3", "]"}], "^=", "39767"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"FirstDate", "[", "Schedule3", "]"}], "^=", "40731"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"GenRule", "[", "Schedule3", "]"}], "^=", "Backward"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"NextToLastDate", "[", "Schedule3", "]"}], "^=", "40731"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Overwrite", "[", "Schedule3", "]"}], "^=", "True"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Permanent", "[", "Schedule3", "]"}], "^=", "True"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Properties", "[", "Schedule3", "]"}], "^=", "11"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"Tenor", "[", "Schedule3", "]"}], "^=", "\<\"1Y\"\>"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"TermDateConv", "[", "Schedule3", "]"}], "^=", 
         "Unadjusted"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"TerminationDate", "[", "Schedule3", "]"}], "^=", "43421"}]},
       {" "},
       {
        RowBox[{
         RowBox[{"ValueObject", "[", "Schedule3", "]"}], "^=", "qlSchedule"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`Schedule3],
  Editable->False]], "Print",
 CellTags->{"Create", "Info3519023305-2306250"},
 CellID->117874942]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Anaylsing a Schedule", "Section",
 CellChangeTimes->{{3.435905334068478*^9, 3.435905338287228*^9}, {
  3.435911983005978*^9, 3.435911989443478*^9}},
 CellTags->"Analysing",
 CellID->183073991],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"schedule", " ", "=", 
   RowBox[{"Schedule", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2018", ",", "11", ",", "17"}], "}"}], ",", "\"\<1Y\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ScheduleBDC", "[", "schedule", "]"}], " "}]}], "Input",
 CellTags->"Analysing",
 CellLabel->"In[1]:=",
 CellID->49958634],

Cell[BoxData["\<\"Unadjusted\"\>"], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[3]=",
 CellID->41343575]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleCalendar", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435912009255978*^9, 3.435912044724728*^9}},
 CellTags->"Analysing",
 CellLabel->"In[4]:=",
 CellID->810183506],

Cell[BoxData["\<\"TARGET\"\>"], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[4]=",
 CellID->33695909]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleDates", "[", "schedule", "]"}]], "Input",
 CellTags->"Analysing",
 CellLabel->"In[4]:=",
 CellID->219528380],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2008", ",", "11", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2011", ",", "7", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "11", ",", "17"}], "}"}]}], "}"}]], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[4]=",
 CellID->211164635]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ScheduleEmpty"}]], "Input",
 CellChangeTimes->{{3.435912060396603*^9, 3.435912069662228*^9}},
 CellTags->"Analysing",
 CellLabel->"In[6]:=",
 CellID->99211478],

Cell[BoxData[
 StyleBox["\<\"ScheduleEmpty[ObjecctId_Symbol] returns TRUE if the given \
Schedule object is empty.       \\nObjectId: id of existing \
QuantLib::Schedule object\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->{"Analysing", "Info3519023306-2306250"},
 CellID->178963648]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleEmpty", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435912075662228*^9, 3.435912083318478*^9}},
 CellTags->"Analysing",
 CellLabel->"In[7]:=",
 CellID->435866522],

Cell[BoxData["False"], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[7]=",
 CellID->648163974]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleEndDate", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435912088474728*^9, 3.435912096537228*^9}},
 CellTags->"Analysing",
 CellLabel->"In[8]:=",
 CellID->916539898],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2018", ",", "11", ",", "17"}], "}"}]], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[8]=",
 CellID->88337722]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleEndOfMonth", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435912088474728*^9, 3.435912109818478*^9}},
 CellTags->"Analysing",
 CellLabel->"In[9]:=",
 CellID->123488440],

Cell[BoxData["True"], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[9]=",
 CellID->57247030]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ScheduleIsRegular"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->726208870],

Cell[BoxData[
 StyleBox["\<\"ScheduleIsRegular[ObjecctId_Symbol] returns TRUE if the \
selected period in the given Schedule object is regular.       \\nObjectId: \
id of existing QuantLib::Schedule object\\nIndex: one based period index. \
Default value = 1.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3519023307-2306250",
 CellID->270359855]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleIsRegular", "[", "schedule", "]"}]], "Input",
 CellTags->"Analysing",
 CellLabel->"In[11]:=",
 CellID->96107656],

Cell[BoxData["False"], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[11]=",
 CellID->376349034]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleNextDate", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435912088474728*^9, 3.435912140193478*^9}},
 CellTags->"Analysing",
 CellLabel->"In[12]:=",
 CellID->344271176],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2011", ",", "7", ",", "7"}], "}"}]], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[12]=",
 CellID->2707191]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SchedulePreviousDate", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435912088474728*^9, 3.435912150302853*^9}},
 CellTags->"Analysing",
 CellLabel->"In[13]:=",
 CellID->332192613],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2008", ",", "11", ",", "15"}], "}"}]], "Output",
 CellTags->"Analysing",
 CellLabel->"Out[13]=",
 CellID->992912]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleRule", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435915433334103*^9, 3.435915439287228*^9}},
 CellLabel->"In[14]:=",
 CellID->166314851],

Cell[BoxData["\<\"Backward\"\>"], "Output",
 CellLabel->"Out[14]=",
 CellID->444773991]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleSize", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435915433334103*^9, 3.435915453787228*^9}},
 CellLabel->"In[15]:=",
 CellID->408651726],

Cell[BoxData["3"], "Output",
 CellLabel->"Out[15]=",
 CellID->875103769]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleTenor", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435915433334103*^9, 3.435915465990353*^9}},
 CellLabel->"In[16]:=",
 CellID->14646113],

Cell[BoxData["\<\"1Y\"\>"], "Output",
 CellLabel->"Out[16]=",
 CellID->39721141]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScheduleTerminationDateBDC", "[", "schedule", "]"}]], "Input",
 CellChangeTimes->{{3.435915499693478*^9, 3.435915504865353*^9}},
 CellLabel->"In[17]:=",
 CellID->284750549],

Cell[BoxData["\<\"Unadjusted\"\>"], "Output",
 CellLabel->"Out[17]=",
 CellID->221921799]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowToolbars->"EditBar",
WindowSize->{765, 834},
WindowMargins->{{Automatic, -875}, {-335, Automatic}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
ShowSelection->True,
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 160, 4, 85, "Chapter",
   CellTags->"Overview",
   CellID->4185181],
  Cell[730, 28, 237, 8, 31, "MathCaption",
   CellTags->"Overview",
   CellID->195068211],
  Cell[970, 38, 275, 6, 28, "Input",
   CellTags->"Overview",
   CellID->41477043],
  Cell[1270, 48, 226, 6, 28, "Input",
   CellTags->"Overview",
   CellID->542079237],
  Cell[1499, 56, 504, 11, 71, "Output",
   CellTags->"Overview",
   CellID->498557229],
  Cell[2018, 70, 228, 4, 30, "Text",
   CellTags->"Overview",
   CellID->23936829],
  Cell[2271, 78, 456, 11, 28, "Input",
   CellTags->"Overview",
   CellID->194783854],
  Cell[2730, 91, 121, 4, 36, "Output",
   CellTags->"Overview",
   CellID->7890676],
  Cell[2888, 100, 314, 9, 28, "Input",
   CellTags->"Overview",
   CellID->645846884],
  Cell[3205, 111, 483, 10, 71, "Output",
   CellTags->"Overview",
   CellID->334229803]},
 "Create"->{
  Cell[3725, 126, 194, 4, 51, "Section",
   CellTags->"Create",
   CellID->217281131],
  Cell[3944, 134, 260, 6, 65, "Input",
   CellTags->"Create",
   CellID->323748158],
  Cell[4207, 142, 1169, 17, 251, "Print",
   CellTags->{"Create", "Info3519023304-2306250"},
   CellID->210052328],
  Cell[5379, 161, 871, 21, 71, "Output",
   CellTags->"Create",
   CellID->105621045],
  Cell[6287, 187, 339, 11, 28, "Input",
   CellTags->"Create",
   CellID->148007757],
  Cell[6629, 200, 100, 3, 36, "Output",
   CellTags->"Create",
   CellID->460490386],
  Cell[6766, 208, 380, 8, 28, "Input",
   CellTags->"Create",
   CellID->199191220],
  Cell[7171, 220, 119, 2, 42, "Print",
   CellTags->{"Create", "Info3519023305-2306250"},
   CellID->57690570],
  Cell[7293, 224, 2446, 80, 443, "Print",
   CellTags->{"Create", "Info3519023305-2306250"},
   CellID->117874942]},
 "Info3519023304-2306250"->{
  Cell[4207, 142, 1169, 17, 251, "Print",
   CellTags->{"Create", "Info3519023304-2306250"},
   CellID->210052328]},
 "Info3519023305-2306250"->{
  Cell[7171, 220, 119, 2, 42, "Print",
   CellTags->{"Create", "Info3519023305-2306250"},
   CellID->57690570],
  Cell[7293, 224, 2446, 80, 443, "Print",
   CellTags->{"Create", "Info3519023305-2306250"},
   CellID->117874942]},
 "Analysing"->{
  Cell[9800, 311, 198, 4, 51, "Section",
   CellTags->"Analysing",
   CellID->183073991],
  Cell[10023, 319, 533, 15, 65, "Input",
   CellTags->"Analysing",
   CellID->49958634],
  Cell[10559, 336, 111, 3, 36, "Output",
   CellTags->"Analysing",
   CellID->41343575],
  Cell[10707, 344, 209, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->810183506],
  Cell[10919, 351, 107, 3, 36, "Output",
   CellTags->"Analysing",
   CellID->33695909],
  Cell[11063, 359, 140, 4, 28, "Input",
   CellTags->"Analysing",
   CellID->219528380],
  Cell[11206, 365, 340, 11, 36, "Output",
   CellTags->"Analysing",
   CellID->211164635],
  Cell[11583, 381, 188, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->99211478],
  Cell[11774, 388, 286, 5, 56, "Print",
   CellTags->{"Analysing", "Info3519023306-2306250"},
   CellID->178963648],
  Cell[12097, 398, 206, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->435866522],
  Cell[12306, 405, 99, 3, 36, "Output",
   CellTags->"Analysing",
   CellID->648163974],
  Cell[12442, 413, 208, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->916539898],
  Cell[12653, 420, 154, 5, 36, "Output",
   CellTags->"Analysing",
   CellID->88337722],
  Cell[12844, 430, 211, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->123488440],
  Cell[13058, 437, 97, 3, 36, "Output",
   CellTags->"Analysing",
   CellID->57247030],
  Cell[13690, 461, 144, 4, 28, "Input",
   CellTags->"Analysing",
   CellID->96107656],
  Cell[13837, 467, 100, 3, 36, "Output",
   CellTags->"Analysing",
   CellID->376349034],
  Cell[13974, 475, 210, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->344271176],
  Cell[14187, 482, 152, 5, 36, "Output",
   CellTags->"Analysing",
   CellID->2707191],
  Cell[14376, 492, 214, 5, 28, "Input",
   CellTags->"Analysing",
   CellID->332192613],
  Cell[14593, 499, 153, 5, 36, "Output",
   CellTags->"Analysing",
   CellID->992912]},
 "Info3519023306-2306250"->{
  Cell[11774, 388, 286, 5, 56, "Print",
   CellTags->{"Analysing", "Info3519023306-2306250"},
   CellID->178963648]},
 "Info3519023307-2306250"->{
  Cell[13299, 450, 354, 6, 71, "Print",
   CellTags->"Info3519023307-2306250",
   CellID->270359855]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 17145, 594},
 {"Create", 18025, 625},
 {"Info3519023304-2306250", 18915, 653},
 {"Info3519023305-2306250", 19061, 657},
 {"Analysing", 19306, 664},
 {"Info3519023306-2306250", 21231, 728},
 {"Info3519023307-2306250", 21378, 732}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 160, 4, 85, "Chapter",
 CellTags->"Overview",
 CellID->4185181],
Cell[730, 28, 237, 8, 31, "MathCaption",
 CellTags->"Overview",
 CellID->195068211],
Cell[970, 38, 275, 6, 28, "Input",
 CellTags->"Overview",
 CellID->41477043],
Cell[CellGroupData[{
Cell[1270, 48, 226, 6, 28, "Input",
 CellTags->"Overview",
 CellID->542079237],
Cell[1499, 56, 504, 11, 71, "Output",
 CellTags->"Overview",
 CellID->498557229]
}, Open  ]],
Cell[2018, 70, 228, 4, 30, "Text",
 CellTags->"Overview",
 CellID->23936829],
Cell[CellGroupData[{
Cell[2271, 78, 456, 11, 28, "Input",
 CellTags->"Overview",
 CellID->194783854],
Cell[2730, 91, 121, 4, 36, "Output",
 CellTags->"Overview",
 CellID->7890676]
}, Open  ]],
Cell[CellGroupData[{
Cell[2888, 100, 314, 9, 28, "Input",
 CellTags->"Overview",
 CellID->645846884],
Cell[3205, 111, 483, 10, 71, "Output",
 CellTags->"Overview",
 CellID->334229803]
}, Open  ]],
Cell[CellGroupData[{
Cell[3725, 126, 194, 4, 51, "Section",
 CellTags->"Create",
 CellID->217281131],
Cell[CellGroupData[{
Cell[3944, 134, 260, 6, 65, "Input",
 CellTags->"Create",
 CellID->323748158],
Cell[4207, 142, 1169, 17, 251, "Print",
 CellTags->{"Create", "Info3519023304-2306250"},
 CellID->210052328],
Cell[5379, 161, 871, 21, 71, "Output",
 CellTags->"Create",
 CellID->105621045]
}, Open  ]],
Cell[CellGroupData[{
Cell[6287, 187, 339, 11, 28, "Input",
 CellTags->"Create",
 CellID->148007757],
Cell[6629, 200, 100, 3, 36, "Output",
 CellTags->"Create",
 CellID->460490386]
}, Open  ]],
Cell[CellGroupData[{
Cell[6766, 208, 380, 8, 28, "Input",
 CellTags->"Create",
 CellID->199191220],
Cell[CellGroupData[{
Cell[7171, 220, 119, 2, 42, "Print",
 CellTags->{"Create", "Info3519023305-2306250"},
 CellID->57690570],
Cell[7293, 224, 2446, 80, 443, "Print",
 CellTags->{"Create", "Info3519023305-2306250"},
 CellID->117874942]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9800, 311, 198, 4, 51, "Section",
 CellTags->"Analysing",
 CellID->183073991],
Cell[CellGroupData[{
Cell[10023, 319, 533, 15, 65, "Input",
 CellTags->"Analysing",
 CellID->49958634],
Cell[10559, 336, 111, 3, 36, "Output",
 CellTags->"Analysing",
 CellID->41343575]
}, Open  ]],
Cell[CellGroupData[{
Cell[10707, 344, 209, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->810183506],
Cell[10919, 351, 107, 3, 36, "Output",
 CellTags->"Analysing",
 CellID->33695909]
}, Open  ]],
Cell[CellGroupData[{
Cell[11063, 359, 140, 4, 28, "Input",
 CellTags->"Analysing",
 CellID->219528380],
Cell[11206, 365, 340, 11, 36, "Output",
 CellTags->"Analysing",
 CellID->211164635]
}, Open  ]],
Cell[CellGroupData[{
Cell[11583, 381, 188, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->99211478],
Cell[11774, 388, 286, 5, 56, "Print",
 CellTags->{"Analysing", "Info3519023306-2306250"},
 CellID->178963648]
}, Open  ]],
Cell[CellGroupData[{
Cell[12097, 398, 206, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->435866522],
Cell[12306, 405, 99, 3, 36, "Output",
 CellTags->"Analysing",
 CellID->648163974]
}, Open  ]],
Cell[CellGroupData[{
Cell[12442, 413, 208, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->916539898],
Cell[12653, 420, 154, 5, 36, "Output",
 CellTags->"Analysing",
 CellID->88337722]
}, Open  ]],
Cell[CellGroupData[{
Cell[12844, 430, 211, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->123488440],
Cell[13058, 437, 97, 3, 36, "Output",
 CellTags->"Analysing",
 CellID->57247030]
}, Open  ]],
Cell[CellGroupData[{
Cell[13192, 445, 104, 3, 28, "Input",
 CellID->726208870],
Cell[13299, 450, 354, 6, 71, "Print",
 CellTags->"Info3519023307-2306250",
 CellID->270359855]
}, Open  ]],
Cell[CellGroupData[{
Cell[13690, 461, 144, 4, 28, "Input",
 CellTags->"Analysing",
 CellID->96107656],
Cell[13837, 467, 100, 3, 36, "Output",
 CellTags->"Analysing",
 CellID->376349034]
}, Open  ]],
Cell[CellGroupData[{
Cell[13974, 475, 210, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->344271176],
Cell[14187, 482, 152, 5, 36, "Output",
 CellTags->"Analysing",
 CellID->2707191]
}, Open  ]],
Cell[CellGroupData[{
Cell[14376, 492, 214, 5, 28, "Input",
 CellTags->"Analysing",
 CellID->332192613],
Cell[14593, 499, 153, 5, 36, "Output",
 CellTags->"Analysing",
 CellID->992912]
}, Open  ]],
Cell[CellGroupData[{
Cell[14783, 509, 182, 4, 28, "Input",
 CellID->166314851],
Cell[14968, 515, 87, 2, 36, "Output",
 CellID->444773991]
}, Open  ]],
Cell[CellGroupData[{
Cell[15092, 522, 182, 4, 28, "Input",
 CellID->408651726],
Cell[15277, 528, 72, 2, 36, "Output",
 CellID->875103769]
}, Open  ]],
Cell[CellGroupData[{
Cell[15386, 535, 182, 4, 28, "Input",
 CellID->14646113],
Cell[15571, 541, 80, 2, 36, "Output",
 CellID->39721141]
}, Open  ]],
Cell[CellGroupData[{
Cell[15688, 548, 196, 4, 28, "Input",
 CellID->284750549],
Cell[15887, 554, 89, 2, 36, "Output",
 CellID->221921799]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
