(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8386,        324]
NotebookOptionsPosition[      4127,        168]
NotebookOutlinePosition[      6841,        261]
CellTagsIndexPosition[      6714,        254]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["ShortRateModels"], "Chapter",
 CellTags->"Overview",
 CellID->90715321],

Cell["functions to construct and use short-rate model objects.", "Text",
 CellTags->"Overview",
 CellID->468312896],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->474991236],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->380869735],

Cell["\<\
Within the ShortRateModels part there are several constructors and no member \
functions available \
\>", "Text",
 CellChangeTimes->{{3.436080587296875*^9, 3.43608058778125*^9}},
 CellTags->"Overview",
 CellID->54549975],

Cell[CellGroupData[{

Cell["Select[Category[ShortRateModels],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->49517587],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HullWhite", ",", "Vasicek"}], "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->918178556]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->109590304],

Cell[CellGroupData[{

Cell["HullWhite", "Subsubsection",
 CellTags->"Constructor",
 CellID->46618818],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"YieldCurve", "EURYC", 
     RowBox[{"yield", " ", "term", " ", 
      RowBox[{"structure", "."}]}]},
    {"A", "0.03", 
     RowBox[{"a", "."}]},
    {"Sigma", "0.15", 
     RowBox[{"volatility", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->93993302],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YieldCurve", "=", 
   RowBox[{"FlatForward", "[", "0.4", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"A", "=", "0.03"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Sigma", "=", "0.15"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[5]:=",
 CellID->15513665],

Cell[CellGroupData[{

Cell["obj=HullWhite[YieldCurve,A,Sigma]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[9]:=",
 CellID->350670130],

Cell[BoxData["HullWhite5"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[9]=",
 CellID->44106046]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vasicek", "Subsubsection",
 CellTags->"Constructor",
 CellID->41676762],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"A", "0.03", 
     RowBox[{"mean", " ", "reverting", " ", 
      RowBox[{"speed", "."}]}]},
    {"B", "0.03", 
     RowBox[{"short", "-", 
      RowBox[{"rate", " ", "limit", " ", 
       RowBox[{"value", "."}]}]}]},
    {"Lambda", "0.0", 
     RowBox[{"risk", " ", 
      RowBox[{"premium", "."}]}]},
    {"Sigma", "0.15", 
     RowBox[{"volatility", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->458152931],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=", "0.03"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"B", "=", "0.03"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", "0.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", "0.15"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[1]:=",
 CellID->23655867],

Cell[CellGroupData[{

Cell["obj=Vasicek[A,B,Lambda,Sigma]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[6]:=",
 CellID->598572272],

Cell[BoxData["Vasicek6"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[6]=",
 CellID->141792236]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, -561}, {Automatic, 56}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 85, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->90715321],
  Cell[655, 26, 115, 2, 30, "Text",
   CellTags->"Overview",
   CellID->468312896],
  Cell[773, 30, 114, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->474991236],
  Cell[890, 34, 103, 3, 28, "Input",
   CellTags->"Overview",
   CellID->380869735],
  Cell[996, 39, 230, 6, 50, "Text",
   CellTags->"Overview",
   CellID->54549975],
  Cell[1251, 49, 133, 3, 28, "Input",
   CellTags->"Overview",
   CellID->49517587],
  Cell[1387, 54, 153, 5, 36, "Output",
   CellTags->"Overview",
   CellID->918178556]},
 "Constructo"->{
  Cell[1577, 64, 76, 2, 51, "Section",
   CellTags->"Constructo",
   CellID->109590304]},
 "Constructor"->{
  Cell[1678, 70, 79, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->46618818],
  Cell[2143, 87, 374, 11, 83, "Input",
   CellTags->"Constructor",
   CellID->15513665],
  Cell[2542, 102, 119, 3, 28, "Input",
   CellTags->"Constructor",
   CellID->350670130],
  Cell[2664, 107, 105, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->44106046],
  Cell[2818, 116, 77, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->41676762],
  Cell[3437, 138, 391, 12, 101, "Input",
   CellTags->"Constructor",
   CellID->23655867],
  Cell[3853, 154, 115, 3, 28, "Input",
   CellTags->"Constructor",
   CellID->598572272],
  Cell[3971, 159, 104, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->141792236]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 5232, 200},
 {"Constructo", 5850, 222},
 {"Constructor", 5958, 226}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 85, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->90715321],
Cell[655, 26, 115, 2, 30, "Text",
 CellTags->"Overview",
 CellID->468312896],
Cell[773, 30, 114, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->474991236],
Cell[890, 34, 103, 3, 28, "Input",
 CellTags->"Overview",
 CellID->380869735],
Cell[996, 39, 230, 6, 50, "Text",
 CellTags->"Overview",
 CellID->54549975],
Cell[CellGroupData[{
Cell[1251, 49, 133, 3, 28, "Input",
 CellTags->"Overview",
 CellID->49517587],
Cell[1387, 54, 153, 5, 36, "Output",
 CellTags->"Overview",
 CellID->918178556]
}, Open  ]],
Cell[CellGroupData[{
Cell[1577, 64, 76, 2, 51, "Section",
 CellTags->"Constructo",
 CellID->109590304],
Cell[CellGroupData[{
Cell[1678, 70, 79, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->46618818],
Cell[1760, 74, 380, 11, 95, "Input",
 CellID->93993302],
Cell[2143, 87, 374, 11, 83, "Input",
 CellTags->"Constructor",
 CellID->15513665],
Cell[CellGroupData[{
Cell[2542, 102, 119, 3, 28, "Input",
 CellTags->"Constructor",
 CellID->350670130],
Cell[2664, 107, 105, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->44106046]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2818, 116, 77, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->41676762],
Cell[2898, 120, 536, 16, 111, "Input",
 CellID->458152931],
Cell[3437, 138, 391, 12, 101, "Input",
 CellTags->"Constructor",
 CellID->23655867],
Cell[CellGroupData[{
Cell[3853, 154, 115, 3, 28, "Input",
 CellTags->"Constructor",
 CellID->598572272],
Cell[3971, 159, 104, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->141792236]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
