(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     35742,       1240]
NotebookOptionsPosition[     24082,        815]
NotebookOutlinePosition[     30027,       1017]
CellTagsIndexPosition[     29872,       1009]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData["SmileSectionStructures"], "Chapter",
 CellTags->"Overview",
 CellID->375154206],

Cell["functions to construct and use SmileSection objects.", "Text",
 CellTags->"Overview",
 CellID->33937068],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->674644],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->639264307],

Cell["\<\
Within the SmileSectionStructures part there are several constructors and \
member functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->599613220],

Cell["Select[Category[SmileSectionStructures],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellID->749706],

Cell["Select[Category[SmileSectionStructures],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellID->322971538],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->368244820],

Cell[CellGroupData[{

Cell["FlatSmileSection", "Subsubsection",
 CellTags->"Constructor",
 CellID->192185989],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "11"}], "}"}], 
     RowBox[{
      RowBox[{"smile", "'"}], "s", " ", "expiry", " ", "as", " ", 
      RowBox[{"date", "."}]}]},
    {"Volatility", "0.14", 
     RowBox[{"volatilities", "."}]},
    {"RefDate", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "11"}], "}"}], 
     RowBox[{"ref", " ", 
      RowBox[{"date", "."}]}]},
    {"AtmValue", "0.04", 
     RowBox[{"Current", " ", "value", " ", "of", " ", "the", " ", 
      RowBox[{"underlying", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.436080881859375*^9, 3.43608088646875*^9}, {
  3.436080954734375*^9, 3.436080958515625*^9}},
 CellID->131254265],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->3974606],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "3", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Volatility", "=", "0.14"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RefDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "1", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmValue", "=", "0.04"}], ";"}]}], "Input",
 CellChangeTimes->{{3.436080896671875*^9, 3.43608091015625*^9}, 
   3.436080965703125*^9},
 CellTags->"Constructor",
 CellLabel->"In[200]:=",
 CellID->248489711],

Cell[CellGroupData[{

Cell["obj=FlatSmileSection[OptionDate,Volatility,RefDate,AtmValue]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[204]:=",
 CellID->158679249],

Cell[BoxData["FlatSmileSection1"], "Output",
 CellChangeTimes->{{3.43608091315625*^9, 3.4360809230625*^9}, 
   3.436080967953125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[204]=",
 CellID->35623139]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSection", "Subsubsection",
 CellTags->"Constructor",
 CellID->78813699],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{"3", "m"}], 
     RowBox[{
      RowBox[{"smile", "'"}], "s", " ", "expiry", " ", "as", " ", 
      RowBox[{"Date", "."}]}]},
    {"ForwardRate", "exampleValue", 
     RowBox[{"Atm", " ", "forward", " ", 
      RowBox[{"rate", "."}]}]},
    {"Strike", 
     RowBox[{
     "0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04", " "}], 
     RowBox[{"strikes", "."}]},
    {"FloatingStrike", "exampleValue", 
     RowBox[{"Strikes", " ", "are", " ", "floating", " ", "or", " ", 
      RowBox[{"fixed", "."}]}]},
    {"AtmVolatility", "0.045", 
     RowBox[{"atm", " ", 
      RowBox[{"volatility", "."}]}]},
    {"VolatilitySpreads", "exampleValue", 
     RowBox[{"volatilities", " ", "spread", " ", "at", " ", "option", " ", 
      RowBox[{"expiries", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->846235198],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Alpha", "0.0", 
     RowBox[{"alpha", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Beta", "0.0", 
     RowBox[{"beta", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Nu", "0.0", 
     RowBox[{"nu", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Rho", "0.0", 
     RowBox[{"rho", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"AlphaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "alpha", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"BetaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "beta", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"NuIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "nu", " ", "value", " ", "provided",
        " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", 
      " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"RhoIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "rho", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"VegaWeighted", "false", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "interpolation", " ", "is", " ", 
      "weighted", " ", "using", " ", "options", " ", 
      RowBox[{"Vega", "."}]}]},
    {"EndCriteria", "\"\<\>\"", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Method", "\"\<\>\"", 
     RowBox[{"OptimizationMethod", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->297509953],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "3", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ForwardRate", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", 
   RowBox[{"{", 
    RowBox[{"0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04"}], 
    " ", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FloatingStrike", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmVolatility", "=", "0.045"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"VolatilitySpreads", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.436080979984375*^9},
 CellTags->"Constructor",
 CellID->12229801],

Cell["\<\
obj=SabrInterpolatedSmileSection[OptionDate,ForwardRate,Strike,FloatingStrike,\
AtmVolatility,VolatilitySpreads]\
\>", "Input",
 CellTags->"Constructor",
 CellID->103156138]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSection1", "Subsubsection",
 CellTags->"Constructor",
 CellID->315778155],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{"3", "m"}], 
     RowBox[{
      RowBox[{"smile", "'"}], "s", " ", "expiry", " ", "as", " ", 
      RowBox[{"Date", "."}]}]},
    {"ForwardRate", "exampleValue", 
     RowBox[{"Atm", " ", "forward", " ", "rate", " ", 
      RowBox[{"quote", "."}]}]},
    {"Strike", 
     RowBox[{
     "0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04", " "}], 
     RowBox[{"strikes", "."}]},
    {"FloatingStrike", "exampleValue", 
     RowBox[{"Strikes", " ", "are", " ", "floating", " ", "or", " ", 
      RowBox[{"fixed", "."}]}]},
    {"AtmVolatility", "0.045", 
     RowBox[{"atm", " ", "volatility", " ", 
      RowBox[{"quote", "."}]}]},
    {"VolatilitySpreads", "exampleValue", 
     RowBox[{
     "volatilities", " ", "spread", " ", "quotes", " ", "at", " ", "option", 
      " ", 
      RowBox[{"expiries", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->426672001],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Alpha", "0.0", 
     RowBox[{"alpha", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Beta", "0.0", 
     RowBox[{"beta", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Nu", "0.0", 
     RowBox[{"nu", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Rho", "0.0", 
     RowBox[{"rho", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"AlphaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "alpha", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"BetaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "beta", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"NuIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "nu", " ", "value", " ", "provided",
        " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", 
      " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"RhoIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "rho", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"VegaWeighted", "false", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "interpolation", " ", "is", " ", 
      "weighted", " ", "using", " ", "options", " ", 
      RowBox[{"Vega", "."}]}]},
    {"EndCriteria", "\"\<\>\"", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Method", "\"\<\>\"", 
     RowBox[{"OptimizationMethod", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->276839070],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionDate", "=", 
   RowBox[{"3", "m"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ForwardRate", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strike", "=", 
   RowBox[{"{", 
    RowBox[{"0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04"}], 
    " ", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FloatingStrike", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmVolatility", "=", "0.045"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"VolatilitySpreads", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->32859848],

Cell["\<\
obj=SabrInterpolatedSmileSection1[OptionDate,ForwardRate,Strike,\
FloatingStrike,AtmVolatility,VolatilitySpreads]\
\>", "Input",
 CellTags->"Constructor",
 CellID->275606245]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrSmileSection", "Subsubsection",
 CellTags->"Constructor",
 CellID->48004226],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionTime", 
     RowBox[{"1.0", " "}], 
     RowBox[{
      RowBox[{"smile", "'"}], "s", " ", "expiry", " ", "as", " ", 
      RowBox[{"time", "."}]}]},
    {"Strikes", 
     RowBox[{
     "0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04", " "}], 
     RowBox[{"strikes", "."}]},
    {"StdDevs", 
     RowBox[{"0.1", ",", " ", "0.2", ",", " ", "0.3", ",", " ", "0.4", " "}], 
     
     RowBox[{"standard", " ", "deviations", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "volatilities"}], " ", "times", " ",
          "square", " ", "root", " ", "of", " ", "time", " ", "to", " ", 
         "option", " ", "expiry"}], ")"}], "."}]}]},
    {"Forward", 
     RowBox[{"0.045", " "}], 
     RowBox[{"atm", " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->130613144],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Alpha", "0.0", 
     RowBox[{"alpha", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Beta", "0.0", 
     RowBox[{"beta", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Nu", "0.0", 
     RowBox[{"nu", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"Rho", "0.0", 
     RowBox[{"rho", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"fixed", " ", "value", " ", "or", " ", "guess"}], ")"}], 
       "."}]}]},
    {"AlphaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "alpha", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"BetaIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "beta", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"NuIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "nu", " ", "value", " ", "provided",
        " ", "is", " ", "to", " ", "be", " ", "kept", " ", "fixed"}], ",", 
      " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"RhoIsFixed", "false", 
     RowBox[{
      RowBox[{
      "TRUE", " ", "if", " ", "the", " ", "rho", " ", "value", " ", 
       "provided", " ", "is", " ", "to", " ", "be", " ", "kept", " ", 
       "fixed"}], ",", " ", 
      RowBox[{
      "FALSE", " ", "if", " ", "it", " ", "is", " ", "just", " ", "a", " ", 
       RowBox[{"guess", "."}]}]}]},
    {"VegaWeighted", "false", 
     RowBox[{
     "TRUE", " ", "if", " ", "the", " ", "interpolation", " ", "is", " ", 
      "weighted", " ", "using", " ", "options", " ", 
      RowBox[{"Vega", "."}]}]},
    {"EndCriteria", "\"\<\>\"", 
     RowBox[{"EndCriteria", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Method", "\"\<\>\"", 
     RowBox[{"Optimization", " ", 
      RowBox[{"Method", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->925317],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionTime", "=", "1.0"}], " ", ";"}], "\n", 
 RowBox[{
  RowBox[{"Strikes", "=", 
   RowBox[{"{", 
    RowBox[{"0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04"}], 
    " ", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDevs", "=", 
   RowBox[{"{", 
    RowBox[{"0.1", ",", " ", "0.2", ",", " ", "0.3", ",", " ", "0.4"}], " ", 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Forward", "=", "0.045"}], " ", ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->462179735],

Cell["obj=SabrSmileSection[OptionTime,Strikes,StdDevs,Forward]", "Input",
 CellTags->"Constructor",
 CellID->903020829]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolatedSmileSection", "Subsubsection",
 CellTags->"Constructor",
 CellID->172959588],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{"3", "m"}], 
     RowBox[{
      RowBox[{"smile", "'"}], "s", " ", "expiry", " ", "as", " ", 
      RowBox[{"date", "."}]}]},
    {"Strikes", 
     RowBox[{
     "0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04", " "}], 
     RowBox[{"strikes", "."}]},
    {"StdDevs", 
     RowBox[{"0.1", ",", " ", "0.2", ",", " ", "0.3", ",", " ", "0.4", " "}], 
     
     RowBox[{"standard", " ", "deviations", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "volatilities"}], " ", "times", " ",
          "square", " ", "root", " ", "of", " ", "time", " ", "to", " ", 
         "option", " ", "expiry"}], ")"}], "."}]}]},
    {"AtmLevel", "0.1", 
     RowBox[{"Current", " ", "value", " ", "of", " ", "the", " ", 
      RowBox[{"underlying", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->183439846],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",\

 CellID->745207223],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OptionDate", "=", 
   RowBox[{"3", "m"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Strikes", "=", 
   RowBox[{"{", 
    RowBox[{"0.01", ",", " ", "0.02", ",", " ", "0.03", ",", " ", "0.04"}], 
    " ", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"StdDevs", "=", 
   RowBox[{"{", 
    RowBox[{"0.1", ",", " ", "0.2", ",", " ", "0.3", ",", " ", "0.4"}], " ", 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmLevel", "=", "0.1"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->178662154],

Cell["\<\
obj=InterpolatedSmileSection[OptionDate,Strikes,StdDevs,AtmLevel]\
\>", "Input",
 CellTags->"Constructor",
 CellID->125974609]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmileSectionFromSabrVolSurface", "Subsubsection",
 CellTags->"Constructor",
 CellID->5530490],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SabrVolSurface", "exampleValue", 
     RowBox[{"SabrVolSurface", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"OptionTime", "exampleValue", 
     RowBox[{
      RowBox[{"smile", "'"}], "s", " ", "expiry", " ", "as", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->13228337],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SabrVolSurface", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionTime", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->733327189],

Cell["\<\
obj=SmileSectionFromSabrVolSurface[SabrVolSurface,OptionTime]\
\>", "Input",
 CellTags->"Constructor",
 CellID->14501181]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->412431783],

Cell[CellGroupData[{

Cell["SmileSectionVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->117196721],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Strike", "0.0", 
     RowBox[{"strike", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->40131189],

Cell["SmileSectionVolatility[obj]", "Input",
 CellTags->"Member",
 CellID->164623595]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmileSectionVariance", "Subsubsection",
 CellTags->"Member",
 CellID->138126032],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Strike", "0.0", 
     RowBox[{"strike", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->461446936],

Cell["SmileSectionVariance[obj]", "Input",
 CellTags->"Member",
 CellID->3334290]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmileSectionAtmLevel", "Subsubsection",
 CellTags->"Member",
 CellID->137775125],

Cell["SmileSectionAtmLevel[obj]", "Input",
 CellTags->"Member",
 CellID->153544469]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmileSectionExerciseDate", "Subsubsection",
 CellTags->"Member",
 CellID->205254248],

Cell["SmileSectionExerciseDate[obj]", "Input",
 CellTags->"Member",
 CellID->228913846]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmileSectionDayCounter", "Subsubsection",
 CellTags->"Member",
 CellID->284194973],

Cell["SmileSectionDayCounter[obj]", "Input",
 CellTags->"Member",
 CellID->426031384]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionAlpha", "Subsubsection",
 CellTags->"Member",
 CellID->178281853],

Cell["SabrInterpolatedSmileSectionAlpha[obj]", "Input",
 CellTags->"Member",
 CellID->485928151]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionBeta", "Subsubsection",
 CellTags->"Member",
 CellID->2177572],

Cell["SabrInterpolatedSmileSectionBeta[obj]", "Input",
 CellTags->"Member",
 CellID->64634559]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionNu", "Subsubsection",
 CellTags->"Member",
 CellID->95704538],

Cell["SabrInterpolatedSmileSectionNu[obj]", "Input",
 CellTags->"Member",
 CellID->63261696]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionRho", "Subsubsection",
 CellTags->"Member",
 CellID->490316859],

Cell["SabrInterpolatedSmileSectionRho[obj]", "Input",
 CellTags->"Member",
 CellID->375210770]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionError", "Subsubsection",
 CellTags->"Member",
 CellID->520752797],

Cell["SabrInterpolatedSmileSectionError[obj]", "Input",
 CellTags->"Member",
 CellID->57539522]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionMaxError", "Subsubsection",
 CellTags->"Member",
 CellID->171137677],

Cell["SabrInterpolatedSmileSectionMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->126890954]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrInterpolatedSmileSectionEndCriteria", "Subsubsection",
 CellTags->"Member",
 CellID->235754024],

Cell["SabrInterpolatedSmileSectionEndCriteria[obj]", "Input",
 CellTags->"Member",
 CellID->212046576]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{Automatic, 621}, {96, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{"SearchTextTranslated" -> "", "SearchText" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[590, 23, 93, 2, 99, "Chapter",
   CellTags->"Overview",
   CellID->375154206],
  Cell[686, 27, 110, 2, 37, "Text",
   CellTags->"Overview",
   CellID->33937068],
  Cell[799, 31, 111, 2, 53, "MathCaption",
   CellTags->"Overview",
   CellID->674644],
  Cell[913, 35, 80, 2, 41, "Input",
   CellTags->"Overview",
   CellID->639264307],
  Cell[996, 39, 170, 5, 37, "Text",
   CellTags->"Overview",
   CellID->599613220],
  Cell[1169, 46, 115, 2, 41, "Input",
   CellTags->"Overview",
   CellID->749706],
  Cell[1287, 50, 113, 2, 41, "Input",
   CellTags->"Overview",
   CellID->322971538]},
 "Constructo"->{
  Cell[1425, 56, 76, 2, 77, "Section",
   CellTags->"Constructo",
   CellID->368244820]},
 "Constructor"->{
  Cell[1526, 62, 87, 2, 47, "Subsubsection",
   CellTags->"Constructor",
   CellID->192185989],
  Cell[2732, 99, 547, 17, 102, "Input",
   CellTags->"Constructor",
   CellID->248489711],
  Cell[3304, 120, 148, 3, 70, "Input",
   CellTags->"Constructor",
   CellID->158679249],
  Cell[3455, 125, 203, 5, 70, "Output",
   CellTags->"Constructor",
   CellID->35623139],
  Cell[3707, 136, 98, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->78813699],
  Cell[7616, 247, 706, 21, 70, "Input",
   CellTags->"Constructor",
   CellID->12229801],
  Cell[8325, 270, 183, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->103156138],
  Cell[8545, 280, 100, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->315778155],
  Cell[12512, 393, 620, 19, 70, "Input",
   CellTags->"Constructor",
   CellID->32859848],
  Cell[13135, 414, 184, 5, 70, "Input",
   CellTags->"Constructor",
   CellID->275606245],
  Cell[13356, 424, 86, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->48004226],
  Cell[17134, 534, 519, 16, 70, "Input",
   CellTags->"Constructor",
   CellID->462179735],
  Cell[17656, 552, 119, 2, 70, "Input",
   CellTags->"Constructor",
   CellID->903020829],
  Cell[17812, 559, 95, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->172959588],
  Cell[19204, 600, 525, 17, 70, "Input",
   CellTags->"Constructor",
   CellID->178662154],
  Cell[19732, 619, 136, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->125974609],
  Cell[19905, 628, 99, 2, 70, "Subsubsection",
   CellTags->"Constructor",
   CellID->5530490],
  Cell[20451, 645, 210, 6, 70, "Input",
   CellTags->"Constructor",
   CellID->733327189],
  Cell[20664, 653, 131, 4, 70, "Input",
   CellTags->"Constructor",
   CellID->14501181]},
 "Member"->{
  Cell[20844, 663, 75, 2, 70, "Section",
   CellTags->"Member",
   CellID->412431783],
  Cell[20944, 669, 88, 2, 70, "Subsubsection",
   CellTags->"Member",
   CellID->117196721],
  Cell[21250, 680, 85, 2, 28, "Input",
   CellTags->"Member",
   CellID->164623595],
  Cell[21372, 687, 86, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->138126032],
  Cell[21677, 698, 81, 2, 28, "Input",
   CellTags->"Member",
   CellID->3334290],
  Cell[21795, 705, 86, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->137775125],
  Cell[21884, 709, 83, 2, 28, "Input",
   CellTags->"Member",
   CellID->153544469],
  Cell[22004, 716, 90, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->205254248],
  Cell[22097, 720, 87, 2, 28, "Input",
   CellTags->"Member",
   CellID->228913846],
  Cell[22221, 727, 88, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->284194973],
  Cell[22312, 731, 85, 2, 28, "Input",
   CellTags->"Member",
   CellID->426031384],
  Cell[22434, 738, 99, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->178281853],
  Cell[22536, 742, 96, 2, 28, "Input",
   CellTags->"Member",
   CellID->485928151],
  Cell[22669, 749, 96, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->2177572],
  Cell[22768, 753, 94, 2, 28, "Input",
   CellTags->"Member",
   CellID->64634559],
  Cell[22899, 760, 95, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->95704538],
  Cell[22997, 764, 92, 2, 28, "Input",
   CellTags->"Member",
   CellID->63261696],
  Cell[23126, 771, 97, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->490316859],
  Cell[23226, 775, 94, 2, 28, "Input",
   CellTags->"Member",
   CellID->375210770],
  Cell[23357, 782, 99, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->520752797],
  Cell[23459, 786, 95, 2, 28, "Input",
   CellTags->"Member",
   CellID->57539522],
  Cell[23591, 793, 102, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->171137677],
  Cell[23696, 797, 99, 2, 28, "Input",
   CellTags->"Member",
   CellID->126890954],
  Cell[23832, 804, 105, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->235754024],
  Cell[23940, 808, 102, 2, 28, "Input",
   CellTags->"Member",
   CellID->212046576]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 25135, 846},
 {"Constructo", 25747, 868},
 {"Constructor", 25855, 872},
 {"Member", 27630, 930}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 93, 2, 99, "Chapter",
 CellTags->"Overview",
 CellID->375154206],
Cell[686, 27, 110, 2, 37, "Text",
 CellTags->"Overview",
 CellID->33937068],
Cell[799, 31, 111, 2, 53, "MathCaption",
 CellTags->"Overview",
 CellID->674644],
Cell[913, 35, 80, 2, 41, "Input",
 CellTags->"Overview",
 CellID->639264307],
Cell[996, 39, 170, 5, 37, "Text",
 CellTags->"Overview",
 CellID->599613220],
Cell[1169, 46, 115, 2, 41, "Input",
 CellTags->"Overview",
 CellID->749706],
Cell[1287, 50, 113, 2, 41, "Input",
 CellTags->"Overview",
 CellID->322971538],
Cell[CellGroupData[{
Cell[1425, 56, 76, 2, 77, "Section",
 CellTags->"Constructo",
 CellID->368244820],
Cell[CellGroupData[{
Cell[1526, 62, 87, 2, 47, "Subsubsection",
 CellTags->"Constructor",
 CellID->192185989],
Cell[1616, 66, 833, 22, 146, "Input",
 CellID->131254265],
Cell[2452, 90, 277, 7, 93, "Input",
 CellID->3974606],
Cell[2732, 99, 547, 17, 102, "Input",
 CellTags->"Constructor",
 CellID->248489711],
Cell[CellGroupData[{
Cell[3304, 120, 148, 3, 70, "Input",
 CellTags->"Constructor",
 CellID->158679249],
Cell[3455, 125, 203, 5, 70, "Output",
 CellTags->"Constructor",
 CellID->35623139]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3707, 136, 98, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->78813699],
Cell[3808, 140, 972, 25, 70, "Input",
 CellID->846235198],
Cell[4783, 167, 2830, 78, 70, "Input",
 CellID->297509953],
Cell[7616, 247, 706, 21, 70, "Input",
 CellTags->"Constructor",
 CellID->12229801],
Cell[8325, 270, 183, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->103156138]
}, Open  ]],
Cell[CellGroupData[{
Cell[8545, 280, 100, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->315778155],
Cell[8648, 284, 1028, 27, 70, "Input",
 CellID->426672001],
Cell[9679, 313, 2830, 78, 70, "Input",
 CellID->276839070],
Cell[12512, 393, 620, 19, 70, "Input",
 CellTags->"Constructor",
 CellID->32859848],
Cell[13135, 414, 184, 5, 70, "Input",
 CellTags->"Constructor",
 CellID->275606245]
}, Open  ]],
Cell[CellGroupData[{
Cell[13356, 424, 86, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->48004226],
Cell[13445, 428, 986, 27, 70, "Input",
 CellID->130613144],
Cell[14434, 457, 2697, 75, 70, "Input",
 CellID->925317],
Cell[17134, 534, 519, 16, 70, "Input",
 CellTags->"Constructor",
 CellID->462179735],
Cell[17656, 552, 119, 2, 70, "Input",
 CellTags->"Constructor",
 CellID->903020829]
}, Open  ]],
Cell[CellGroupData[{
Cell[17812, 559, 95, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->172959588],
Cell[17910, 563, 1009, 26, 70, "Input",
 CellID->183439846],
Cell[18922, 591, 279, 7, 70, "Input",
 CellID->745207223],
Cell[19204, 600, 525, 17, 70, "Input",
 CellTags->"Constructor",
 CellID->178662154],
Cell[19732, 619, 136, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->125974609]
}, Open  ]],
Cell[CellGroupData[{
Cell[19905, 628, 99, 2, 70, "Subsubsection",
 CellTags->"Constructor",
 CellID->5530490],
Cell[20007, 632, 441, 11, 70, "Input",
 CellID->13228337],
Cell[20451, 645, 210, 6, 70, "Input",
 CellTags->"Constructor",
 CellID->733327189],
Cell[20664, 653, 131, 4, 70, "Input",
 CellTags->"Constructor",
 CellID->14501181]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20844, 663, 75, 2, 70, "Section",
 CellTags->"Member",
 CellID->412431783],
Cell[CellGroupData[{
Cell[20944, 669, 88, 2, 70, "Subsubsection",
 CellTags->"Member",
 CellID->117196721],
Cell[21035, 673, 212, 5, 70, "Input",
 CellID->40131189],
Cell[21250, 680, 85, 2, 28, "Input",
 CellTags->"Member",
 CellID->164623595]
}, Open  ]],
Cell[CellGroupData[{
Cell[21372, 687, 86, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->138126032],
Cell[21461, 691, 213, 5, 65, "Input",
 CellID->461446936],
Cell[21677, 698, 81, 2, 28, "Input",
 CellTags->"Member",
 CellID->3334290]
}, Open  ]],
Cell[CellGroupData[{
Cell[21795, 705, 86, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->137775125],
Cell[21884, 709, 83, 2, 28, "Input",
 CellTags->"Member",
 CellID->153544469]
}, Open  ]],
Cell[CellGroupData[{
Cell[22004, 716, 90, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->205254248],
Cell[22097, 720, 87, 2, 28, "Input",
 CellTags->"Member",
 CellID->228913846]
}, Open  ]],
Cell[CellGroupData[{
Cell[22221, 727, 88, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->284194973],
Cell[22312, 731, 85, 2, 28, "Input",
 CellTags->"Member",
 CellID->426031384]
}, Open  ]],
Cell[CellGroupData[{
Cell[22434, 738, 99, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->178281853],
Cell[22536, 742, 96, 2, 28, "Input",
 CellTags->"Member",
 CellID->485928151]
}, Open  ]],
Cell[CellGroupData[{
Cell[22669, 749, 96, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->2177572],
Cell[22768, 753, 94, 2, 28, "Input",
 CellTags->"Member",
 CellID->64634559]
}, Open  ]],
Cell[CellGroupData[{
Cell[22899, 760, 95, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->95704538],
Cell[22997, 764, 92, 2, 28, "Input",
 CellTags->"Member",
 CellID->63261696]
}, Open  ]],
Cell[CellGroupData[{
Cell[23126, 771, 97, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->490316859],
Cell[23226, 775, 94, 2, 28, "Input",
 CellTags->"Member",
 CellID->375210770]
}, Open  ]],
Cell[CellGroupData[{
Cell[23357, 782, 99, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->520752797],
Cell[23459, 786, 95, 2, 28, "Input",
 CellTags->"Member",
 CellID->57539522]
}, Open  ]],
Cell[CellGroupData[{
Cell[23591, 793, 102, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->171137677],
Cell[23696, 797, 99, 2, 28, "Input",
 CellTags->"Member",
 CellID->126890954]
}, Open  ]],
Cell[CellGroupData[{
Cell[23832, 804, 105, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->235754024],
Cell[23940, 808, 102, 2, 28, "Input",
 CellTags->"Member",
 CellID->212046576]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
