(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17963,        665]
NotebookOptionsPosition[     10425,        386]
NotebookOutlinePosition[     14595,        530]
CellTagsIndexPosition[     14440,        522]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Swap", "Chapter",
 CellTags->"Overview",
 CellID->367858257],

Cell["functions to construct and use Swap objects.", "Text",
 CellTags->"Overview",
 CellID->120563055],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->386623916],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->545760422],

Cell["\<\
Within the Swap part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->491721763],

Cell[CellGroupData[{

Cell["Select[Category[Swap],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[236]:=",
 CellID->751893626],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"MakeCms", ",", "Swap"}], "}"}]], "Output",
 CellChangeTimes->{3.436090818234375*^9},
 CellTags->"Overview",
 CellLabel->"Out[236]=",
 CellID->377007698]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Swap],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[237]:=",
 CellID->17111587],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "SwapLegAnalysis", ",", "SwapLegBPS", ",", "SwapLegNPV", ",", 
   "SwapMaturityDate", ",", "SwapStartDate"}], "}"}]], "Output",
 CellChangeTimes->{3.436090819140625*^9},
 CellTags->"Overview",
 CellLabel->"Out[237]=",
 CellID->911817517]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->204173419],

Cell[CellGroupData[{

Cell["Swap", "Subsubsection",
 CellTags->"Constructor",
 CellID->152640600],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LegIDs", 
     RowBox[{"leg", " ", "object", " ", 
      RowBox[{"IDs", "."}]}]},
    {"Payer", 
     RowBox[{"TRUE", " ", "for", " ", "payed", " ", 
      RowBox[{"leg", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->4725802],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"effectiveDate", " ", "=", " ", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"\"\<2D\>\"", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<Target\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"terminationDate", " ", "=", " ", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"effectiveDate", ",", "\"\<10Y\>\"", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<Target\>\""}], ",", 
     RowBox[{"BusinessDayConvention", "\[Rule]", "\"\<Unadjusted\>\""}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fixschedule", "=", 
   RowBox[{"Schedule", "[", 
    RowBox[{"effectiveDate", ",", "terminationDate", ",", "\"\<1Y\>\"", ",", 
     RowBox[{
     "BusinessDayConvention", "\[Rule]", " ", "\"\<Modified Following\>\""}], 
     ",", 
     RowBox[{"TermDateConv", "\[Rule]", "\"\<Modified Following\>\""}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"floatschedule", " ", "=", 
   RowBox[{"Schedule", "[", 
    RowBox[{"effectiveDate", ",", "terminationDate", ",", "\"\<6M\>\"", ",", 
     RowBox[{
     "BusinessDayConvention", "\[Rule]", " ", "\"\<Modified Following\>\""}], 
     ",", 
     RowBox[{"TermDateConv", "\[Rule]", "\"\<Modified Following\>\""}]}], 
    "]"}]}], ";"}]}], "Input",
 CellLabel->"In[28]:=",
 CellID->377813151],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nominal", " ", "=", "1000000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yc", "=", " ", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<NullCalendar\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"index", " ", "=", " ", 
   RowBox[{"Euribor", "[", 
    RowBox[{"\"\<6M\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", "yc"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"floatleg", " ", "=", 
   RowBox[{"IborLeg", "[", 
    RowBox[{"Nominal", ",", "floatschedule", ",", "index"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fixedleg", "=", 
   RowBox[{"FixedRateLeg", "[", 
    RowBox[{
     RowBox[{"{", "Nominal", "}"}], ",", "fixschedule", ",", 
     RowBox[{"{", "0.05", "}"}], ",", "\"\<30/360 (Bond Basis)\>\""}], 
    "]"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[44]:=",
 CellID->364404240],

Cell[CellGroupData[{

Cell["\<\
swap=Swap[{fixedleg,floatleg },{True,False}]\
\>", "Input",
 CellTags->"Constructor",
 CellLabel->"In[53]:=",
 CellID->410319295],

Cell[BoxData["Swap59"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[53]=",
 CellID->64944447]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeCms", "Subsubsection",
 CellTags->"Constructor",
 CellID->238665232],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapTenor", 
     RowBox[{"swap", " ", "tenor", " ", 
      RowBox[{"period", "."}]}]},
    {"SwapIndex", 
     RowBox[{"SwapIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"IborIndex", 
     RowBox[{"IborIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"ForwardStart", 
     RowBox[{"forward", " ", "start", " ", 
      RowBox[{"period", "."}]}]},
    {"CmsCouponPricer", 
     RowBox[{"CmsCouponPricer", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->547709668],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"IborSpread", "0.0", 
     RowBox[{"spread", " ", "over", " ", "the", " ", "ibor", " ", 
      RowBox[{"leg", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->594419],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SwapTenor", "=", "\"\<10Y\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SwapIndex", "=", "EuriborSwapFixA10Y"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"IborIndex", "=", "Euribor3M"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ForwardStart", "=", "\"\<0D\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CmsCouponPricer", "=", "CmsCouponPricerID"}], ";"}]}], "Input",
 CellChangeTimes->{{3.436090834921875*^9, 3.436090840015625*^9}},
 CellTags->"Constructor",
 CellID->255801830],

Cell["\<\
obj=MakeCms[SwapTenor,SwapIndex,IborIndex,ForwardStart,CmsCouponPricer]\
\>", "Input",
 CellTags->"Constructor",
 CellID->248574665]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->697229416],

Cell[CellGroupData[{

Cell["SwapLegBPS", "Subsubsection",
 CellTags->"Member",
 CellID->74097296],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LegNumber", 
     RowBox[{"Zero", " ", "based", " ", "leg", " ", "number", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"e", ".", "g", ".", " ", "use"}], " ", "0", " ", "for", " ",
           "the", " ", "first", " ", "leg"}], ",", " ", 
         RowBox[{"1", " ", "for", " ", "the", " ", "second", " ", "leg"}], 
         ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->7264173],

Cell[BoxData[
 RowBox[{
  RowBox[{"LegNumber", "=", "1"}], ";"}]], "Input",
 CellTags->"Member",
 CellLabel->"In[1]:=",
 CellID->111826091],

Cell[CellGroupData[{

Cell["SwapLegBPS[swap,LegNumber]", "Input",
 CellTags->"Member",
 CellLabel->"In[2]:=",
 CellID->49726756],

Cell[BoxData[
 RowBox[{"SwapLegBPS", "[", 
  RowBox[{"swap", ",", "1"}], "]"}]], "Output",
 CellTags->"Member",
 CellLabel->"Out[2]=",
 CellID->48840589]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwapLegNPV", "Subsubsection",
 CellTags->"Member",
 CellID->65283904],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LegNumber", 
     RowBox[{"Zero", " ", "based", " ", "leg", " ", "number", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"e", ".", "g", ".", " ", "use"}], " ", "0", " ", "for", " ",
           "the", " ", "first", " ", "leg"}], ",", " ", 
         RowBox[{"1", " ", "for", " ", "the", " ", "second", " ", "leg"}], 
         ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->457614557],

Cell[BoxData[
 RowBox[{
  RowBox[{"LegNumber", "=", "1"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->155204314],

Cell["SwapLegNPV[obj,LegNumber]", "Input",
 CellTags->"Member",
 CellID->431520635]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwapStartDate", "Subsubsection",
 CellTags->"Member",
 CellID->470842808],

Cell["SwapStartDate[obj]", "Input",
 CellTags->"Member",
 CellID->939799149]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwapMaturityDate", "Subsubsection",
 CellTags->"Member",
 CellID->181881045],

Cell["SwapMaturityDate[obj]", "Input",
 CellTags->"Member",
 CellID->291203705]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwapLegAnalysis", "Subsubsection",
 CellTags->"Member",
 CellID->59171705],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"LegNumber", 
     RowBox[{"Zero", " ", "based", " ", "leg", " ", "number", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"e", ".", "g", ".", " ", "use"}], " ", "0", " ", "for", " ",
           "the", " ", "first", " ", "leg"}], ",", " ", 
         RowBox[{"1", " ", "for", " ", "the", " ", "second", " ", "leg"}], 
         ",", " ", 
         RowBox[{"etc", "."}]}], ")"}], "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->155321288],

Cell[BoxData[
 RowBox[{
  RowBox[{"LegNumber", "=", "1"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->256991512],

Cell["SwapLegAnalysis[obj,LegNumber]", "Input",
 CellTags->"Member",
 CellID->199542413]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{616, 750},
WindowMargins->{{47, Automatic}, {Automatic, 93}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
ShowSelection->True,
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 66, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->367858257],
  Cell[636, 26, 103, 2, 30, "Text",
   CellTags->"Overview",
   CellID->120563055],
  Cell[742, 30, 114, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->386623916],
  Cell[859, 34, 103, 3, 28, "Input",
   CellTags->"Overview",
   CellID->545760422],
  Cell[965, 39, 152, 5, 50, "Text",
   CellTags->"Overview",
   CellID->491721763],
  Cell[1142, 48, 125, 3, 28, "Input",
   CellTags->"Overview",
   CellID->751893626],
  Cell[1270, 53, 192, 6, 36, "Output",
   CellTags->"Overview",
   CellID->377007698],
  Cell[1499, 64, 119, 3, 28, "Input",
   CellTags->"Overview",
   CellID->17111587],
  Cell[1621, 69, 279, 8, 54, "Output",
   CellTags->"Overview",
   CellID->911817517]},
 "Constructo"->{
  Cell[1937, 82, 76, 2, 51, "Section",
   CellTags->"Constructo",
   CellID->204173419]},
 "Constructor"->{
  Cell[2038, 88, 75, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->152640600],
  Cell[3893, 140, 992, 29, 119, "Input",
   CellTags->"Constructor",
   CellID->364404240],
  Cell[4910, 173, 139, 5, 28, "Input",
   CellTags->"Constructor",
   CellID->410319295],
  Cell[5052, 180, 102, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->64944447],
  Cell[5203, 189, 78, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->238665232],
  Cell[6237, 222, 494, 13, 101, "Input",
   CellTags->"Constructor",
   CellID->255801830],
  Cell[6734, 237, 142, 4, 28, "Input",
   CellTags->"Constructor",
   CellID->248574665]},
 "Member"->{
  Cell[6925, 247, 75, 2, 51, "Section",
   CellTags->"Member",
   CellID->697229416],
  Cell[7025, 253, 75, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->74097296],
  Cell[7703, 273, 139, 5, 28, "Input",
   CellTags->"Member",
   CellID->111826091],
  Cell[7867, 282, 106, 3, 28, "Input",
   CellTags->"Member",
   CellID->49726756],
  Cell[7976, 287, 153, 5, 36, "Output",
   CellTags->"Member",
   CellID->48840589],
  Cell[8178, 298, 75, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->65283904],
  Cell[8858, 318, 116, 4, 28, "Input",
   CellTags->"Member",
   CellID->155204314],
  Cell[8977, 324, 83, 2, 28, "Input",
   CellTags->"Member",
   CellID->431520635],
  Cell[9097, 331, 79, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->470842808],
  Cell[9179, 335, 76, 2, 28, "Input",
   CellTags->"Member",
   CellID->939799149],
  Cell[9292, 342, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->181881045],
  Cell[9377, 346, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->291203705],
  Cell[9493, 353, 80, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->59171705],
  Cell[10178, 373, 116, 4, 28, "Input",
   CellTags->"Member",
   CellID->256991512],
  Cell[10297, 379, 88, 2, 28, "Input",
   CellTags->"Member",
   CellID->199542413]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 11549, 419},
 {"Constructo", 12342, 447},
 {"Constructor", 12450, 451},
 {"Member", 13111, 473}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 66, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->367858257],
Cell[636, 26, 103, 2, 30, "Text",
 CellTags->"Overview",
 CellID->120563055],
Cell[742, 30, 114, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->386623916],
Cell[859, 34, 103, 3, 28, "Input",
 CellTags->"Overview",
 CellID->545760422],
Cell[965, 39, 152, 5, 50, "Text",
 CellTags->"Overview",
 CellID->491721763],
Cell[CellGroupData[{
Cell[1142, 48, 125, 3, 28, "Input",
 CellTags->"Overview",
 CellID->751893626],
Cell[1270, 53, 192, 6, 36, "Output",
 CellTags->"Overview",
 CellID->377007698]
}, Open  ]],
Cell[CellGroupData[{
Cell[1499, 64, 119, 3, 28, "Input",
 CellTags->"Overview",
 CellID->17111587],
Cell[1621, 69, 279, 8, 54, "Output",
 CellTags->"Overview",
 CellID->911817517]
}, Open  ]],
Cell[CellGroupData[{
Cell[1937, 82, 76, 2, 51, "Section",
 CellTags->"Constructo",
 CellID->204173419],
Cell[CellGroupData[{
Cell[2038, 88, 75, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->152640600],
Cell[2116, 92, 352, 10, 78, "Input",
 CellID->4725802],
Cell[2471, 104, 1419, 34, 191, "Input",
 CellID->377813151],
Cell[3893, 140, 992, 29, 119, "Input",
 CellTags->"Constructor",
 CellID->364404240],
Cell[CellGroupData[{
Cell[4910, 173, 139, 5, 28, "Input",
 CellTags->"Constructor",
 CellID->410319295],
Cell[5052, 180, 102, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->64944447]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5203, 189, 78, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->238665232],
Cell[5284, 193, 661, 19, 128, "Input",
 CellID->547709668],
Cell[5948, 214, 286, 6, 65, "Input",
 CellID->594419],
Cell[6237, 222, 494, 13, 101, "Input",
 CellTags->"Constructor",
 CellID->255801830],
Cell[6734, 237, 142, 4, 28, "Input",
 CellTags->"Constructor",
 CellID->248574665]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6925, 247, 75, 2, 51, "Section",
 CellTags->"Member",
 CellID->697229416],
Cell[CellGroupData[{
Cell[7025, 253, 75, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->74097296],
Cell[7103, 257, 597, 14, 100, "Input",
 CellID->7264173],
Cell[7703, 273, 139, 5, 28, "Input",
 CellTags->"Member",
 CellID->111826091],
Cell[CellGroupData[{
Cell[7867, 282, 106, 3, 28, "Input",
 CellTags->"Member",
 CellID->49726756],
Cell[7976, 287, 153, 5, 36, "Output",
 CellTags->"Member",
 CellID->48840589]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8178, 298, 75, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->65283904],
Cell[8256, 302, 599, 14, 100, "Input",
 CellID->457614557],
Cell[8858, 318, 116, 4, 28, "Input",
 CellTags->"Member",
 CellID->155204314],
Cell[8977, 324, 83, 2, 28, "Input",
 CellTags->"Member",
 CellID->431520635]
}, Open  ]],
Cell[CellGroupData[{
Cell[9097, 331, 79, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->470842808],
Cell[9179, 335, 76, 2, 28, "Input",
 CellTags->"Member",
 CellID->939799149]
}, Open  ]],
Cell[CellGroupData[{
Cell[9292, 342, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->181881045],
Cell[9377, 346, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->291203705]
}, Open  ]],
Cell[CellGroupData[{
Cell[9493, 353, 80, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->59171705],
Cell[9576, 357, 599, 14, 100, "Input",
 CellID->155321288],
Cell[10178, 373, 116, 4, 28, "Input",
 CellTags->"Member",
 CellID->256991512],
Cell[10297, 379, 88, 2, 28, "Input",
 CellTags->"Member",
 CellID->199542413]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
