(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12435,        472]
NotebookOptionsPosition[      6481,        252]
NotebookOutlinePosition[      9970,        373]
CellTagsIndexPosition[      9819,        365]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Swaption", "Chapter",
 CellTags->"Overview",
 CellID->385706214],

Cell["functions to construct and use Swaption objects.", "Text",
 CellTags->"Overview",
 CellID->367853716],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->419947741],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellID->290593514],

Cell["\<\
Within the Swaption part there are several constructors and member functions \
available \
\>", "Text",
 CellTags->"Overview",
 CellID->307216090],

Cell[CellGroupData[{

Cell["Select[Category[Swaption],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[269]:=",
 CellID->1224801],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"MakeSwaption", ",", "Swaption"}], "}"}]], "Output",
 CellChangeTimes->{3.43609090790625*^9},
 CellTags->"Overview",
 CellLabel->"Out[269]=",
 CellID->893334104]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Swaption],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[270]:=",
 CellID->100146743],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "SwaptionImpliedVolatility", ",", "SwaptionSettlementType", ",", 
   "SwaptionType"}], "}"}]], "Output",
 CellChangeTimes->{3.436090908875*^9},
 CellTags->"Overview",
 CellLabel->"Out[270]=",
 CellID->62565499]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->401438253],

Cell[CellGroupData[{

Cell["Swaption", "Subsubsection",
 CellTags->"Constructor",
 CellID->209343546],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"VanillaSwap", 
     RowBox[{"underlying", " ", 
      RowBox[{"(", "vanilla", ")"}], " ", "swap", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Exercise", 
     RowBox[{"Exercise", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"SettlementType", 
     RowBox[{"settlement", " ", "type", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"PhysicalSettlement", ",", " ", "CashSettlement"}], ")"}], 
       "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->778340965],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VanillaSwap", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Exercise", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SettlementType", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->116183732],

Cell["obj=Swaption[VanillaSwap,Exercise,SettlementType]", "Input",
 CellTags->"Constructor",
 CellID->230255993]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeSwaption", "Subsubsection",
 CellTags->"Constructor",
 CellID->893604790],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapIndex", 
     RowBox[{"SwapIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"OptionTenor", 
     RowBox[{"option", " ", "tenor", " ", "as", " ", "Period", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "'"}], "5", 
         RowBox[{"Y", "'"}]}], ")"}], "."}]}]},
    {"PricingEngineID", 
     RowBox[{"Swaption", " ", "PricingEngine", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->61278031],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Strike", "0.0", 
     RowBox[{"strike", "."}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->158834832],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SwapIndex", "=", "EuriborSwapFixA10Y"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionTenor", "=", "\"\<5Y\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PricingEngineID", "=", "SwaptionEngineID"}], ";"}]}], "Input",
 CellChangeTimes->{{3.43609092896875*^9, 3.436090930203125*^9}},
 CellTags->"Constructor",
 CellID->874586807],

Cell["obj=MakeSwaption[SwapIndex,OptionTenor,PricingEngineID]", "Input",
 CellTags->"Constructor",
 CellID->509211515]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->621389936],

Cell[CellGroupData[{

Cell["SwaptionType", "Subsubsection",
 CellTags->"Member",
 CellID->414809877],

Cell["SwaptionType[obj]", "Input",
 CellTags->"Member",
 CellID->212942502]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwaptionSettlementType", "Subsubsection",
 CellTags->"Member",
 CellID->207912878],

Cell["SwaptionSettlementType[obj]", "Input",
 CellTags->"Member",
 CellID->421207795]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwaptionImpliedVolatility", "Subsubsection",
 CellTags->"Member",
 CellID->396526711],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Price", 
     RowBox[{
     "Price", " ", "used", " ", "to", " ", "infer", " ", "the", " ", 
      "implied", " ", 
      RowBox[{"volatility", "."}]}]},
    {"YieldCurve", 
     RowBox[{"discounting", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->555674477],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Guess", "0.10", 
     RowBox[{"Volatility", " ", 
      RowBox[{"guess", "."}]}]},
    {"Accuracy", 
     RowBox[{
      RowBox[{"1.0", "e"}], "-", "6"}], 
     RowBox[{"solver", " ", 
      RowBox[{"accuracy", "."}]}]},
    {"MaxIter", "100", 
     RowBox[{"solver", " ", "max", " ", 
      RowBox[{"iterations", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->289422930],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Price", "=", "0.2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YieldCurve", "=", "EURYC"}], ";"}]}], "Input",
 CellTags->"Member",
 CellID->626867288],

Cell["SwaptionImpliedVolatility[obj,Price,YieldCurve]", "Input",
 CellTags->"Member",
 CellID->422388621]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{717, 748},
WindowMargins->{{Automatic, -821}, {81, Automatic}},
WindowFrame->"Normal",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
Magnification->1.,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 70, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->385706214],
  Cell[640, 26, 107, 2, 30, "Text",
   CellTags->"Overview",
   CellID->367853716],
  Cell[750, 30, 114, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->419947741],
  Cell[867, 34, 80, 2, 28, "Input",
   CellTags->"Overview",
   CellID->290593514],
  Cell[950, 38, 156, 5, 30, "Text",
   CellTags->"Overview",
   CellID->307216090],
  Cell[1131, 47, 127, 3, 28, "Input",
   CellTags->"Overview",
   CellID->1224801],
  Cell[1261, 52, 200, 6, 36, "Output",
   CellTags->"Overview",
   CellID->893334104],
  Cell[1498, 63, 124, 3, 28, "Input",
   CellTags->"Overview",
   CellID->100146743],
  Cell[1625, 68, 252, 8, 36, "Output",
   CellTags->"Overview",
   CellID->62565499]},
 "Constructo"->{
  Cell[1914, 81, 76, 2, 51, "Section",
   CellTags->"Constructo",
   CellID->401438253]},
 "Constructor"->{
  Cell[2015, 87, 79, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->209343546],
  Cell[2715, 110, 280, 8, 65, "Input",
   CellTags->"Constructor",
   CellID->116183732],
  Cell[2998, 120, 112, 2, 28, "Input",
   CellTags->"Constructor",
   CellID->230255993],
  Cell[3147, 127, 83, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->893604790],
  Cell[4088, 157, 355, 9, 65, "Input",
   CellTags->"Constructor",
   CellID->874586807],
  Cell[4446, 168, 118, 2, 28, "Input",
   CellTags->"Constructor",
   CellID->509211515]},
 "Member"->{
  Cell[4613, 176, 75, 2, 51, "Section",
   CellTags->"Member",
   CellID->621389936],
  Cell[4713, 182, 78, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->414809877],
  Cell[4794, 186, 75, 2, 28, "Input",
   CellTags->"Member",
   CellID->212942502],
  Cell[4906, 193, 88, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->207912878],
  Cell[4997, 197, 85, 2, 28, "Input",
   CellTags->"Member",
   CellID->421207795],
  Cell[5119, 204, 91, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->396526711],
  Cell[6153, 237, 180, 6, 47, "Input",
   CellTags->"Member",
   CellID->626867288],
  Cell[6336, 245, 105, 2, 28, "Input",
   CellTags->"Member",
   CellID->422388621]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 7630, 286},
 {"Constructo", 8420, 314},
 {"Constructor", 8528, 318},
 {"Member", 9095, 337}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 70, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->385706214],
Cell[640, 26, 107, 2, 30, "Text",
 CellTags->"Overview",
 CellID->367853716],
Cell[750, 30, 114, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->419947741],
Cell[867, 34, 80, 2, 28, "Input",
 CellTags->"Overview",
 CellID->290593514],
Cell[950, 38, 156, 5, 30, "Text",
 CellTags->"Overview",
 CellID->307216090],
Cell[CellGroupData[{
Cell[1131, 47, 127, 3, 28, "Input",
 CellTags->"Overview",
 CellID->1224801],
Cell[1261, 52, 200, 6, 36, "Output",
 CellTags->"Overview",
 CellID->893334104]
}, Open  ]],
Cell[CellGroupData[{
Cell[1498, 63, 124, 3, 28, "Input",
 CellTags->"Overview",
 CellID->100146743],
Cell[1625, 68, 252, 8, 36, "Output",
 CellTags->"Overview",
 CellID->62565499]
}, Open  ]],
Cell[CellGroupData[{
Cell[1914, 81, 76, 2, 51, "Section",
 CellTags->"Constructo",
 CellID->401438253],
Cell[CellGroupData[{
Cell[2015, 87, 79, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->209343546],
Cell[2097, 91, 615, 17, 116, "Input",
 CellID->778340965],
Cell[2715, 110, 280, 8, 65, "Input",
 CellTags->"Constructor",
 CellID->116183732],
Cell[2998, 120, 112, 2, 28, "Input",
 CellTags->"Constructor",
 CellID->230255993]
}, Open  ]],
Cell[CellGroupData[{
Cell[3147, 127, 83, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->893604790],
Cell[3233, 131, 631, 17, 95, "Input",
 CellID->61278031],
Cell[3867, 150, 218, 5, 65, "Input",
 CellID->158834832],
Cell[4088, 157, 355, 9, 65, "Input",
 CellTags->"Constructor",
 CellID->874586807],
Cell[4446, 168, 118, 2, 28, "Input",
 CellTags->"Constructor",
 CellID->509211515]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4613, 176, 75, 2, 51, "Section",
 CellTags->"Member",
 CellID->621389936],
Cell[CellGroupData[{
Cell[4713, 182, 78, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->414809877],
Cell[4794, 186, 75, 2, 28, "Input",
 CellTags->"Member",
 CellID->212942502]
}, Open  ]],
Cell[CellGroupData[{
Cell[4906, 193, 88, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->207912878],
Cell[4997, 197, 85, 2, 28, "Input",
 CellTags->"Member",
 CellID->421207795]
}, Open  ]],
Cell[CellGroupData[{
Cell[5119, 204, 91, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->396526711],
Cell[5213, 208, 445, 11, 78, "Input",
 CellID->555674477],
Cell[5661, 221, 489, 14, 95, "Input",
 CellID->289422930],
Cell[6153, 237, 180, 6, 47, "Input",
 CellTags->"Member",
 CellID->626867288],
Cell[6336, 245, 105, 2, 28, "Input",
 CellTags->"Member",
 CellID->422388621]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
