(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     56580,       1755]
NotebookOptionsPosition[     42773,       1288]
NotebookOutlinePosition[     48738,       1472]
CellTagsIndexPosition[     48609,       1465]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["YieldTermStructures", "Chapter",
 CellChangeTimes->{{3.524550765734375*^9, 3.524550766421875*^9}},
 CellTags->"Overview"],

Cell["functions to construct and use TermStructure objects.", "Text",
 CellTags->"Overview"],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview"],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:="],

Cell["\<\
Within the TermStructures part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview"],

Cell[CellGroupData[{

Cell["Select[Category[YieldTermStructures],QLConstructor[#]&]", "Input",
 CellChangeTimes->{3.524550774703125*^9},
 CellTags->"Overview",
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "DiscountCurve", ",", "FlatForward", ",", "ForwardCurve", ",", 
   "ForwardSpreadedTermStructure", ",", "ImpliedTermStructure", ",", 
   "InterpolatedYieldCurve", ",", "RelinkableHandleYieldTermStructure", ",", 
   "ZeroCurve"}], "}"}]], "Output",
 CellChangeTimes->{3.436187238390625*^9, 3.43618741759375*^9, 
  3.43618877590625*^9, 3.436243036875*^9, 3.436268715703125*^9, 
  3.4362688638125*^9, 3.436269385796875*^9, 3.436269722*^9, 
  3.436270274859375*^9, 3.43627247265625*^9, 3.436273088296875*^9, 
  3.43627540871875*^9, 3.436505321044673*^9, 3.436508062904048*^9, 
  3.524550598140625*^9, 3.52455077584375*^9, 3.52455090934375*^9, 
  3.52455192009375*^9, 3.524553261625*^9, 3.524553668171875*^9, 
  3.524554426*^9, 3.524556762109375*^9},
 CellTags->"Overview",
 CellLabel->"Out[2]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[YieldTermStructures],QLMember[#]&]", "Input",
 CellChangeTimes->{3.52455077996875*^9},
 CellTags->"Overview",
 CellLabel->"In[3]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "InterpolatedYieldCurveData", ",", "InterpolatedYieldCurveDates", ",", 
   "InterpolatedYieldCurveJumpDates", ",", "InterpolatedYieldCurveJumpTimes", 
   ",", "InterpolatedYieldCurveTimes", ",", "TermStructureCalendar", ",", 
   "TermStructureDayCounter", ",", "TermStructureMaxDate", ",", 
   "TermStructureReferenceDate", ",", "TermStructureSettlementDays", ",", 
   "TermStructureTimeFromReference", ",", "YieldTSDiscount", ",", 
   "YieldTSForwardRate", ",", "YieldTSForwardRate2", ",", "YieldTSZeroRate"}],
   "}"}]], "Output",
 CellChangeTimes->{3.436187239515625*^9, 3.436187418609375*^9, 
  3.43618877675*^9, 3.43624303846875*^9, 3.436268716734375*^9, 
  3.436268863828125*^9, 3.436269387203125*^9, 3.43626972309375*^9, 
  3.4362702756875*^9, 3.436272473953125*^9, 3.436273089296875*^9, 
  3.436275410140625*^9, 3.436505321950923*^9, 3.436508062935298*^9, 
  3.524550598265625*^9, 3.524550781109375*^9, 3.52455091078125*^9, 
  3.52455192021875*^9, 3.524553262765625*^9, 3.524553668296875*^9, 
  3.52455442603125*^9, 3.524556762390625*^9},
 CellTags->"Overview",
 CellLabel->"Out[3]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructor"],

Cell[CellGroupData[{

Cell["RelinkableHandleYieldTermStructure", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurrentLink", "\<\"\"\>", 
     RowBox[{
      RowBox[{"YieldTermStructure", " ", "object", " ", 
       RowBox[{"ID", ".", " ", "If"}], " ", "omitted"}], ",", " ", 
      RowBox[{"nothing", " ", "is", " ", "linked", " ", "by", " ", "the", " ", 
       RowBox[{"RelinkableHandle", "."}]}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[CellGroupData[{

Cell["obj=RelinkableHandleYieldTermStructure[]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[4]:="],

Cell[BoxData["RelinkableHandleYieldTermStructure3"], "Output",
 CellChangeTimes->{3.43618726246875*^9, 3.436187421421875*^9, 
  3.4361887795625*^9, 3.436243043*^9, 3.436268723515625*^9, 
  3.43626886421875*^9, 3.4362693899375*^9, 3.436269725828125*^9, 
  3.436270278890625*^9, 3.43627247678125*^9, 3.436273092265625*^9, 
  3.4362754121875*^9, 3.436505324669673*^9, 3.436508062997798*^9, 
  3.524550598296875*^9, 3.524550915109375*^9, 3.52455192028125*^9, 
  3.52455326584375*^9, 3.524553668328125*^9, 3.524554426109375*^9, 
  3.52455676271875*^9},
 CellTags->"Constructor",
 CellLabel->"Out[4]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiscountCurve", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveDates", 
     RowBox[{"dates", " ", "of", " ", "the", " ", 
      RowBox[{"curve", "."}]}]},
    {"CurveDiscounts", 
     RowBox[{
     "discount", " ", "factors", " ", "for", " ", "the", " ", "above", " ", 
      RowBox[{"dates", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "10"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CurveDiscounts", "=", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "0.95", ",", "0.9", ",", "0.85", ",", "0.8"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.436187322484375*^9, 3.436187324953125*^9}, {
  3.52137036271875*^9, 3.52137036334375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[5]:="],

Cell[CellGroupData[{

Cell["obj=DiscountCurve[CurveDates,CurveDiscounts]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[8]:="],

Cell[BoxData["DiscountCurve4"], "Output",
 CellChangeTimes->{3.4361873279375*^9, 3.436187427484375*^9, 
  3.436188784984375*^9, 3.436243046828125*^9, 3.436268739796875*^9, 
  3.436268864265625*^9, 3.43626939478125*^9, 3.436269731296875*^9, 
  3.43627028196875*^9, 3.436272480796875*^9, 3.436273101390625*^9, 
  3.43627541571875*^9, 3.436505329247798*^9, 3.436508063029048*^9, 
  3.521370365390625*^9, 3.524550598390625*^9, 3.524550926984375*^9, 
  3.5245519205625*^9, 3.524553271296875*^9, 3.524553668375*^9, 
  3.524554426171875*^9, 3.524556763125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
Alternativly the dates can be given in short form in relation to the \
valuation date as\
\>", "Text",
 CellChangeTimes->{{3.4362687461875*^9, 3.436268747109375*^9}, {
  3.4362687994375*^9, 3.436268827609375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<1M\>\"", ",", "\"\<3M\>\"", ",", "\"\<6M\>\"", ",", "\"\<9M\>\"", 
     ",", "\"\<12M\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"obj", "=", 
  RowBox[{"DiscountCurve", "[", 
   RowBox[{"CurveDates", ",", "CurveDiscounts"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.436268838265625*^9, 3.43626883846875*^9}},
 CellLabel->"In[9]:="],

Cell[BoxData["DiscountCurve5"], "Output",
 CellChangeTimes->{{3.43626883915625*^9, 3.436268864296875*^9}, 
   3.436269396421875*^9, 3.436269733234375*^9, 3.43627028325*^9, 
   3.436272482328125*^9, 3.436273102984375*^9, 3.436275417546875*^9, 
   3.436505330700923*^9, 3.436508063060298*^9, 3.521370367765625*^9, 
   3.524550598453125*^9, 3.524550929375*^9, 3.524551920609375*^9, 
   3.524553273578125*^9, 3.52455366840625*^9, 3.52455442621875*^9, 
   3.524556763359375*^9},
 CellLabel->"Out[10]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ZeroCurve", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"CurveDates", 
     RowBox[{"dates", " ", "of", " ", "the", " ", 
      RowBox[{"curve", "."}]}]},
    {"CurveYields", 
     RowBox[{"zero", " ", "rates", " ", "for", " ", "the", " ", "above", " ", 
      RowBox[{"dates", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "10"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CurveYields", "=", 
   RowBox[{"{", 
    RowBox[{"0.02", ",", "0.02", ",", "0.02", ",", "0.02", ",", "0.02"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.436188798171875*^9, 3.4361888030625*^9}},
 CellTags->"Constructor",
 CellLabel->"In[11]:="],

Cell[CellGroupData[{

Cell["obj=ZeroCurve[CurveDates,CurveYields]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[13]:="],

Cell[BoxData["ZeroCurve6"], "Output",
 CellChangeTimes->{
  3.436188807546875*^9, 3.43624305065625*^9, {3.436268846140625*^9, 
   3.43626886434375*^9}, 3.436269742375*^9, 3.43627028765625*^9, 
   3.436272486609375*^9, 3.43627310728125*^9, 3.436275421421875*^9, 
   3.436505335154048*^9, 3.436508063091548*^9, 3.521370372359375*^9, 
   3.524550598625*^9, 3.5245509371875*^9, 3.52455192065625*^9, 
   3.52455327821875*^9, 3.524553668609375*^9, 3.524554426296875*^9, 
   3.5245567634375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
Alternativly the dates can be given in short form in relation to the \
valuation date as\
\>", "Text",
 CellChangeTimes->{{3.4362687461875*^9, 3.436268747109375*^9}, {
  3.4362687994375*^9, 3.436268827609375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<1M\>\"", ",", "\"\<3M\>\"", ",", "\"\<6M\>\"", ",", "\"\<9M\>\"", 
     ",", "\"\<12M\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"obj", "=", 
  RowBox[{"ZeroCurve", "[", 
   RowBox[{"CurveDates", ",", "CurveDiscounts"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.436268838265625*^9, 3.43626883846875*^9}, 
   3.52455098734375*^9},
 CellLabel->"In[14]:="],

Cell[BoxData["ZeroCurve7"], "Output",
 CellChangeTimes->{{3.43626883915625*^9, 3.436268864296875*^9}, 
   3.436269396421875*^9, 3.436269733234375*^9, 3.43627028325*^9, 
   3.436272482328125*^9, 3.436273102984375*^9, 3.436275417546875*^9, 
   3.436505330700923*^9, 3.436508063060298*^9, 3.521370367765625*^9, 
   3.524550598453125*^9, 3.524550929375*^9, 3.524550988953125*^9, 
   3.524551920703125*^9, 3.52455328021875*^9, 3.524553668640625*^9, 
   3.524554426359375*^9, 3.52455676346875*^9},
 CellLabel->"Out[15]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ForwardCurve", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"CurveDates", 
      RowBox[{"dates", " ", "of", " ", "the", " ", 
       RowBox[{"curve", "."}]}]},
     {"ForwardYields", 
      RowBox[{
      "forwards", " ", "rates", " ", "for", " ", "the", " ", "above", " ", 
       RowBox[{"dates", "."}]}]}
    }]], "DefinitionBox",
   CellTags->"Constructor"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{{3.524553291359375*^9, 3.524553299234375*^9}}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "10"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ForwardYields", "=", 
   RowBox[{"{", 
    RowBox[{"0.02", ",", "0.02", ",", "0.02", ",", "0.02", ",", "0.02"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.4361888176875*^9},
 CellTags->"Constructor",
 CellLabel->"In[16]:="],

Cell[CellGroupData[{

Cell["obj=ForwardCurve[CurveDates,ForwardYields]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[18]:="],

Cell[BoxData["ForwardCurve8"], "Output",
 CellChangeTimes->{3.436188820234375*^9, 3.43624305546875*^9, 
  3.436268864375*^9, 3.436269748359375*^9, 3.436270292140625*^9, 
  3.43627249084375*^9, 3.436273111375*^9, 3.436275425484375*^9, 
  3.436505338685298*^9, 3.436508063122798*^9, 3.521370376921875*^9, 
  3.524550598671875*^9, 3.52455099996875*^9, 3.52455192075*^9, 
  3.52455330625*^9, 3.5245536686875*^9, 3.524554426421875*^9, 
  3.52455676353125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[18]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FlatForward", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"Calendar", 
      RowBox[{"holiday", " ", "calendar", " ", 
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], " ", "to", " ", 
       "advance", " ", "from", " ", "global", " ", 
       RowBox[{"EvaluationDate", "."}]}]},
     {"Rate", 
      RowBox[{"the", " ", "curve", " ", 
       RowBox[{"level", "."}]}]}
    }]], "DefinitionBox",
   CellTags->"Constructor"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{
  3.5245533090625*^9, {3.5245543558125*^9, 3.5245543558125*^9}}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Compounding", "Continuous", 
     RowBox[{"Interest", " ", "rate", " ", "compounding", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Simple", ":", 
          RowBox[{"1", "+", "rt"}]}], ",", " ", 
         RowBox[{"Compounded", ":", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "^", "t"}]}], ",", " ", 
         RowBox[{"Continuous", ":", 
          RowBox[{"e", "^", 
           RowBox[{"{", "rt", "}"}]}]}]}], ")"}], "."}]}]},
    {"NDays", "0", 
     RowBox[{
      RowBox[{
       RowBox[{
       "number", " ", "of", " ", "days", " ", "to", " ", "advance", " ", 
        "from", " ", "EvaluationDate", " ", 
        RowBox[{"(", 
         RowBox[{"usually", " ", "zero", " ", "or", " ", "two"}], ")"}]}], 
       ":", " ", 
       RowBox[{
       "it", " ", "fixes", " ", "the", " ", "date", " ", "at", " ", "which", 
        " ", "the", " ", "discount", " ", "factor"}]}], " ", "=", " ", 
      RowBox[{"1.0", "."}]}]},
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]},
    {"Frequency", "\<\"Annual\"\>", 
     RowBox[{"frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellChangeTimes->{{3.436188912359375*^9, 3.4361889138125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rate", "=", "0.044"}], ";"}]], "Input",
 CellChangeTimes->{{3.436188828*^9, 3.436188835640625*^9}, {
  3.436188877953125*^9, 3.436188878328125*^9}, {3.524553321921875*^9, 
  3.524553322578125*^9}},
 CellTags->"Constructor",
 CellLabel->"In[19]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obj", "=", 
  RowBox[{"FlatForward", "[", 
   RowBox[{"Rate", ",", 
    RowBox[{"Compounding", "->", "\"\<Continuous\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.436188926734375*^9, {3.521370308375*^9, 3.521370334734375*^9}, 
   3.52137039709375*^9},
 CellTags->"Constructor",
 CellLabel->"In[20]:="],

Cell[BoxData["FlatForward9"], "Output",
 CellChangeTimes->{3.43618884278125*^9, 3.43618892825*^9, 3.436243059875*^9, 
  3.436268864625*^9, 3.436269752578125*^9, 3.436270299703125*^9, 
  3.436272494375*^9, 3.43627311471875*^9, 3.43627542859375*^9, 
  3.436505341825923*^9, 3.436508063154048*^9, 3.521370297828125*^9, 
  3.52137040075*^9, 3.52455059871875*^9, 3.524551006125*^9, 
  3.524551920796875*^9, 3.5245533244375*^9, 3.524553668734375*^9, 
  3.5245544265*^9, 3.524556763671875*^9},
 CellTags->"Constructor",
 CellLabel->"Out[20]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ForwardSpreadedTermStructure", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"BaseYieldCurve", 
     RowBox[{"Base", " ", "YieldTermStructure", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"Spread", 
     RowBox[{"spread", "."}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"BaseYieldCurve", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Compounding", "->", "\"\<Continuous\>\""}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Spread", "=", "0.0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.43618896853125*^9, 3.436189000234375*^9}, 
   3.5213704105*^9},
 CellTags->"Constructor",
 CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell["obj=ForwardSpreadedTermStructure[BaseYieldCurve,Spread]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[23]:="],

Cell[BoxData["ForwardSpreadedTermStructure11"], "Output",
 CellChangeTimes->{3.436189003171875*^9, 3.43626886465625*^9, 
  3.436269757203125*^9, 3.436270308109375*^9, 3.436270351625*^9, 
  3.4362704455625*^9, 3.436272508078125*^9, 3.436273118171875*^9, 
  3.436275431296875*^9, 3.436505345247798*^9, 3.436508063279048*^9, 
  3.521370413984375*^9, 3.524550599*^9, 3.524551013046875*^9, 
  3.52455192103125*^9, 3.52455333790625*^9, 3.5245536689375*^9, 
  3.524554426578125*^9, 3.52455676375*^9},
 CellTags->"Constructor",
 CellLabel->"Out[23]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImpliedTermStructure", "Subsubsection",
 CellTags->"Constructor"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"BaseYieldCurve", 
      RowBox[{"Base", " ", "YieldTermStructure", " ", "object", " ", 
       RowBox[{"ID", "."}]}]},
     {"ReferenceDate", 
      RowBox[{
      "the", " ", "reference", " ", "date", " ", "the", " ", "base", " ", 
       "YieldTermStructure", " ", "should", " ", "be", " ", "shifted", " ", 
       RowBox[{"to", "."}]}]}
    }]], "DefinitionBox",
   CellTags->"Constructor"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{3.5245533428125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BaseYieldCurve", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Compounding", "->", "\"\<Continuous\>\""}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.436272531015625*^9, 3.436272538296875*^9}, 
   3.52137043003125*^9, {3.521370475125*^9, 3.521370481875*^9}},
 CellTags->"Constructor",
 CellLabel->"In[24]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obj", "=", 
  RowBox[{"ImpliedTermStructure", "[", 
   RowBox[{"BaseYieldCurve", ",", 
    RowBox[{"EvaluationDate", "[", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521370440203125*^9, 3.5213704651875*^9}, {
   3.5245503583125*^9, 3.524550362*^9}, 3.5245503925625*^9},
 CellTags->"Constructor",
 CellLabel->"In[25]:="],

Cell[BoxData["ImpliedTermStructure13"], "Output",
 CellChangeTimes->{
  3.4362688650625*^9, 3.4362725405625*^9, 3.4362726235625*^9, 
   3.436273161265625*^9, 3.436273659375*^9, 3.43627543465625*^9, 
   3.436505349419673*^9, 3.436508063310298*^9, 3.52137043434375*^9, {
   3.52137046615625*^9, 3.521370483625*^9}, {3.52455036284375*^9, 
   3.52455039353125*^9}, 3.524550599046875*^9, 3.524551019046875*^9, 
   3.524551921109375*^9, 3.5245533465*^9, 3.524553668984375*^9, 
   3.52455442665625*^9, 3.5245567638125*^9},
 CellTags->"Constructor",
 CellLabel->"Out[25]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterpolatedYieldCurve", "Subsubsection",
 CellChangeTimes->{{3.5245571124375*^9, 3.524557119265625*^9}},
 CellTags->"Constructor"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"CurveDates", 
      RowBox[{"dates", " ", "of", " ", "the", " ", 
       RowBox[{"curve", "."}]}]},
     {"data", 
      RowBox[{
      "forwards", " ", "rates", " ", "for", " ", "the", " ", "above", " ", 
       RowBox[{"dates", "."}]}]}
    }]], "DefinitionBox",
   CellTags->"Constructor"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{{3.524553291359375*^9, 3.524553299234375*^9}, {
  3.52455714053125*^9, 3.524557148359375*^9}}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", "\<\"Actual/365 (Fixed)\"\>", 
     RowBox[{"DayCounter", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "10"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{"0.02", ",", "0.02", ",", "0.02", ",", "0.02", ",", "0.02"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4361888176875*^9, {3.52455718465625*^9, 3.52455718509375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[48]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obj", "=", 
  RowBox[{"InterpolatedYieldCurve", "[", 
   RowBox[{"CurveDates", ",", "data", ",", 
    RowBox[{"TraitsID", "->", "\"\<ZeroYield\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52455718978125*^9, 3.52455720171875*^9}, {
  3.5245572341875*^9, 3.524557270875*^9}, {3.52455733178125*^9, 
  3.52455733375*^9}},
 FormatType->"InputForm",
 CellTags->"Constructor",
 CellLabel->"In[55]:="],

Cell[BoxData["InterpolatedYieldCurve16"], "Output",
 CellChangeTimes->{3.436188820234375*^9, 3.43624305546875*^9, 
  3.436268864375*^9, 3.436269748359375*^9, 3.436270292140625*^9, 
  3.43627249084375*^9, 3.436273111375*^9, 3.436275425484375*^9, 
  3.436505338685298*^9, 3.436508063122798*^9, 3.521370376921875*^9, 
  3.524550598671875*^9, 3.52455099996875*^9, 3.52455192075*^9, 
  3.52455330625*^9, 3.5245536686875*^9, 3.524554426421875*^9, 
  3.52455676353125*^9, 3.52455720321875*^9, 3.52455727165625*^9, 
  3.5245573345625*^9},
 CellTags->"Constructor",
 CellLabel->"Out[55]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["TermStructureDayCounter", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["TermStructureDayCounter[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[26]:="],

Cell[BoxData["\<\"Actual/365 (Fixed)\"\>"], "Output",
 CellChangeTimes->{
  3.43626886515625*^9, {3.436273168234375*^9, 3.436273203671875*^9}, 
   3.43627366434375*^9, 3.436275437390625*^9, 3.436505351966548*^9, 
   3.436508063341548*^9, 3.5245505993125*^9, 3.5245510459375*^9, 
   3.52455192115625*^9, 3.52455334878125*^9, 3.524553669015625*^9, 
   3.524554426703125*^9, 3.52455676384375*^9},
 CellTags->"Member",
 CellLabel->"Out[26]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TermStructureMaxDate", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["TermStructureMaxDate[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[27]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2199", ",", "12", ",", "31"}], "}"}]], "Output",
 CellChangeTimes->{3.436268865171875*^9, 3.436275439375*^9, 
  3.436505353325923*^9, 3.436508063357173*^9, 3.52455059934375*^9, 
  3.52455104765625*^9, 3.5245519211875*^9, 3.524553351921875*^9, 
  3.524553669046875*^9, 3.52455442675*^9, 3.524556763875*^9},
 CellTags->"Member",
 CellLabel->"Out[27]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TermStructureReferenceDate", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["TermStructureReferenceDate[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[28]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2011", ",", "9", ",", "9"}], "}"}]], "Output",
 CellChangeTimes->{3.436268865203125*^9, 3.436275444046875*^9, 
  3.436505355529048*^9, 3.436508063388423*^9, 3.524550599359375*^9, 
  3.5245510493125*^9, 3.52455192121875*^9, 3.524553355515625*^9, 
  3.5245536690625*^9, 3.524554426875*^9, 3.52455676390625*^9},
 CellTags->"Member",
 CellLabel->"Out[28]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TermStructureTimeFromReference", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Date", 
     RowBox[{
     "vector", " ", "of", " ", "dates", " ", "or", " ", "a", " ", "single", 
      " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text",
 CellChangeTimes->{{3.5245511341875*^9, 3.52455113715625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"date", "=", 
   RowBox[{"CalendarAdvance", "[", "\"\<1Y\>\"", "]"}]}], ";"}], "\n", 
 RowBox[{"TermStructureTimeFromReference", "[", 
  RowBox[{"obj", ",", "date"}], "]"}]}], "Input",
 CellChangeTimes->{{3.43627025615625*^9, 3.43627025809375*^9}, {
  3.4362754504375*^9, 3.43627545071875*^9}, {3.524551145953125*^9, 
  3.524551181*^9}},
 CellTags->"Member",
 CellLabel->"In[29]:="],

Cell[BoxData[
 RowBox[{"{", "1.0054794520547945`", "}"}]], "Output",
 CellChangeTimes->{
  3.436268865546875*^9, {3.43627545384375*^9, 3.4362754638125*^9}, 
   3.436505359607173*^9, 3.436508063419673*^9, 3.5245505994375*^9, 
   3.524551054078125*^9, {3.524551170359375*^9, 3.524551181671875*^9}, 
   3.52455192125*^9, 3.524553364578125*^9, 3.52455366909375*^9, 
   3.524554426921875*^9, 3.52455676396875*^9},
 CellTags->"Member",
 CellLabel->"Out[30]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TermStructureCalendar", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["TermStructureCalendar[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[31]:="],

Cell[BoxData["\<\"TARGET\"\>"], "Output",
 CellChangeTimes->{3.4362688655625*^9, 3.43627546778125*^9, 
  3.436505361122798*^9, 3.436508063435298*^9, 3.52455059946875*^9, 
  3.52455119175*^9, 3.52455192128125*^9, 3.52455336846875*^9, 
  3.524553669125*^9, 3.52455442696875*^9, 3.524556764*^9},
 CellTags->"Member",
 CellLabel->"Out[31]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TermStructureSettlementDays", "Subsubsection",
 CellTags->"Member"],

Cell[CellGroupData[{

Cell["TermStructureSettlementDays[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[32]:="],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.43626886559375*^9, 3.436275470015625*^9, 
  3.436505362607173*^9, 3.436508063450923*^9, 3.5245505996875*^9, 
  3.5245511939375*^9, 3.5245519213125*^9, 3.524553370625*^9, 
  3.52455366915625*^9, 3.524554427015625*^9, 3.52455676403125*^9},
 CellTags->"Member",
 CellLabel->"Out[32]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["YieldTSDiscount", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"DfDates", 
      RowBox[{"vector", " ", "of", " ", 
       RowBox[{"dates", "."}]}]}
    }]], "DefinitionBox",
   CellTags->"Member"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{3.52455337625*^9}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "False", 
     RowBox[{"True", " ", "allows", " ", 
      RowBox[{"extrapolation", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellChangeTimes->{{3.436269284734375*^9, 3.436269291328125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DfDates", "=", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<1Y\>\"", ",", "\"\<2Y\>\"", ",", "\"\<3Y\>\"", ",", "\"\<4Y\>\"", 
      ",", "\"\<5Y\>\""}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.436275477359375*^9, 3.436275488109375*^9}, {
  3.524551204328125*^9, 3.524551212625*^9}},
 CellTags->"Member",
 CellLabel->"In[33]:="],

Cell[CellGroupData[{

Cell["YieldTSDiscount[obj,DfDates]", "Input",
 CellTags->"Member",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.956723267616893`", ",", "0.9156504902849`", ",", "0.8762353603402705`", 
   ",", "0.8385168957554429`", ",", "0.8023253373005346`"}], "}"}]], "Output",
 CellChangeTimes->{3.43627549021875*^9, 3.436505366497798*^9, 
  3.436508063482173*^9, 3.524550599734375*^9, 3.524551215015625*^9, 
  3.524551921375*^9, 3.52455338096875*^9, 3.524553669203125*^9, 
  3.524554427078125*^9, 3.524556764171875*^9},
 CellTags->"Member",
 CellLabel->"Out[34]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["YieldTSForwardRate", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"D1", 
     RowBox[{"first", " ", 
      RowBox[{"date", "."}]}]},
    {"D2", 
     RowBox[{"second", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Text",
 CellChangeTimes->{{3.524551897484375*^9, 3.524551897484375*^9}}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", 
     RowBox[{
      RowBox[{"Actual", "/", "365"}], " ", 
      RowBox[{"(", "Fixed", ")"}]}], 
     RowBox[{"result", " ", "day", " ", "counter"}]},
    {"Compounding", "Continuous", 
     RowBox[{"Interest", " ", "rate", " ", "compounding", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Simple", ":", 
          RowBox[{"1", "+", "rt"}]}], ",", " ", 
         RowBox[{"Compounded", ":", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "^", "t"}]}], ",", " ", 
         RowBox[{"Continuous", ":", 
          RowBox[{"e", "^", 
           RowBox[{"{", "rt", "}"}]}]}]}], ")"}], "."}]}]},
    {"Frequency", "\<\"Annual\"\>", 
     RowBox[{"frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]},
    {"AllowExtrapolation", "false", 
     RowBox[{"TRUE", " ", "allows", " ", 
      RowBox[{"extrapolation", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellChangeTimes->{{3.52455213859375*^9, 3.52455213859375*^9}, {
  3.524554260265625*^9, 3.524554269796875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"D1", "=", 
   RowBox[{"CalendarAdvance", "[", "\"\<1M\>\"", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"D2", "=", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<2M\>\"", ",", "\"\<3M\>\"", ",", "\"\<4M\>\"", ",", "\"\<5M\>\"", 
      ",", "\"\<6M\>\""}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.436275495953125*^9, 3.436275542875*^9}, {
  3.524551241640625*^9, 3.524551268875*^9}, {3.524551824171875*^9, 
  3.52455182534375*^9}, {3.524552869453125*^9, 3.5245528704375*^9}},
 CellTags->"Member",
 CellLabel->"In[35]:="],

Cell[CellGroupData[{

Cell["YieldTSForwardRate[obj,D1,D2]", "Input",
 CellChangeTimes->{{3.524551838109375*^9, 3.52455188728125*^9}},
 CellTags->"Member",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.044000000000002135`", ",", "0.043999999999999435`", ",", 
   "0.04400000000000013`", ",", "0.04400000000000051`", ",", 
   "0.04399999999999988`"}], "}"}]], "Output",
 CellChangeTimes->{3.43626886578125*^9, 3.436505372888423*^9, 
  3.436508063560298*^9, 3.52455059978125*^9, 3.52455127221875*^9, 
  3.52455189053125*^9, 3.524551921578125*^9, 3.524553387703125*^9, 
  3.52455366925*^9, 3.52455442715625*^9, 3.524556764296875*^9},
 CellTags->"Member",
 CellLabel->"Out[37]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["YieldTSForwardRate2", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"Date", 
      RowBox[{"first", " ", 
       RowBox[{"date", "."}]}]},
     {"Period", 
      RowBox[{"Period", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"e", ".", "g", ".", " ", "'"}], "7", 
           RowBox[{"D", "'"}]}], ",", " ", 
          RowBox[{"'", "3", 
           RowBox[{"M", "'"}]}], ",", " ", 
          RowBox[{"'", "1", 
           RowBox[{"Y", "'"}]}], ",", " ", "etc"}], ")"}], "."}]}]}
    }]], "DefinitionBox",
   CellTags->"Member"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{{3.524552146078125*^9, 3.524552146078125*^9}, {
   3.524552445359375*^9, 3.524552445359375*^9}, 3.524553530421875*^9}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", 
     RowBox[{
      RowBox[{"Actual", "/", "365"}], " ", 
      RowBox[{"(", "Fixed", ")"}]}], 
     RowBox[{"result", " ", "day", " ", "counter"}]},
    {"Compounding", "Continuous", 
     RowBox[{"Interest", " ", "rate", " ", "compounding", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Simple", ":", 
          RowBox[{"1", "+", "rt"}]}], ",", " ", 
         RowBox[{"Compounded", ":", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "^", "t"}]}], ",", " ", 
         RowBox[{"Continuous", ":", 
          RowBox[{"e", "^", 
           RowBox[{"{", "rt", "}"}]}]}]}], ")"}], "."}]}]},
    {"Frequency", "\<\"Annual\"\>", 
     RowBox[{"frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]},
    {"AllowExtrapolation", "false", 
     RowBox[{"TRUE", " ", "allows", " ", 
      RowBox[{"extrapolation", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellChangeTimes->{{3.52455243203125*^9, 3.524552433296875*^9}, {
  3.524554277640625*^9, 3.524554277640625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dates", "=", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<2M\>\"", ",", "\"\<3M\>\"", ",", "\"\<4M\>\"", ",", "\"\<5M\>\"", 
      ",", "\"\<6M\>\""}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"period", "=", "\"\<1Y\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.436508077997798*^9, 3.436508095763423*^9}, {
   3.5245520159375*^9, 3.524552063953125*^9}, 3.524553015953125*^9},
 CellTags->"Member",
 CellLabel->"In[38]:="],

Cell[CellGroupData[{

Cell["YieldTSForwardRate2[obj,dates,period]", "Input",
 CellChangeTimes->{{3.52455207165625*^9, 3.524552083859375*^9}, {
  3.524553021765625*^9, 3.524553022859375*^9}},
 CellTags->"Member",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.04399999999999989`", ",", "0.04399999999999989`", ",", 
   "0.0440000000000001`", ",", "0.0440000000000001`", ",", 
   "0.04400000000000004`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.436268865828125*^9, 3.436508063638423*^9, 3.524550599953125*^9, 
   3.524551921703125*^9, {3.5245520725625*^9, 3.5245520851875*^9}, 
   3.524553023609375*^9, 3.52455339471875*^9, 3.524556764359375*^9},
 CellTags->"Member",
 CellLabel->"Out[40]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["YieldTSZeroRate", "Subsubsection",
 CellTags->"Member"],

Cell[BoxData[
 RowBox[{Cell[BoxData[GridBox[{
     {"Dates", 
      RowBox[{"date", "."}]}
    }]], "DefinitionBox",
   CellTags->"Member"], Cell["Calling Parameters", "Caption"]}]], "Text",
 CellChangeTimes->{
  3.5245534263125*^9, {3.524553551921875*^9, 3.52455356009375*^9}}],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"DayCounter", 
     RowBox[{
      RowBox[{"Actual", "/", "365"}], " ", 
      RowBox[{"(", "Fixed", ")"}]}], 
     RowBox[{"result", " ", "day", " ", "counter"}]},
    {"Compounding", "Continuous", 
     RowBox[{"Interest", " ", "rate", " ", "compounding", " ", "rule", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Simple", ":", 
          RowBox[{"1", "+", "rt"}]}], ",", " ", 
         RowBox[{"Compounded", ":", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "^", "t"}]}], ",", " ", 
         RowBox[{"Continuous", ":", 
          RowBox[{"e", "^", 
           RowBox[{"{", "rt", "}"}]}]}]}], ")"}], "."}]}]},
    {"Frequency", "\<\"Annual\"\>", 
     RowBox[{"frequency", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Annual"}], ",", " ", "Semiannual", 
         ",", " ", "Every4Month", ",", " ", "Quarterly", ",", " ", 
         "Bimonthly", ",", " ", "Monthly"}], ")"}], "."}]}]},
    {"AllowExtrapolation", "false", 
     RowBox[{"TRUE", " ", "allows", " ", 
      RowBox[{"extrapolation", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Text",
 CellChangeTimes->{{3.52455243203125*^9, 3.524552433296875*^9}, {
  3.524554279921875*^9, 3.524554279921875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dates", "=", 
   RowBox[{"CalendarAdvance", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<2M\>\"", ",", "\"\<3M\>\"", ",", "\"\<4M\>\"", ",", "\"\<5M\>\"", 
      ",", "\"\<6M\>\""}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.436505455216548*^9, 3.436505465466548*^9}, {
  3.5245534320625*^9, 3.52455347271875*^9}},
 CellTags->"Member",
 CellLabel->"In[41]:="],

Cell[CellGroupData[{

Cell["YieldTSZeroRate[obj,dates]", "Input",
 CellChangeTimes->{{3.52455347609375*^9, 3.524553480515625*^9}},
 CellTags->"Member",
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.044000000000000344`", ",", "0.04400000000000013`", ",", 
   "0.04399999999999985`", ",", "0.04400000000000009`", ",", "0.044`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436268865890625*^9, 3.436508063669673*^9, 
  3.524550599984375*^9, 3.52455192175*^9, 3.52455348109375*^9, 
  3.52455676440625*^9},
 CellTags->"Member",
 CellLabel->"Out[42]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
InterpolatedYieldCurveData, InterpolatedYieldCurveDates, \
InterpolatedYieldCurveTimes\
\>", "Subsubsection",
 CellChangeTimes->{{3.524557452921875*^9, 3.524557469546875*^9}},
 CellTags->"Member"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CurveDates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "10"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{"0.02", ",", "0.02", ",", "0.02", ",", "0.02", ",", "0.02"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4361888176875*^9, {3.52455718465625*^9, 3.52455718509375*^9}},
 CellTags->"Constructor",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"obj", "=", 
  RowBox[{"InterpolatedYieldCurve", "[", 
   RowBox[{"CurveDates", ",", "data", ",", 
    RowBox[{"TraitsID", "->", "\"\<ZeroYield\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52455718978125*^9, 3.52455720171875*^9}, {
  3.5245572341875*^9, 3.524557270875*^9}, {3.52455733178125*^9, 
  3.52455733375*^9}},
 FormatType->"InputForm",
 CellTags->"Constructor",
 CellLabel->"In[55]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InterpolatedYieldCurveData", "[", "obj", "]"}]], "Input",
 CellChangeTimes->{{3.524557403046875*^9, 3.524557404390625*^9}},
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.02`", ",", "0.02`", ",", "0.02`", ",", "0.02`", ",", "0.02`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.52455740503125*^9},
 CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InterpolatedYieldCurveDates", "[", "obj", "]"}]], "Input",
 CellChangeTimes->{{3.52455742215625*^9, 3.524557424140625*^9}},
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2008", ",", "11", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2008", ",", "12", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "1", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "2", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "3", ",", "10"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.52455742484375*^9},
 CellLabel->"Out[57]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InterpolatedYieldCurveTimes", "[", "obj", "]"}]], "Input",
 CellChangeTimes->{{3.524557436203125*^9, 3.5245574388125*^9}},
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.0821917808219178`", ",", "0.16712328767123288`", ",", 
   "0.25205479452054796`", ",", "0.3287671232876712`"}], "}"}]], "Output",
 CellChangeTimes->{3.524557439546875*^9},
 CellLabel->"Out[58]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
WindowToolbars->"EditBar",
WindowSize->{769, 765},
WindowMargins->{{Automatic, 132}, {Automatic, 18}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 127, 2, 99, "Chapter",
   CellTags->"Overview"],
  Cell[697, 26, 92, 1, 37, "Text",
   CellTags->"Overview"],
  Cell[792, 29, 94, 1, 53, "MathCaption",
   CellTags->"Overview"],
  Cell[889, 32, 83, 2, 41, "Input",
   CellTags->"Overview"],
  Cell[975, 36, 142, 4, 37, "Text",
   CellTags->"Overview"],
  Cell[1142, 44, 160, 3, 41, "Input",
   CellTags->"Overview"],
  Cell[1305, 49, 833, 16, 59, "Output",
   CellTags->"Overview"],
  Cell[2175, 70, 154, 3, 41, "Input",
   CellTags->"Overview"],
  Cell[2332, 75, 1134, 20, 116, "Output",
   CellTags->"Overview"]},
 "Constructor"->{
  Cell[3503, 100, 57, 1, 77, "Section",
   CellTags->"Constructor"],
  Cell[3585, 105, 85, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[4140, 120, 106, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[4249, 124, 596, 10, 39, "Output",
   CellTags->"Constructor"],
  Cell[4894, 140, 64, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[5621, 162, 891, 24, 82, "Input",
   CellTags->"Constructor"],
  Cell[6537, 190, 110, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[6650, 194, 602, 10, 39, "Output",
   CellTags->"Constructor"],
  Cell[8504, 243, 60, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[9212, 264, 768, 22, 62, "Input",
   CellTags->"Constructor"],
  Cell[10005, 290, 104, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[10112, 294, 538, 10, 39, "Output",
   CellTags->"Constructor"],
  Cell[11942, 344, 63, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[12741, 367, 746, 22, 62, "Input",
   CellTags->"Constructor"],
  Cell[13512, 393, 109, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[13624, 397, 504, 9, 39, "Output",
   CellTags->"Constructor"],
  Cell[14177, 412, 62, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[16503, 474, 282, 7, 41, "Input",
   CellTags->"Constructor"],
  Cell[16810, 485, 332, 9, 41, "Input",
   CellTags->"Constructor"],
  Cell[17145, 496, 536, 9, 39, "Output",
   CellTags->"Constructor"],
  Cell[17730, 511, 79, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[18131, 524, 401, 12, 62, "Input",
   CellTags->"Constructor"],
  Cell[18557, 540, 122, 2, 41, "Input",
   CellTags->"Constructor"],
  Cell[18682, 544, 543, 9, 39, "Output",
   CellTags->"Constructor"],
  Cell[19274, 559, 71, 1, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[19888, 576, 386, 10, 41, "Input",
   CellTags->"Constructor"],
  Cell[20299, 590, 349, 8, 41, "Input",
   CellTags->"Constructor"],
  Cell[20651, 600, 565, 10, 39, "Output",
   CellTags->"Constructor"],
  Cell[21265, 616, 137, 2, 47, "Subsubsection",
   CellTags->"Constructor"],
  Cell[22177, 641, 784, 23, 62, "Input",
   CellTags->"Constructor"],
  Cell[22986, 668, 423, 10, 41, "Input",
   CellTags->"Constructor"],
  Cell[23412, 680, 580, 10, 39, "Output",
   CellTags->"Constructor"],
  Cell[39963, 1193, 784, 23, 62, "Input",
   CellTags->"Constructor"],
  Cell[40750, 1218, 423, 10, 41, "Input",
   CellTags->"Constructor"]},
 "Member"->{
  Cell[24053, 697, 55, 1, 77, "Section",
   CellTags->"Member"],
  Cell[24133, 702, 69, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[24227, 707, 90, 2, 41, "Input",
   CellTags->"Member"],
  Cell[24320, 711, 438, 8, 39, "Output",
   CellTags->"Member"],
  Cell[24807, 725, 66, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[24898, 730, 87, 2, 41, "Input",
   CellTags->"Member"],
  Cell[24988, 734, 390, 8, 39, "Output",
   CellTags->"Member"],
  Cell[25427, 748, 72, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[25524, 753, 93, 2, 41, "Input",
   CellTags->"Member"],
  Cell[25620, 757, 393, 8, 39, "Output",
   CellTags->"Member"],
  Cell[26062, 771, 76, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[26516, 786, 417, 10, 62, "Input",
   CellTags->"Member"],
  Cell[26936, 798, 453, 9, 39, "Output",
   CellTags->"Member"],
  Cell[27438, 813, 67, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[27530, 818, 88, 2, 41, "Input",
   CellTags->"Member"],
  Cell[27621, 822, 337, 6, 39, "Output",
   CellTags->"Member"],
  Cell[28007, 834, 73, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[28105, 839, 94, 2, 41, "Input",
   CellTags->"Member"],
  Cell[28202, 843, 332, 6, 39, "Output",
   CellTags->"Member"],
  Cell[28583, 855, 61, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[29252, 875, 412, 11, 41, "Input",
   CellTags->"Member"],
  Cell[29689, 890, 90, 2, 41, "Input",
   CellTags->"Member"],
  Cell[29782, 894, 485, 10, 39, "Output",
   CellTags->"Member"],
  Cell[30316, 910, 64, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[32133, 960, 602, 15, 62, "Input",
   CellTags->"Member"],
  Cell[32760, 979, 156, 3, 41, "Input",
   CellTags->"Member"],
  Cell[32919, 984, 518, 11, 39, "Output",
   CellTags->"Member"],
  Cell[33486, 1001, 65, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[35709, 1062, 501, 13, 62, "Input",
   CellTags->"Member"],
  Cell[36235, 1079, 213, 4, 41, "Input",
   CellTags->"Member"],
  Cell[36451, 1085, 478, 11, 39, "Output",
   CellTags->"Member"],
  Cell[36978, 1102, 61, 1, 47, "Subsubsection",
   CellTags->"Member"],
  Cell[38722, 1150, 410, 11, 41, "Input",
   CellTags->"Member"],
  Cell[39157, 1165, 153, 3, 41, "Input",
   CellTags->"Member"],
  Cell[39313, 1170, 392, 10, 39, "Output",
   CellTags->"Member"],
  Cell[39754, 1186, 206, 5, 47, "Subsubsection",
   CellTags->"Member"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 43149, 1301},
 {"Constructor", 43748, 1320},
 {"Member", 46180, 1389}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 127, 2, 99, "Chapter",
 CellTags->"Overview"],
Cell[697, 26, 92, 1, 37, "Text",
 CellTags->"Overview"],
Cell[792, 29, 94, 1, 53, "MathCaption",
 CellTags->"Overview"],
Cell[889, 32, 83, 2, 41, "Input",
 CellTags->"Overview"],
Cell[975, 36, 142, 4, 37, "Text",
 CellTags->"Overview"],
Cell[CellGroupData[{
Cell[1142, 44, 160, 3, 41, "Input",
 CellTags->"Overview"],
Cell[1305, 49, 833, 16, 59, "Output",
 CellTags->"Overview"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2175, 70, 154, 3, 41, "Input",
 CellTags->"Overview"],
Cell[2332, 75, 1134, 20, 116, "Output",
 CellTags->"Overview"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3503, 100, 57, 1, 77, "Section",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[3585, 105, 85, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[3673, 108, 442, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[4140, 120, 106, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[4249, 124, 596, 10, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4894, 140, 64, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[4961, 143, 398, 10, 99, "Text"],
Cell[5362, 155, 256, 5, 64, "Text"],
Cell[5621, 162, 891, 24, 82, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[6537, 190, 110, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[6650, 194, 602, 10, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]],
Cell[7267, 207, 223, 5, 23, "Text"],
Cell[CellGroupData[{
Cell[7515, 216, 440, 11, 48, "Input"],
Cell[7958, 229, 497, 8, 25, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8504, 243, 60, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[8567, 246, 383, 9, 99, "Text"],
Cell[8953, 257, 256, 5, 64, "Text"],
Cell[9212, 264, 768, 22, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[10005, 290, 104, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[10112, 294, 538, 10, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]],
Cell[10665, 307, 223, 5, 23, "Text"],
Cell[CellGroupData[{
Cell[10913, 316, 462, 12, 48, "Input"],
Cell[11378, 330, 515, 8, 25, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11942, 344, 63, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[12008, 347, 471, 11, 80, "Text"],
Cell[12482, 360, 256, 5, 64, "Text"],
Cell[12741, 367, 746, 22, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[13512, 393, 109, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[13624, 397, 504, 9, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14177, 412, 62, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[14242, 415, 584, 14, 107, "Text"],
Cell[14829, 431, 1671, 41, 265, "Text"],
Cell[16503, 474, 282, 7, 41, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[16810, 485, 332, 9, 41, "Input",
 CellTags->"Constructor"],
Cell[17145, 496, 536, 9, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17730, 511, 79, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[17812, 514, 316, 8, 99, "Text"],
Cell[18131, 524, 401, 12, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[18557, 540, 122, 2, 41, "Input",
 CellTags->"Constructor"],
Cell[18682, 544, 543, 9, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19274, 559, 71, 1, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[19348, 562, 537, 12, 107, "Text"],
Cell[19888, 576, 386, 10, 41, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[20299, 590, 349, 8, 41, "Input",
 CellTags->"Constructor"],
Cell[20651, 600, 565, 10, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21265, 616, 137, 2, 47, "Subsubsection",
 CellTags->"Constructor"],
Cell[21405, 620, 510, 12, 80, "Text"],
Cell[21918, 634, 256, 5, 64, "Text"],
Cell[22177, 641, 784, 23, 62, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[22986, 668, 423, 10, 41, "Input",
 CellTags->"Constructor"],
Cell[23412, 680, 580, 10, 39, "Output",
 CellTags->"Constructor"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24053, 697, 55, 1, 77, "Section",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[24133, 702, 69, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[24227, 707, 90, 2, 41, "Input",
 CellTags->"Member"],
Cell[24320, 711, 438, 8, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24807, 725, 66, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[24898, 730, 87, 2, 41, "Input",
 CellTags->"Member"],
Cell[24988, 734, 390, 8, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25427, 748, 72, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[25524, 753, 93, 2, 41, "Input",
 CellTags->"Member"],
Cell[25620, 757, 393, 8, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26062, 771, 76, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[26141, 774, 350, 8, 83, "Text"],
Cell[CellGroupData[{
Cell[26516, 786, 417, 10, 62, "Input",
 CellTags->"Member"],
Cell[26936, 798, 453, 9, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27438, 813, 67, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[27530, 818, 88, 2, 41, "Input",
 CellTags->"Member"],
Cell[27621, 822, 337, 6, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28007, 834, 73, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[28105, 839, 94, 2, 41, "Input",
 CellTags->"Member"],
Cell[28202, 843, 332, 6, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28583, 855, 61, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[28647, 858, 275, 7, 64, "Text"],
Cell[28925, 867, 324, 6, 64, "Text"],
Cell[29252, 875, 412, 11, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[29689, 890, 90, 2, 41, "Input",
 CellTags->"Member"],
Cell[29782, 894, 485, 10, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30316, 910, 64, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[30383, 913, 349, 9, 99, "Text"],
Cell[30735, 924, 1395, 34, 203, "Text"],
Cell[32133, 960, 602, 15, 62, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[32760, 979, 156, 3, 41, "Input",
 CellTags->"Member"],
Cell[32919, 984, 518, 11, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33486, 1001, 65, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[33554, 1004, 753, 20, 80, "Text"],
Cell[34310, 1026, 1396, 34, 203, "Text"],
Cell[35709, 1062, 501, 13, 62, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[36235, 1079, 213, 4, 41, "Input",
 CellTags->"Member"],
Cell[36451, 1085, 478, 11, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36978, 1102, 61, 1, 47, "Subsubsection",
 CellTags->"Member"],
Cell[37042, 1105, 278, 7, 64, "Text"],
Cell[37323, 1114, 1396, 34, 203, "Text"],
Cell[38722, 1150, 410, 11, 41, "Input",
 CellTags->"Member"],
Cell[CellGroupData[{
Cell[39157, 1165, 153, 3, 41, "Input",
 CellTags->"Member"],
Cell[39313, 1170, 392, 10, 39, "Output",
 CellTags->"Member"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39754, 1186, 206, 5, 47, "Subsubsection",
 CellTags->"Member"],
Cell[39963, 1193, 784, 23, 62, "Input",
 CellTags->"Constructor"],
Cell[40750, 1218, 423, 10, 41, "Input",
 CellTags->"Constructor"],
Cell[CellGroupData[{
Cell[41198, 1232, 171, 3, 27, "Input"],
Cell[41372, 1237, 191, 5, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41600, 1247, 171, 3, 27, "Input"],
Cell[41774, 1252, 485, 14, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42296, 1271, 170, 3, 27, "Input"],
Cell[42469, 1276, 252, 6, 25, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
