(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     33815,       1201]
NotebookOptionsPosition[     22469,        777]
NotebookOutlinePosition[     27876,        962]
CellTagsIndexPosition[     27721,        954]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["VanillaSwap", "Chapter",
 CellTags->"Overview",
 CellID->533195328],

Cell["functions to construct and use VanillaSwap objects.", "Text",
 CellTags->"Overview",
 CellID->166770329],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->36475174],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->322555979],

Cell["\<\
Within the VanillaSwap part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->77446490],

Cell[CellGroupData[{

Cell["Select[Category[VanillaSwap],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->88004101],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "MakeIMMSwap", ",", "MakeVanillaSwap", ",", "VanillaSwap", ",", 
   "VanillaSwapFromSwapIndex", ",", "VanillaSwapFromSwapRateHelper"}], 
  "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->232788788]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[VanillaSwap],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->65206508],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "VanillaSwapFairRate", ",", "VanillaSwapFairSpread", ",", 
   "VanillaSwapFixedDayCount", ",", "VanillaSwapFixedLegAnalysis", ",", 
   "VanillaSwapFixedLegBPS", ",", "VanillaSwapFixedLegNPV", ",", 
   "VanillaSwapFixedRate", ",", "VanillaSwapFloatingDayCount", ",", 
   "VanillaSwapFloatingLegAnalysis", ",", "VanillaSwapFloatingLegBPS", ",", 
   "VanillaSwapFloatingLegNPV", ",", "VanillaSwapNominal", ",", 
   "VanillaSwapPaymentConvention", ",", "VanillaSwapSpread", ",", 
   "VanillaSwapType"}], "}"}]], "Output",
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->439658406]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->155902392],

Cell[CellGroupData[{

Cell["VanillaSwap", "Subsubsection",
 CellTags->"Constructor",
 CellID->4299686],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"PayerReceiver", 
     RowBox[{
      RowBox[{
      "PAYER", " ", "to", " ", "pay", " ", "the", " ", "fixed", " ", "rate"}],
       ",", " ", 
      RowBox[{"RECEIVER", " ", "to", " ", "receive", " ", 
       RowBox[{"it", "."}]}]}]},
    {"Nominal", 
     RowBox[{"Notional", " ", 
      RowBox[{"Amount", "."}]}]},
    {"FixedLegSchedule", 
     RowBox[{"fixed", " ", "leg", " ", "schedule", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"FixedRate", 
     RowBox[{"the", " ", "fixed", " ", 
      RowBox[{"rate", "."}]}]},
    {"FixedLegDayCounter", 
     RowBox[{"fixed", " ", "leg", " ", "day", " ", "counter", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Actual"}], "/", "360"}], ")"}], 
       "."}]}]},
    {"FloatingLegSchedule", 
     RowBox[{"floating", " ", "leg", " ", "schedule", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"IborIndex", 
     RowBox[{"floating", " ", "leg", " ", "IborIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"FloatingLegSpread", 
     RowBox[{"Index", " ", 
      RowBox[{"Spread", "."}]}]},
    {"FloatingLegDayCounter", 
     RowBox[{"floating", " ", "day", " ", "counter", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "Actual"}], "/", "360"}], ")"}], 
       "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 Editable->False,
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->523881657],

Cell[BoxData[{
 RowBox[{Cell[BoxData[GridBox[{
     {"FixDayCounter", "\"\<Actual/365 (Fixed)\>\"", 
      RowBox[{
      "Day", " ", "Counter", " ", "for", " ", "the", " ", "fixed", " ", 
       "leg"}]},
     {"FloatingLegDayCounter", "\"\<Actual/365 (Fixed)\>\"", 
      RowBox[{
      "Day", " ", "Counter", " ", "for", " ", "the", " ", "floating", " ", 
       "leg"}]},
     {"PaymentConvention", "\"\<Following\>\"", 
      RowBox[{"Payment", " ", 
       RowBox[{"dates", "'"}], " ", "business", " ", "day", " ", 
       RowBox[{"convention", "."}]}]},
     {"Spread", "0.", 
      RowBox[{"Spread", " ", "on", " ", "the", " ", "floating", " ", "rate"}]}
    }]], "DefinitionBox3Col",
   CellTags->"Constructor"], 
  "\n"}], "\[IndentingNewLine]", Cell["Option Setting", "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->89191279],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\n", 
 RowBox[{
  RowBox[{"Nominal", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"terminationDate", " ", "=", " ", 
   RowBox[{"CalendarAdvance", "[", "\"\<10Y\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FixedLegSchedule", "=", 
   RowBox[{"Schedule", "[", 
    RowBox[{"terminationDate", ",", "\"\<1Y\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FixedRate", "=", "0.05"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FloatingLegSchedule", "=", 
   RowBox[{"Schedule", "[", 
    RowBox[{"terminationDate", ",", "\"\<6M\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yc", " ", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<NullCalendar\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IborIndex", "=", 
   RowBox[{"Euribor", "[", 
    RowBox[{"\"\<6M\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", "yc"}]}], "]"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[1]:=",
 CellID->217897320],

Cell[CellGroupData[{

Cell["\<\
obj=VanillaSwap[Nominal,FixedLegSchedule,FixedRate,FloatingLegSchedule,\
IborIndex,\"Payer\"]\
\>", "Input",
 CellTags->"Constructor",
 CellLabel->"In[9]:=",
 CellID->112305527],

Cell[BoxData["VanillaSwap15"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[9]=",
 CellID->278746554]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaSwapFromSwapIndex", "Subsubsection",
 CellTags->"Constructor",
 CellID->631357076],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapIndex", 
     RowBox[{"the", " ", "SwapIndex", " ", "index", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"FixingDate", 
     RowBox[{"fixing", " ", 
      RowBox[{"date", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->68721348],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yc", " ", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<NullCalendar\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IborIndex", "=", 
   RowBox[{"Euribor", "[", 
    RowBox[{"\"\<6M\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", "yc"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"swapIndex", "=", 
   RowBox[{"SwapIndex", "[", 
    RowBox[{
    "\"\<Libor\>\"", ",", "\"\<1Y\>\"", ",", "2", ",", "\"\<10Y\>\"", ",", 
     "\"\<Following\>\"", ",", "\"\<30/360 (Bond Basis)\>\"", ",", 
     "IborIndex"}], "]"}]}], " ", ";"}], "\n", 
 RowBox[{
  RowBox[{"FixingDate", "=", 
   RowBox[{"EvaluationDate", "[", "]"}]}], ";"}], "\n", 
 RowBox[{"obj", "=", 
  RowBox[{"VanillaSwapFromSwapIndex", "[", 
   RowBox[{"swapIndex", ",", "FixingDate"}], "]"}]}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[1]:=",
 CellID->48266977],

Cell[BoxData["VanillaSwapFromSwapIndex11"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[6]=",
 CellID->288132231]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaSwapFromSwapRateHelper", "Subsubsection",
 CellTags->"Constructor",
 CellID->548448874],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapRateHelper", 
     RowBox[{"the", " ", "SwapRateHelper", " ", "index", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->129465734],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yc", " ", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<NullCalendar\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IborIndex", "=", 
   RowBox[{"Euribor", "[", 
    RowBox[{"\"\<6M\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", "yc"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"swapRateHelper", " ", "=", 
   RowBox[{"SwapRateHelper2", "[", 
    RowBox[{
    "0.04", ",", "\"\<3Y\>\"", ",", "\"\<Annual\>\"", ",", "IborIndex"}], 
    "]"}]}], " "}], "\n", 
 RowBox[{"obj", "=", 
  RowBox[{
  "VanillaSwapFromSwapRateHelper", "[", "swapRateHelper", "]"}]}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->227767331],

Cell[BoxData["SwapRateHelper214"], "Output",
 CellLabel->"Out[4]=",
 CellID->80350485],

Cell[BoxData["VanillaSwapFromSwapRateHelper15"], "Output",
 CellLabel->"Out[5]=",
 CellID->17137492]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeVanillaSwap", "Subsubsection",
 CellTags->"Constructor",
 CellID->178099924],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapTenor", 
     RowBox[{"swap", " ", "tenor", " ", "period", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "5"}], "Y"}], ")"}], "."}]}]},
    {"IborIndex", 
     RowBox[{"floating", " ", "IborIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"ForwardStart", 
     RowBox[{"forward", " ", "start", " ", 
      RowBox[{"period", "."}]}]},
    {
     RowBox[{"Pricing", " ", "Engine"}], 
     RowBox[{"Pricing", " ", "Engine", " ", "for", " ", 
      RowBox[{"discounting", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->540606947],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FixedRate", "0.0", 
     RowBox[{"the", " ", "fixed", " ", 
      RowBox[{"rate", "."}]}]},
    {"FixedLegDayCounter", "\"\<30/360 (Bond Basis)\>\"", 
     RowBox[{"fixed", " ", "leg", " ", "day", " ", 
      RowBox[{"counter", "."}]}]},
    {"FloatingLegSpread", "0.0", 
     RowBox[{
     "the", " ", "spread", " ", "in", " ", "the", " ", "floating", " ", "leg",
       " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->78302816],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SwapTenor", "=", "\"\<5Y\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yc", " ", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<NullCalendar\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IborIndex", "=", 
   RowBox[{"Euribor", "[", 
    RowBox[{"\"\<6M\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", "yc"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ForwardStart", "=", "\"\<0D\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"disc", " ", "=", " ", 
   RowBox[{"DiscountingSwapEngine", "[", "yc", "]"}]}], ";"}], "\n", 
 RowBox[{"obj", "=", 
  RowBox[{"MakeVanillaSwap", "[", 
   RowBox[{"SwapTenor", ",", "IborIndex", ",", "ForwardStart", ",", "disc"}], 
   "]"}]}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[1]:=",
 CellID->474029467],

Cell[BoxData["MakeVanillaSwap19"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[7]=",
 CellID->826390665]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeIMMSwap", "Subsubsection",
 CellTags->"Constructor",
 CellID->343321246],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SwapTenor", 
     RowBox[{"swap", " ", "tenor", " ", "period", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"e", ".", "g", ".", " ", "2"}], "Y"}], ")"}], "."}]}]},
    {"IborIndex", 
     RowBox[{"floating", " ", "IborIndex", " ", "object", " ", 
      RowBox[{"ID", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->464007335],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"FixedRate", "0.0", 
     RowBox[{"the", " ", "fixed", " ", 
      RowBox[{"rate", "."}]}]},
    {"FirstImmDate", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Date", "[", "]"}], ",", "3"}], "]"}], 
     RowBox[{"First", " ", 
      RowBox[{"(", "IMM", ")"}], " ", 
      RowBox[{"date", "."}]}]},
    {"FixedLegDayCounter", "\"\<30/360 (Bond Basis)\>\"", 
     RowBox[{"fixed", " ", "leg", " ", "day", " ", 
      RowBox[{"counter", "."}]}]},
    {"FloatingLegSpread", "0.0", 
     RowBox[{
     "the", " ", "spread", " ", "in", " ", "the", " ", "floating", " ", "leg",
       " ", 
      RowBox[{"rate", "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 Evaluatable->False,
 EmphasizeSyntaxErrors->True,
 CellID->1043816132],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SwapTenor", "=", "\"\<2Y\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yc", " ", "=", 
   RowBox[{"FlatForward", "[", 
    RowBox[{"0.044", ",", 
     RowBox[{"Calendar", "\[Rule]", "\"\<NullCalendar\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IborIndex", "=", 
   RowBox[{"Euribor", "[", 
    RowBox[{"\"\<6M\>\"", ",", 
     RowBox[{"YieldCurve", "\[Rule]", "yc"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"disc", " ", "=", " ", 
   RowBox[{"DiscountingSwapEngine", "[", "yc", "]"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[1]:=",
 CellID->144964124],

Cell[CellGroupData[{

Cell["obj=MakeIMMSwap[SwapTenor,IborIndex,disc]", "Input",
 CellTags->"Constructor",
 CellLabel->"In[6]:=",
 CellID->71003718],

Cell[BoxData["MakeIMMSwap23"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[6]=",
 CellID->27527106]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->137354499],

Cell[CellGroupData[{

Cell["VanillaSwapFixedLegBPS", "Subsubsection",
 CellTags->"Member",
 CellID->41256566],

Cell["\<\
Needs[\"QuantLib`\"]
yc =FlatForward[0.044,Calendar\[Rule]\"NullCalendar\"];
IborIndex=Euribor[\"6M\",YieldCurve\[Rule]yc];
swapIndex=SwapIndex[\"Libor\",\"1Y\",2,\"10Y\",\"Following\",\"30/360 (Bond \
Basis)\",IborIndex,DiscountCurve\[Rule]yc] ;
obj=VanillaSwapFromSwapIndex[swapIndex,EvaluationDate[]];\
\>", "Input",
 CellTags->"Member",
 CellLabel->"In[1]:=",
 CellID->65200661],

Cell[CellGroupData[{

Cell["\<\
VanillaSwapFairRate[obj]
VanillaSwapFairSpread[obj]\
\>", "Input",
 CellTags->"Member",
 CellLabel->"In[6]:=",
 CellID->298821372],

Cell[BoxData["0.04510833295714753`"], "Output",
 CellTags->"Member",
 CellLabel->"Out[6]=",
 CellID->13312866],

Cell[BoxData[
 RowBox[{"-", "0.04387952114706614`"}]], "Output",
 CellTags->"Member",
 CellLabel->"Out[7]=",
 CellID->4160002]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
VanillaSwapFixedLegBPS[obj]
VanillaSwapFixedLegNPV[obj]\
\>", "Input",
 CellTags->"Member",
 CellLabel->"In[8]:=",
 CellID->2870431],

Cell[BoxData[
 RowBox[{"-", "0.00009563773371003584`"}]], "Output",
 CellTags->"Member",
 CellLabel->"Out[8]=",
 CellID->6120577],

Cell[BoxData["0.`"], "Output",
 CellTags->"Member",
 CellLabel->"Out[9]=",
 CellID->573020490]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"VanillaSwapFloatingLegBPS", "[", "obj", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"VanillaSwapFloatingLegNPV", "[", "obj", "]"}]}], "Input",
 CellLabel->"In[10]:=",
 CellID->127170447],

Cell[BoxData["0.00009831599394625012`"], "Output",
 CellLabel->"Out[10]=",
 CellID->60325627],

Cell[BoxData["0.043140587354593085`"], "Output",
 CellLabel->"Out[11]=",
 CellID->196188654]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VanillaSwapType", "[", "obj", "]"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->536399967],

Cell[BoxData["\<\"Payer\"\>"], "Output",
 CellLabel->"Out[12]=",
 CellID->356282815]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VanillaSwapNominal", "[", "obj", "]"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->320227984],

Cell[BoxData["1.`"], "Output",
 CellLabel->"Out[13]=",
 CellID->134840666]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VanillaSwapFixedRate", "[", "obj", "]"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->8293382],

Cell[BoxData["0.`"], "Output",
 CellLabel->"Out[14]=",
 CellID->507772272]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaSwapFixedDayCount[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[15]:=",
 CellID->34527733],

Cell[BoxData["\<\"30/360 (Bond Basis)\"\>"], "Output",
 CellTags->"Member",
 CellLabel->"Out[15]=",
 CellID->172204564]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaSwapSpread[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[16]:=",
 CellID->254920901],

Cell[BoxData["0.`"], "Output",
 CellTags->"Member",
 CellLabel->"Out[16]=",
 CellID->2687991]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaSwapFloatingDayCount[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[17]:=",
 CellID->256727006],

Cell[BoxData["\<\"Actual/360\"\>"], "Output",
 CellTags->"Member",
 CellLabel->"Out[17]=",
 CellID->53299982]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanillaSwapPaymentConvention[obj]", "Input",
 CellTags->"Member",
 CellLabel->"In[18]:=",
 CellID->72823153],

Cell[BoxData["\<\"Modified Following\"\>"], "Output",
 CellTags->"Member",
 CellLabel->"Out[18]=",
 CellID->312058372]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
VanillaSwapFixedLegAnalysis[obj]/.( x_/; IntegerQ[x] && 30000 < x < 60000)  \
\[RuleDelayed]  DateString[ ToCalendar[x],\"DateShort\"]  // TableForm\
\>", "Input",
 CellTags->"Member",
 CellLabel->"In[19]:=",
 CellID->53462541],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Payment Date\"\>", "\<\"Amount\"\>", "\<\"Nominal\"\>", \
"\<\"Accrual Start Date\"\>", "\<\"Accrual End Date\"\>", "\<\"Accrual Days\"\
\>", "\<\"Index\"\>", "\<\"Fixing Days\"\>", "\<\"Fixing Dates\"\>", "\<\"Day \
Counter\"\>", "\<\"Accrual Period\"\>", "\<\"Effective Rate\"\>", \
"\<\"Floor\"\>", "\<\"Gearing\"\>", "\<\"Index Fixing\"\>", "\<\"Conv. Adj.\"\
\>", "\<\"Spread\"\>", "\<\"Cap\"\>", "\<\"Call Digital Payoff\"\>", "\<\"Put \
Digital Payoff\"\>"},
    {"\<\"Thu 23 Aug 2012\"\>", "0.`", 
     "1.`", "\<\"Tue 23 Aug 2011\"\>", "\<\"Thu 23 Aug 2012\"\>", 
     "360", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"30/360 (Bond \
Basis)\"\>", "1.`", 
     "0.`", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\
\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellTags->"Member",
 CellLabel->"Out[19]//TableForm=",
 CellID->417191551]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
VanillaSwapFloatingLegAnalysis[obj]/.( x_/; IntegerQ[x] && 30000 < x < 60000) \
 \[RuleDelayed]  DateString[ ToCalendar[x],\"DateShort\"]  // TableForm\
\>", "Input",
 CellTags->"Member",
 CellLabel->"In[20]:=",
 CellID->376179797],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Payment Date\"\>", "\<\"Amount\"\>", "\<\"Nominal\"\>", \
"\<\"Accrual Start Date\"\>", "\<\"Accrual End Date\"\>", "\<\"Accrual Days\"\
\>", "\<\"Index\"\>", "\<\"Fixing Days\"\>", "\<\"Fixing Dates\"\>", "\<\"Day \
Counter\"\>", "\<\"Accrual Period\"\>", "\<\"Effective Rate\"\>", \
"\<\"Floor\"\>", "\<\"Gearing\"\>", "\<\"Index Fixing\"\>", "\<\"Conv. Adj.\"\
\>", "\<\"Spread\"\>", "\<\"Cap\"\>", "\<\"Call Digital Payoff\"\>", "\<\"Put \
Digital Payoff\"\>"},
    {"\<\"Thu 23 Feb 2012\"\>", "0.022428645264951808`", 
     "1.`", "\<\"Tue 23 Aug 2011\"\>", "\<\"Thu 23 Feb 2012\"\>", 
     "184", "\<\"Euribor6M Actual/360\"\>", 
     "2", "\<\"Fri 19 Aug 2011\"\>", "\<\"Actual/360\"\>", 
     "0.5111111111111111`", "0.043882132040123104`", "\<\"#N/A\"\>", "1.`", 
     "0.043882132040123104`", "0.`", 
     "0.`", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>"},
    {"\<\"Thu 23 Aug 2012\"\>", "0.022182171633423398`", 
     "1.`", "\<\"Thu 23 Feb 2012\"\>", "\<\"Thu 23 Aug 2012\"\>", 
     "182", "\<\"Euribor6M Actual/360\"\>", 
     "2", "\<\"Tue 21 Feb 2012\"\>", "\<\"Actual/360\"\>", 
     "0.5055555555555555`", "0.04387682301116716`", "\<\"#N/A\"\>", "1.`", 
     "0.04387682301116716`", "0.`", 
     "0.`", "\<\"#N/A\"\>", "\<\"#N/A\"\>", "\<\"#N/A\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellTags->"Member",
 CellLabel->"Out[20]//TableForm=",
 CellID->2459927]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{902, 898},
WindowMargins->{{Automatic, -268}, {19, Automatic}},
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 73, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->533195328],
  Cell[643, 26, 110, 2, 30, "Text",
   CellTags->"Overview",
   CellID->166770329],
  Cell[756, 30, 113, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->36475174],
  Cell[872, 34, 103, 3, 28, "Input",
   CellTags->"Overview",
   CellID->322555979],
  Cell[978, 39, 158, 5, 30, "Text",
   CellTags->"Overview",
   CellID->77446490],
  Cell[1161, 48, 129, 3, 28, "Input",
   CellTags->"Overview",
   CellID->88004101],
  Cell[1293, 53, 264, 8, 36, "Output",
   CellTags->"Overview",
   CellID->232788788],
  Cell[1594, 66, 124, 3, 28, "Input",
   CellTags->"Overview",
   CellID->65206508],
  Cell[1721, 71, 625, 13, 88, "Output",
   CellTags->"Overview",
   CellID->439658406]},
 "Constructo"->{
  Cell[2383, 89, 76, 2, 51, "Section",
   CellTags->"Constructo",
   CellID->155902392]},
 "Constructor"->{
  Cell[2484, 95, 80, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->4299686],
  Cell[5048, 170, 1090, 31, 155, "Input",
   CellTags->"Constructor",
   CellID->217897320],
  Cell[6163, 205, 187, 6, 28, "Input",
   CellTags->"Constructor",
   CellID->112305527],
  Cell[6353, 213, 109, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->278746554],
  Cell[6511, 222, 95, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->631357076],
  Cell[7054, 242, 1052, 29, 119, "Input",
   CellTags->"Constructor",
   CellID->48266977],
  Cell[8109, 273, 122, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->288132231],
  Cell[8280, 282, 100, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->548448874],
  Cell[9835, 337, 86, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->178099924],
  Cell[11358, 385, 960, 26, 137, "Input",
   CellTags->"Constructor",
   CellID->474029467],
  Cell[12321, 413, 113, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->826390665],
  Cell[12483, 422, 82, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->343321246],
  Cell[13956, 468, 737, 21, 101, "Input",
   CellTags->"Constructor",
   CellID->144964124],
  Cell[14718, 493, 126, 3, 28, "Input",
   CellTags->"Constructor",
   CellID->71003718],
  Cell[14847, 498, 108, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->27527106]},
 "Member"->{
  Cell[15016, 508, 75, 2, 51, "Section",
   CellTags->"Member",
   CellID->137354499],
  Cell[15116, 514, 87, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->41256566],
  Cell[15206, 518, 392, 10, 96, "Input",
   CellTags->"Member",
   CellID->65200661],
  Cell[15623, 532, 140, 6, 45, "Input",
   CellTags->"Member",
   CellID->298821372],
  Cell[15766, 540, 110, 3, 36, "Output",
   CellTags->"Member",
   CellID->13312866],
  Cell[15879, 545, 126, 4, 36, "Output",
   CellTags->"Member",
   CellID->4160002],
  Cell[16042, 554, 142, 6, 45, "Input",
   CellTags->"Member",
   CellID->2870431],
  Cell[16187, 562, 129, 4, 36, "Output",
   CellTags->"Member",
   CellID->6120577],
  Cell[16319, 568, 94, 3, 36, "Output",
   CellTags->"Member",
   CellID->573020490],
  Cell[17588, 630, 110, 3, 28, "Input",
   CellTags->"Member",
   CellID->34527733],
  Cell[17701, 635, 119, 3, 36, "Output",
   CellTags->"Member",
   CellID->172204564],
  Cell[17857, 643, 104, 3, 28, "Input",
   CellTags->"Member",
   CellID->254920901],
  Cell[17964, 648, 93, 3, 36, "Output",
   CellTags->"Member",
   CellID->2687991],
  Cell[18094, 656, 114, 3, 28, "Input",
   CellTags->"Member",
   CellID->256727006],
  Cell[18211, 661, 109, 3, 36, "Output",
   CellTags->"Member",
   CellID->53299982],
  Cell[18357, 669, 114, 3, 28, "Input",
   CellTags->"Member",
   CellID->72823153],
  Cell[18474, 674, 118, 3, 36, "Output",
   CellTags->"Member",
   CellID->312058372],
  Cell[18629, 682, 237, 6, 28, "Input",
   CellTags->"Member",
   CellID->53462541],
  Cell[18869, 690, 1405, 30, 62, "Output",
   CellTags->"Member",
   CellID->417191551],
  Cell[20311, 725, 241, 6, 28, "Input",
   CellTags->"Member",
   CellID->376179797],
  Cell[20555, 733, 1862, 38, 77, "Output",
   CellTags->"Member",
   CellID->2459927]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 23574, 809},
 {"Constructo", 24365, 837},
 {"Constructor", 24473, 841},
 {"Member", 25887, 887}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 73, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->533195328],
Cell[643, 26, 110, 2, 30, "Text",
 CellTags->"Overview",
 CellID->166770329],
Cell[756, 30, 113, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->36475174],
Cell[872, 34, 103, 3, 28, "Input",
 CellTags->"Overview",
 CellID->322555979],
Cell[978, 39, 158, 5, 30, "Text",
 CellTags->"Overview",
 CellID->77446490],
Cell[CellGroupData[{
Cell[1161, 48, 129, 3, 28, "Input",
 CellTags->"Overview",
 CellID->88004101],
Cell[1293, 53, 264, 8, 36, "Output",
 CellTags->"Overview",
 CellID->232788788]
}, Open  ]],
Cell[CellGroupData[{
Cell[1594, 66, 124, 3, 28, "Input",
 CellTags->"Overview",
 CellID->65206508],
Cell[1721, 71, 625, 13, 88, "Output",
 CellTags->"Overview",
 CellID->439658406]
}, Open  ]],
Cell[CellGroupData[{
Cell[2383, 89, 76, 2, 51, "Section",
 CellTags->"Constructo",
 CellID->155902392],
Cell[CellGroupData[{
Cell[2484, 95, 80, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->4299686],
Cell[2567, 99, 1604, 46, 194, "Input",
 Evaluatable->False,
 CellID->523881657],
Cell[4174, 147, 871, 21, 129, "Input",
 Evaluatable->False,
 CellID->89191279],
Cell[5048, 170, 1090, 31, 155, "Input",
 CellTags->"Constructor",
 CellID->217897320],
Cell[CellGroupData[{
Cell[6163, 205, 187, 6, 28, "Input",
 CellTags->"Constructor",
 CellID->112305527],
Cell[6353, 213, 109, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->278746554]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6511, 222, 95, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->631357076],
Cell[6609, 226, 420, 12, 78, "Input",
 Evaluatable->False,
 CellID->68721348],
Cell[CellGroupData[{
Cell[7054, 242, 1052, 29, 119, "Input",
 CellTags->"Constructor",
 CellID->48266977],
Cell[8109, 273, 122, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->288132231]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8280, 282, 100, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->548448874],
Cell[8383, 286, 350, 9, 65, "Input",
 Evaluatable->False,
 CellID->129465734],
Cell[CellGroupData[{
Cell[8758, 299, 836, 24, 101, "Input",
 CellID->227767331],
Cell[9597, 325, 86, 2, 36, "Output",
 CellID->80350485],
Cell[9686, 329, 100, 2, 36, "Output",
 CellID->17137492]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9835, 337, 86, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->178099924],
Cell[9924, 341, 776, 22, 111, "Input",
 Evaluatable->False,
 CellID->540606947],
Cell[10703, 365, 630, 16, 95, "Input",
 Evaluatable->False,
 CellID->78302816],
Cell[CellGroupData[{
Cell[11358, 385, 960, 26, 137, "Input",
 CellTags->"Constructor",
 CellID->474029467],
Cell[12321, 413, 113, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->826390665]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12483, 422, 82, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->343321246],
Cell[12568, 426, 532, 15, 78, "Input",
 Evaluatable->False,
 CellID->464007335],
Cell[13103, 443, 850, 23, 111, "Input",
 Evaluatable->False,
 CellID->1043816132],
Cell[13956, 468, 737, 21, 101, "Input",
 CellTags->"Constructor",
 CellID->144964124],
Cell[CellGroupData[{
Cell[14718, 493, 126, 3, 28, "Input",
 CellTags->"Constructor",
 CellID->71003718],
Cell[14847, 498, 108, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->27527106]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15016, 508, 75, 2, 51, "Section",
 CellTags->"Member",
 CellID->137354499],
Cell[CellGroupData[{
Cell[15116, 514, 87, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->41256566],
Cell[15206, 518, 392, 10, 96, "Input",
 CellTags->"Member",
 CellID->65200661],
Cell[CellGroupData[{
Cell[15623, 532, 140, 6, 45, "Input",
 CellTags->"Member",
 CellID->298821372],
Cell[15766, 540, 110, 3, 36, "Output",
 CellTags->"Member",
 CellID->13312866],
Cell[15879, 545, 126, 4, 36, "Output",
 CellTags->"Member",
 CellID->4160002]
}, Open  ]],
Cell[CellGroupData[{
Cell[16042, 554, 142, 6, 45, "Input",
 CellTags->"Member",
 CellID->2870431],
Cell[16187, 562, 129, 4, 36, "Output",
 CellTags->"Member",
 CellID->6120577],
Cell[16319, 568, 94, 3, 36, "Output",
 CellTags->"Member",
 CellID->573020490]
}, Open  ]],
Cell[CellGroupData[{
Cell[16450, 576, 210, 5, 47, "Input",
 CellID->127170447],
Cell[16663, 583, 93, 2, 36, "Output",
 CellID->60325627],
Cell[16759, 587, 92, 2, 36, "Output",
 CellID->196188654]
}, Open  ]],
Cell[CellGroupData[{
Cell[16888, 594, 114, 3, 28, "Input",
 CellID->536399967],
Cell[17005, 599, 84, 2, 36, "Output",
 CellID->356282815]
}, Open  ]],
Cell[CellGroupData[{
Cell[17126, 606, 117, 3, 28, "Input",
 CellID->320227984],
Cell[17246, 611, 74, 2, 36, "Output",
 CellID->134840666]
}, Open  ]],
Cell[CellGroupData[{
Cell[17357, 618, 117, 3, 28, "Input",
 CellID->8293382],
Cell[17477, 623, 74, 2, 36, "Output",
 CellID->507772272]
}, Open  ]],
Cell[CellGroupData[{
Cell[17588, 630, 110, 3, 28, "Input",
 CellTags->"Member",
 CellID->34527733],
Cell[17701, 635, 119, 3, 36, "Output",
 CellTags->"Member",
 CellID->172204564]
}, Open  ]],
Cell[CellGroupData[{
Cell[17857, 643, 104, 3, 28, "Input",
 CellTags->"Member",
 CellID->254920901],
Cell[17964, 648, 93, 3, 36, "Output",
 CellTags->"Member",
 CellID->2687991]
}, Open  ]],
Cell[CellGroupData[{
Cell[18094, 656, 114, 3, 28, "Input",
 CellTags->"Member",
 CellID->256727006],
Cell[18211, 661, 109, 3, 36, "Output",
 CellTags->"Member",
 CellID->53299982]
}, Open  ]],
Cell[CellGroupData[{
Cell[18357, 669, 114, 3, 28, "Input",
 CellTags->"Member",
 CellID->72823153],
Cell[18474, 674, 118, 3, 36, "Output",
 CellTags->"Member",
 CellID->312058372]
}, Open  ]],
Cell[CellGroupData[{
Cell[18629, 682, 237, 6, 28, "Input",
 CellTags->"Member",
 CellID->53462541],
Cell[18869, 690, 1405, 30, 62, "Output",
 CellTags->"Member",
 CellID->417191551]
}, Open  ]],
Cell[CellGroupData[{
Cell[20311, 725, 241, 6, 28, "Input",
 CellTags->"Member",
 CellID->376179797],
Cell[20555, 733, 1862, 38, 77, "Output",
 CellTags->"Member",
 CellID->2459927]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
