(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     46399,       1730]
NotebookOptionsPosition[     26302,        991]
NotebookOutlinePosition[     35987,       1321]
CellTagsIndexPosition[     35799,       1312]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Volatilities", "Chapter",
 CellTags->"Overview",
 CellID->391865964],

Cell["functions to construct and use volatility objects.", "Text",
 CellTags->"Overview",
 CellID->157905548],

Cell["The first step is to load the QuantLib package. ", "MathCaption",
 CellTags->"Overview",
 CellID->31436434],

Cell["Needs[\"QuantLib`\"]", "Input",
 CellTags->"Overview",
 CellLabel->"In[1]:=",
 CellID->255322246],

Cell["\<\
Within the Volatilities part there are several constructors and member \
functions available \
\>", "Text",
 CellTags->"Overview",
 CellID->155489],

Cell[CellGroupData[{

Cell["Select[Category[Volatilities],QLConstructor[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[2]:=",
 CellID->212444776],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AbcdAtmVolCurve", ",", "BlackConstantVol", ",", "BlackVarianceSurface", 
   ",", "SabrVolSurface"}], "}"}]], "Output",
 CellChangeTimes->{3.436091605265625*^9, 3.436091796859375*^9, 
  3.43609207534375*^9},
 CellTags->"Overview",
 CellLabel->"Out[2]=",
 CellID->33328166]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Volatilities],QLMember[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[3]:=",
 CellID->164542977],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AtmCurve", ",", "BlackAtmVolCurveAtmVariance", ",", 
   "BlackAtmVolCurveAtmVariance2", ",", "BlackAtmVolCurveAtmVariance3", ",", 
   "BlackAtmVolCurveAtmVol", ",", "BlackAtmVolCurveAtmVol2", ",", 
   "BlackAtmVolCurveAtmVol3", ",", "VolatilitySpreads", ",", 
   "VolatilitySpreads2", ",", "VolatilityTermStructureBusinessDayConvention", 
   ",", "VolatilityTermStructureMaxStrike", ",", 
   "VolatilityTermStructureMinStrike", ",", 
   "VolatilityTermStructureOptionDateFromTenor"}], "}"}]], "Output",
 CellChangeTimes->{3.436091606328125*^9, 3.436091797953125*^9, 
  3.436092076296875*^9},
 CellTags->"Overview",
 CellLabel->"Out[3]=",
 CellID->62766747]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select[Category[Volatilities],QLProcedure[#]&]", "Input",
 CellTags->"Overview",
 CellLabel->"In[4]:=",
 CellID->1034464],

Cell[BoxData[
 RowBox[{"{", "SabrVolatility", "}"}]], "Output",
 CellChangeTimes->{3.43609160721875*^9, 3.43609179909375*^9, 
  3.436092077203125*^9},
 CellTags->"Overview",
 CellLabel->"Out[4]=",
 CellID->372551976]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructors", "Section",
 CellTags->"Constructo",
 CellID->6535473],

Cell[CellGroupData[{

Cell["BlackConstantVol", "Subsubsection",
 CellTags->"Constructor",
 CellID->519488021],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]},
    {"Volatility", 
     RowBox[{"volatility", "."}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.436092012921875*^9, 3.436092012921875*^9}},
 CellID->411876125],

Cell[BoxData[{Cell[BoxData[
  RowBox[{GridBox[{
     {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
      RowBox[{"DayCounter", " ", 
       RowBox[{"ID", "."}]}]}
    }], GridBox[{
     {"Calendar", "\"\<TARGET\>\"", 
      RowBox[{"holiday", " ", "calendar", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], "."}]}]}
    }]}]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.43609193628125*^9, 3.4360919373125*^9}, {
  3.43609198496875*^9, 3.43609205134375*^9}},
 CellID->218989525],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SettlementDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "11", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Calendar", "=", "\"\<TARGET\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Volatility", "=", "0.2"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[22]:=",
 CellID->60511335],

Cell[CellGroupData[{

Cell["obj=BlackConstantVol[SettlementDate,Volatility]", "Input",
 CellChangeTimes->{3.436091907921875*^9},
 CellTags->"Constructor",
 CellLabel->"In[5]:=",
 CellID->562172742],

Cell[BoxData["BlackConstantVol28"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[5]=",
 CellID->192709307]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackVarianceSurface", "Subsubsection",
 CellTags->"Constructor",
 CellID->3069914],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDate", 
     RowBox[{"settlement", " ", 
      RowBox[{"date", "."}]}]},
    {"Dates", 
     RowBox[{"dates", "."}]},
    {"Strikes", 
     RowBox[{"strikes", "."}]},
    {"Volatilities", 
     RowBox[{"volatilities", "."}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.43609211925*^9, 3.43609211925*^9}},
 CellID->197864184],

Cell[BoxData[{Cell[BoxData[
  RowBox[{GridBox[{
     {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
      RowBox[{"DayCounter", " ", 
       RowBox[{"ID", "."}]}]}
    }], GridBox[{
     {"Calendar", "\"\<TARGET\>\"", 
      RowBox[{"holiday", " ", "calendar", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], "."}]}]}
    }]}]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.436092113796875*^9, 3.436092113796875*^9}},
 CellID->241186037],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<QuantLib`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"settlementDate", "=", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "9", ",", "11"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dates", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "11"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "11"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"strikes", "=", 
   RowBox[{"{", 
    RowBox[{"0.03", ",", " ", "0.05", ",", " ", "0.10"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"volatilities", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0.2", ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "dates", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "strikes", "]"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[20]:=",
 CellID->401234712],

Cell[CellGroupData[{

Cell["\<\
obj=BlackVarianceSurface[settlementDate,dates,strikes,volatilities]\
\>", "Input",
 CellTags->"Constructor",
 CellLabel->"In[25]:=",
 CellID->178025370],

Cell[BoxData["BlackVarianceSurface31"], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[25]=",
 CellID->70375520]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurve", "Subsubsection",
 CellTags->"Constructor",
 CellID->9912498],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"SettlementDays", 
     RowBox[{"settlement", " ", 
      RowBox[{"days", "."}]}]},
    {"OptionTenors", 
     RowBox[{"options", " ", 
      RowBox[{"tenors", "."}]}]},
    {"VolatilitiesQuotes", 
     RowBox[{"volatilities", " ", 
      RowBox[{"quotes", "."}]}]},
    {"InclusionInInterpolation", 
     RowBox[{
      RowBox[{"inclusion", " ", 
       RowBox[{"flags", ".", " ", "If"}], " ", "omitted"}], ",", " ", 
      RowBox[{"all", " ", "volatilities", " ", "are", " ", 
       RowBox[{"interpolated", "."}]}]}]},
    {"Convention", 
     RowBox[{"business", " ", "day", " ", "convention", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "Following"}], ")"}], "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellChangeTimes->{{3.43609219490625*^9, 3.43609219490625*^9}},
 CellID->223025719],

Cell[BoxData[{Cell[BoxData[
  RowBox[{GridBox[{
     {"DayCounter", "\"\<Actual/365 (Fixed)\>\"", 
      RowBox[{"DayCounter", " ", 
       RowBox[{"ID", "."}]}]}
    }], GridBox[{
     {"Calendar", "\"\<TARGET\>\"", 
      RowBox[{"holiday", " ", "calendar", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", ".", "g", ".", " ", "TARGET"}], ")"}], "."}]}]}
    }]}]], "DefinitionBox3Col",
  CellTags->"Constructor"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellChangeTimes->{{3.4360921866875*^9, 3.43609219046875*^9}},
 CellID->391335970],

Cell[BoxData[{
 RowBox[{
  RowBox[{"settlementDays", "=", "2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"optionTenors", "=", 
   RowBox[{"{", "\"\<1Y\>\"", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"volatilitiesQuotes", "=", 
   RowBox[{"{", "0.2", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"inclusionInInterpolation", "=", 
   RowBox[{"{", "True", "}"}]}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellLabel->"In[13]:=",
 CellID->439806113],

Cell[CellGroupData[{

Cell["\<\
obj=AbcdAtmVolCurve[settlementDays,optionTenors,volatilitiesQuotes,\
inclusionInInterpolation,\"Following\"]\
\>", "Input",
 CellTags->"Constructor",
 CellLabel->"In[18]:=",
 CellID->150346971],

Cell[BoxData[
 RowBox[{"AbcdAtmVolCurve", "[", 
  RowBox[{"2", ",", 
   RowBox[{"{", "\<\"1Y\"\>", "}"}], ",", 
   RowBox[{"{", "0.2`", "}"}], ",", 
   RowBox[{"{", "True", "}"}], ",", "\<\"Following\"\>"}], "]"}]], "Output",
 CellTags->"Constructor",
 CellLabel->"Out[18]=",
 CellID->495985108]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SabrVolSurface", "Subsubsection",
 CellTags->"Constructor",
 CellID->73269802],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"InterestRateIndex", 
     RowBox[{"interest", " ", "rate", " ", "index", " ", "object", " ", 
      RowBox[{"ID", "."}]}]},
    {"BlackAtmVolCurve", 
     RowBox[{"the", " ", "atm", " ", "volatility", " ", 
      RowBox[{"curve", "."}]}]},
    {"OptionTenors", 
     RowBox[{"options", " ", 
      RowBox[{"tenors", "."}]}]},
    {"AtmRateSpreads", 
     RowBox[{"spreads", "."}]},
    {"VolatilitiesQuotes", 
     RowBox[{"volatilities", " ", 
      RowBox[{"quotes", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Constructor"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->130505861],

Cell[BoxData[{
 RowBox[{
  RowBox[{"InterestRateIndex", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BlackAtmVolCurve", "=", "exampleValue"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OptionTenors", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AtmRateSpreads", "=", 
   RowBox[{"{", "exampleValue", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"VolatilitiesQuotes", "=", "exampleValue"}], ";"}]}], "Input",
 CellTags->"Constructor",
 CellID->9938806],

Cell["\<\
obj=SabrVolSurface[InterestRateIndex,BlackAtmVolCurve,OptionTenors,\
AtmRateSpreads,VolatilitiesQuotes]\
\>", "Input",
 CellTags->"Constructor",
 CellID->289193226]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Member function", "Section",
 CellTags->"Member",
 CellID->121652447],

Cell[CellGroupData[{

Cell["VolatilityTermStructureBusinessDayConvention", "Subsubsection",
 CellTags->"Member",
 CellID->100429151],

Cell["VolatilityTermStructureBusinessDayConvention[obj]", "Input",
 CellTags->"Member",
 CellID->716322735]
}, Open  ]],

Cell[CellGroupData[{

Cell["VolatilityTermStructureOptionDateFromTenor", "Subsubsection",
 CellTags->"Member",
 CellID->397426775],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Tenor", 
     RowBox[{"option", " ", 
      RowBox[{"tenor", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->254801627],

Cell[BoxData[
 RowBox[{
  RowBox[{"Tenor", "=", "\"\<1Y\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.436092204703125*^9, 3.4360922061875*^9}},
 CellTags->"Member",
 CellID->128773035],

Cell["VolatilityTermStructureOptionDateFromTenor[obj,Tenor]", "Input",
 CellTags->"Member",
 CellID->150921201]
}, Open  ]],

Cell[CellGroupData[{

Cell["VolatilityTermStructureMinStrike", "Subsubsection",
 CellTags->"Member",
 CellID->226264065],

Cell["VolatilityTermStructureMinStrike[obj]", "Input",
 CellTags->"Member",
 CellID->215780542]
}, Open  ]],

Cell[CellGroupData[{

Cell["VolatilityTermStructureMaxStrike", "Subsubsection",
 CellTags->"Member",
 CellID->686188259],

Cell["VolatilityTermStructureMaxStrike[obj]", "Input",
 CellTags->"Member",
 CellID->39160675]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackAtmVolCurveAtmVol", "Subsubsection",
 CellTags->"Member",
 CellID->48145862],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{
     "The", " ", "date", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->567210066],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "False", 
     RowBox[{"Extrapolation", " ", "Flag", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TRUE", " ", "allows", " ", "extrapolation"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellChangeTimes->{{3.436092212421875*^9, 3.4360922141875*^9}},
 CellID->53905025],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionDate", "=", 
   RowBox[{"{", 
    RowBox[{"2010", ",", "3", ",", "11"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.436092221828125*^9, 3.436092225984375*^9}},
 CellTags->"Member",
 CellLabel->"In[9]:=",
 CellID->71082653],

Cell["BlackAtmVolCurveAtmVol[obj,OptionDate]", "Input",
 CellTags->"Member",
 CellLabel->"In[10]:=",
 CellID->523591806]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackAtmVolCurveAtmVol2", "Subsubsection",
 CellTags->"Member",
 CellID->348759139],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionTenor", 
     RowBox[{
     "The", " ", "time", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->454673259],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "false", 
     RowBox[{"Extrapolation", " ", "Flag", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TRUE", " ", "allows", " ", "extrapolation"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->525436350],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionTenor", "=", "\"\<1Y\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.436092245609375*^9, 3.43609224703125*^9}},
 CellTags->"Member",
 CellID->338584321],

Cell["BlackAtmVolCurveAtmVol2[obj,OptionTenor]", "Input",
 CellTags->"Member",
 CellID->233169582]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackAtmVolCurveAtmVol3", "Subsubsection",
 CellTags->"Member",
 CellID->329294757],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionTime", 
     RowBox[{
     "The", " ", "time", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->68898241],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "false", 
     RowBox[{"Extrapolation", " ", "Flag", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TRUE", " ", "allows", " ", "extrapolation"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->172869023],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionTime", "=", "1.0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->138227436],

Cell["BlackAtmVolCurveAtmVol3[obj,OptionTime]", "Input",
 CellTags->"Member",
 CellID->232065160]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackAtmVolCurveAtmVariance", "Subsubsection",
 CellTags->"Member",
 CellID->543419043],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{
     "The", " ", "date", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->11720197],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "false", 
     RowBox[{"Extrapolation", " ", "Flag", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TRUE", " ", "allows", " ", "extrapolation"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->486009641],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionDate", "=", 
   RowBox[{"1", "Y"}]}], ";"}]], "Input",
 CellTags->"Member",
 CellID->147213712],

Cell["BlackAtmVolCurveAtmVariance[obj,OptionDate]", "Input",
 CellTags->"Member",
 CellID->362967163]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackAtmVolCurveAtmVariance2", "Subsubsection",
 CellTags->"Member",
 CellID->23110281],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionTenor", 
     RowBox[{
     "The", " ", "tenor", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->361242328],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "false", 
     RowBox[{"Extrapolation", " ", "Flag", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TRUE", " ", "allows", " ", "extrapolation"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->20073035],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionTenor", "=", "\"\<1Y\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.436092261671875*^9, 3.436092262890625*^9}},
 CellTags->"Member",
 CellID->11537067],

Cell["BlackAtmVolCurveAtmVariance2[obj,OptionTenor]", "Input",
 CellTags->"Member",
 CellID->5079536]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlackAtmVolCurveAtmVariance3", "Subsubsection",
 CellTags->"Member",
 CellID->403410449],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionTime", 
     RowBox[{
     "The", " ", "time", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->42637897],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"AllowExtrapolation", "false", 
     RowBox[{"Extrapolation", " ", "Flag", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TRUE", " ", "allows", " ", "extrapolation"}], ")"}], "."}]}]}
   }]], "DefinitionBox3Col",
  CellTags->"Member"], "\n", Cell["Option Setting", "Caption"]}], "Input",
 CellID->553224142],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionTime", "=", "1.0"}], ";"}]], "Input",
 CellTags->"Member",
 CellID->436752515],

Cell["BlackAtmVolCurveAtmVariance3[obj,OptionTime]", "Input",
 CellTags->"Member",
 CellID->109138136]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveOptionTenors", "Subsubsection",
 CellTags->"Member",
 CellID->46447899],

Cell["AbcdAtmVolCurveOptionTenors[obj]", "Input",
 CellTags->"Member",
 CellID->469665891]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveOptionTenorsInInterpolation", "Subsubsection",
 CellTags->"Member",
 CellID->633140097],

Cell["AbcdAtmVolCurveOptionTenorsInInterpolation[obj]", "Input",
 CellTags->"Member",
 CellID->451147836]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveOptionDates", "Subsubsection",
 CellTags->"Member",
 CellID->49591851],

Cell["AbcdAtmVolCurveOptionDates[obj]", "Input",
 CellTags->"Member",
 CellID->386791742]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveOptionTimes", "Subsubsection",
 CellTags->"Member",
 CellID->516517129],

Cell["AbcdAtmVolCurveOptionTimes[obj]", "Input",
 CellTags->"Member",
 CellID->412746817]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveRmsError", "Subsubsection",
 CellTags->"Member",
 CellID->261437458],

Cell["AbcdAtmVolCurveRmsError[obj]", "Input",
 CellTags->"Member",
 CellID->103383347]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveMaxError", "Subsubsection",
 CellTags->"Member",
 CellID->301918920],

Cell["AbcdAtmVolCurveMaxError[obj]", "Input",
 CellTags->"Member",
 CellID->49924767]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveA", "Subsubsection",
 CellTags->"Member",
 CellID->328683680],

Cell["AbcdAtmVolCurveA[obj]", "Input",
 CellTags->"Member",
 CellID->189124236]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveB", "Subsubsection",
 CellTags->"Member",
 CellID->167883549],

Cell["AbcdAtmVolCurveB[obj]", "Input",
 CellTags->"Member",
 CellID->237520985]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveC", "Subsubsection",
 CellTags->"Member",
 CellID->231499867],

Cell["AbcdAtmVolCurveC[obj]", "Input",
 CellTags->"Member",
 CellID->456003704]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveD", "Subsubsection",
 CellTags->"Member",
 CellID->334247034],

Cell["AbcdAtmVolCurveD[obj]", "Input",
 CellTags->"Member",
 CellID->51932044]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveKatOptionTenors", "Subsubsection",
 CellTags->"Member",
 CellID->730629646],

Cell["AbcdAtmVolCurveKatOptionTenors[obj]", "Input",
 CellTags->"Member",
 CellID->516597181]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbcdAtmVolCurveK", "Subsubsection",
 CellTags->"Member",
 CellID->80977668],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Time", 
     RowBox[{"time", "."}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->383636843],

Cell[BoxData[
 RowBox[{
  RowBox[{"Time", "=", "\"\<1M\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.43609226778125*^9, 3.436092269*^9}},
 CellTags->"Member",
 CellID->417618770],

Cell["AbcdAtmVolCurveK[obj,Time]", "Input",
 CellTags->"Member",
 CellID->733727679]
}, Open  ]],

Cell[CellGroupData[{

Cell["VolatilitySpreads", "Subsubsection",
 CellTags->"Member",
 CellID->749853352],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionDate", 
     RowBox[{
     "The", " ", "date", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->189020272],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionDate", "=", "\"\<1Y\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.436092271*^9, 3.436092272578125*^9}},
 CellTags->"Member",
 CellID->658720262],

Cell["VolatilitySpreads[obj,OptionDate]", "Input",
 CellTags->"Member",
 CellID->6600652]
}, Open  ]],

Cell[CellGroupData[{

Cell["VolatilitySpreads2", "Subsubsection",
 CellTags->"Member",
 CellID->905659970],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"OptionTenor", 
     RowBox[{
     "The", " ", "tenor", " ", "at", " ", "which", " ", "the", " ", 
      "volatility", " ", "is", " ", 
      RowBox[{"evaluated", "."}]}]}
   }]], "DefinitionBox",
  CellTags->"Member"], "\n", Cell["Calling Parameters", "Caption"]}], "Input",
 CellID->108182640],

Cell[BoxData[
 RowBox[{
  RowBox[{"OptionTenor", "=", "\"\<1Y\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.436092273890625*^9, 3.436092274890625*^9}},
 CellTags->"Member",
 CellID->53447522],

Cell["VolatilitySpreads2[obj,OptionTenor]", "Input",
 CellTags->"Member",
 CellID->30399961]
}, Open  ]],

Cell[CellGroupData[{

Cell["AtmCurve", "Subsubsection",
 CellTags->"Member",
 CellID->251570608],

Cell["AtmCurve[obj]", "Input",
 CellTags->"Member",
 CellID->280600352]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedures", "Section",
 CellTags->"Procedure",
 CellID->807075570],

Cell[CellGroupData[{

Cell["SabrVolatility", "Subsubsection",
 CellTags->"Procedure",
 CellID->94214192],

Cell[BoxData[{Cell[BoxData[GridBox[{
    {"Strike", 
     RowBox[{"option", " ", 
      RowBox[{"strike", "."}]}]},
    {"Forward", 
     RowBox[{"underlying", " ", "forward", " ", 
      RowBox[{"value", "."}]}]},
    {"ExpTime", 
     RowBox[{"expiry", " ", "time", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"in", " ", "years"}], ")"}], "."}]}]},
    {"Alpha", 
     RowBox[{"alpha", "."}]},
    {"Beta", 
     RowBox[{"beta", "."}]},
    {"Nu", 
     RowBox[{"nu", "."}]},
    {"Rho", 
     RowBox[{"rho", "."}]}
   }]], "DefinitionBox",
  CellTags->"Procedure"], "\n", Cell["Calling Parameters", 
  "Caption"]}], "Input",
 CellID->551955537],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Strike", "=", "0.06"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"forward", "=", "0.04"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ExpTime", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"alpha", "=", "0.02"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"beta", "=", "0.6"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nu", "=", ".02"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rho", "=", "0.03"}], ";"}]}], "Input",
 CellChangeTimes->{{3.436091547375*^9, 3.436091563421875*^9}},
 CellTags->"Procedure",
 CellLabel->"In[11]:=",
 CellID->119329323],

Cell[CellGroupData[{

Cell["SabrVolatility[Strike,forward,ExpTime,alpha,beta,nu,rho]", "Input",
 CellChangeTimes->{{3.43609156621875*^9, 3.4360915755625*^9}},
 CellTags->"Procedure",
 CellLabel->"In[18]:=",
 CellID->50247985],

Cell[BoxData["0.06704763345010922`"], "Output",
 CellChangeTimes->{{3.4360915828125*^9, 3.43609159290625*^9}, 
   3.4360922811875*^9},
 CellTags->"Procedure",
 CellLabel->"Out[18]=",
 CellID->73982903]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FileChangeProtection->None,
Editable->True,
WindowSize->{839, 750},
WindowMargins->{{Automatic, -971}, {Automatic, 67}},
WindowFrame->"Normal",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
PageHeaders->{{None, None, None}, {None, None, 
   Cell[
    TextData[{
      Cell[
       TextData[{"Printed from [[YOUR APPLICATION'S NAME]] documentation "}], 
       "PageHeader"], 
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"]}], 
    CellMargins -> {{Inherited, -29}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {
   Cell[
    TextData[{"\[Copyright] 2008 Weber & Partner. All rights reserved."}], 
    "PageFooter"], None, None}},
TaggingRules->{
 "SearchTextTranslated" -> "", "SearchText" -> "", "LinkTrails" -> ""},
CreateCellID->True,
ShowCellTags->False,
Magnification->1.,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Overview"->{
  Cell[567, 22, 74, 2, 85, "Chapter",
   CellTags->"Overview",
   CellID->391865964],
  Cell[644, 26, 109, 2, 30, "Text",
   CellTags->"Overview",
   CellID->157905548],
  Cell[756, 30, 113, 2, 31, "MathCaption",
   CellTags->"Overview",
   CellID->31436434],
  Cell[872, 34, 103, 3, 28, "Input",
   CellTags->"Overview",
   CellID->255322246],
  Cell[978, 39, 157, 5, 30, "Text",
   CellTags->"Overview",
   CellID->155489],
  Cell[1160, 48, 131, 3, 28, "Input",
   CellTags->"Overview",
   CellID->212444776],
  Cell[1294, 53, 314, 9, 36, "Output",
   CellTags->"Overview",
   CellID->33328166],
  Cell[1645, 67, 126, 3, 28, "Input",
   CellTags->"Overview",
   CellID->164542977],
  Cell[1774, 72, 699, 15, 88, "Output",
   CellTags->"Overview",
   CellID->62766747],
  Cell[2510, 92, 127, 3, 28, "Input",
   CellTags->"Overview",
   CellID->1034464],
  Cell[2640, 97, 216, 6, 36, "Output",
   CellTags->"Overview",
   CellID->372551976]},
 "Constructo"->{
  Cell[2893, 108, 74, 2, 51, "Section",
   CellTags->"Constructo",
   CellID->6535473]},
 "Constructor"->{
  Cell[2992, 114, 87, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->519488021],
  Cell[4122, 149, 423, 12, 83, "Input",
   CellTags->"Constructor",
   CellID->60511335],
  Cell[4570, 165, 175, 4, 28, "Input",
   CellTags->"Constructor",
   CellID->562172742],
  Cell[4748, 171, 114, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->192709307],
  Cell[4911, 180, 89, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->3069914],
  Cell[6068, 217, 1022, 32, 101, "Input",
   CellTags->"Constructor",
   CellID->401234712],
  Cell[7115, 253, 162, 5, 28, "Input",
   CellTags->"Constructor",
   CellID->178025370],
  Cell[7280, 260, 118, 3, 36, "Output",
   CellTags->"Constructor",
   CellID->70375520],
  Cell[7447, 269, 84, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->9912498],
  Cell[9057, 316, 442, 14, 83, "Input",
   CellTags->"Constructor",
   CellID->439806113],
  Cell[9524, 334, 203, 6, 28, "Input",
   CellTags->"Constructor",
   CellID->150346971],
  Cell[9730, 342, 295, 8, 36, "Output",
   CellTags->"Constructor",
   CellID->495985108],
  Cell[10074, 356, 84, 2, 30, "Subsubsection",
   CellTags->"Constructor",
   CellID->73269802],
  Cell[10816, 380, 492, 14, 101, "Input",
   CellTags->"Constructor",
   CellID->9938806],
  Cell[11311, 396, 174, 5, 28, "Input",
   CellTags->"Constructor",
   CellID->289193226]},
 "Member"->{
  Cell[11534, 407, 75, 2, 51, "Section",
   CellTags->"Member",
   CellID->121652447],
  Cell[11634, 413, 110, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->100429151],
  Cell[11747, 417, 107, 2, 28, "Input",
   CellTags->"Member",
   CellID->716322735],
  Cell[11891, 424, 108, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->397426775],
  Cell[12241, 436, 185, 5, 28, "Input",
   CellTags->"Member",
   CellID->128773035],
  Cell[12429, 443, 111, 2, 28, "Input",
   CellTags->"Member",
   CellID->150921201],
  Cell[12577, 450, 98, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->226264065],
  Cell[12678, 454, 95, 2, 28, "Input",
   CellTags->"Member",
   CellID->215780542],
  Cell[12810, 461, 98, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->686188259],
  Cell[12911, 465, 94, 2, 28, "Input",
   CellTags->"Member",
   CellID->39160675],
  Cell[13042, 472, 87, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->48145862],
  Cell[13897, 497, 268, 8, 28, "Input",
   CellTags->"Member",
   CellID->71082653],
  Cell[14168, 507, 120, 3, 28, "Input",
   CellTags->"Member",
   CellID->523591806],
  Cell[14325, 515, 89, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->348759139],
  Cell[15120, 539, 192, 5, 28, "Input",
   CellTags->"Member",
   CellID->338584321],
  Cell[15315, 546, 98, 2, 28, "Input",
   CellTags->"Member",
   CellID->233169582],
  Cell[15450, 553, 89, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->329294757],
  Cell[16243, 577, 119, 4, 28, "Input",
   CellTags->"Member",
   CellID->138227436],
  Cell[16365, 583, 97, 2, 28, "Input",
   CellTags->"Member",
   CellID->232065160],
  Cell[16499, 590, 93, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->543419043],
  Cell[17296, 614, 136, 5, 28, "Input",
   CellTags->"Member",
   CellID->147213712],
  Cell[17435, 621, 101, 2, 28, "Input",
   CellTags->"Member",
   CellID->362967163],
  Cell[17573, 628, 93, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->23110281],
  Cell[18372, 652, 192, 5, 28, "Input",
   CellTags->"Member",
   CellID->11537067],
  Cell[18567, 659, 101, 2, 28, "Input",
   CellTags->"Member",
   CellID->5079536],
  Cell[18705, 666, 94, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->403410449],
  Cell[19503, 690, 119, 4, 28, "Input",
   CellTags->"Member",
   CellID->436752515],
  Cell[19625, 696, 102, 2, 28, "Input",
   CellTags->"Member",
   CellID->109138136],
  Cell[19764, 703, 92, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->46447899],
  Cell[19859, 707, 90, 2, 28, "Input",
   CellTags->"Member",
   CellID->469665891],
  Cell[19986, 714, 108, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->633140097],
  Cell[20097, 718, 105, 2, 28, "Input",
   CellTags->"Member",
   CellID->451147836],
  Cell[20239, 725, 91, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->49591851],
  Cell[20333, 729, 89, 2, 28, "Input",
   CellTags->"Member",
   CellID->386791742],
  Cell[20459, 736, 92, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->516517129],
  Cell[20554, 740, 89, 2, 28, "Input",
   CellTags->"Member",
   CellID->412746817],
  Cell[20680, 747, 89, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->261437458],
  Cell[20772, 751, 86, 2, 28, "Input",
   CellTags->"Member",
   CellID->103383347],
  Cell[20895, 758, 89, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->301918920],
  Cell[20987, 762, 85, 2, 28, "Input",
   CellTags->"Member",
   CellID->49924767],
  Cell[21109, 769, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->328683680],
  Cell[21194, 773, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->189124236],
  Cell[21310, 780, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->167883549],
  Cell[21395, 784, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->237520985],
  Cell[21511, 791, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->231499867],
  Cell[21596, 795, 79, 2, 28, "Input",
   CellTags->"Member",
   CellID->456003704],
  Cell[21712, 802, 82, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->334247034],
  Cell[21797, 806, 78, 2, 28, "Input",
   CellTags->"Member",
   CellID->51932044],
  Cell[21912, 813, 96, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->730629646],
  Cell[22011, 817, 93, 2, 28, "Input",
   CellTags->"Member",
   CellID->516597181],
  Cell[22141, 824, 81, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->80977668],
  Cell[22430, 835, 179, 5, 28, "Input",
   CellTags->"Member",
   CellID->417618770],
  Cell[22612, 842, 84, 2, 28, "Input",
   CellTags->"Member",
   CellID->733727679],
  Cell[22733, 849, 83, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->749853352],
  Cell[23157, 863, 186, 5, 28, "Input",
   CellTags->"Member",
   CellID->658720262],
  Cell[23346, 870, 89, 2, 28, "Input",
   CellTags->"Member",
   CellID->6600652],
  Cell[23472, 877, 84, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->905659970],
  Cell[23899, 891, 192, 5, 28, "Input",
   CellTags->"Member",
   CellID->53447522],
  Cell[24094, 898, 92, 2, 28, "Input",
   CellTags->"Member",
   CellID->30399961],
  Cell[24223, 905, 74, 2, 30, "Subsubsection",
   CellTags->"Member",
   CellID->251570608],
  Cell[24300, 909, 71, 2, 28, "Input",
   CellTags->"Member",
   CellID->280600352]},
 "Procedure"->{
  Cell[24420, 917, 73, 2, 51, "Section",
   CellTags->"Procedure",
   CellID->807075570],
  Cell[24518, 923, 82, 2, 30, "Subsubsection",
   CellTags->"Procedure",
   CellID->94214192],
  Cell[25267, 952, 551, 18, 137, "Input",
   CellTags->"Procedure",
   CellID->119329323],
  Cell[25843, 974, 203, 4, 28, "Input",
   CellTags->"Procedure",
   CellID->50247985],
  Cell[26049, 980, 201, 5, 36, "Output",
   CellTags->"Procedure",
   CellID->73982903]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Overview", 27451, 1025},
 {"Constructo", 28411, 1059},
 {"Constructor", 28518, 1063},
 {"Member", 29914, 1109},
 {"Procedure", 35322, 1293}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 74, 2, 85, "Chapter",
 CellTags->"Overview",
 CellID->391865964],
Cell[644, 26, 109, 2, 30, "Text",
 CellTags->"Overview",
 CellID->157905548],
Cell[756, 30, 113, 2, 31, "MathCaption",
 CellTags->"Overview",
 CellID->31436434],
Cell[872, 34, 103, 3, 28, "Input",
 CellTags->"Overview",
 CellID->255322246],
Cell[978, 39, 157, 5, 30, "Text",
 CellTags->"Overview",
 CellID->155489],
Cell[CellGroupData[{
Cell[1160, 48, 131, 3, 28, "Input",
 CellTags->"Overview",
 CellID->212444776],
Cell[1294, 53, 314, 9, 36, "Output",
 CellTags->"Overview",
 CellID->33328166]
}, Open  ]],
Cell[CellGroupData[{
Cell[1645, 67, 126, 3, 28, "Input",
 CellTags->"Overview",
 CellID->164542977],
Cell[1774, 72, 699, 15, 88, "Output",
 CellTags->"Overview",
 CellID->62766747]
}, Open  ]],
Cell[CellGroupData[{
Cell[2510, 92, 127, 3, 28, "Input",
 CellTags->"Overview",
 CellID->1034464],
Cell[2640, 97, 216, 6, 36, "Output",
 CellTags->"Overview",
 CellID->372551976]
}, Open  ]],
Cell[CellGroupData[{
Cell[2893, 108, 74, 2, 51, "Section",
 CellTags->"Constructo",
 CellID->6535473],
Cell[CellGroupData[{
Cell[2992, 114, 87, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->519488021],
Cell[3082, 118, 398, 11, 78, "Input",
 Evaluatable->False,
 CellID->411876125],
Cell[3483, 131, 636, 16, 135, "Input",
 Evaluatable->False,
 CellID->218989525],
Cell[4122, 149, 423, 12, 83, "Input",
 CellTags->"Constructor",
 CellID->60511335],
Cell[CellGroupData[{
Cell[4570, 165, 175, 4, 28, "Input",
 CellTags->"Constructor",
 CellID->562172742],
Cell[4748, 171, 114, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->192709307]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4911, 180, 89, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->3069914],
Cell[5003, 184, 467, 14, 111, "Input",
 CellID->197864184],
Cell[5473, 200, 592, 15, 135, "Input",
 Evaluatable->False,
 CellID->241186037],
Cell[6068, 217, 1022, 32, 101, "Input",
 CellTags->"Constructor",
 CellID->401234712],
Cell[CellGroupData[{
Cell[7115, 253, 162, 5, 28, "Input",
 CellTags->"Constructor",
 CellID->178025370],
Cell[7280, 260, 118, 3, 36, "Output",
 CellTags->"Constructor",
 CellID->70375520]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7447, 269, 84, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->9912498],
Cell[7534, 273, 949, 25, 150, "Input",
 CellID->223025719],
Cell[8486, 300, 568, 14, 135, "Input",
 CellID->391335970],
Cell[9057, 316, 442, 14, 83, "Input",
 CellTags->"Constructor",
 CellID->439806113],
Cell[CellGroupData[{
Cell[9524, 334, 203, 6, 28, "Input",
 CellTags->"Constructor",
 CellID->150346971],
Cell[9730, 342, 295, 8, 36, "Output",
 CellTags->"Constructor",
 CellID->495985108]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10074, 356, 84, 2, 30, "Subsubsection",
 CellTags->"Constructor",
 CellID->73269802],
Cell[10161, 360, 652, 18, 128, "Input",
 CellID->130505861],
Cell[10816, 380, 492, 14, 101, "Input",
 CellTags->"Constructor",
 CellID->9938806],
Cell[11311, 396, 174, 5, 28, "Input",
 CellTags->"Constructor",
 CellID->289193226]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11534, 407, 75, 2, 51, "Section",
 CellTags->"Member",
 CellID->121652447],
Cell[CellGroupData[{
Cell[11634, 413, 110, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->100429151],
Cell[11747, 417, 107, 2, 28, "Input",
 CellTags->"Member",
 CellID->716322735]
}, Open  ]],
Cell[CellGroupData[{
Cell[11891, 424, 108, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->397426775],
Cell[12002, 428, 236, 6, 65, "Input",
 CellID->254801627],
Cell[12241, 436, 185, 5, 28, "Input",
 CellTags->"Member",
 CellID->128773035],
Cell[12429, 443, 111, 2, 28, "Input",
 CellTags->"Member",
 CellID->150921201]
}, Open  ]],
Cell[CellGroupData[{
Cell[12577, 450, 98, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->226264065],
Cell[12678, 454, 95, 2, 28, "Input",
 CellTags->"Member",
 CellID->215780542]
}, Open  ]],
Cell[CellGroupData[{
Cell[12810, 461, 98, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->686188259],
Cell[12911, 465, 94, 2, 28, "Input",
 CellTags->"Member",
 CellID->39160675]
}, Open  ]],
Cell[CellGroupData[{
Cell[13042, 472, 87, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->48145862],
Cell[13132, 476, 335, 8, 65, "Input",
 CellID->567210066],
Cell[13470, 486, 424, 9, 101, "Input",
 CellID->53905025],
Cell[13897, 497, 268, 8, 28, "Input",
 CellTags->"Member",
 CellID->71082653],
Cell[14168, 507, 120, 3, 28, "Input",
 CellTags->"Member",
 CellID->523591806]
}, Open  ]],
Cell[CellGroupData[{
Cell[14325, 515, 89, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->348759139],
Cell[14417, 519, 336, 8, 65, "Input",
 CellID->454673259],
Cell[14756, 529, 361, 8, 101, "Input",
 CellID->525436350],
Cell[15120, 539, 192, 5, 28, "Input",
 CellTags->"Member",
 CellID->338584321],
Cell[15315, 546, 98, 2, 28, "Input",
 CellTags->"Member",
 CellID->233169582]
}, Open  ]],
Cell[CellGroupData[{
Cell[15450, 553, 89, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->329294757],
Cell[15542, 557, 334, 8, 65, "Input",
 CellID->68898241],
Cell[15879, 567, 361, 8, 101, "Input",
 CellID->172869023],
Cell[16243, 577, 119, 4, 28, "Input",
 CellTags->"Member",
 CellID->138227436],
Cell[16365, 583, 97, 2, 28, "Input",
 CellTags->"Member",
 CellID->232065160]
}, Open  ]],
Cell[CellGroupData[{
Cell[16499, 590, 93, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->543419043],
Cell[16595, 594, 334, 8, 65, "Input",
 CellID->11720197],
Cell[16932, 604, 361, 8, 101, "Input",
 CellID->486009641],
Cell[17296, 614, 136, 5, 28, "Input",
 CellTags->"Member",
 CellID->147213712],
Cell[17435, 621, 101, 2, 28, "Input",
 CellTags->"Member",
 CellID->362967163]
}, Open  ]],
Cell[CellGroupData[{
Cell[17573, 628, 93, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->23110281],
Cell[17669, 632, 337, 8, 65, "Input",
 CellID->361242328],
Cell[18009, 642, 360, 8, 101, "Input",
 CellID->20073035],
Cell[18372, 652, 192, 5, 28, "Input",
 CellTags->"Member",
 CellID->11537067],
Cell[18567, 659, 101, 2, 28, "Input",
 CellTags->"Member",
 CellID->5079536]
}, Open  ]],
Cell[CellGroupData[{
Cell[18705, 666, 94, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->403410449],
Cell[18802, 670, 334, 8, 65, "Input",
 CellID->42637897],
Cell[19139, 680, 361, 8, 101, "Input",
 CellID->553224142],
Cell[19503, 690, 119, 4, 28, "Input",
 CellTags->"Member",
 CellID->436752515],
Cell[19625, 696, 102, 2, 28, "Input",
 CellTags->"Member",
 CellID->109138136]
}, Open  ]],
Cell[CellGroupData[{
Cell[19764, 703, 92, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->46447899],
Cell[19859, 707, 90, 2, 28, "Input",
 CellTags->"Member",
 CellID->469665891]
}, Open  ]],
Cell[CellGroupData[{
Cell[19986, 714, 108, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->633140097],
Cell[20097, 718, 105, 2, 28, "Input",
 CellTags->"Member",
 CellID->451147836]
}, Open  ]],
Cell[CellGroupData[{
Cell[20239, 725, 91, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->49591851],
Cell[20333, 729, 89, 2, 28, "Input",
 CellTags->"Member",
 CellID->386791742]
}, Open  ]],
Cell[CellGroupData[{
Cell[20459, 736, 92, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->516517129],
Cell[20554, 740, 89, 2, 28, "Input",
 CellTags->"Member",
 CellID->412746817]
}, Open  ]],
Cell[CellGroupData[{
Cell[20680, 747, 89, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->261437458],
Cell[20772, 751, 86, 2, 28, "Input",
 CellTags->"Member",
 CellID->103383347]
}, Open  ]],
Cell[CellGroupData[{
Cell[20895, 758, 89, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->301918920],
Cell[20987, 762, 85, 2, 28, "Input",
 CellTags->"Member",
 CellID->49924767]
}, Open  ]],
Cell[CellGroupData[{
Cell[21109, 769, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->328683680],
Cell[21194, 773, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->189124236]
}, Open  ]],
Cell[CellGroupData[{
Cell[21310, 780, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->167883549],
Cell[21395, 784, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->237520985]
}, Open  ]],
Cell[CellGroupData[{
Cell[21511, 791, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->231499867],
Cell[21596, 795, 79, 2, 28, "Input",
 CellTags->"Member",
 CellID->456003704]
}, Open  ]],
Cell[CellGroupData[{
Cell[21712, 802, 82, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->334247034],
Cell[21797, 806, 78, 2, 28, "Input",
 CellTags->"Member",
 CellID->51932044]
}, Open  ]],
Cell[CellGroupData[{
Cell[21912, 813, 96, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->730629646],
Cell[22011, 817, 93, 2, 28, "Input",
 CellTags->"Member",
 CellID->516597181]
}, Open  ]],
Cell[CellGroupData[{
Cell[22141, 824, 81, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->80977668],
Cell[22225, 828, 202, 5, 65, "Input",
 CellID->383636843],
Cell[22430, 835, 179, 5, 28, "Input",
 CellTags->"Member",
 CellID->417618770],
Cell[22612, 842, 84, 2, 28, "Input",
 CellTags->"Member",
 CellID->733727679]
}, Open  ]],
Cell[CellGroupData[{
Cell[22733, 849, 83, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->749853352],
Cell[22819, 853, 335, 8, 65, "Input",
 CellID->189020272],
Cell[23157, 863, 186, 5, 28, "Input",
 CellTags->"Member",
 CellID->658720262],
Cell[23346, 870, 89, 2, 28, "Input",
 CellTags->"Member",
 CellID->6600652]
}, Open  ]],
Cell[CellGroupData[{
Cell[23472, 877, 84, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->905659970],
Cell[23559, 881, 337, 8, 65, "Input",
 CellID->108182640],
Cell[23899, 891, 192, 5, 28, "Input",
 CellTags->"Member",
 CellID->53447522],
Cell[24094, 898, 92, 2, 28, "Input",
 CellTags->"Member",
 CellID->30399961]
}, Open  ]],
Cell[CellGroupData[{
Cell[24223, 905, 74, 2, 30, "Subsubsection",
 CellTags->"Member",
 CellID->251570608],
Cell[24300, 909, 71, 2, 28, "Input",
 CellTags->"Member",
 CellID->280600352]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24420, 917, 73, 2, 51, "Section",
 CellTags->"Procedure",
 CellID->807075570],
Cell[CellGroupData[{
Cell[24518, 923, 82, 2, 30, "Subsubsection",
 CellTags->"Procedure",
 CellID->94214192],
Cell[24603, 927, 661, 23, 161, "Input",
 CellID->551955537],
Cell[25267, 952, 551, 18, 137, "Input",
 CellTags->"Procedure",
 CellID->119329323],
Cell[CellGroupData[{
Cell[25843, 974, 203, 4, 28, "Input",
 CellTags->"Procedure",
 CellID->50247985],
Cell[26049, 980, 201, 5, 36, "Output",
 CellTags->"Procedure",
 CellID->73982903]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
