(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      4802,        139]
NotebookOptionsPosition[      4212,        114]
NotebookOutlinePosition[      4557,        129]
CellTagsIndexPosition[      4514,        126]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
QuantLib example : Discrete Hedging\
\>", "Title",
 CellChangeTimes->{{3.521369367421875*^9, 3.521369370671875*^9}, {
   3.52186607190625*^9, 3.52186607584375*^9}, 3.52267193628125*^9, {
   3.526032856421875*^9, 3.526032866609375*^9}}],

Cell[TextData[{
 "The QuantLib example \"DiscreteHedging.cpp\" the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " way."
}], "Text",
 CellChangeTimes->{{3.442726551265625*^9, 3.442726565609375*^9}, {
   3.44272673103125*^9, 3.4427267686875*^9}, 3.521364288265625*^9, {
   3.52136938809375*^9, 3.521369395078125*^9}, 3.52267193628125*^9, {
   3.526032871203125*^9, 3.52603287434375*^9}},
 CellID->214388999],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.526032884765625*^9, 3.526032886859375*^9}}],

Cell["\<\
This example computes profit and loss of a discrete interval hedging strategy \
and compares with the results of Derman & Kamal\[CloseCurlyQuote]s (Goldman \
Sachs Equity Derivatives Research) Research Note: \[OpenCurlyDoubleQuote]When \
You Cannot Hedge Continuously: The Corrections to Black-Scholes\
\[CloseCurlyDoubleQuote]  \
http://www.ederman.com/emanuelderman/GSQSpapers/when_you_cannot_hedge.pdf\
\>", "Text",
 CellChangeTimes->{{3.52136985240625*^9, 3.5213699205625*^9}, 
   3.52267193628125*^9, 3.52603290453125*^9, {3.526033360765625*^9, 
   3.5260334188125*^9}}],

Cell["\<\
Suppose an option hedger sells an European option and receives the \
Black-Scholes value as the options premium.
Then he follows a Black-Scholes hedging strategy, rehedging at discrete, \
evenly spaced time intervals as the underlying stock changes. At expiration, \
the hedger delivers the option payoff to the option holder, and unwinds the \
hedge. We are interested in understanding the final profit or loss of this \
strategy.\
\>", "Text",
 CellChangeTimes->{{3.52136985240625*^9, 3.5213699205625*^9}, 
   3.52267193628125*^9, 3.52603290453125*^9, {3.526033360765625*^9, 
   3.526033427640625*^9}}],

Cell["\<\
 If the hedger had followed the exact Black-Scholes replication strategy, \
re-hedging continuously as the underlying stock evolved towards its final \
value at expiration, then, no matter what path the stock took, the final P&L \
would be exactly zero. When the replication strategy deviates from the exact \
Black-Scholes method, the final P&L may deviate from zero. This     deviation \
is called the replication error. When the hedger rebalances at discrete \
rather than continuous intervals, the hedge is imperfect and the replication \
is inexact. The more often hedging occurs, the smaller the replication error.\
\>", "Text",
 CellChangeTimes->{{3.52136985240625*^9, 3.5213699205625*^9}, 
   3.52267193628125*^9, 3.52603290453125*^9, {3.526033360765625*^9, 
   3.526033458203125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"T", "=", 
   RowBox[{"1", "/", "12."}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"K", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", "0.20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", "0.05"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"risk", " ", "free", " ", "rate"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.52603298146875*^9, 3.52603301665625*^9}, {
  3.52603305146875*^9, 3.526033111765625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rDiscount", "=", 
   RowBox[{
    RowBox[{"std", "::", "exp"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r_"}], "*", "maturity_"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.526033066390625*^9, 3.526033066390625*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{716, 867},
WindowMargins->{{18, Automatic}, {Automatic, 23}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 245, 5, 83, "Title"],
Cell[827, 29, 413, 10, 29, "Text",
 CellID->214388999],
Cell[CellGroupData[{
Cell[1265, 43, 97, 1, 71, "Section"],
Cell[1365, 46, 585, 10, 65, "Text"],
Cell[1953, 58, 614, 11, 83, "Text"],
Cell[2570, 71, 803, 12, 101, "Text"],
Cell[3376, 85, 533, 15, 112, "Input"],
Cell[3912, 102, 272, 8, 31, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

